(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    305652,       8283]*)
(*NotebookOutlinePosition[    313613,       8461]*)
(*  CellTagsIndexPosition[    311990,       8426]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["\<\
Generalizations of the Fundamental Theorem of Calculus (Part \
II)\
\>", "Title",
  CellTags->"mmtag:16:divergence_theorem"],

Cell["\<\
Using Divergence theorem to find London attraction potential \
between point particle and a finite cylinder.\
\>", "Subtitle"],

Cell[CellGroupData[{

Cell[BoxData[
    \(The\ \(dipole--\) 
      dipole\ interaction\ force\ goes\ like\ \(1\/r\^6\) . \ \ The\ London\ \
interaction\ that\ gives\ the\ \ force\ between\ two\ bodies\ due\ to\ the\ \
superposition\ of\ all\ pointwise\ dipole\ interactions . \ \
\[IndentingNewLine]\[IndentingNewLine]To\ find\ such\ forces, \ 
    it\ is\ necessary\ to\ integrate\ over\ the\ volumes\ of\ both\ \(bodies\
--\) an\ integral\ over\ six\ dimensions . \ \ There\ are\ a\ few\ \
\(cases--\) such\ as\ two\ spheres, \ 
    a\ sphere\ and\ a\ semi - infinite\ solid, \ 
    etc . \(--\(-where\)\)\ closed\ form\ solutions\ can\ be\ obtained . \ \ \
\ However, \ in\ general, \ 
    it\ is\ necessary\ to\ perform\ a\ numerical\ integration . \ \ If\ the\ \
integral\ over\ both\ volumes\ could\ be\ converted\ to\ integrals\ over\ \
both\ surfaces, 
    then\ the\ numerical\ integration\ is\ considerably\ more\ efficient . \ \
\ Such\ conversions, \ 
    can\ be\ obtained\ though\ application\ of\ the\ divergence\ theorem . \
\[IndentingNewLine]\[IndentingNewLine]\ 
        Here\ is\ an\ example\ for\ the\ interaction\ between\ a\ single\ \
\((point)\)\ and\ a\ finite\ volume\ \((a\ cylinder)\) . \ \ To\ proceed, \ \ \
a\ vector\ \ integrand\ \ must\ be\ found\ for\ which\ the\ divergence\ is\ \
the\ desired\ \ pointwise\ \(\(interaction\)\(.\)\)\)], "Subsection",
  CellTags->{
  "mmtag:16:pointwise_interaction_between_two_volumes", 
    "mmtag:16:numerical_integration__reducing_the_amount_of_brute_force", 
    "mmtag:16:brute_force__reducing_in_numerical_integration"}],

Cell[TextData[{
  "Find ",
  Cell[BoxData[
      \(TraditionalForm\`\(F\& \[Rule] \)\)]],
  " such that div ",
  Cell[BoxData[
      \(TraditionalForm\`\(F\& \[Rule] \)\)]],
  " is ",
  Cell[BoxData[
      \(TraditionalForm\`\(-1\)\/\((\(r\& \[Rule] \) - \(x\& \[Rule] \))\)\^6\
\)]],
  "   where ",
  Cell[BoxData[
      \(TraditionalForm\`\(r\& \[Rule] \)\)]],
  " = (\[Xi],\[Eta],\[Zeta]) is a position in the cylinder and ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\& \[Rule] \)\)]],
  "=(x,y,z) is a general position in space (A fairly general method to do \
this and similar problems can be found in ",
  StyleBox["Argento C; Jagota A; Carter WC",
    FontSize->12],
  StyleBox[" ``",
    FontSize->12,
    FontWeight->"Bold"],
  StyleBox["Surface formulation for molecular interactions of macroscopic \
bodies'' J.Mech. Physics Solids 1997,  pp 1161-1183 .",
    FontSize->12]
}], "Text",
  CellTags->{
  "mmtag:16:divergence_theorem__example_usage_to_convert_volume_integration_\
to_surface_integrals", 
    "mmtag:16:dipole_interaction_between_cylinder_and_pont"}],

Cell["\<\
The following is a ``guess'' at the vector potential; it will be \
verified as the correct one by checking its divergence.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FVecLondon\  = \ \(1\/\(3 \((\((\[Xi] - x)\)\^2\  + \((\[Eta] - y)\)\^2\
\  + \ \((\[Zeta] - z)\)\^2)\)\^3\)\) {\[Xi] - x, \ \[Eta] - y, \ \[Zeta] - 
            z}\)], "Input",
  CellTags->"mmtag:16:London_interaction__vector_potential"],

Cell[BoxData[
    \({\(\(-x\) + \[Xi]\)\/\(3\ \((\((\(-z\) + \[Zeta])\)\^2 + \((\(-y\) + \
\[Eta])\)\^2 + \((\(-x\) + \[Xi])\)\^2)\)\^3\), \(\(-y\) + \[Eta]\)\/\(3\ \((\
\((\(-z\) + \[Zeta])\)\^2 + \((\(-y\) + \[Eta])\)\^2 + \((\(-x\) + \
\[Xi])\)\^2)\)\^3\), \(\(-z\) + \[Zeta]\)\/\(3\ \((\((\(-z\) + \[Zeta])\)\^2 \
+ \((\(-y\) + \[Eta])\)\^2 + \((\(-x\) + \[Xi])\)\^2)\)\^3\)}\)], "Output",
  CellTags->"mmtag:16:London_interaction__vector_potential"]
}, Open  ]],

Cell[BoxData[
    \(<< Calculus`VectorAnalysis`\)], "Input"],

Cell["\<\
The following verifies that the correct vector potential is \
obtained\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FullSimplify[
      Div[FVecLondon, Cartesian[\[Xi], \[Eta], \[Zeta]]]]\)], "Input",
  CellTags->"mmtag:16:Div[]"],

Cell[BoxData[
    \(\(-\(1\/\((\((z - \[Zeta])\)\^2 + \((y - \[Eta])\)\^2 + \((x - \[Xi])\)\
\^2)\)\^3\)\)\)], "Output",
  CellTags->"mmtag:16:Div[]"]
}, Open  ]],

Cell[TextData[{
  "Therefore,  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_\(Cylinder\[IndentingNewLine]
          Volume\)\(1\/\((\(r\& \[Rule] \) - \(x\& \[Rule] \))\)\^6\) \
\[DifferentialD]V\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_\(Cylinder\[IndentingNewLine]
          Surfaces\)\(FVecLondon\&\[RightVector]\) \[Bullet] \[DifferentialD]\
\(A\& \[Rule] \)\)]],
  " =  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_\(Cylinder\[IndentingNewLine]
          Surface\)\(FVecLondon\&\[RightVector]\) \[Bullet] \
\[DifferentialD]\(A\& \[Rule] \)\)]],
  "+ ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_\(Cylinder\[IndentingNewLine]
          Ends\)\(FVecLondon\&\[RightVector]\) \[Bullet] \
\[DifferentialD]\(A\& \[Rule] \)\)]],
  " is the total interaction between a point an a cylinder."
}], "Text"],

Cell[TextData[{
  "Cylindrical coordinates: (\[Xi],\[Eta],\[Zeta]) = (r Cos[t], r Sin[t], \
\[Zeta]):\nOne cylindrical surface  r= R = const. t \[Element] (0, 2\[Pi]), \
\[Zeta] \[Element] (-",
  Cell[BoxData[
      \(TraditionalForm\`L\/2\)]],
  " , ",
  Cell[BoxData[
      \(TraditionalForm\`L\/2\)]],
  ")\nTwo caps r \[Element] (0,R) t \[Element] (0, 2\[Pi]), \[Zeta]=\
\[PlusMinus]",
  Cell[BoxData[
      \(TraditionalForm\`L\/2\)]]
}], "Text",
  CellTags->"mmtag:16:integral__over_cylinder"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Cylinder Surface normals and differential quantities", "Section"],

Cell["\<\
The following is a parametric representation of a cylinder surface \
that is coaxial with the z-axis (the cylinder ends will be included \
later)\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CylSurf\  = \ {R\ Cos[t], \ R\ \ Sin[t], \[Zeta]}\)], "Input"],

Cell[BoxData[
    \({R\ Cos[t], R\ Sin[t], \[Zeta]}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The infinitessimal surface vectors ",
  Cell[BoxData[
      \(TraditionalForm\`\(R\_u\)\&\[RightVector]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(R\_v\)\&\[RightVector]\)]],
  " for the cylinder surface are obtained by differentiation; they will be \
used to find the surface patch d",
  Cell[BoxData[
      \(TraditionalForm\`\(A\& \[Rule] \)\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(CylSurfRt\  = \ D[CylSurf, t]\), "\[IndentingNewLine]", 
    \(CylSurfRz\ \ \  = \ D[CylSurf, \[Zeta]]\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[
    \({\(-R\)\ Sin[t], R\ Cos[t], 0}\)], "Output"],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(CylSurfRz\\)\\\" is similar to existing \
symbol \\\"\\!\\(CylSurfRt\\)\\\". \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
    \({0, 0, 1}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The surface normal given by ",
  Cell[BoxData[
      \(TraditionalForm\`\(R\_u\)\&\[RightVector]\)]],
  " \[Times] ",
  Cell[BoxData[
      \(TraditionalForm\`\(R\_v\)\&\[RightVector]\)]],
  " for the cylinder surface, there for the following (multiplied by \
d\[Theta] dz) is the infinitessimal oriented surface patch d",
  Cell[BoxData[
      \(TraditionalForm\`\(A\& \[Rule] \)\)]],
  "."
}], "Text",
  CellTags->"mmtag:16:surface_normal__example"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NormalVecCylSurf\  = \ Cross[CylSurfRt, CylSurfRz]\)], "Input",
  CellTags->"mmtag:16:Cross[]"],

Cell[BoxData[
    \({R\ Cos[t], R\ Sin[t], 0}\)], "Output",
  CellTags->"mmtag:16:Cross[]"]
}, Open  ]],

Cell["\<\
The integrand to be evaluated over the cylinder surface is the \
vector potential, dotted into \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CylinderIntegrand\[Theta]\[Zeta]\  = \ 
      FullSimplify[\((FVecLondon /. {\[Xi] \[Rule] 
                  R\ Cos[t], \ \[Eta] \[Rule] \ R\ Sin[t]})\) . 
          NormalVecCylSurf]\)], "Input"],

Cell[BoxData[
    \(\(R\ \((R - x\ Cos[t] - y\ Sin[t])\)\)\/\(3\ \((R\^2 + x\^2 + y\^2 + \
\((z - \[Zeta])\)\^2 - 2\ R\ \((x\ Cos[t] + y\ Sin[t])\))\)\^3\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Closed form for integral is un-findable, use a numeric integration--this \
will be written in two forms\n1) A general function of x,y,z of the point \
particle and the cylinder radius and length.\n2) Because of the polar \
symmetry, the integral should  be a function of only r = ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(x\^2\  + \ y\^2\)\)]],
  "\n\nWe can use the same function name twice, but with a different number \
of arguments.  But, first we will try to do at least one of the two \
integrations symbolically.  If we can do this, it will reduce the original \
numerical integration from three dimensions down to 1---which is a nice \
bargain if we can find it."
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
Try and see if we can do one of the two integrals.  First, let's \
try theta:\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Integrate[CylinderIntegrand\[Theta]\[Zeta], t, \ 
      Assumptions -> 
        R\  > \ 0\  && \ \ \[Zeta]\  \[Element] \ Reals\  && \ 
          x\  \[Element] \ Reals && y \[Element] \ Reals && \ 
          z\  \[Element] \ Reals]\)], "Input"],

Cell[BoxData[
    \(1\/3\ R\ Integrate[\(R - x\ Cos[t] - y\ Sin[t]\)\/\((R\^2 + x\^2 + y\^2 \
+ \((z - \[Zeta])\)\^2 - 2\ R\ \((x\ Cos[t] + y\ Sin[t])\))\)\^3, t, 
        Assumptions \[Rule] 
          R > 0 && \[Zeta] \[Element] Reals && x \[Element] Reals && 
            y \[Element] Reals && z \[Element] Reals]\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
The integral over theta gives no symbolic form...Try and see if we \
can do one of the two integrals.  So, let's try \[Zeta]:\
\>", "Subsubsection",\

  CellTags->{
  "mmtag:16:numerical_integration__reducing_the_amount_of_brute_force_even_\
more_with_finesse", 
    "mmtag:16:brute_force__finesse_and_reducing_in_numerical_integration"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(CylinderIntegrand\[Theta]Ind\[Zeta] = 
      Integrate[CylinderIntegrand\[Theta]\[Zeta], \[Zeta]\ , \ 
        Assumptions -> 
          R\  > \ 0\  && \ \ L > 0\  && \ \ x\  \[Element] \ Reals && 
            y \[Element] \ Reals && \ z\  \[Element] \ Reals && \ 
            t \[Element] \ Reals]\)], "Input"],

Cell[BoxData[
    \(1\/3\ R\ \((R - x\ Cos[t] - 
          y\ Sin[t])\)\ \((\(-\(\(3\ ArcTan[\(z - \[Zeta]\)\/\@\(R\^2 + x\^2 \
+ y\^2 - 2\ R\ x\ Cos[t] - 2\ R\ y\ Sin[t]\)]\)\/\(8\ \((R\^2 + x\^2 + y\^2 - \
2\ R\ x\ Cos[t] - 2\ R\ y\ Sin[t])\)\^\(5/2\)\)\)\) - \(3\ \((z - \
\[Zeta])\)\)\/\(8\ \((R\^2 + x\^2 + y\^2 - 2\ R\ x\ Cos[t] - 2\ R\ y\ Sin[t])\
\)\^2\ \((R\^2 + x\^2 + y\^2 + \((z - \[Zeta])\)\^2 - 2\ R\ x\ Cos[t] - 2\ R\ \
y\ Sin[t])\)\) + \(z - \[Zeta]\)\/\(4\ \((R\^2 + x\^2 + y\^2 + \((z - \
\[Zeta])\)\^2 - 2\ R\ x\ Cos[t] - 2\ R\ y\ Sin[t])\)\^2\ \((\(-R\^2\) - x\^2 \
- y\^2 + 2\ R\ x\ Cos[t] + 2\ R\ y\ Sin[t])\)\))\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Here we will use a trickof using Evaluate[] in a function \
definition to save time--a small diversion here will demonstrate why this is \
efficient\
\>", "Text",
  CellTags->{
  "mmtag:16:Evaluate[]__in_function_definitions", 
    "mmtag:16:defining_functions_from_previously_evaluated_functions", 
    "mmtag:16:functions__definiting_from_previously_defined_expressions_\
without_using_replacement_rules"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      f[c_]\  := \ Evaluate[Integrate[Exp[Tan[x]], {x, 0, c}]]]\)], "Input"],

Cell[BoxData[
    \({7.776986999999998`\ Second, Null}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[g[c_]\  := \ Integrate[Exp[Tan[x]], {x, 0, c}]]\)], "Input"],

Cell[BoxData[
    \({0.000032999999998395424`\ Second, Null}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?f\)\)], "Input"],

Cell["Global`f", "Print",
  CellTags->"Info3339740806-1604724"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {GridBox[{
                {\(f[c_] := 
                    c\ If[\(-\(\[Pi]\/2\)\) \[LessEqual] 
                            Re[c] \[LessEqual] \[Pi]\/2 || 
                          Im[c] \[NotEqual] 
                            0, \(\[ImaginaryI]\ \[ExponentialE]\^\(-\
\[ImaginaryI]\)\ \((\(-ExpIntegralEi[\[ImaginaryI]]\) + \[ExponentialE]\^\(2\ \
\[ImaginaryI]\)\ \((ExpIntegralEi[\(-\[ImaginaryI]\)] - ExpIntegralEi[\(-\
\[ImaginaryI]\) + Tan[c]])\) + ExpIntegralEi[\[ImaginaryI] + \
Tan[c]])\)\)\/\(2\ c\), 
                        Integrate[\[ExponentialE]\^Tan[c\ x], {x, 0, 1}, 
                          Assumptions \[Rule] \(! \((\(-\(\[Pi]\/2\)\) \
\[LessEqual] Re[c] \[LessEqual] \[Pi]\/2 || Im[c] \[NotEqual] 0)\)\)]]\)}
                },
              GridBaseline->{Baseline, {1, 1}},
              ColumnWidths->0.999,
              ColumnAlignments->{Left}]}
          },
        GridBaseline->{Baseline, {1, 1}},
        ColumnAlignments->{Left}],
      Definition[ "f"],
      Editable->False]], "Print",
  CellTags->"Info3339740806-1604724"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?g\)\)], "Input"],

Cell["Global`g", "Print",
  CellTags->"Info3339740806-3383149"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {GridBox[{
                {\(g[
                      c_] := \[Integral]\_0\%c\( \[ExponentialE]\^Tan[
                              x]\) \[DifferentialD]x\)}
                },
              GridBaseline->{Baseline, {1, 1}},
              ColumnWidths->0.999,
              ColumnAlignments->{Left}]}
          },
        GridBaseline->{Baseline, {1, 1}},
        ColumnAlignments->{Left}],
      Definition[ "g"],
      Editable->False]], "Print",
  CellTags->"Info3339740806-3383149"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[f[0.5]]\)], "Input"],

Cell[BoxData[
    \({0.0009340000000008786`\ Second, \(\(0.6572099322091018`\)\(\
\[InvisibleSpace]\)\) + 5.551115123125783`*^-17\ \[ImaginaryI]}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[g[0.5]]\)], "Input"],

Cell[BoxData[
    \({0.12612800000000135`\ Second, \(\(0.6572099313456736`\)\(\
\[InvisibleSpace]\)\) + 5.551115123125783`*^-17\ \[ImaginaryI]}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[BoxData[
    \(CylinderIntegrand\[Theta][x_, y_, z_, CylRad_, CylLen_]\  := \ 
      Evaluate[Simplify[\((CylinderIntegrand\[Theta]Ind\[Zeta] /. {\[Zeta] -> 
                    CylLen/2, 
                  R -> CylRad})\) - \((CylinderIntegrand\[Theta]Ind\[Zeta] /. \
{\[Zeta] -> \(-CylLen\)/2, R -> CylRad})\), 
          Assumptions -> 
            CylRad\  > \ 0\  && \ \ CylLen > 0\  && \ \ x\  \[Element] \ 
                Reals && y \[Element] \ Reals && \ 
              z\  \[Element] \ Reals && \ t \[Element] \ Reals]]\)], "Input"],

Cell[BoxData[
    \(CylinderContribution[x_, \ y_, \ z_, \ CylRad_\ , \ CylLen_]\  := \ 
      NIntegrate[
        Evaluate[
          CylinderIntegrand\[Theta][x, y, z, CylRad, CylLen], {t, 0, \ 
            2  \[Pi]}]]\)], "Input",
  CellTags->"mmtag:16:NIntegrate[]"],

Cell[BoxData[
    \(Because\ of\ the\ polar\ symmetry, \ 
    this\ contribution\ should\ only\ be\ a\ function\ of\ the\ distance\ \((\
\@\(x\^2 + y\^2\))\), \ 
    so\ we\ can\ write\ a\ new\ function\ \((with\ the\ same\ name)\)\ with\ \
fewer\ arguments\)], "Text",
  CellTags->"mmtag:16:functions_overloading"],

Cell[BoxData[
    \(CylinderContribution[dist_, \ z_, \ CylRad_\ , \ CylLen_]\  := 
      NIntegrate[
        Evaluate[
          CylinderIntegrand\[Theta][dist, 0, z, CylRad, CylLen], {t, 0, \ 
            2  \[Pi]}]]\)], "Input"],

Cell["\<\
Checking the numerical integration for the first form of the \
function\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CylinderContribution[2, 2, 1/2, 1, 1]\)], "Input"],

Cell[BoxData[
    \(\(-0.011617409378892947`\)\)], "Output"]
}, Open  ]],

Cell["\<\
Checking the numerical integration for the second form of the \
function\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CylinderContribution[2\ Sqrt[2], 1/2, 1, 1]\)], "Input"],

Cell[BoxData[
    \(\(-0.01161740937889297`\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Top Cap Surface normals and differential quantities, parallel \
method to cylinder surface\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TopSurf\  = \ {r\ Cos[t], r\ Sin[t], L\/2}\)], "Input"],

Cell[BoxData[
    \({r\ Cos[t], r\ Sin[t], L\/2}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(TopSurfRt\  = \ D[TopSurf, t]\), "\[IndentingNewLine]", 
    \(TopSurfRr\ \ \  = \ D[TopSurf, r]\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[
    \({\(-r\)\ Sin[t], r\ Cos[t], 0}\)], "Output"],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(TopSurfRr\\)\\\" is similar to existing \
symbol \\\"\\!\\(TopSurfRt\\)\\\". \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
    \({Cos[t], Sin[t], 0}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(The\ oriented\ surface\ patch\ d \( 
          A\& \[Rule] \)\ for\ the\ top\ surface\ is\ the\ following\ \
\((multiplied\ by\ dr\ d\[Theta])\)\)], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NormalVecTopSurf\  = \ 
      FullSimplify[Cross[TopSurfRr, TopSurfRt]]\)], "Input"],

Cell[BoxData[
    \({0, 0, r}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TopIntegrand\[Theta]r\ \  = \ 
      FullSimplify[\((FVecLondon /. {\[Xi] \[Rule] 
                  r\ Cos[t], \ \[Eta] \[Rule] \ r\ Sin[t], \[Zeta] \[Rule] 
                  L/2})\) . NormalVecTopSurf]\)], "Input"],

Cell[BoxData[
    \(\(r\ \((L - 2\ z)\)\)\/\(6\ \((1\/4\ \((L - 2\ z)\)\^2 + \((x - r\ \
Cos[t])\)\^2 + \((y - r\ Sin[t])\)\^2)\)\^3\)\)], "Output"]
}, Open  ]],

Cell["\<\
Because we will need to numerically integrate over r and over t, we \
might try the same trick as above and see if one of these integrals can be \
expressed in closed form.\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
Integrating over \[Theta] doesn't provide a closed form (this next \
step takes a while to evaluate...)\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Integrate[TopIntegrand\[Zeta]r, \ {t, 0, 2  \[Pi]}, 
      Assumptions\  \[Rule] \ 
        r\  \[GreaterEqual] \ 0\  && \ 
          L\  > \ 0\  && \ \ x \[Element] \ Reals\  && \ 
          y\  \[Element] \ Reals\  && \ z\  \[Element] \ Reals]\)], "Input",
  Editable->False],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(TopIntegrand\[Zeta]r\\)\\\" is similar to \
existing symbol \\\"\\!\\(TopIntegrand\[Theta]r\\)\\\". \\!\\(\\*ButtonBox[\\\
\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\\\", \
ButtonFrame->None, ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    \(Integrate[\(r\ \((L - 2\ z)\)\)\/\(6\ \((1\/4\ \((L - 2\ z)\)\^2 + \((x \
- r\ Cos[t])\)\^2 + \((y - r\ Sin[t])\)\^2)\)\^3\), {t, 0, 2\ \[Pi]}, 
      Assumptions \[Rule] {r > 0, L > 0, x \[Element] Reals, 
          y \[Element] Reals, z \[Element] Reals}]\)], "Output",
  Editable->False],

Cell[BoxData[
    \(2\ \[Pi]\ TopIntegrand\[Zeta]r\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Integrating over r does work", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TopIntegrand\[Theta]Indr = \ 
      Integrate[TopIntegrand\[Theta]r, \ r, 
        Assumptions\  \[Rule] \ 
          t\  \[GreaterEqual] \ 0\  && \ 
            L\  > \ 0\  && \ \ \ x \[Element] \ Reals\  && \ 
            y\  \[Element] \ Reals\  && \ z\  \[Element] \ Reals]\)], "Input"],

Cell[BoxData[
    \(1\/6\ \((L - 
          2\ z)\)\ \((\(-\(\(12\ ArcTan[\(2\ \((\(-r\) + x\ Cos[t] + y\ \
Sin[t])\)\)\/\@\(L\^2 + 2\ x\^2 + 2\ y\^2 - 4\ L\ z + 4\ z\^2 - 2\ x\^2\ \
Cos[2\ t] + 2\ y\^2\ Cos[2\ t] - 4\ x\ y\ Sin[2\ t]\)]\ \((x\ Cos[t] + 
                      y\ Sin[t])\)\)\/\((L\^2 + 2\ x\^2 + 2\ y\^2 - 4\ L\ z + \
4\ z\^2 - 2\ x\^2\ Cos[2\ t] + 2\ y\^2\ Cos[2\ t] - 4\ x\ y\ Sin[2\ \
t])\)\^\(5/2\)\)\) + \(12\ \((\(-x\^2\) - y\^2 + 2\ r\ x\ Cos[t] - x\^2\ \
Cos[2\ t] + y\^2\ Cos[2\ t] + 2\ r\ y\ Sin[t] - 2\ x\ y\ Sin[2\ \
t])\)\)\/\(\((L\^2 + 4\ r\^2 + 4\ x\^2 + 4\ y\^2 - 4\ L\ z + 4\ z\^2 - 8\ r\ \
x\ Cos[t] - 8\ r\ y\ Sin[t])\)\ \((L\^2 + 2\ x\^2 + 2\ y\^2 - 4\ L\ z + 4\ \
z\^2 - 2\ x\^2\ Cos[2\ t] + 2\ y\^2\ Cos[2\ t] - 4\ x\ y\ Sin[2\ t])\)\^2\) - \
\(4\ \((\(-L\^2\) - 4\ x\^2 - 4\ y\^2 + 4\ L\ z - 4\ z\^2 + 4\ r\ x\ Cos[t] + \
4\ r\ y\ Sin[t])\)\)\/\(\((L\^2 + 4\ r\^2 + 4\ x\^2 + 4\ y\^2 - 4\ L\ z + 4\ \
z\^2 - 8\ r\ x\ Cos[t] - 8\ r\ y\ Sin[t])\)\^2\ \((\(-L\^2\) - 2\ x\^2 - 2\ y\
\^2 + 4\ L\ z - 4\ z\^2 + 2\ x\^2\ Cos[2\ t] - 2\ y\^2\ Cos[2\ t] + 4\ x\ y\ \
Sin[2\ t])\)\))\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TopIntegrand\[Theta][x_, y_, z_, CylRad_, CylLen_]\  := 
      Evaluate[Simplify[\((TopIntegrand\[Theta]Indr /. {r -> CylRad, 
                  L -> CylLen})\) - \((TopIntegrand\[Theta]Indr /. {r -> 0, 
                  L -> CylLen})\)]]\)], "Input"],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(TopIntegrand\[Theta]\\)\\\" is similar to \
existing symbol \\\"\\!\\(TopIntegrand\[Theta]r\\)\\\". \\!\\(\\*ButtonBox[\\\
\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\\\", \
ButtonFrame->None, ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"]
}, Open  ]],

Cell[BoxData[
    \(TopContribution[xpos_, \ ypos_, \ zpos_, \ CylRad_\ , \ CylLen_]\  := \ 
      NIntegrate[
        Evaluate[
          TopIntegrand\[Theta][xpos, ypos, zpos, \ CylRad, \ CylLen], {t, 0, 
            2\ \[Pi]}]]\)], "Input"],

Cell[BoxData[
    \(TopContribution[dist_, \ zpos_, \ CylRad_\ , \ CylLen_]\  := \ 
      NIntegrate[
        Evaluate[
          TopIntegrand\[Theta][dist, 0, zpos, \ CylRad, \ CylLen], {t, 0, 
            2\ \[Pi]}]]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TopContribution[Sqrt[2], Sqrt[2], 1/3, 1, 2]\)], "Input"],

Cell[BoxData[
    \(0.019746507925389237`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TopContribution[2, 1/3, 1, 2]\)], "Input"],

Cell[BoxData[
    \(0.0197465079253876`\)], "Output"]
}, Open  ]],

Cell["Bottom Cap Surface normals and differential quantities", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BotSurf\  = \ {r\ Cos[t], r\ Sin[t], \(-L\)\/2}\)], "Input"],

Cell[BoxData[
    \({r\ Cos[t], r\ Sin[t], \(-\(L\/2\)\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(BotSurfRt\  = \ D[BotSurf, t]\), "\[IndentingNewLine]", 
    \(BotSurfRr\ \ \  = \ D[BotSurf, r]\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[
    \({\(-r\)\ Sin[t], r\ Cos[t], 0}\)], "Output"],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(BotSurfRr\\)\\\" is similar to existing \
symbol \\\"\\!\\(BotSurfRt\\)\\\". \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
    \({Cos[t], Sin[t], 0}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(The\ oriented\ surface\ patch\ d \( 
          A\& \[Rule] \)\ for\ the\ bottom\ surface\ is\ the\ following\ \
\((multiplied\ by\ dr\ d\[Theta])\)\)], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NormalVecBotSurf\  = \ 
      FullSimplify[Cross[BotSurfRt, BotSurfRr]]\)], "Input"],

Cell[BoxData[
    \({0, 0, \(-r\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BotIntegrand\[Theta]r\  = \ 
      FullSimplify[\((FVecLondon /. {\[Xi] \[Rule] 
                  r\ Cos[t], \ \[Eta] \[Rule] \ 
                  r\ Sin[t], \[Zeta] \[Rule] \(-L\)/2})\) . 
          NormalVecBotSurf]\)], "Input"],

Cell[BoxData[
    \(\(32\ r\ \((L + 2\ z)\)\)\/\(3\ \((4\ \((r\^2 + x\^2 + y\^2)\) + \((L + \
2\ z)\)\^2 - 8\ r\ \((x\ Cos[t] + y\ Sin[t])\))\)\^3\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BotIntegrand\[Theta]Indr = \ 
      Integrate[BotIntegrand\[Theta]r, \ r, 
        Assumptions\  \[Rule] \ 
          t\  \[GreaterEqual] \ 0\  && \ 
            L\  > \ 0\  && \ \ \ x \[Element] \ Reals\  && \ 
            y\  \[Element] \ Reals\  && \ z\  \[Element] \ Reals]\)], "Input"],

Cell[BoxData[
    \(32\/3\ \((L + 
          2\ z)\)\ \((\(-\(\((3\ ArcTan[\(2\ \((\(-r\) + x\ Cos[t] + y\ \
Sin[t])\)\)\/\@\(L\^2 + 2\ x\^2 + 2\ y\^2 + 4\ L\ z + 4\ z\^2 - 2\ x\^2\ \
Cos[2\ t] + 2\ y\^2\ Cos[2\ t] - 4\ x\ y\ Sin[2\ t]\)]\ \((x\ Cos[t] + 
                      y\ Sin[t])\))\)/\((16\ \@\(L\^2 + 2\ x\^2 + 2\ y\^2 + 4\
\ L\ z + 4\ z\^2 - 2\ x\^2\ Cos[2\ t] + 2\ y\^2\ Cos[2\ t] - 4\ x\ y\ Sin[2\ \
t]\)\ \((\(-L\^2\) - 2\ x\^2 - 2\ y\^2 - 4\ L\ z - 4\ z\^2 + 2\ x\^2\ Cos[2\ \
t] - 2\ y\^2\ Cos[2\ t] + 4\ x\ y\ Sin[2\ t])\)\^2)\)\)\) + \(3\ \((\(-x\^2\) \
- y\^2 + 2\ r\ x\ Cos[t] - x\^2\ Cos[2\ t] + y\^2\ Cos[2\ t] + 2\ r\ y\ \
Sin[t] - 2\ x\ y\ Sin[2\ t])\)\)\/\(16\ \((L\^2 + 4\ r\^2 + 4\ x\^2 + 4\ y\^2 \
+ 4\ L\ z + 4\ z\^2 - 8\ r\ x\ Cos[t] - 8\ r\ y\ Sin[t])\)\ \((\(-L\^2\) - 2\ \
x\^2 - 2\ y\^2 - 4\ L\ z - 4\ z\^2 + 2\ x\^2\ Cos[2\ t] - 2\ y\^2\ Cos[2\ t] \
+ 4\ x\ y\ Sin[2\ t])\)\^2\) + \(L\^2 + 4\ x\^2 + 4\ y\^2 + 4\ L\ z + 4\ z\^2 \
- 4\ r\ x\ Cos[t] - 4\ r\ y\ Sin[t]\)\/\(16\ \((L\^2 + 4\ r\^2 + 4\ x\^2 + 4\ \
y\^2 + 4\ L\ z + 4\ z\^2 - 8\ r\ x\ Cos[t] - 8\ r\ y\ Sin[t])\)\^2\ \
\((\(-L\^2\) - 2\ x\^2 - 2\ y\^2 - 4\ L\ z - 4\ z\^2 + 2\ x\^2\ Cos[2\ t] - 2\
\ y\^2\ Cos[2\ t] + 4\ x\ y\ Sin[2\ t])\)\))\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BotIntegrand\[Theta][x_, y_, z_, CylRad_, CylLen_]\  := 
      Evaluate[Simplify[\((BotIntegrand\[Theta]Indr /. {r -> CylRad, 
                  L -> CylLen})\) - \((BotIntegrand\[Theta]Indr /. {r -> 0, 
                  L -> CylLen})\)]]\)], "Input"],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(BotIntegrand\[Theta]\\)\\\" is similar to \
existing symbol \\\"\\!\\(BotIntegrand\[Theta]r\\)\\\". \\!\\(\\*ButtonBox[\\\
\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\\\", \
ButtonFrame->None, ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"]
}, Open  ]],

Cell[BoxData[
    \(BotContribution[xpos_, \ ypos_, \ zpos_, \ CylRad_\ , \ CylLen_]\  := \ 
      NIntegrate[
        Evaluate[
          BotIntegrand\[Theta][xpos, ypos, zpos, \ CylRad, \ CylLen], {t, 0, 
            2\ \[Pi]}]]\)], "Input"],

Cell[BoxData[
    \(BotContribution[dist_, \ zpos_, \ CylRad_\ , \ CylLen_]\  := \ 
      NIntegrate[
        Evaluate[
          BotIntegrand\[Theta][dist, 0, zpos, \ CylRad, \ CylLen], {t, 0, 
            2\ \[Pi]}]]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BotContribution[Sqrt[2], Sqrt[2], 1/3, 1, 2]\)], "Input"],

Cell[BoxData[
    \(0.011074868917683132`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BotContribution[2, 1/3, 1, 2]\)], "Input"],

Cell[BoxData[
    \(0.011074868917684923`\)], "Output"]
}, Open  ]],

Cell["Adding up all the surface integral contributions", "Text"],

Cell[BoxData[
    \(LondonCylinderPotential[dist_, \ zpos_, \ CylRad_\ , \ CylLen_]\ \  := 
      CylinderContribution[dist, zpos, CylRad, CylLen]\  + \ 
        TopContribution[dist, zpos, CylRad, CylLen]\  + \ 
        BotContribution[dist, zpos, CylRad, CylLen]\)], "Input",
  CellTags->
  "mmtag:16:dipole_interaction_between_cylinder_and_pont__function_for"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LondonCylinderPotential[2,  .5, 1, 3]\)], "Input"],

Cell[BoxData[
    \(\(-0.252331039462739`\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LondonCylinderPotential[ .25,  .5, 1, 3]\)], "Input"],

Cell[BoxData[
    \(3.4393174758259777`\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \( (*Plot[
        LondonCylinderPotential[dist, zpos, 1, 2], {dist, 1.1, 3}, {zpos, 0, 
          3}]*) \)], "Input"],

Cell[BoxData[
    \(<< Graphics`Graphics`\)], "Input"],

Cell["\<\
Visualize result as a function of radial distance at different \
altitudes\
\>", "Text",
  CellTags->
  "mmtag:16:dipole_interaction_between_cylinder_and_pont__visualization_of"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LondonPlot\  = 
      Plot[\[IndentingNewLine]{LondonCylinderPotential[dist, 0, 1, 4/3], 
          LondonCylinderPotential[dist, 2/3, 1, 4/3], 
          LondonCylinderPotential[dist, 4/3, 1, 4/3], 
          LondonCylinderPotential[dist, 2, 1, 
            4/3]}, \[IndentingNewLine]{dist, 0.01, 3}, 
        PlotStyle \[Rule] {{Thickness[0.02], 
              RGBColor[1, 0, 0]}, {Thickness[0.015], \ 
              RGBColor[0, 0.5, 0]}, \ {Thickness[0.01], 
              RGBColor[0, 0, 1]}, {Thickness[0.005], 
              RGBColor[1, 0, 1]}}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.291692 0.000736423 [
[.18254 .27919 -14.5 -20 ]
[.18254 .27919 14.5 0 ]
[.34127 .27919 -7 -20 ]
[.34127 .27919 7 0 ]
[.5 .27919 -14.5 -20 ]
[.5 .27919 14.5 0 ]
[.65873 .27919 -7 -20 ]
[.65873 .27919 7 0 ]
[.81746 .27919 -14.5 -20 ]
[.81746 .27919 14.5 0 ]
[.97619 .27919 -7 -20 ]
[.97619 .27919 7 0 ]
[.01131 .14441 -46.9375 -10 ]
[.01131 .14441 0 10 ]
[.01131 .43898 -34 -10 ]
[.01131 .43898 0 10 ]
[.01131 .58626 -34 -10 ]
[.01131 .58626 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .29169 m
.18254 .29794 L
s
gsave
.18254 .27919 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.34127 .29169 m
.34127 .29794 L
s
gsave
.34127 .27919 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .29169 m
.5 .29794 L
s
gsave
.5 .27919 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.65873 .29169 m
.65873 .29794 L
s
gsave
.65873 .27919 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.81746 .29169 m
.81746 .29794 L
s
gsave
.81746 .27919 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2.5) show
1.000 setlinewidth
grestore
.97619 .29169 m
.97619 .29794 L
s
gsave
.97619 .27919 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.125 Mabswid
.05556 .29169 m
.05556 .29544 L
s
.0873 .29169 m
.0873 .29544 L
s
.11905 .29169 m
.11905 .29544 L
s
.15079 .29169 m
.15079 .29544 L
s
.21429 .29169 m
.21429 .29544 L
s
.24603 .29169 m
.24603 .29544 L
s
.27778 .29169 m
.27778 .29544 L
s
.30952 .29169 m
.30952 .29544 L
s
.37302 .29169 m
.37302 .29544 L
s
.40476 .29169 m
.40476 .29544 L
s
.43651 .29169 m
.43651 .29544 L
s
.46825 .29169 m
.46825 .29544 L
s
.53175 .29169 m
.53175 .29544 L
s
.56349 .29169 m
.56349 .29544 L
s
.59524 .29169 m
.59524 .29544 L
s
.62698 .29169 m
.62698 .29544 L
s
.69048 .29169 m
.69048 .29544 L
s
.72222 .29169 m
.72222 .29544 L
s
.75397 .29169 m
.75397 .29544 L
s
.78571 .29169 m
.78571 .29544 L
s
.84921 .29169 m
.84921 .29544 L
s
.88095 .29169 m
.88095 .29544 L
s
.9127 .29169 m
.9127 .29544 L
s
.94444 .29169 m
.94444 .29544 L
s
.01 w
0 .29169 m
1 .29169 L
s
.25 Mabswid
.02381 .14441 m
.03006 .14441 L
s
gsave
.01131 .14441 -107.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(200) show
1.000 setlinewidth
grestore
.02381 .43898 m
.03006 .43898 L
s
gsave
.01131 .43898 -95 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(200) show
1.000 setlinewidth
grestore
.02381 .58626 m
.03006 .58626 L
s
gsave
.01131 .58626 -95 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(400) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .03394 m
.02756 .03394 L
s
.02381 .07076 m
.02756 .07076 L
s
.02381 .10759 m
.02756 .10759 L
s
.02381 .18123 m
.02756 .18123 L
s
.02381 .21805 m
.02756 .21805 L
s
.02381 .25487 m
.02756 .25487 L
s
.02381 .32851 m
.02756 .32851 L
s
.02381 .36533 m
.02756 .36533 L
s
.02381 .40216 m
.02756 .40216 L
s
.02381 .4758 m
.02756 .4758 L
s
.02381 .51262 m
.02756 .51262 L
s
.02381 .54944 m
.02756 .54944 L
s
.01 w
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.02 w
.02698 .29551 m
.02816 .29551 L
.02922 .29551 L
.03162 .29551 L
.03383 .29551 L
.03593 .29552 L
.04063 .29553 L
.04573 .29554 L
.05072 .29555 L
.056 .29557 L
.06549 .29562 L
.07581 .29568 L
.08547 .29576 L
.09608 .29586 L
.10749 .296 L
.11756 .29616 L
.12855 .29637 L
.13905 .29662 L
.14857 .29691 L
.16818 .2977 L
.17894 .29832 L
.18908 .29907 L
.19881 .3 L
.20909 .30129 L
.21787 .30275 L
.2275 .3049 L
.23273 .30639 L
.23768 .30808 L
.24695 .31226 L
.25214 .31538 L
.25693 .31897 L
.2622 .32395 L
.26779 .33086 L
.27267 .3388 L
.27713 .34829 L
.28204 .36217 L
.2872 .38259 L
.29171 .40786 L
.2959 .44104 L
.29831 .46625 L
.3005 .49453 L
.30303 .53559 L
.30542 .58551 L
s
.30542 .58551 m
.30661 .61803 L
s
.34072 .61803 m
.34072 0 L
s
.37522 0 m
.37538 .00502 L
.37762 .05591 L
.38179 .12328 L
.38417 .1506 L
.38639 .17115 L
.38904 .19078 L
.39146 .20523 L
.3964 .22728 L
.39913 .23636 L
.40171 .2435 L
.40627 .25342 L
.4105 .26039 L
.41515 .26626 L
.4201 .27105 L
.42544 .275 L
.43036 .27782 L
.43575 .28025 L
.44145 .28227 L
.45104 .28474 L
.45648 .28579 L
.46156 .28659 L
.47199 .28785 L
.48186 .28871 L
.49072 .28928 L
.50036 .28976 L
.50974 .29012 L
.52008 .29042 L
.53089 .29067 L
.54102 .29085 L
.55083 .29099 L
.56115 .29111 L
.5796 .29126 L
.58913 .29132 L
.59929 .29138 L
.6176 .29145 L
.63889 .29151 L
.65898 .29155 L
.67895 .29159 L
.69734 .29161 L
.71606 .29162 L
.73663 .29164 L
.75603 .29165 L
.77686 .29166 L
.79798 .29166 L
.81802 .29167 L
.85615 .29167 L
.87581 .29168 L
.89674 .29168 L
.9167 .29168 L
Mistroke
.93825 .29168 L
.97619 .29169 L
Mfstroke
0 .5 0 r
.015 w
.02698 .29267 m
.02816 .29267 L
.02922 .29267 L
.03162 .29267 L
.03383 .29267 L
.03593 .29267 L
.04063 .29268 L
.04573 .29268 L
.056 .2927 L
.06549 .29273 L
.07519 .29276 L
.08588 .29281 L
.09716 .29287 L
.10749 .29294 L
.12683 .29312 L
.1375 .29326 L
.14764 .29341 L
.15719 .29359 L
.16738 .29383 L
.1857 .29442 L
.19596 .29489 L
.20704 .29556 L
.21751 .29642 L
.22715 .2975 L
.23685 .29901 L
.24591 .301 L
.25111 .30251 L
.25585 .30421 L
.26132 .30669 L
.2665 .30974 L
.27108 .31319 L
.27613 .31818 L
.2814 .32528 L
.28635 .33459 L
.29096 .34677 L
.29518 .36252 L
.2974 .3733 L
.29982 .38783 L
.30235 .40704 L
.30471 .42992 L
.30732 .46324 L
.30974 .50439 L
.31239 .56658 L
.31372 .60746 L
s
.31372 .60746 m
.31401 .61803 L
s
.34247 .61803 m
.34247 0 L
s
.3684 0 m
.37028 .05544 L
.37272 .10721 L
.37514 .14473 L
.37768 .17411 L
.37985 .19335 L
.38223 .20994 L
.38475 .22373 L
.38749 .23544 L
.3899 .24366 L
.39245 .25073 L
.39729 .26078 L
.40175 .26737 L
.40688 .27285 L
.41169 .27661 L
.41696 .27969 L
.42262 .28214 L
.42785 .28386 L
.43271 .28511 L
.43848 .28628 L
.4437 .28712 L
.4534 .28828 L
.45872 .28876 L
.46373 .28913 L
.47347 .2897 L
.48376 .29014 L
.49254 .29042 L
.50217 .29066 L
.51235 .29085 L
.52163 .29099 L
.53247 .29112 L
.54248 .29121 L
.56152 .29134 L
.57156 .29139 L
.58222 .29143 L
.60164 .2915 L
.61986 .29154 L
.63999 .29157 L
.65844 .2916 L
.67731 .29162 L
.69795 .29163 L
.71751 .29164 L
.7384 .29165 L
.75969 .29166 L
.77978 .29167 L
.81813 .29167 L
.83796 .29168 L
.85894 .29168 L
.89672 .29168 L
.91611 .29168 L
Mistroke
.93694 .29168 L
.97619 .29169 L
Mfstroke
0 0 1 r
.01 w
.02698 .2907 m
.02816 .2907 L
.02922 .2907 L
.03162 .2907 L
.03383 .2907 L
.03593 .2907 L
.04063 .2907 L
.04573 .29071 L
.056 .29071 L
.06549 .29071 L
.07519 .29071 L
.08588 .29072 L
.10749 .29073 L
.12683 .29075 L
.14764 .29077 L
.18873 .29083 L
.2283 .2909 L
.26637 .291 L
.30688 .29111 L
.34588 .29123 L
.38732 .29135 L
.42725 .29145 L
.46568 .29152 L
.48516 .29155 L
.50654 .29157 L
.5459 .29161 L
.56534 .29162 L
.58619 .29163 L
.60593 .29164 L
.62741 .29165 L
.66712 .29166 L
.68683 .29167 L
.70777 .29167 L
.74539 .29168 L
.78546 .29168 L
.82402 .29168 L
.86502 .29168 L
.90452 .29169 L
.9425 .29169 L
.97619 .29169 L
s
1 0 1 r
.005 w
.02698 .29163 m
.02816 .29163 L
.02922 .29163 L
.03162 .29163 L
.03383 .29163 L
.03593 .29163 L
.04063 .29163 L
.04573 .29163 L
.056 .29163 L
.06549 .29163 L
.08588 .29163 L
.10749 .29163 L
.14519 .29163 L
.18535 .29163 L
.22399 .29164 L
.26508 .29164 L
.30465 .29165 L
.34272 .29165 L
.38323 .29166 L
.42223 .29166 L
.46367 .29167 L
.5036 .29167 L
.54203 .29168 L
.58289 .29168 L
.62225 .29168 L
.66009 .29168 L
.70038 .29168 L
.73916 .29169 L
.78039 .29169 L
.8201 .29169 L
.8583 .29169 L
.89895 .29169 L
.93808 .29169 L
.97571 .29169 L
.97619 .29169 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oo
oo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX0
03?ooo]Z1Ol0003ooookJ_oooo]Z2_oonfX003?ooo]Z1Ol0003ooookJ_oooo]Z2_oonfX003?ooo]Z
1Ol0002PoookJP?oo`001ol0O`07oookJPOo07l01Ooo003ooookJTcooo]Z000coookJPGo0000X?oo
nfX3ool000Oo07l01ooonfX7o`1o00Goo`00oooonfY<oookJP00<ooonfX5o`000:3ooo]Z0ooo0007
o`1o00Oooo]Z1ol0O`05ool00?oooo]ZC?oonfX003?ooo]Z1Ol0002PoookJP?oo`001ol0O`07oook
JPOo07l01Ooo003ooookJTcooo]Z000coookJPGo0000X?oonfX3ool000Oo07l01ooonfX7o`1o00Go
o`00oooonfY<oookJP00<ooonfX5o`000:3ooo]Z0ooo0007o`1o00Oooo]Z1ol0O`05ool00?oooo]Z
C?oonfX003?ooo]Z1Ol0002PoookJP?oo`001ol0O`07oookJPOo07l01Ooo003ooookJTcooo]Z000c
oookJPGo0000X?oonfX3ool000Oo07l01ooonfX7o`1o00Goo`00oooonfY<oookJP00<ooonfX5o`00
0:3ooo]Z0ooo0007o`1o00Oooo]Z1ol0O`05ool00?oooo]ZC?oonfX003?ooo]Z1Ol0002PoookJP?o
o`001ol0O`07oookJPOo07l01Ooo003ooookJTcooo]Z000coookJPGo0000X?oonfX3ool000Oo07l0
1ooonfX7o`1o00Goo`00oooonfY<oookJP00<ooonfX5o`000:3ooo]Z0ooo0007o`1o00Oooo]Z1ol0
O`05ool00?oooo]ZC?oonfX003?ooo]Z1Ol0002PoookJP?oo`001ol0O`07oookJPSo07l01?oo003o
oookJTcooo]Z000coookJPGo0000X?oonfX3ool000Oo07l01ooonfX8o`1o00Goo`00oooonfY;oook
JP00<ooonfX5o`000:3ooo]Z0ooo0007o`1o00Oooo]Z2?l0O`05ool00?oooo]ZBooonfX003?ooo]Z
1Ol0002PoookJP?oo`001ol0O`07oookJPSo07l01Ooo003ooookJT_ooo]Z000coookJPGo0000X?oo
nfX3ool000Oo07l01ooonfX8o`1o00Goo`00oooonfY;oookJP00<ooonfX5o`000:3ooo]Z0ooo0007
o`1o00Oooo]Z2?l0O`05ool00?oooo]ZBooonfX003?ooo]Z1Ol0002PoookJP?oo`001ol0O`08oook
JPOo07l01Ooo003ooookJT_ooo]Z000coookJPGo0000X?oonfX3ool000Oo07l02?oonfX7o`1o00Go
o`00oooonfY;oookJP00<ooonfX5o`000:3ooo]Z0ooo0007o`1o00Sooo]Z1ol0O`05ool00?oooo]Z
BooonfX003?ooo]Z1Ol0002PoookJP?oo`001ol0O`08oookJPOo07l01Ooo003ooookJT_ooo]Z000c
oookJPGo0000X?oonfX3ool000Oo07l02?oonfX7o`1o00Goo`00oooonfY;oookJP00<ooonfX5o`00
0:3ooo]Z0ooo0007o`1o00Sooo]Z1ol0O`05ool00?oooo]ZBooonfX003?ooo]Z1Ol0002PoookJP?o
o`001ol0O`08oookJPOo07l01Ooo003ooookJT_ooo]Z000coookJPGo0000X?oonfX3ool000Oo07l0
2?oonfX7o`1o00Goo`00oooonfY;oookJP00<ooonfX5o`000:3ooo]Z0ooo0007o`1o00Sooo]Z1ol0
O`05ool00?oooo]ZBooonfX003?ooo]Z1Ol0002PoookJP?oo`001ol0O`08oookJPOo07l01Ooo003o
oookJT_ooo]Z000coookJPGo0000X?oonfX3ool000Oo07l02?oonfX7o`1o00Goo`00oooonfY;oook
JP00<ooonfX5o`000:3ooo]Z0ooo0007o`1o00Sooo]Z1ol0O`05ool00?oooo]ZBooonfX003?ooo]Z
1Ol0002PoookJP?oo`001ol0O`08oookJPOo07l01Ooo003ooookJT_ooo]Z000coookJPGo0000X?oo
nfX3ool000Oo07l02?oonfX7o`1o00Goo`00oooonfY;oookJP00<ooonfX5o`000:3ooo]Z0ooo0007
o`1o00Sooo]Z1ol0O`05ool00?oooo]ZBooonfX003?ooo]Z1Ol0002PoookJP?oo`001ol0O`08oook
JPOo07l01Ooo003ooookJT_ooo]Z000coookJPGo0000X?oonfX3ool000Oo07l02?oonfX7o`1o00Go
o`00oooonfY;oookJP00<ooonfX5o`000:3ooo]Z0ooo0007o`1o00Sooo]Z1ol0O`05ool00?oooo]Z
BooonfX003?ooo]Z1Ol0002PoookJP?oo`001ol0O`08oookJPOo07l01_oo003ooookJT[ooo]Z000c
oookJPGo0000X?oonfX3ool000Oo07l02?oonfX7o`1o00Koo`00oooonfY:oookJP00<ooonfX5o`00
0:3ooo]Z0ooo0007o`1o00Sooo]Z1ol0O`06ool00?oooo]ZB_oonfX003?ooo]Z1Ol0002PoookJP?o
o`001ol0O`08oookJPOo07l01_oo003ooookJT[ooo]Z000coookJPGo0000X?oonfX3ool000Oo07l0
2?oonfX7o`1o00Koo`00oooonfY:oookJP00<ooonfX5o`000:3ooo]Z0ooo0007o`1o00Sooo]Z2?l0
O`05ool00?oooo]ZB_oonfX003?ooo]Z1Ol0002PoookJP?oo`001ol0O`08oookJPSo07l01Ooo003o
oookJT[ooo]Z000coookJPGo0000X?oonfX3ool000Oo07l02?oonfX8o`1o00Goo`00oooonfY:oook
JP00<ooonfX5o`000:3ooo]Z0ooo0007o`1o00Sooo]Z2?l0O`05ool00?oooo]ZB_oonfX003?ooo]Z
1Ol0002PoookJP?oo`001ol0O`08oookJPSo07l01Ooo003ooookJT[ooo]Z000coookJPGo0000X?oo
nfX3ool000Oo07l02?oonfX8o`1o00Goo`00oooonfY:oookJP00<ooonfX5o`000:3ooo]Z0ooo0007
o`1o00Wooo]Z1ol0O`05ool00?oooo]ZB_oonfX003?ooo]Z1Ol0002PoookJP?oo`001ol0O`09oook
JPOo07l01Ooo003ooookJT[ooo]Z000coookJPGo0000X?oonfX3ool000Oo07l02OoonfX7o`1o00Go
o`00oooonfY:oookJP00<ooonfX5o`000:3ooo]Z0ooo0007o`1o00Wooo]Z1ol0O`05ool00?oooo]Z
B_oonfX003?ooo]Z1Ol0002PoookJP?oo`001ol0O`09oookJPOo07l01Ooo003ooookJT[ooo]Z000c
oookJPGo0000X?oonfX3ool000Oo07l02OoonfX7o`1o00Goo`00oooonfY:oookJP00<ooonfX5o`00
0:3ooo]Z0ooo0007o`1o00Wooo]Z1ol0O`06ool00?oooo]ZBOoonfX003?ooo]Z1Ol0002PoookJP?o
o`001ol0O`09oookJPOo07l01_oo003ooookJTWooo]Z000coookJPGo0000X?oonfX3ool000Oo07l0
2OoonfX7o`1o00Koo`00oooonfY9oookJP00<ooonfX5o`000:3ooo]Z0ooo0007o`1o00Wooo]Z1ol0
O`06ool00?oooo]ZBOoonfX003?ooo]Z1Ol0002PoookJP?oo`001ol0O`09oookJPOo07l01_oo003o
oookJTWooo]Z000coookJPGo0000X?oonfX3ool000Oo07l02OoonfX7o`1o00Koo`00oooonfY9oook
JP00<ooonfX5o`000:3ooo]Z0ooo0007o`1o00Wooo]Z1ol0O`06ool00?oooo]ZBOoonfX003?ooo]Z
1Ol0002PoookJP?oo`001ol0O`09oookJPSo07l01Ooo003ooookJTWooo]Z000coookJPGo0000X?oo
nfX3ool000Oo07l02OoonfX8o`1o00Goo`00oooonfY9oookJP00<ooonfX5o`000:3ooo]Z0ooo0007
o`1o00Wooo]Z2?l0O`05ool00?oooo]ZBOoonfX003?ooo]Z1Ol0002PoookJP?oo`001ol0O`09oook
JPSo07l01Ooo003ooookJTWooo]Z000coookJPGo0000X?oonfX3ool000Oo07l02OoonfX8o`1o00Go
o`00oooonfY9oookJP00<ooonfX5o`000:3ooo]Z0ooo0007o`1o00Wooo]Z2?l0O`05ool00?oooo]Z
BOoonfX003?ooo]Z1Ol0002PoookJP?oo`001ol0O`0:oookJPOo07l01_oo003ooookJTSooo]Z000c
oookJPGo0000X?oonfX3ool000Oo07l02_oonfX7o`1o00Koo`00oooonfY8oookJP00<ooonfX5o`00
0:3ooo]Z0ooo0007o`1o00[ooo]Z1ol0O`06ool00?oooo]ZB?oonfX003?ooo]Z1Ol0002PoookJP?o
o`001ol0O`0:oookJPOo07l01_oo003ooookJTSooo]Z000coookJPGo0000X?oonfX3ool000Oo07l0
2_oonfX8o`1o00Goo`00oooonfY8oookJP00<ooonfX5o`000:3ooo]Z0ooo0007o`1o00[ooo]Z2?l0
O`05ool00?oooo]ZB?oonfX003?ooo]Z1Ol0002PoookJP?oo`001ol0O`0:oookJPSo07l01Ooo003o
oookJTSooo]Z000?oookJPWo001o0ooonfX5o`00O`Gooo]Z1Ol007l9oookJPGo0000X?oonfX3ool0
00Oo07l02_oonfX8o`1o00Koo`00oooonfY7oookJP003ooonfX9o`00O`;ooo]Z1ol007l3oookJPOo
001o2?oonfX5o`000:3ooo]Z0ooo0007o`1o00[ooo]Z2?l0O`06ool00?oooo]ZAooonfX000oooo]Z
1?l007l7oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00
O`Sooo]Z1Ol0002PoookJP?oo`001ol0O`0:oookJPSo07l01_oo003ooookJTOooo]Z0003oookJP[o
001o0ooonfX4o`00O`Gooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00
O`Oooo]Z1Ol0002PoookJP?oo`001ol0O`0;oookJPOo07l01_oo003ooookJTOooo]Z0003oookJP[o
001o1?oonfX5o`00O`?ooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00
O`Oooo]Z1_l0002OoookJP?oo`001ol0O`0;oookJPOo07l01_oo003ooookJTOooo]Z000CoookJPCo
001o0_oonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1ooonfX5o`00
0:3ooo]Z0ooo0007o`1o00_ooo]Z1ol0O`06ool00?oooo]ZAooonfX001Cooo]Z0ol007l2oookJP?o
001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l7oookJPGo0000X?oonfX3ool0
00Oo07l02ooonfX7o`1o00Koo`00oooonfY7oookJP005OoonfX3o`00O`04oookJ_l007oo001oo`00
O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1ooonfX5o`000:3ooo]Z0ooo0007
o`1o00_ooo]Z1ol0O`06ool00?oooo]ZAooonfX000oooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00
Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l7oookJPGo0000X?oo
nfX3ool000Oo07l02ooonfX7o`1o00Koo`00oooonfY7oookJP003ooonfX3o`00O`?ooo]Z0ol007l0
1?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Oooo]Z
1Ol0002PoookJP?oo`001ol0O`0;oookJPSo07l01_oo003ooookJTKooo]Z000?oookJPCo001o0_oo
nfX3o`00O`;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo
001o2?oonfX5o`000:3ooo]Z0ooo0007o`1o00_ooo]Z2?l0O`06ool00?oooo]ZA_oonfX0013ooo]Z
1ol007l3oookJPOo001o0ooonfX7o`00O`Sooo]Z1Ol0002PoookJP?oo`001ol0O`0;oookJPSo07l0
1_oo003ooookJTKooo]Z000AoookJPGo001o1OoonfX5o`00O`Gooo]Z1Ol007l9oookJPGo0000X?oo
nfX3ool000Oo07l02ooonfX8o`1o00Koo`00oooonfY6oookJP00<ooonfX5o`000:3ooo]Z0ooo0007
o`1o00_ooo]Z2?l0O`06ool00?oooo]ZA_oonfX003?ooo]Z1Ol0002PoookJP?oo`001ol0O`0;oook
JPSo07l01_oo003ooookJTKooo]Z000coookJPGo0000X?oonfX3ool000Oo07l03?oonfX7o`1o00Ko
o`00oooonfY6oookJP00<ooonfX5o`000:3ooo]Z0ooo0007o`1o00cooo]Z1ol0O`06ool00?oooo]Z
A_oonfX003?ooo]Z1Ol0002PoookJP?oo`001ol0O`0<oookJPOo07l01_oo003ooookJTKooo]Z000c
oookJPGo0000X?oonfX3ool000Oo07l03?oonfX7o`1o00Koo`00oooonfY6oookJP00<ooonfX5o`00
0:3ooo]Z0ooo0007o`1o00cooo]Z1ol0O`06ool00?oooo]ZA_oonfX003?ooo]Z1Ol0002PoookJP?o
o`001ol0O`0<oookJPOo07l01ooo003ooookJTGooo]Z000coookJPGo0000X?oonfX3ool000Oo07l0
3?oonfX7o`1o00Ooo`00oooonfY5oookJP00<ooonfX5o`000:3ooo]Z0ooo0007o`1o00cooo]Z2?l0
O`06ool00?oooo]ZAOoonfX003?ooo]Z1Ol0002PoookJP?oo`001ol0O`0<oookJPSo07l01_oo003o
oookJTGooo]Z000coookJPGo0000X?oonfX3ool000Oo07l03?oonfX8o`1o00Koo`00oooonfY5oook
JP00<ooonfX5o`000:3ooo]Z0ooo0007o`1o00cooo]Z2?l0O`06ool00?oooo]ZAOoonfX003?ooo]Z
1Ol0002PoookJP?oo`001ol0O`0<oookJPSo07l01_oo003ooookJTGooo]Z000coookJPGo0000X?oo
nfX3ool000Oo07l03?oonfX8o`1o00Koo`00oooonfY5oookJP00<ooonfX5o`000:3ooo]Z0ooo0007
o`1o00gooo]Z1ol0O`06ool00?oooo]ZAOoonfX003?ooo]Z1Ol0002PoookJP?oo`001ol0O`0=oook
JPOo07l01ooo003ooookJTCooo]Z000coookJPGo0000X?oonfX3ool000Oo07l03OoonfX8o`1o00Ko
o`00oooonfY4oookJP00<ooonfX5o`000:3ooo]Z0ooo0007o`1o00gooo]Z2?l0O`06ool00?oooo]Z
A?oonfX003?ooo]Z1Ol0002PoookJP?oo`001ol0O`0=oookJPSo07l01_oo003ooookJTCooo]Z000c
oookJPGo0000X?oonfX3ool000Oo07l03OoonfX8o`1o00Koo`00oooonfY4oookJP00<ooonfX5o`00
0:3ooo]Z0ooo0007o`1o00gooo]Z2Ol0O`05ool00?oooo]ZA?oonfX003?ooo]Z1Ol0002PoookJP?o
o`001ol0O`0=oookJPWo07l01_oo003ooookJT?ooo]Z000coookJPGo0000X?oonfX3ool000Oo07l0
3_oonfX8o`1o00Koo`00oooonfY3oookJP00<ooonfX5o`000:3ooo]Z0ooo0007o`1o00kooo]Z2?l0
O`06ool00?oooo]Z@ooonfX003?ooo]Z1Ol0002PoookJP?oo`001ol0O`0>oookJPSo07l01_oo003o
oookJT?ooo]Z000coookJPGo0000X?oonfX3ool000Oo07l03_oonfX8o`1o00Ooo`00oooonfY2oook
JP00<ooonfX5o`000:3ooo]Z0ooo0007o`1o00oooo]Z2?l0O`06ool00?oooo]Z@_oonfX003?ooo]Z
1Ol0002PoookJP?oo`001ol0O`0?oookJPSo07l01_oo003ooookJT;ooo]Z000coookJPGo0000X?oo
nfX3ool000Oo07l03ooonfX8o`1o00Koo`00oooonfY2oookJP00<ooonfX5o`000:3ooo]Z0ooo0007
o`1o00oooo]Z2?l0O`07ool00?oooo]Z@OoonfX003?ooo]Z1Ol0002PoookJP?oo`001ol0O`0?oook
JPSo07l01ooo003ooookJT7ooo]Z000coookJPGo0000X?oonfX3ool000Oo07l03ooonfX8o`1o00Oo
o`00oooonfY1oookJP00<ooonfX5o`000:3ooo]Z0ooo0007o`1o013ooo]Z1ol0O`08ool00?oooo]Z
@?oonfX003?ooo]Z1Ol0002PoookJP?oo`001ol0O`0@oookJPSo07l01ooo003ooookJT3ooo]Z000c
oookJPGo0000X?oonfX3ool000Oo07l04?oonfX8o`1o00Soo`00oooonfXooookJP00<ooonfX5o`00
0:3ooo]Z0ooo0007o`1o013ooo]Z2?l0O`08ool00?oooo]Z?ooonfX003?ooo]Z1Ol0002PoookJP?o
o`001ol0O`0@oookJPSo07l02?oo003ooookJSoooo]Z000coookJPGo0000X?oonfX3ool000Oo07l0
4?oonfX9o`1o00Soo`00oooonfXnoookJP00<ooonfX5o`000:3ooo]Z0ooo0007o`1o013ooo]Z2Ol0
O`08ool00?oooo]Z?_oonfX003?ooo]Z1Ol0002PoookJP?oo`001ol0O`0AoookJPWo07l01ooo003o
oookJSkooo]Z000coookJPGo0000X?oonfX3ool000Oo07l04OoonfX9o`1o00Soo`00oooonfXmoook
JP00<ooonfX5o`000:3ooo]Z0ooo0007o`1o017ooo]Z2Ol0O`08ool00?oooo]Z?OoonfX003?ooo]Z
1Ol0002PoookJP?oo`001ol0O`0AoookJP[o07l01ooo003ooookJSgooo]Z000coookJPGo0000X?oo
nfX3ool000Oo07l04_oonfX9o`1o00Soo`00oooonfXloookJP00<ooonfX5o`000:3ooo]Z0ooo0007
o`1o01;ooo]Z2Ol0O`08ool00?oooo]Z??oonfX003?ooo]Z1Ol0002PoookJP?oo`001ol0O`0Coook
JPWo07l02?oo003ooookJS_ooo]Z000coookJPGo0000X?oonfX3ool000Oo07l04ooonfX:o`1o00So
o`00oooonfXjoookJP00<ooonfX5o`0004Oooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00OdGooo]Z
0ooo0007o`1o01?ooo]Z2_l0O`09ool002;ooo]Z0ol007l4oookJP?o001o0ooonfX5o`00OdGooo]Z
2Ol007m4oookJPWo001o0_oonfX3o`00O`?ooo]Z1Ol007m8oookJPGo001o3ooonfX003?ooo]Z1Ol0
0016oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007m4oookJP?oo`001ol0O`0DoookJP[o07l02?oo
000RoookJP?o001o1?oonfX3o`00O`;ooo]Z1ol007m4oookJPWo001oA?oonfX9o`00O`;ooo]Z0ol0
07l2oookJPOo001oA_oonfX7o`00O`kooo]Z000coookJPGo0000A_oonfX3o`00O`04oookJ_l007oo
001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00OdCooo]Z
0ooo0007o`1o01Cooo]Z2_l0O`09ool0027ooo]Z0ol007l4oookJP?o001o00?ooo]Zo`00Ool007l0
0_l007l01?oonf[o001oo`00Ool007m4oookJPCo001oBOoonfX4o`00O`Oooo]Z0ol007l00ooonf[o
001oo`00O`02o`00O`04oookJ_l007oo001oo`00OdGooo]Z0ol007l3oookJP?o001o3OoonfX003?o
oo]Z1Ol00015oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o@ooonfX3ool000Oo
07l05?oonfX;o`1o00Woo`008?oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001oA?oonfX4o`00OdWo
oo]Z1?l007l:oookJP?o001o0ooonfX3o`00OdCooo]Z0ol007l3oookJP?o001o3OoonfX003?ooo]Z
1Ol00015oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007m3oookJP?oo`001ol0O`0EoookJP[o07l0
2_oo000OoookJP?o001o3_oonfX3o`00OdGooo]Z1Ol007m8oookJPGo001o3_oonfX3o`00Od[ooo]Z
0ol007l=oookJP00<ooonfX5o`0004Gooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Od?ooo]Z0ooo
0007o`1o01Kooo]Z2_l0O`0:ool001kooo]Z0ol007l>oookJP?o001oAooonfX4o`00OdWooo]Z1?l0
07l=oookJP?o001oB_oonfX3o`00O`gooo]Z000coookJPGo0000AOoonfX3o`00O`?ooo]Z0ol007l7
oookJP;o001o0_oonfX4o`00Od?ooo]Z0ooo0007o`1o01Kooo]Z2ol0O`0;ool001cooo]Z0ol007l9
oookJP;o001o0_oonfX4o`00OdSooo]Z0ol007m:oookJP?o001o2?oonfX2o`00O`;ooo]Z1?l007m8
oookJPCo001o3_oonfX003?ooo]Z1Ol00015oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007m4oook
JP?oo`001ol0O`0GoookJP_o07l02ooo000KoookJP?o001o2OoonfX7o`00Od[ooo]Z0ol007m:oook
JP?o001o1ooonfX7o`00OdWooo]Z0ol007l?oookJP00<ooonfX5o`0004Gooo]Z0ol007l3oookJP?o
001o1ooonfX6o`00OdGooo]Z0ooo0007o`1o01Oooo]Z3?l0O`0<ool001Wooo]Z0ol007l9oookJPKo
001oAOoonfX3o`00O`?ooo]Z0ol007m4oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007m<oookJP;o
001o3_oonfX003?ooo]Z1Ol00015oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007m9oookJP?oo`00
1ol0O`0HoookJPco07l03Ooo000DoookJPKo001o2OoonfX2o`00OdWooo]Z0ol007l3oookJP?o001o
A?oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001oB_oonfX3o`00O`?ooo]Z0ol007l=oookJP00<ooo
nfX5o`0004Kooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001oBOoonfX3ool000Oo07l0
6?oonfX?o`1o00_oo`004ooonfX6o`00O`Wooo]Z0_l007m9oookJPCo001o0_oonfX3o`00OdCooo]Z
1?l007l2oookJP?o001o1ooonfX2o`00Od[ooo]Z0ol007l3oookJP?o001o3OoonfX003?ooo]Z1Ol0
0016oookJPOo001o2OoonfX7o`00Od?ooo]Z0ooo0007o`1o01Wooo]Z4?l0O`0<ool001;ooo]Z1?l0
07l:oookJPOo001oA?oonfX7o`00OdKooo]Z1ol007l9oookJPOo001oAOoonfX7o`00O`kooo]Z000c
oookJPGo0000AooonfX5o`00O`[ooo]Z1ol007m3oookJP?oo`001ol0O`0JoookJQ3o07l03ooo000?
oookJP?o001o2_oonfX7o`00OdGooo]Z1Ol007m8oookJPGo001o2_oonfX7o`00OdKooo]Z1Ol007l?
oookJP00<ooonfX5o`000:3ooo]Z0ooo0007o`1o01_ooo]Z4_l0O`0@ool00?oooo]Z8_oonfX003?o
oo]Z1Ol0002PoookJP?oo`001ol0O`0LoookJQKo07l04_oo003ooookJQ_ooo]Z000coookJPGo0000
X?oonfX3ool000Oo07l07OoonfXLo`1o01Goo`00oooonfXAoookJP00<ooonfX5o`000:3ooo]Z0ooo
0007o`1o01kooo]Z9_l0O`0_ool00>_ooo]Z000coookJPGo0000X?oonfX3ool000Oo07l08OoonfY2
o`1o0>ooo`003?oonfX003?ooo]Z00?o0000o`1o0?l00?l0S_l00?lDoookJP?oo`001ol0O`0Soook
J_oo07l0;ol0O`000ooo003ooo]ZoookJP0:oookJP009_oonfX<o`0000;oo`0000?o07l0o`00ool0
0?l0ool00?olo`00o`03o`1o0?oo003o000000[o00000OoonfX002Kooo]Z3?l00002ool00003o`1o
0?l00?oo003o0?oo003oo?l00?l00ol0O`3oo`00o`00000:o`00007ooo]Z000VoookJPco00000_oo
00000ol0O`3o003oool0o`3oool0oo[oo`3o0_l00?l00ol0O`3oo`00o`00000:o`00007ooo]Z000V
oookJPco00000_oo00000ol0O`3o003oool0o`3oool0oo[oo`3o0_l00?l00ol0O`3oo`00o`00000:
o`00007ooo]Z000VoookJPco00000_oo001mo`1o00oo0000ool00?mco`00o`03o`1o0?oo003o0000
00[o00000OoonfX003;ooo]Z0_oo0021o`1o02?ooo]Z0ooo0007o`1o03_ooo]Z8_oo003do`1o0003
ool00?oonf[ooo]Z00[ooo]Z000boookJS?oo`00DOl0O`0RoookJP?oo`001ol0O`15oookJ_ooo`00
3_oo000<oookJP00<_oonfYJool002go07l07ooonfX3ool000Oo07l0J_oonf[Xool000cooo]Z000b
oookJV_oo`007Ol0O`0NoookJP?oo`001ol0O`3ooookJUoooo]Z000boookJW3oo`006Ol0O`0Moook
JP?oo`001ol0O`3ooookJUoooo]Z000coookJPGo0000>OoonfXfool001Go07l07?oonfX3ool000Oo
07l0oooonfYOoookJP00<ooonfX5o`0004oooo]Z9?oo000Bo`1o01_ooo]Z0ooo0007o`1o0?oooo]Z
GooonfX003?ooo]Z1Ol0001IoookJQkoo`003ol0O`0JoookJP?oo`001ol0O`3ooookJUoooo]Z000c
oookJPGo0000G_oonfXJool000oo07l06OoonfX3ool000Oo07l0oooonfYOoookJP00<ooonfX5o`00
06?ooo]Z6?oo000<o`1o01Wooo]Z0ooo0007o`1o0?oooo]ZGooonfX003?ooo]Z1Ol0001WoookJQGo
o`003?l0O`0HoookJP?oo`001ol0O`3ooookJUoooo]Z000coookJPGo0000J_oonfXCool000co07l0
5ooonfX3ool000Oo07l0oooonfYOoookJP00<ooonfX5o`0006cooo]Z4_oo000<o`1o01Kooo]Z0ooo
0007o`1o0?oooo]ZGooonfX003?ooo]Z1Ol0001_oookJQ3oo`002ol0O`0FoookJP?oo`001ol0O`3o
oookJUoooo]Z000coookJPGo0000LOoonfX?ool000_o07l05OoonfX3ool000Oo07l0oooonfYOoook
JP00<ooonfX5o`0007?ooo]Z3Ooo000<o`1o01Cooo]Z0ooo0007o`1o0?oooo]ZGooonfX003?ooo]Z
1Ol0001doookJPgoo`002ol0O`0DoookJP?oo`001ol0O`3ooookJUoooo]Z000coookJPGo0000MOoo
nfX=ool000_o07l04ooonfX3ool000Oo07l0oooonfYOoookJP00<ooonfX5o`0007Kooo]Z3Ooo000:
o`1o01?ooo]Z0ooo0007o`1o0?oooo]ZGooonfX003?ooo]Z1Ol0001goookJPcoo`002ol0O`0Boook
JP?oo`001ol0O`3ooookJUoooo]Z000coookJPGo0000MooonfX=ool000[o07l04_oonfX3ool000Oo
07l0oooonfYOoookJP00<ooonfX5o`0007Sooo]Z3Ooo0009o`1o01;ooo]Z0ooo0007o`1o0?oooo]Z
GooonfX003?ooo]Z1Ol0001ioookJPcoo`002_l0O`0AoookJP?oo`001ol0O`3ooookJUoooo]Z000c
oookJPGo0000N_oonfX<ool000Wo07l04OoonfX3ool000Oo07l0oooonfYOoookJP00<ooonfX5o`00
07[ooo]Z3?oo0009o`1o017ooo]Z0ooo0007o`1o0?oooo]ZGooonfX003?ooo]Z1Ol0001koookJPco
o`002?l0O`0AoookJP?oo`001ol0O`3ooookJUoooo]Z000coookJPGo0000NooonfX<ool000Wo07l0
4?oonfX3ool000Oo07l0oooonfYOoookJP00<ooonfX5o`0007cooo]Z2ooo0009o`1o013ooo]Z0ooo
0007o`1o0?oooo]ZGooonfX003?ooo]Z1Ol0001loookJPcoo`002?l0O`0@oookJP?oo`001ol0O`3o
oookJUoooo]Z000coookJPGo0000OOoonfX;ool000So07l04?oonfX3ool000Oo07l0oooonfYOoook
JP00<ooonfX5o`0007kooo]Z2_oo0009o`1o00oooo]Z0ooo0007o`1o0?oooo]ZGooonfX003?ooo]Z
1Ol0001noookJP[oo`002Ol0O`0?oookJP?oo`001ol0O`3ooookJUoooo]Z000coookJPGo0000Oooo
nfX:ool000So07l03ooonfX3ool000Oo07l0oooonfYOoookJP00<ooonfX5o`0007oooo]Z2_oo0008
o`1o00oooo]Z0ooo0007o`1o0?oooo]ZGooonfX003?ooo]Z1Ol0001ooookJP[oo`002?l0O`0?oook
JP?oo`001ol0O`3ooookJUoooo]Z000coookJPGo0000P?oonfX9ool000Wo07l03_oonfX3ool000Oo
07l0oooonfYOoookJP00<ooonfX5o`00083ooo]Z2_oo0008o`1o00kooo]Z0ooo0007o`1o0?oooo]Z
GooonfX003?ooo]Z1Ol00020oookJP[oo`002?l0O`0>oookJP?oo`001ol0O`3ooookJUoooo]Z000c
oookJPGo0000POoonfX9ool000So07l03_oonfX3ool000Oo07l0oooonfYOoookJP00<ooonfX5o`00
087ooo]Z2Ooo0008o`1o00kooo]Z0ooo0007o`1o0?oooo]ZGooonfX003?ooo]Z1Ol00021oookJPWo
o`002Ol0O`0=oookJP?oo`001ol0O`3ooookJUoooo]Z000coookJPGo0000POoonfX:ool000So07l0
3OoonfX3ool000Oo07l0oooonfYOoookJP00<ooonfX5o`0008;ooo]Z2Ooo0008o`1o00gooo]Z0ooo
0007o`1o0?oooo]ZGooonfX003?ooo]Z1Ol00022oookJPWoo`002?l0O`0=oookJP?oo`001ol0O`3o
oookJUoooo]Z000coookJPGo0000P_oonfX9ool000Wo07l03?oonfX3ool000Oo07l0oooonfYOoook
JP00<ooonfX5o`0008?ooo]Z2?oo0009o`1o00cooo]Z0ooo0007o`1o0?oooo]ZGooonfX003?ooo]Z
1Ol00023oookJPWoo`002?l0O`0<oookJP?oo`001ol0O`3ooookJUoooo]Z000coookJPGo0000Pooo
nfX9ool000So07l03?oonfX3ool000Oo07l0oooonfYOoookJP00<ooonfX5o`0008?ooo]Z2Ooo0008
o`1o00cooo]Z0ooo0007o`1o0?oooo]ZGooonfX003?ooo]Z1Ol00024oookJPSoo`002?l0O`0<oook
JP?oo`001ol0O`3ooookJUoooo]Z000coookJPGo0000Q?oonfX9ool000Oo07l03?oonfX3ool000Oo
07l0oooonfYOoookJP00<ooonfX5o`0008Cooo]Z2Ooo0008o`1o00_ooo]Z0ooo0007o`1o0?oooo]Z
GooonfX003?ooo]Z1Ol00024oookJPWoo`002?l0O`0;oookJP?oo`001ol0O`3ooookJUoooo]Z000c
oookJPGo0000Q?oonfX9ool000So07l02ooonfX3ool000Oo07l0oooonfYOoookJP00<ooonfX5o`00
08Gooo]Z2?oo0008o`1o00_ooo]Z0ooo0007o`1o0?oooo]ZGooonfX003?ooo]Z1Ol00025oookJPSo
o`002?l0O`0;oookJP?oo`001ol0O`3ooookJUoooo]Z000coookJPGo0000QOoonfX8ool000So07l0
2ooonfX3ool000Oo07l0oooonfYOoookJP00<ooonfX5o`0008Gooo]Z2Ooo0007o`1o00_ooo]Z0ooo
0007o`1o0?oooo]ZGooonfX003?ooo]Z1Ol00025oookJPWoo`001ol0O`0;oookJP?oo`001ol0O`3o
oookJUoooo]Z000coookJPGo0000QOoonfX9ool000Oo07l02ooonfX3ool000Oo07l0oooonfYOoook
JP00<ooonfX5o`0008Gooo]Z2Ooo0007o`1o00_ooo]Z0ooo0007o`1o0?oooo]ZGooonfX003?ooo]Z
1Ol00026oookJPSoo`001ol0O`0;oookJP?oo`001ol0O`3ooookJUoooo]Z000coookJPGo0000Q_oo
nfX8ool000So07l02_oonfX3ool000Oo07l0oooonfYOoookJP00<ooonfX5o`0008Kooo]Z2?oo0008
o`1o00[ooo]Z0ooo0007o`1o0?oooo]ZGooonfX003?ooo]Z1Ol00026oookJPSoo`002?l0O`0:oook
JP?oo`001ol0O`3ooookJUoooo]Z000coookJPGo0000Q_oonfX8ool000So07l02_oonfX3ool000Oo
07l0oooonfYOoookJP00<ooonfX5o`0008Kooo]Z2?oo0008o`1o00[ooo]Z0ooo0007o`1o0?oooo]Z
GooonfX003?ooo]Z1Ol00026oookJPSoo`002?l0O`0:oookJP?oo`001ol0O`3ooookJUoooo]Z000c
oookJPGo0000QooonfX8ool000Oo07l02_oonfX3ool000Oo07l0oooonfYOoookJP00<ooonfX5o`00
08Oooo]Z2?oo0007o`1o00[ooo]Z0ooo0007o`1o0?oooo]ZGooonfX003?ooo]Z1Ol00027oookJPSo
o`001ol0O`0:oookJP?oo`001ol0O`3ooookJUoooo]Z000?oookJPWo001o0ooonfX5o`00O`Gooo]Z
1Ol007l9oookJPGo0000QooonfX8ool000Oo07l02_oonfX3ool000Oo07l0oooonfYOoookJP003ooo
nfX9o`00O`;ooo]Z1ol007l3oookJPOo001o2?oonfX5o`0008Oooo]Z2?oo0008o`1o00Wooo]Z0ooo
0007o`1o0?oooo]ZGooonfX000oooo]Z1?l007l7oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol00028oookJPOoo`002?l0O`09oookJP?oo`00
1ol0O`3ooookJUoooo]Z000@oookJPCo001o1OoonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00
Ool007l3oookJP?o001o1ooonfX5o`0008Sooo]Z1ooo0008o`1o00Wooo]Z0ooo0007o`1o0?oooo]Z
GooonfX0017ooo]Z1Ol007l3oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z
0ol007l7oookJPKo0000QooonfX7ool000So07l02OoonfX3ool000Oo07l0oooonfYOoookJP004ooo
nfX4o`00O`;ooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Oooo]Z
1Ol00028oookJPOoo`002?l0O`09oookJP?oo`001ol0O`3ooookJUoooo]Z000DoookJP?o001o0_oo
nfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1ooonfX5o`0008Sooo]Z
1ooo0008o`1o00Wooo]Z0ooo0007o`1o0?oooo]ZGooonfX001Gooo]Z0ol007l01?oonf[o001oo`00
Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Oooo]Z1Ol00028oookJPSo
o`001ol0O`09oookJP?oo`001ol0O`3ooookJUoooo]Z000?oookJP?o001o0ooonfX3o`00O`04oook
J_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1ooonfX5o`00
08Wooo]Z1ooo0007o`1o00Wooo]Z0ooo0007o`1o0?oooo]ZGooonfX000oooo]Z0ol007l3oookJP?o
001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l7
oookJPGo0000ROoonfX7ool000Oo07l02OoonfX3ool000Oo07l0oooonfYOoookJP003ooonfX4o`00
O`;ooo]Z0ol007l2oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo
001oo`00O`Sooo]Z1Ol00029oookJPOoo`002?l0O`08oookJP?oo`001ol0O`3ooookJUoooo]Z000@
oookJPOo001o0ooonfX7o`00O`?ooo]Z1ol007l8oookJPGo0000ROoonfX7ool000So07l02?oonfX3
ool000Oo07l0oooonfYOoookJP004OoonfX5o`00O`Gooo]Z1Ol007l5oookJPGo001o2OoonfX5o`00
08Wooo]Z1ooo0008o`1o00Sooo]Z0ooo0007o`1o0?oooo]ZGooonfX003?ooo]Z1Ol00029oookJPOo
o`002?l0O`08oookJP?oo`001ol0O`3ooookJUoooo]Z000coookJPGo0000ROoonfX7ool000So07l0
2?oonfX3ool000Oo07l0oooonfYOoookJP00<ooonfX5o`0008Wooo]Z1ooo0008o`1o00Sooo]Z0ooo
0007o`1o0?oooo]ZGooonfX003?ooo]Z1Ol00029oookJPSoo`001ol0O`08oookJP?oo`001ol0O`3o
oookJUoooo]Z000coookJPGo0000ROoonfX8ool000Oo07l02?oonfX3ool000Oo07l0oooonfYOoook
JP00<ooonfX5o`0008[ooo]Z1ooo0007o`1o00Sooo]Z0ooo0007o`1o0?oooo]ZGooonfX003?ooo]Z
1Ol0002:oookJPOoo`001ol0O`08oookJP?oo`001ol0O`3ooookJUoooo]Z000coookJPGo0000R_oo
nfX7ool000Oo07l02?oonfX3ool000Oo07l0oooonfYOoookJP00<ooonfX5o`0008[ooo]Z1ooo0007
o`1o00Sooo]Z0ooo0007o`1o0?oooo]ZGooonfX003?ooo]Z1Ol0002:oookJPOoo`001ol0O`08oook
JP?oo`001ol0O`3ooookJUoooo]Z000coookJPGo0000R_oonfX7ool000Oo07l02?oonfX3ool000Oo
07l0oooonfYOoookJP00<ooonfX5o`0008[ooo]Z1ooo0007o`1o00Sooo]Z0ooo0007o`1o0?oooo]Z
GooonfX003?ooo]Z1Ol0002:oookJPOoo`001ol0O`08oookJP?oo`001ol0O`3ooookJUoooo]Z000c
oookJPGo0000R_oonfX7ool000So07l01ooonfX3ool000Oo07l0oooonfYOoookJP00<ooonfX5o`00
08[ooo]Z1ooo0008o`1o00Oooo]Z0ooo0007o`1o0?oooo]ZGooonfX003?ooo]Z1Ol0002:oookJPOo
o`002?l0O`07oookJP?oo`001ol0O`3ooookJUoooo]Z000coookJPGo0000R_oonfX7ool000So07l0
1ooonfX3ool000Oo07l0oooonfYOoookJP00<ooonfX5o`0008[ooo]Z1ooo0008o`1o00Oooo]Z0ooo
0007o`1o0?oooo]ZGooonfX003?ooo]Z1Ol0002:oookJPOoo`002?l0O`07oookJP?oo`001ol0O`3o
oookJUoooo]Z000coookJPGo0000RooonfX7ool000Oo07l01ooonfX3ool000Oo07l0oooonfYOoook
JP00<ooonfX5o`0008_ooo]Z1ooo0007o`1o00Oooo]Z0ooo0007o`1o0?oooo]ZGooonfX003?ooo]Z
1Ol0002;oookJPOoo`001ol0O`07oookJP?oo`001ol0O`3ooookJUoooo]Z000coookJPGo0000Rooo
nfX7ool000Oo07l01ooonfX3ool000Oo07l0oooonfYOoookJP00<ooonfX5o`0008_ooo]Z1ooo0007
o`1o00Oooo]Z0ooo0007o`1o0?oooo]ZGooonfX003?ooo]Z1Ol0002;oookJPOoo`001ol0O`07oook
JP?oo`001ol0O`3ooookJUoooo]Z000coookJPGo0000RooonfX7ool000Oo07l01ooonfX3ool000Oo
07l0oooonfYOoookJP00<ooonfX5o`0008_ooo]Z1ooo0007o`1o00Oooo]Z0ooo0007o`1o0?oooo]Z
GooonfX003?ooo]Z1Ol0002;oookJPOoo`001ol0O`07oookJP?oo`001ol0O`3ooookJUoooo]Z000c
oookJPGo0000RooonfX7ool000Oo07l01ooonfX3ool000Oo07l0oooonfYOoookJP00<ooonfX5o`00
08_ooo]Z1ooo0007o`1o00Oooo]Z0ooo0007o`1o0?oooo]ZGooonfX003?ooo]Z1Ol0002;oookJPOo
o`001ol0O`07oookJP?oo`001ol0O`3ooookJUoooo]Z000coookJPGo0000RooonfX7ool000Oo07l0
1ooonfX3ool000Oo07l0oooonfYOoookJP00<ooonfX5o`0008_ooo]Z1ooo0007o`1o00Oooo]Z0ooo
0007o`1o0?oooo]ZGooonfX003?ooo]Z1Ol0002;oookJPOoo`001ol0O`07oookJP?oo`001ol0O`3o
oookJUoooo]Z000coookJPGo0000RooonfX7ool000Oo07l01ooonfX3ool000Oo07l0oooonfYOoook
JP00<ooonfX5o`0008_ooo]Z1ooo0007o`1o00Oooo]Z0ooo0007o`1o0?oooo]ZGooonfX003?ooo]Z
1Ol0002;oookJPOoo`001ol0O`07oookJP?oo`001ol0O`3ooookJUoooo]Z000coookJPGo0000S?oo
nfX6ool000Oo07l01ooonfX3ool000Oo07l0oooonfYOoookJP00<ooonfX5o`0008cooo]Z1_oo0007
o`1o00Oooo]Z0ooo0007o`1o0?oooo]ZGooonfX003?ooo]Z1Ol0002<oookJPKoo`001ol0O`07oook
JP?oo`001ol0O`3ooookJUoooo]Z000coookJPGo0000S?oonfX6ool000So07l01_oonfX3ool000Oo
07l0oooonfYOoookJP00<ooonfX5o`0008cooo]Z1_oo0008o`1o00Kooo]Z0ooo0007o`1o0?oooo]Z
GooonfX003?ooo]Z1Ol0002<oookJPKoo`002?l0O`06oookJP?oo`001ol0O`3ooookJUoooo]Z000c
oookJPGo0000S?oonfX6ool000So07l01_oonfX3ool000Oo07l0oooonfYOoookJP00<ooonfX5o`00
08cooo]Z1_oo0008o`1o00Kooo]Z0ooo0007o`1o0?oooo]ZGooonfX003?ooo]Z1Ol0002<oookJPKo
o`002?l0O`06oookJP?oo`001ol0O`3ooookJUoooo]Z000coookJPGo0000S?oonfX7ool000Oo07l0
1_oonfX3ool000Oo07l0oooonfYOoookJP00<ooonfX5o`0008cooo]Z1ooo0007o`1o00Kooo]Z0ooo
0007o`1o0?oooo]ZGooonfX003?ooo]Z1Ol0002<oookJPOoo`001ol0O`06oookJP?oo`001ol0O`3o
oookJUoooo]Z000coookJPGo0000S?oonfX7ool000Oo07l01_oonfX3ool000Oo07l0oooonfYOoook
JP00<ooonfX5o`0008cooo]Z1ooo0007o`1o00Kooo]Z0ooo0007o`1o0?oooo]ZGooonfX003?ooo]Z
1Ol0002<oookJPOoo`001ol0O`06oookJP?oo`001ol0O`3ooookJUoooo]Z000coookJPGo0000S?oo
nfX7ool000Oo07l01_oonfX3ool000Oo07l0oooonfYOoookJP00<ooonfX5o`0008cooo]Z1ooo0007
o`1o00Kooo]Z0ooo0007o`1o0?oooo]ZGooonfX003?ooo]Z1Ol0002<oookJPOoo`001ol0O`06oook
JP?oo`001ol0O`3ooookJUoooo]Z000coookJPGo0000SOoonfX6ool000Oo07l01_oonfX3ool000Oo
07l0oooonfYOoookJP00<ooonfX5o`0008gooo]Z1_oo0007o`1o00Kooo]Z0ooo0007o`1o0?oooo]Z
GooonfX003?ooo]Z1Ol0002=oookJPKoo`001ol0O`06oookJP?oo`001ol0O`3ooookJUoooo]Z000c
oookJPGo0000SOoonfX6ool000Oo07l01_oonfX3ool000Oo07l0oooonfYOoookJP00<ooonfX5o`00
08gooo]Z1_oo0007o`1o00Kooo]Z0ooo0007o`1o0?oooo]ZGooonfX003?ooo]Z1Ol0002=oookJPKo
o`001ol0O`06oookJP?oo`001ol0O`3ooookJUoooo]Z000coookJPGo0000SOoonfX6ool000Oo07l0
1_oonfX3ool000Oo07l0oooonfYOoookJP00<ooonfX5o`0008gooo]Z1_oo0007o`1o00Kooo]Z0ooo
0007o`1o0?oooo]ZGooonfX003?ooo]Z1Ol0002=oookJPKoo`001ol0O`06oookJP?oo`001ol0O`3o
oookJUoooo]Z000coookJPGo0000SOoonfX6ool000Oo07l01_oonfX3ool000Oo07l0oooonfYOoook
JP005?oonfX3o`00O`Cooo]Z1Ol007l5oookJPGo001o2OoonfX5o`0008gooo]Z1_oo0007o`1o00Ko
oo]Z0ooo0007o`1o0?oooo]ZGooonfX001Cooo]Z0ol007l3oookJPOo001o0ooonfX7o`00O`Sooo]Z
1Ol0002=oookJPKoo`001ol0O`06oookJP?oo`001ol0O`3ooookJUoooo]Z000DoookJP?o001o0ooo
nfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo
0000SOoonfX6ool000Oo07l01_oonfX3ool000Oo07l0oooonfYOoookJP003ooonfX9o`00O`04oook
J_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1ooonfX5o`00
08kooo]Z1Ooo0008o`1o00Gooo]Z0ooo0007o`1o0?oooo]ZGooonfX000oooo]Z2Ol007l01?oonf[o
001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Oooo]Z1_l0002=
oookJPGoo`002?l0O`05oookJP?oo`001ol0O`3ooookJUoooo]Z000?oookJP;o001o0ooonfX3o`00
O`;ooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Oooo]Z1Ol0002>
oookJPGoo`002?l0O`05oookJP?oo`001ol0O`3ooookJUoooo]Z000@oookJP;o001o0_oonfX3o`00
O`;ooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Oooo]Z1Ol0002>
oookJPGoo`002?l0O`05oookJP?oo`001ol0O`3ooookJUoooo]Z000@oookJP?o001o00Cooo]Zo`00
Ool007oo001o0_oonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1ooo
nfX5o`0008kooo]Z1Ooo0008o`1o00Gooo]Z0ooo0007o`1o0?oooo]ZGooonfX0017ooo]Z0_l007l0
1?oonf[o001oo`00Ool007l2oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z
0ol007l7oookJPGo0000S_oonfX5ool000So07l01OoonfX3ool000Oo07l0oooonfYOoookJP004_oo
nfX5o`00O`;ooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Oooo]Z
1Ol0002>oookJPKoo`001ol0O`05oookJP?oo`001ol0O`3ooookJUoooo]Z000BoookJPGo001o0ooo
nfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo
0000S_oonfX6ool000Oo07l01OoonfX3ool000Oo07l0oooonfYOoookJP004ooonfX4o`00O`?ooo]Z
1ol007l3oookJPOo001o2?oonfX5o`0008kooo]Z1_oo0007o`1o00Gooo]Z0ooo0007o`1o0?oooo]Z
GooonfX001Cooo]Z0ol007l4oookJPGo001o1OoonfX5o`00O`Wooo]Z1Ol0002>oookJPKoo`001ol0
O`05oookJP?oo`001ol0O`3ooookJUoooo]Z000coookJPGo0000S_oonfX6ool000Oo07l01OoonfX3
ool000Oo07l0oooonfYOoookJP00<ooonfX5o`0008kooo]Z1_oo0007o`1o00Gooo]Z0ooo0007o`1o
0?oooo]ZGooonfX003?ooo]Z1Ol0002>oookJPKoo`001ol0O`05oookJP?oo`001ol0O`3ooookJUoo
oo]Z000coookJPGo0000S_oonfX6ool000Oo07l01OoonfX3ool000Oo07l0oooonfYOoookJP00<ooo
nfX5o`0008kooo]Z1_oo0007o`1o00Gooo]Z0ooo0007o`1o0?oooo]ZGooonfX003?ooo]Z1Ol0002>
oookJPKoo`001ol0O`05oookJP?oo`001ol0O`3ooookJUoooo]Z000coookJPGo0000S_oonfX6ool0
00Oo07l01OoonfX3ool000Oo07l0oooonfYOoookJP00<ooonfX5o`0008kooo]Z1_oo0007o`1o00Go
oo]Z0ooo0007o`1o0?oooo]ZGooonfX003?ooo]Z1Ol0002>oookJPKoo`001ol0O`05oookJP?oo`00
1ol0O`3ooookJUoooo]Z000coookJPGo0000oooonf[ooookJP[ooo]Z000coookJPGo0000oooonf[o
oookJP[ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oo
oo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX0
0?oooo]ZoooonfY2oookJP00\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-0.317617, -429.963, \
0.00592763, 2.5553}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The plot above shows the London potential vs. radial distance for four \
different z values, z = 0, z = 2/3, z = 4/3, and z= 2. The cylinder height is \
4/3 and its radius is 1; for values of ",
  StyleBox["z",
    FontSlant->"Italic"],
  " that intersect the cylinder, the potential diverges as ",
  StyleBox["dist",
    FontSlant->"Italic"],
  " -> 1."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[LondonPlot, PlotRange \[Rule] {\(-5\), 3}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.386271 0.0772542 [
[.18254 .37377 -14.5 -20 ]
[.18254 .37377 14.5 0 ]
[.34127 .37377 -7 -20 ]
[.34127 .37377 7 0 ]
[.5 .37377 -14.5 -20 ]
[.5 .37377 14.5 0 ]
[.65873 .37377 -7 -20 ]
[.65873 .37377 7 0 ]
[.81746 .37377 -14.5 -20 ]
[.81746 .37377 14.5 0 ]
[.97619 .37377 -7 -20 ]
[.97619 .37377 7 0 ]
[.01131 0 -26.9375 -10 ]
[.01131 0 0 10 ]
[.01131 .07725 -26.9375 -10 ]
[.01131 .07725 0 10 ]
[.01131 .15451 -26.9375 -10 ]
[.01131 .15451 0 10 ]
[.01131 .23176 -26.9375 -10 ]
[.01131 .23176 0 10 ]
[.01131 .30902 -26.9375 -10 ]
[.01131 .30902 0 10 ]
[.01131 .46353 -14 -10 ]
[.01131 .46353 0 10 ]
[.01131 .54078 -14 -10 ]
[.01131 .54078 0 10 ]
[.01131 .61803 -14 -10 ]
[.01131 .61803 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .38627 m
.18254 .39252 L
s
gsave
.18254 .37377 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.34127 .38627 m
.34127 .39252 L
s
gsave
.34127 .37377 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .38627 m
.5 .39252 L
s
gsave
.5 .37377 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.65873 .38627 m
.65873 .39252 L
s
gsave
.65873 .37377 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.81746 .38627 m
.81746 .39252 L
s
gsave
.81746 .37377 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2.5) show
1.000 setlinewidth
grestore
.97619 .38627 m
.97619 .39252 L
s
gsave
.97619 .37377 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.125 Mabswid
.05556 .38627 m
.05556 .39002 L
s
.0873 .38627 m
.0873 .39002 L
s
.11905 .38627 m
.11905 .39002 L
s
.15079 .38627 m
.15079 .39002 L
s
.21429 .38627 m
.21429 .39002 L
s
.24603 .38627 m
.24603 .39002 L
s
.27778 .38627 m
.27778 .39002 L
s
.30952 .38627 m
.30952 .39002 L
s
.37302 .38627 m
.37302 .39002 L
s
.40476 .38627 m
.40476 .39002 L
s
.43651 .38627 m
.43651 .39002 L
s
.46825 .38627 m
.46825 .39002 L
s
.53175 .38627 m
.53175 .39002 L
s
.56349 .38627 m
.56349 .39002 L
s
.59524 .38627 m
.59524 .39002 L
s
.62698 .38627 m
.62698 .39002 L
s
.69048 .38627 m
.69048 .39002 L
s
.72222 .38627 m
.72222 .39002 L
s
.75397 .38627 m
.75397 .39002 L
s
.78571 .38627 m
.78571 .39002 L
s
.84921 .38627 m
.84921 .39002 L
s
.88095 .38627 m
.88095 .39002 L
s
.9127 .38627 m
.9127 .39002 L
s
.94444 .38627 m
.94444 .39002 L
s
.01 w
0 .38627 m
1 .38627 L
s
.25 Mabswid
.02381 0 m
.03006 0 L
s
gsave
.01131 0 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.02381 .07725 m
.03006 .07725 L
s
gsave
.01131 .07725 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.02381 .15451 m
.03006 .15451 L
s
gsave
.01131 .15451 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.02381 .23176 m
.03006 .23176 L
s
gsave
.01131 .23176 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.02381 .30902 m
.03006 .30902 L
s
gsave
.01131 .30902 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.02381 .46353 m
.03006 .46353 L
s
gsave
.01131 .46353 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.02381 .54078 m
.03006 .54078 L
s
gsave
.01131 .54078 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.02381 .61803 m
.03006 .61803 L
s
gsave
.01131 .61803 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.01 w
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.02 w
.34072 .61803 m
.34072 0 L
s
.47381 0 m
.48186 .07319 L
.49072 .13357 L
.50036 .18376 L
.50974 .22134 L
.52008 .25338 L
.53089 .2791 L
.54102 .29793 L
.55083 .31245 L
.56115 .32473 L
.5796 .34108 L
.58913 .34746 L
.59929 .35311 L
.6176 .36099 L
.63889 .36751 L
.65898 .37189 L
.67895 .37508 L
.69734 .3773 L
.71606 .37904 L
.73663 .38051 L
.75603 .38158 L
.77686 .38248 L
.79798 .38318 L
.81802 .38372 L
.85615 .38446 L
.87581 .38474 L
.89674 .38498 L
.9167 .38517 L
.93825 .38534 L
.97619 .38557 L
s
0 .5 0 r
.015 w
.02698 .48876 m
.02816 .48879 L
.02922 .48883 L
.03162 .48894 L
.03383 .48908 L
.03593 .48924 L
.04063 .48972 L
.04573 .49043 L
.056 .49245 L
.06549 .49507 L
.07519 .49856 L
.08588 .50348 L
.09716 .51008 L
.10749 .51761 L
.12683 .53658 L
.1375 .55057 L
.14764 .56695 L
.15719 .58585 L
.16738 .61074 L
s
.16738 .61074 m
.16953 .61803 L
s
.34247 .61803 m
.34247 0 L
s
.45112 0 m
.4534 .02859 L
.45872 .07865 L
.46373 .11786 L
.47347 .17746 L
.48376 .22325 L
.49254 .25267 L
.50217 .27762 L
.51235 .29794 L
.52163 .31244 L
.53247 .3258 L
.54248 .33556 L
.56152 .34927 L
.57156 .35464 L
.58222 .35933 L
.60164 .36587 L
.61986 .37032 L
.63999 .37393 L
.65844 .3764 L
.67731 .37834 L
.69795 .37995 L
.71751 .38113 L
.7384 .38211 L
.75969 .38289 L
.77978 .38347 L
.81813 .38428 L
.83796 .38459 L
.85894 .38485 L
.89672 .38522 L
.91611 .38536 L
.93694 .38549 L
.97619 .38568 L
s
0 0 1 r
.01 w
.02698 .28258 m
.02816 .28258 L
.02922 .28259 L
.03162 .2826 L
.03383 .28262 L
.03593 .28264 L
.04063 .28269 L
.04573 .28278 L
.056 .28302 L
.06549 .28332 L
.07519 .28371 L
.08588 .28424 L
.10749 .28565 L
.12683 .28732 L
.14764 .28958 L
.18873 .29562 L
.2283 .30364 L
.26637 .31344 L
.30688 .32569 L
.34588 .33817 L
.38732 .35062 L
.42725 .36063 L
.46568 .36802 L
.48516 .37097 L
.50654 .37368 L
.5459 .37745 L
.56534 .37886 L
.58619 .3801 L
.60593 .38107 L
.62741 .38193 L
.66712 .38314 L
.68683 .3836 L
.70777 .384 L
.74539 .38456 L
.78546 .38499 L
.82402 .3853 L
.86502 .38553 L
.90452 .3857 L
.9425 .38582 L
.97619 .3859 L
s
1 0 1 r
.005 w
.02698 .37944 m
.02816 .37944 L
.02922 .37944 L
.03162 .37944 L
.03383 .37944 L
.03593 .37944 L
.04063 .37945 L
.04573 .37946 L
.056 .37947 L
.06549 .3795 L
.08588 .37957 L
.10749 .37967 L
.14519 .37992 L
.18535 .38028 L
.22399 .38069 L
.26508 .3812 L
.30465 .38172 L
.34272 .38225 L
.38323 .38279 L
.42223 .3833 L
.46367 .38379 L
.5036 .3842 L
.54203 .38455 L
.58289 .38487 L
.62225 .38512 L
.66009 .38533 L
.70038 .3855 L
.73916 .38564 L
.78039 .38576 L
.8201 .38586 L
.8583 .38593 L
.89895 .38599 L
.93808 .38604 L
.97571 .38608 L
.97619 .38608 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP005OoonfX5o`00Oooooo]ZoooonfXXoook
JP005?oonfX7o`00Oooooo]ZoooonfXWoookJP004ooonfX4o`00O`04oookJ_l007oo001oo`00O`Wo
oo]Z1Ol0003ooookJ_oooo]Z6OoonfX000Oooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Sooo]Z
1Ol0003ooookJ_oooo]Z6OoonfX000Oooo]Z2_l007l8oookJP?o001o2?oonfX6o`000:?ooo]Z0_oo
0008o`1o03?ooo]Z2?l0O`03oookJP[oo`00oooonfXRoookJP006OoonfX3o`00O`Sooo]Z1Ol0002T
oookJP;oo`002?l0O`0coookJPSo07l00ooonfX:ool00?oooo]Z8_oonfX001Cooo]Z0_l007l2oook
JPCo001o2?oonfX5o`000:Cooo]Z0_oo0008o`1o03?ooo]Z2?l0O`03oookJP_oo`00oooonfXQoook
JP005?oonfX7o`00O`Wooo]Z1Ol0002ToookJP;oo`002?l0O`0coookJPSo07l00ooonfX;ool00?oo
oo]Z8OoonfX001Cooo]Z1_l007l:oookJPGo0000Y?oonfX2ool000So07l0<ooonfX8o`1o00?ooo]Z
2ooo003ooookJR7ooo]Z000DoookJP;o001o3_oonfX5o`000:Cooo]Z0_oo0008o`1o03?ooo]Z2Ol0
O`02oookJP_oo`00oooonfXQoookJP005?oonfX2o`00O`kooo]Z1Ol0002ToookJP;oo`002?l0O`0c
oookJPWo07l00_oonfX;ool00?oooo]Z8OoonfX001Gooo]Z1ol007l8oookJPGo0000Y?oonfX2ool0
00So07l0<ooonfX9o`1o00;ooo]Z2ooo003ooookJR7ooo]Z000EoookJPOo001o2?oonfX5o`000:Co
oo]Z0_oo0008o`1o03?ooo]Z2Ol0O`02oookJP_oo`00oooonfXQoookJP009?oonfX5o`000:Cooo]Z
0_oo0008o`1o03?ooo]Z2Ol0O`02oookJP_oo`00oooonfXQoookJP009?oonfX5o`000:Cooo]Z0_oo
0008o`1o03?ooo]Z2Ol0O`02oookJP_oo`00oooonfXQoookJP009?oonfX5o`000:Cooo]Z0_oo0008
o`1o03?ooo]Z2Ol0O`03oookJP[oo`00oooonfXQoookJP009?oonfX5o`000:Cooo]Z0_oo0008o`1o
03Cooo]Z2?l0O`03oookJP_oo`00oooonfXPoookJP009?oonfX5o`000:Cooo]Z0_oo0008o`1o03Co
oo]Z2?l0O`03oookJP_oo`00oooonfXPoookJP009?oonfX5o`000:Cooo]Z0_oo0008o`1o03Cooo]Z
2?l0O`03oookJP_oo`00oooonfXPoookJP009?oonfX5o`000:Cooo]Z0_oo0008o`1o03Cooo]Z2?l0
O`03oookJP_oo`00oooonfXPoookJP009?oonfX5o`000:Cooo]Z0_oo0008o`1o03Cooo]Z2?l0O`03
oookJP_oo`00oooonfXPoookJP009?oonfX5o`000:Cooo]Z0_oo0008o`1o03Cooo]Z2Ol0O`02oook
JP_oo`00oooonfXPoookJP009?oonfX5o`000:Cooo]Z0_oo0008o`1o03Cooo]Z2Ol0O`02oookJP_o
o`00oooonfXPoookJP009?oonfX5o`000:Cooo]Z0_oo0008o`1o03Cooo]Z2Ol0O`02oookJP_oo`00
oooonfXPoookJP009?oonfX5o`000:Cooo]Z0_oo0008o`1o03Cooo]Z2Ol0O`02oookJP_oo`00oooo
nfXPoookJP009?oonfX5o`000:Cooo]Z0_oo0008o`1o03Cooo]Z2Ol0O`03oookJP_oo`00oooonfXO
oookJP009?oonfX5o`000:Cooo]Z0_oo0008o`1o03Cooo]Z2Ol0O`03oookJP_oo`00oooonfXOoook
JP009?oonfX5o`000:Cooo]Z0_oo0008o`1o03Cooo]Z2Ol0O`03oookJP_oo`00oooonfXOoookJP00
9?oonfX5o`000:Cooo]Z0_oo0008o`1o03Gooo]Z2?l0O`03oookJP_oo`00oooonfXOoookJP009?oo
nfX5o`000:Cooo]Z0_oo0008o`1o03Gooo]Z2?l0O`03oookJP_oo`00oooonfXOoookJP009?oonfX5
o`000:Cooo]Z0_oo0008o`1o03Gooo]Z2Ol0O`02oookJP_oo`00oooonfXOoookJP009?oonfX5o`00
0:Cooo]Z0_oo0008o`1o03Gooo]Z2Ol0O`02oookJP_oo`00oooonfXOoookJP009?oonfX5o`000:Co
oo]Z0_oo0008o`1o03Gooo]Z2Ol0O`02oookJP_oo`00oooonfXOoookJP009?oonfX5o`000:Cooo]Z
0_oo0008o`1o03Gooo]Z2Ol0O`02oookJP_oo`00oooonfXOoookJP009?oonfX5o`000:Cooo]Z0_oo
0008o`1o03Gooo]Z2Ol0O`03oookJP[oo`00oooonfXOoookJP009?oonfX5o`000:Cooo]Z0_oo0008
o`1o03Gooo]Z2Ol0O`03oookJP_oo`00oooonfXNoookJP009?oonfX5o`000:Cooo]Z0_oo0008o`1o
03Gooo]Z2Ol0O`03oookJP_oo`00oooonfXNoookJP009?oonfX5o`000:Cooo]Z0_oo0008o`1o03Ko
oo]Z2?l0O`03oookJP_oo`00oooonfXNoookJP009?oonfX5o`000:Cooo]Z0_oo0008o`1o03Kooo]Z
2?l0O`03oookJP_oo`00oooonfXNoookJP009?oonfX5o`000:Cooo]Z0_oo0008o`1o03Kooo]Z2Ol0
O`02oookJP_oo`00oooonfXNoookJP009?oonfX5o`000:Cooo]Z0_oo0008o`1o03Kooo]Z2Ol0O`02
oookJP_oo`00oooonfXNoookJP006?oonfX3o`00O`Wooo]Z1Ol0002ToookJP;oo`002?l0O`0foook
JPWo07l00_oonfX;ool00?oooo]Z7_oonfX001Sooo]Z0ol007l9oookJPGo0000Y?oonfX2ool000So
07l0=_oonfX9o`1o00;ooo]Z2ooo003ooookJQkooo]Z000HoookJP?o001o2OoonfX5o`000:Cooo]Z
0_oo0008o`1o03Kooo]Z2Ol0O`02oookJPcoo`00oooonfXMoookJP001ooonfX:o`00O`;ooo]Z2Ol0
07l8oookJPGo0000Y?oonfX2ool000So07l0=_oonfX9o`1o00?ooo]Z2ooo003ooookJQgooo]Z0007
oookJP[o001o0_oonfX9o`00O`Sooo]Z1_l0002SoookJP;oo`002?l0O`0foookJPWo07l00ooonfX;
ool00?oooo]Z7OoonfX001?ooo]Z0_l007l3oookJP?o001o2OoonfX5o`000:Cooo]Z0_oo0008o`1o
03Oooo]Z2?l0O`03oookJP_oo`00oooonfXMoookJP005?oonfX2o`00O`;ooo]Z0ol007l9oookJPGo
0000Y?oonfX2ool000So07l0=ooonfX8o`1o00?ooo]Z2ooo003ooookJQgooo]Z000DoookJP?o001o
00Cooo]Zo`00Ool007oo001o2OoonfX5o`000:Cooo]Z0_oo0008o`1o03Oooo]Z2?l0O`03oookJP_o
o`00oooonfXMoookJP005OoonfX2o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0002ToookJP;o
o`002?l0O`0goookJPWo07l00_oonfX;ool00?oooo]Z7OoonfX001Kooo]Z1Ol007l9oookJPGo0000
Y?oonfX2ool000So07l0=ooonfX9o`1o00;ooo]Z3?oo003ooookJQcooo]Z000FoookJPGo001o2Ooo
nfX5o`000:Cooo]Z0_oo0008o`1o03Oooo]Z2Ol0O`02oookJPcoo`00oooonfXLoookJP005ooonfX4
o`00O`Wooo]Z1Ol0002ToookJP;oo`002?l0O`0goookJPWo07l00ooonfX;ool00?oooo]Z7?oonfX0
01Sooo]Z0ol007l9oookJPGo0000Y?oonfX2ool000So07l0=ooonfX9o`1o00?ooo]Z2ooo003ooook
JQcooo]Z000ToookJPGo0000Y?oonfX2ool000So07l0=ooonfX9o`1o00?ooo]Z2ooo003ooookJQco
oo]Z000ToookJPGo0000Y?oonfX2ool000So07l0=ooonfX9o`1o00?ooo]Z2ooo003ooookJQcooo]Z
000ToookJPGo0000Y?oonfX2ool000So07l0>?oonfX8o`1o00?ooo]Z3?oo003ooookJQ_ooo]Z000T
oookJPGo0000Y?oonfX2ool000So07l0>?oonfX8o`1o00?ooo]Z3?oo003ooookJQ_ooo]Z000Toook
JPGo0000Y?oonfX2ool000So07l0>?oonfX8o`1o00?ooo]Z3?oo003ooookJQ_ooo]Z000ToookJPGo
0000Y?oonfX2ool000So07l0>?oonfX8o`1o00Cooo]Z2ooo003ooookJQ_ooo]Z000ToookJPGo0000
Y?oonfX2ool000So07l0>?oonfX9o`1o00?ooo]Z2ooo003ooookJQ_ooo]Z000ToookJPGo0000Y?oo
nfX2ool000So07l0>?oonfX9o`1o00?ooo]Z2ooo003ooookJQ_ooo]Z000ToookJPGo0000Y?oonfX2
ool000So07l0>?oonfX9o`1o00?ooo]Z2ooo003ooookJQ_ooo]Z000ToookJPGo0000Y?oonfX2ool0
00So07l0>?oonfX9o`1o00?ooo]Z3?oo003ooookJQ[ooo]Z000ToookJPGo0000Y?oonfX2ool000So
07l0>?oonfX9o`1o00?ooo]Z3?oo003ooookJQ[ooo]Z000ToookJPGo0000Y?oonfX2ool000So07l0
>?oonfX9o`1o00Cooo]Z2ooo003ooookJQ[ooo]Z000ToookJPGo0000Y?oonfX2ool000So07l0>?oo
nfX9o`1o00Cooo]Z2ooo003ooookJQ[ooo]Z000ToookJPGo0000Y?oonfX2ool000So07l0>OoonfX8
o`1o00Cooo]Z2ooo003ooookJQ[ooo]Z000ToookJPGo0000Y?oonfX2ool000So07l0>OoonfX9o`1o
00?ooo]Z2ooo003ooookJQ[ooo]Z000ToookJPGo0000Y?oonfX2ool000So07l0>OoonfX9o`1o00?o
oo]Z2ooo003ooookJQ[ooo]Z000ToookJPGo0000Y?oonfX2ool000So07l0>OoonfX9o`1o00?ooo]Z
3?oo003ooookJQWooo]Z000ToookJPGo0000Y?oonfX2ool000So07l0>OoonfX9o`1o00?ooo]Z3?oo
003ooookJQWooo]Z000ToookJPGo0000Y?oonfX2ool000So07l0>OoonfX9o`1o00Cooo]Z2ooo003o
oookJQWooo]Z000ToookJPGo0000Y?oonfX2ool000So07l0>OoonfX:o`1o00?ooo]Z2ooo003ooook
JQWooo]Z000ToookJPGo0000Y?oonfX2ool000So07l0>OoonfX:o`1o00?ooo]Z2ooo003ooookJQWo
oo]Z000ToookJPGo0000Y?oonfX2ool000So07l0>_oonfX9o`1o00?ooo]Z2ooo003ooookJQWooo]Z
000ToookJPGo0000Y?oonfX2ool000So07l0>_oonfX9o`1o00?ooo]Z3?oo003ooookJQSooo]Z000T
oookJPGo0000Y?oonfX2ool000So07l0>_oonfX9o`1o00?ooo]Z3?oo003ooookJQSooo]Z000Toook
JPGo0000Y?oonfX2ool000So07l0>_oonfX9o`1o00?ooo]Z3?oo003ooookJQSooo]Z000ToookJPGo
0000Y?oonfX2ool000So07l0>_oonfX:o`1o00?ooo]Z2ooo003ooookJQSooo]Z000ToookJPGo0000
Y?oonfX2ool000So07l0>ooonfX9o`1o00?ooo]Z2ooo003ooookJQSooo]Z000ToookJPGo0000Y?oo
nfX2ool000So07l0>ooonfX9o`1o00?ooo]Z3?oo003ooookJQOooo]Z000ToookJPGo0000Y?oonfX2
ool000So07l0>ooonfX9o`1o00?ooo]Z3?oo003ooookJQOooo]Z000EoookJPGo001o2_oonfX5o`00
0:Cooo]Z0_oo0008o`1o03_ooo]Z2Ol0O`03oookJPcoo`00oooonfXGoookJP005?oonfX7o`00O`Wo
oo]Z1Ol0002ToookJP;oo`002?l0O`0koookJP[o07l00_oonfX<ool00?oooo]Z5ooonfX001?ooo]Z
0ol007l3oookJP?o001o2?oonfX5o`000:Cooo]Z0_oo0008o`1o03_ooo]Z2_l0O`03oookJP_oo`00
oooonfXGoookJP001ooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o2?oonfX5o`000:Cooo]Z0_oo
0008o`1o03cooo]Z2Ol0O`03oookJPcoo`00oooonfXFoookJP001ooonfX:o`00O`Sooo]Z0ol007l8
oookJPKo0000XooonfX2ool000So07l0??oonfX9o`1o00?ooo]Z3?oo003ooookJQKooo]Z000Ioook
JP?o001o2?oonfX5o`000:Cooo]Z0_oo0008o`1o03cooo]Z2Ol0O`03oookJPcoo`00oooonfXFoook
JP005ooonfX4o`00O`Wooo]Z1Ol0002ToookJP;oo`002?l0O`0loookJPWo07l00ooonfX<ool00?oo
oo]Z5_oonfX001Oooo]Z0ol007l:oookJPGo0000Y?oonfX2ool000So07l0??oonfX:o`1o00?ooo]Z
2ooo003ooookJQKooo]Z000IoookJP;o001o2OoonfX5o`000:Cooo]Z0_oo0008o`1o03gooo]Z2Ol0
O`03oookJP_oo`00oooonfXFoookJP004ooonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000Y?oonfX2
ool000So07l0?OoonfX9o`1o00?ooo]Z3?oo003ooookJQGooo]Z000CoookJP?o001o0ooonfX3o`00
O`Sooo]Z1Ol0002ToookJP;oo`002?l0O`0moookJPWo07l00ooonfX<ool00?oooo]Z5OoonfX001Co
oo]Z1ol007l9oookJPGo0000Y?oonfX2ool000So07l0?OoonfX9o`1o00?ooo]Z3?oo003ooookJQGo
oo]Z000EoookJPGo001o2_oonfX5o`000:Cooo]Z0_oo0008o`1o03gooo]Z2_l0O`03oookJP_oo`00
oooonfXEoookJP009?oonfX5o`000:Cooo]Z0_oo0008o`1o03gooo]Z2_l0O`03oookJP_oo`00oooo
nfXEoookJP009?oonfX5o`000:Cooo]Z0_oo0008o`1o03kooo]Z2Ol0O`03oookJPcoo`00oooonfXD
oookJP009?oonfX5o`000:Cooo]Z0_oo0008o`1o03kooo]Z2Ol0O`03oookJPcoo`00oooonfXDoook
JP009?oonfX5o`000:Cooo]Z0_oo0008o`1o03kooo]Z2Ol0O`03oookJPcoo`00oooonfXDoookJP00
9?oonfX5o`000:Cooo]Z0_oo0008o`1o03kooo]Z2_l0O`02oookJPcoo`00oooonfXDoookJP009?oo
nfX5o`000:Cooo]Z0_oo0008o`1o03kooo]Z2_l0O`03oookJP_oo`00oooonfXDoookJP009?oonfX5
o`000:Cooo]Z0_oo0008o`1o03oooo]Z2Ol0O`03oookJPcoo`00oooonfXCoookJP009?oonfX5o`00
0:Cooo]Z0_oo0008o`1o03oooo]Z2Ol0O`03oookJPcoo`00oooonfXCoookJP009?oonfX5o`000:Co
oo]Z0_oo0008o`1o03oooo]Z2Ol0O`03oookJPcoo`00oooonfXCoookJP009?oonfX5o`000:Cooo]Z
0_oo0008o`1o03oooo]Z2_l0O`02oookJPcoo`00oooonfXCoookJP009?oonfX5o`000:Cooo]Z0_oo
0008o`1o03oooo]Z2_l0O`03oookJPcoo`00oooonfXBoookJP009?oonfX5o`000:Cooo]Z0_oo0008
o`1o043ooo]Z2Ol0O`03oookJPcoo`00oooonfXBoookJP009?oonfX5o`000:Cooo]Z0_oo0008o`1o
043ooo]Z2Ol0O`03oookJPcoo`00oooonfXBoookJP009?oonfX5o`000:Cooo]Z0_oo0008o`1o043o
oo]Z2Ol0O`03oookJPcoo`00oooonfXBoookJP009?oonfX5o`000:Cooo]Z0_oo0008o`1o043ooo]Z
2_l0O`02oookJPgoo`00oooonfXAoookJP009?oonfX5o`000:Cooo]Z0_oo0008o`1o043ooo]Z2_l0
O`03oookJPcoo`00oooonfXAoookJP009?oonfX5o`000:Cooo]Z0_oo0008o`1o047ooo]Z2Ol0O`03
oookJPcoo`00oooonfXAoookJP009?oonfX5o`000:Cooo]Z0_oo0008o`1o047ooo]Z2Ol0O`03oook
JPcoo`00oooonfXAoookJP009?oonfX5o`000:Cooo]Z0_oo0008o`1o047ooo]Z2Ol0O`03oookJPco
o`00oooonfXAoookJP009?oonfX5o`000:Cooo]Z0_oo0008o`1o047ooo]Z2_l0O`03oookJPcoo`00
oooonfX@oookJP009?oonfX5o`000:Cooo]Z0_oo0008o`1o047ooo]Z2_l0O`03oookJPcoo`00oooo
nfX@oookJP009?oonfX5o`000:Cooo]Z0_oo0008o`1o04;ooo]Z2Ol0O`03oookJPcoo`00oooonfX@
oookJP009?oonfX5o`000:Cooo]Z0_oo0008o`1o04;ooo]Z2Ol0O`03oookJPcoo`00oooonfX@oook
JP009?oonfX5o`000:Cooo]Z0_oo0008o`1o04;ooo]Z2Ol0O`04oookJPcoo`00oooonfX?oookJP00
9?oonfX5o`000:Cooo]Z0_oo0008o`1o04;ooo]Z2_l0O`03oookJPcoo`00oooonfX?oookJP009?oo
nfX5o`000:Cooo]Z0_oo0008o`1o04;ooo]Z2_l0O`03oookJPcoo`00oooonfX?oookJP009?oonfX5
o`000:Cooo]Z0_oo0008o`1o04?ooo]Z2Ol0O`03oookJPgoo`00oooonfX>oookJP009?oonfX5o`00
0:Cooo]Z0_oo0008o`1o04?ooo]Z2Ol0O`03oookJPgoo`00oooonfX>oookJP009?oonfX5o`000:Co
oo]Z0_oo0008o`1o04?ooo]Z2_l0O`03oookJPcoo`00oooonfX>oookJP004ooonfX9o`00O`Sooo]Z
1Ol0002ToookJP;oo`002?l0O`13oookJP[o07l00ooonfX=ool00?oooo]Z3OoonfX001?ooo]Z2Ol0
07l8oookJPGo0000Y?oonfX2ool000So07l0@ooonfX:o`1o00?ooo]Z3Ooo003ooookJPgooo]Z000C
oookJPCo001o3OoonfX5o`000:Cooo]Z0_oo0008o`1o04Cooo]Z2_l0O`02oookJPgoo`00oooonfX=
oookJP001ooonfX:o`00O`?ooo]Z1?l007l<oookJPGo0000Y?oonfX2ool000So07l0A?oonfX:o`1o
00?ooo]Z3Ooo003ooookJPcooo]Z0007oookJP[o001o1?oonfX5o`00O`[ooo]Z1_l0002SoookJP;o
o`002?l0O`14oookJP[o07l00ooonfX=ool00?oooo]Z3?oonfX001Oooo]Z1?l007l9oookJPGo0000
Y?oonfX2ool000So07l0A?oonfX;o`1o00;ooo]Z3Ooo003ooookJPcooo]Z000HoookJP?o001o2Ooo
nfX5o`000:Cooo]Z0_oo0008o`1o04Gooo]Z2_l0O`03oookJPgoo`00oooonfX;oookJP006OoonfX3
o`00O`Sooo]Z1Ol0002ToookJP;oo`002?l0O`15oookJP[o07l00ooonfX=ool00?oooo]Z2ooonfX0
01?ooo]Z0ol007l3oookJP?o001o2?oonfX5o`000:Cooo]Z0_oo0008o`1o04Gooo]Z2ol0O`02oook
JPgoo`00oooonfX;oookJP004ooonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000Y?oonfX2ool000So
07l0A_oonfX:o`1o00?ooo]Z3Ooo003ooookJP[ooo]Z000CoookJPCo001o0_oonfX3o`00O`Sooo]Z
1Ol0002ToookJP;oo`002?l0O`16oookJP[o07l00ooonfX=ool00?oooo]Z2_oonfX001Cooo]Z1ol0
07l9oookJPGo0000Y?oonfX2ool000So07l0A_oonfX;o`1o00;ooo]Z3Ooo003ooookJP[ooo]Z000E
oookJPGo001o2_oonfX5o`000:Cooo]Z0_oo0008o`1o04Oooo]Z2_l0O`03oookJPgoo`00oooonfX9
oookJP009?oonfX5o`000:Cooo]Z0_oo0008o`1o04Oooo]Z2_l0O`03oookJPgoo`00oooonfX9oook
JP009?oonfX5o`000:Cooo]Z0_oo0008o`1o04Oooo]Z2ol0O`02oookJPkoo`00oooonfX8oookJP00
9?oonfX5o`000:Cooo]Z0_oo0008o`1o04Sooo]Z2_l0O`03oookJPgoo`00oooonfX8oookJP009?oo
nfX5o`000:Cooo]Z0_oo0008o`1o04Sooo]Z2_l0O`03oookJPkoo`00oooonfX7oookJP009?oonfX5
o`000:Cooo]Z0_oo0008o`1o04Sooo]Z2ol0O`02oookJPkoo`00oooonfX7oookJP009?oonfX5o`00
0:Cooo]Z0_oo0008o`1o04Wooo]Z2_l0O`03oookJPgoo`00oooonfX7oookJP009?oonfX5o`000:Co
oo]Z0_oo0008o`1o04Wooo]Z2_l0O`03oookJPkoo`00oooonfX6oookJP009?oonfX5o`000:Cooo]Z
0_oo0008o`1o04Wooo]Z2ol0O`02oookJPkoo`00oooonfX6oookJP009?oonfX5o`000:Cooo]Z0_oo
0008o`1o04[ooo]Z2_l0O`03oookJPkoo`00oooonfX5oookJP009?oonfX5o`000:Cooo]Z0_oo0008
o`1o04[ooo]Z2_l0O`03oookJPkoo`00oooonfX5oookJP009?oonfX5o`000:Cooo]Z0_oo0008o`1o
04[ooo]Z2ol0O`03oookJPkoo`00oooonfX4oookJP009?oonfX5o`000:Cooo]Z0_oo0008o`1o04_o
oo]Z2_l0O`03oookJPkoo`00oooonfX4oookJP009?oonfX5o`000:Cooo]Z0_oo0008o`1o04_ooo]Z
2_l0O`04oookJPgoo`00oooonfX4oookJP009?oonfX5o`000:Cooo]Z0_oo0008o`1o04_ooo]Z2ol0
O`03oookJPkoo`00oooonfX3oookJP009?oonfX5o`000:Cooo]Z0_oo0008o`1o04cooo]Z2_l0O`03
oookJPkoo`00oooonfX3oookJP009?oonfX5o`000:Cooo]Z0_oo0008o`1o04cooo]Z2ol0O`03oook
JPkoo`00oooonfX2oookJP009?oonfX5o`000:Cooo]Z0_oo0008o`1o04cooo]Z2ol0O`03oookJPko
o`00oooonfX2oookJP009?oonfX2o`0002;o003oQOoonfX2ool000So07l0COoonfX;o`1o00?ooo]Z
3_oo003ooookJP7ooo]Z000ToookJP;o0000=_l00?maoookJP;oo`002?l0O`1=oookJP_o07l00ooo
nfX>ool00?oooo]Z0OoonfX002Cooo]Z0_l00011o`00ofKooo]Z0_oo0008o`1o04gooo]Z3?l0O`03
oookJPkoo`00oooonfX002Cooo]Z0_l00019o`00oekooo]Z0_oo0008o`1o04kooo]Z3?l0O`02oook
JPkoo`00oooonfX002Cooo]Z0_l0001>o`00oeWooo]Z0_oo0008o`1o04kooo]Z3?l0O`02oookJPoo
o`00o_oonfX002Cooo]Z1Ol0000KoookJSKo003oDooonfX2ool000So07l0CooonfX<o`1o00;ooo]Z
3_oo003noookJP009?oonfX5o`0002oooo]Z9ol00?m>oookJP;oo`002?l0O`1?oookJPco07l00_oo
nfX?ool00?gooo]Z000ToookJPGo0000>_oonfXRo`00odSooo]Z0_oo0008o`1o053ooo]Z3?l0O`02
oookJPkoo`00oOoonfX002Cooo]Z1Ol00012oookJQoo003o@ooonfX2ool000So07l0D?oonfX<o`1o
00;ooo]Z3ooo003loookJP009?oonfX5o`0004Oooo]Z8?l00?lmoookJP;oo`002?l0O`1AoookJPco
07l00_oonfX?ool00?_ooo]Z000ToookJPGo0000COoonfXOo`00ocSooo]Z0_oo0008o`1o05;ooo]Z
3?l0O`000ooonf[oo`00ool0000>ool00?[ooo]Z000ToookJPGo0000D_oonfXOo`00oc?ooo]Z0_oo
0008o`1o05;ooo]Z3?l0O`02oookJPooo`00n_oonfX001Oooo]Z0ol007l:oookJPGo0000F?oonfXM
o`00oboooo]Z0_oo0008o`1o05?ooo]Z3?l0O`000ooonf[oo`00ool0000>ool00?Wooo]Z000Goook
JP?o001o2_oonfX5o`0005gooo]Z7?l00?l[oookJP;oo`002?l0O`1CoookJPco07l00_oonfX@ool0
0?Sooo]Z000GoookJP?o001o2_oonfX5o`0006?ooo]Z6_l00?lWoookJP;oo`002?l0O`1DoookJPco
07l000?ooo]Zool00?oo00003ooo003goookJP001ooonfX:o`00O`Kooo]Z0ol007l:oookJPGo0000
J?oonfXIo`00ob?ooo]Z0_oo0008o`1o05Cooo]Z3Ol0O`000ooonf[oo`00ool0000>ool00?Oooo]Z
0007oookJP[o001o1_oonfX3o`00O`[ooo]Z1_l0001/oookJQSo003o7ooonfX2ool000So07l0EOoo
nfX<o`1o0003oookJ_oo003oo`0000ooo`00m_oonfX001Oooo]Z0ol007l:oookJPGo0000LOoonfXG
o`00oacooo]Z0_oo0008o`1o05Kooo]Z3?l0O`000ooonf[oo`00ool0000?ool00?Gooo]Z000Goook
JP?o001o2_oonfX5o`0007Gooo]Z5_l00?lIoookJP;oo`002?l0O`1FoookJPgo07l000?ooo]Zool0
0?oo00003ooo003doookJP005ooonfX3o`00O`[ooo]Z1Ol0001ioookJQGo003o5_oonfX2ool000So
07l0EooonfX=o`1o0003oookJ_oo003oo`0000koo`00m?oonfX001Oooo]Z0ol007l:oookJPGo0000
OOoonfXDo`00oa?ooo]Z0_oo0008o`1o05Oooo]Z3_l0O`0Aool00??ooo]Z000DoookJPKo001o2_oo
nfX5o`00087ooo]Z4ol00?l@oookJP;oo`002?l0O`1HoookJPko07l04_oo003aoookJP005?oonfX6
o`00O`[ooo]Z1Ol00024oookJQ?o003o3OoonfX2ool000So07l0FOoonfX>o`1o01;oo`00l?oonfX0
01Kooo]Z1?l007l:oookJPGo0000QooonfXDo`00o`Wooo]Z0_oo0008o`1o05Wooo]Z3ol0O`0Bool0
0>oooo]Z000GoookJP?o001o2_oonfX5o`0008[ooo]Z5?l00?l6oookJP;oo`002?l0O`1JoookJPoo
07l04_oo003^oookJP009?oonfX5o`0008gooo]Z5?l00?l3oookJP;oo`002?l0O`1KoookJPoo07l0
4ooo003/oookJP009?oonfX5o`00093ooo]Z5?l00?l2ool000So07l0G?oonfX?o`1o01?oo`00jooo
nfX002Cooo]Z1Ol0002CoookJQCo003o1ol0O`1MoookJQ3o07l04_oo003ZoookJP009?oonfX5o`00
09Oooo]Z4ol00?l4o`1o05kooo]Z4?l0O`0Bool00>Wooo]Z000ToookJPGo0000V_oonfXCo`00o`03
o`1o0?oonf[ooo]Z05gooo]Z4?l0O`0Cool00>Oooo]Z000ToookJPGo0000WOoonfXDo`00oegooo]Z
4?l0O`0Cool00>Kooo]Z000ToookJPGo0000X?oonfXDo`00oe_ooo]Z4Ol0O`0Bool00>Gooo]Z000T
oookJPGo0000XooonfXDo`00oeWooo]Z4Ol0O`0Bool00>Cooo]Z000ToookJPGo0000Y?oonfX2ool0
01Co003oEooonfXAo`1o01?oo`00h_oonfX002Cooo]Z1Ol0002ToookJP;oo`000ol0O`0Do`00oeGo
oo]Z4Ol0O`0Dool00>3ooo]Z000ToookJPGo0000Y?oonfX2ool000Oo07l04ol00?mDoookJQ7o07l0
5?oo003NoookJP009?oonfX5o`000:Cooo]Z0_oo0008o`1o00;ooo]Z4ol00?mBoookJQ;o07l05?oo
003LoookJP009?oonfX5o`0004Wooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00OdOooo]Z0_oo0008
o`1o00Gooo]Z5?l00?l`oookJP?o001o1?oonfX3o`00O`?ooo]Z1Ol007l=oookJQ?o07l05Ooo000B
oookJPWo001oA_oonfX9o`00O`;ooo]Z0ol007l3oookJPGo001oBOoonfX5o`00OaCooo]Z000Toook
JPGo0000B?oonfX7o`00O`?ooo]Z0ol007l2oookJPOo001oA_oonfX2ool000So07l02?oonfXFo`00
ob_ooo]Z0ol007l4oookJP?o001o0_oonfX7o`00O`gooo]Z5Ol0O`0Dool0013ooo]Z2Ol007m6oook
JPWo001o0_oonfX3o`00O`;ooo]Z1ol007m7oookJPOo001o4ooonfX002Cooo]Z1Ol00018oookJP?o
001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00
Ool007oo001oA_oonfX2ool000So07l02ooonfXGo`00obOooo]Z0ol007l4oookJP?o001o00?ooo]Z
o`00Ool007l00_l007l01?oonf[o001oo`00Ool007l?oookJQKo07l05?oo000=oookJPCo001oBooo
nfX4o`00O`Oooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00OdKooo]Z
0ol007l3oookJP?o001o4_oonfX002Cooo]Z1Ol00017oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol0
07l3oookJP?o001oAOoonfX2ool000So07l03_oonfXHo`00ob?ooo]Z0ol007l8oookJP?o001o0ooo
nfX3o`00O`oooo]Z5ol0O`0Dool000cooo]Z1?l007m;oookJPCo001o2_oonfX3o`00O`?ooo]Z0ol0
07m5oookJP?o001o0ooonfX3o`00Oa;ooo]Z000ToookJPGo0000AooonfX3o`00O`?ooo]Z0ol007l<
oookJP?o001oAOoonfX2ool000So07l04OoonfXJo`00oakooo]Z0ol007l>oookJP?o001o4?oonfXI
o`1o01Coo`002_oonfX5o`00Od[ooo]Z1Ol007l>oookJP?o001oBooonfX3o`00Oa;ooo]Z000Toook
JPGo0000AooonfX3o`00O`?ooo]Z0ol007l<oookJP?o001oAOoonfX2ool000So07l05OoonfXKo`00
oaWooo]Z0ol007l>oookJP?o001o4OoonfXJo`1o01Goo`002OoonfX4o`00Od_ooo]Z1?l007l=oook
JP?o001oBooonfX3o`00Oa;ooo]Z000ToookJPGo0000AooonfX3o`00O`?ooo]Z0ol007l7oookJP;o
001o0_oonfX4o`00OdGooo]Z0_oo0008o`1o01[ooo]Z6ol00?lDoookJP?o001o2OoonfX2o`00O`;o
oo]Z1?l007lCoookJQ_o07l05Ooo0007oookJP?o001oC?oonfX3o`00O`Sooo]Z0_l007l2oookJPCo
001oBOoonfX4o`00Oa?ooo]Z000ToookJPGo0000AooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o
A_oonfX2ool000So07l07_oonfXLo`00o`oooo]Z0ol007l9oookJPOo001o5_oonfXMo`1o01Goo`00
1?oonfX3o`00Odcooo]Z0ol007l7oookJPOo001oB_oonfX3o`00OaCooo]Z000ToookJPGo0000Aooo
nfX3o`00O`?ooo]Z0ol007l7oookJPKo001oAooonfX2ool000So07l08_oonfXMo`00o`[ooo]Z0ol0
07l9oookJPKo001o6OoonfXPo`1o01Goo`000_l007m6oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l0
07m=oookJP;o001o4ooonfX002Cooo]Z1Ol00017oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007m;
oookJP;oo`002?l0O`0WoookJQgo003o0_oonfX6o`00O`Wooo]Z0_l007lPoookJR;o07l05_oo0012
oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007m;oookJP?o001o0ooonfX3o`00Oa;ooo]Z000Toook
JPGo0000B?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007m;oookJP;oo`002?l0O`0/
oookJQgo003o0ol007l9oookJP;o001o8ooonfXTo`1o01Koo`00?OoonfX4o`00O`;ooo]Z0ol007l7
oookJP;o001oBooonfX3o`00O`?ooo]Z0ol007lBoookJP009?oonfX5o`0004Sooo]Z1ol007l9oook
JPOo001oAOoonfX2ool000So07l0<OoonfXQo`00o`Cooo]Z1ol007lOoookJRSo07l06?oo000foook
JPOo001o2OoonfX7o`00OdKooo]Z1ol007lCoookJP009?oonfX5o`0004Wooo]Z1Ol007l:oookJPOo
001oAOoonfX2ool000So07l0=_oonfXWo`00ob;ooo]Z:_l0O`0Mool002gooo]Z1Ol007l:oookJPOo
001oAooonfX5o`00OaCooo]Z000ToookJPGo0000Y?oonfX2ool000So07l0>ooonfX]o`00oaWooo]Z
;ol0O`0Qool009Sooo]Z000ToookJPGo0000Y?oonfX2ool000So07l0@?oonfXbo`00oa;ooo]Z@_l0
O`0Qool008;ooo]Z000ToookJPGo0000Y?oonfX2ool000So07l0AOoonfXho`00o`_ooo]ZBOl0O`0/
ool006cooo]Z000ToookJPGo0000Y?oonfX2ool000So07l0C_oonfY5o`00ofCo07l0Eooo000Koook
JP009?oonfX3o`0004goo`3oFOoonfX2ool000So07l0FOoonfYVo`00ohko07l02ooo000AoookJP00
9?oonfX3o`000:?oo`3o0ooonfX2ool000So07l0I?oonf[1o`00oc;o07l000?oo`00oookJ_oonfX0
3ooonfX001Oooo]ZG?l0002Gool0oc_o0000j?l00?l00ol0O`3oo`00o`00000:o`0000Kooo]Z000G
oookJ[;o0000f?oo0?n<o`00o`03o`1o0?oo003o000000[o00001_oonfX001Oooo]Z]_l00002ool0
00So07l0<_l0003oool0ob?oo`3o0_l00?l00ol0O`3oo`00o`00000:o`0000Kooo]Z000GoookJ[Ko
00000_oo0008o`1o0;_o00003_l00?n;ool0o`;o003o00?o07l0ool00?l000002_l00006oookJP00
5ooonfZfo`0000;oo`002?l0O`38o`0000;oo`00Eol0O`0eo`00o`03o`1o0?oo003o000000[o0000
1_oonfX002Cooo]Z1Ol0001CoookJP03o`000?oonf[ooo]Z04kooo]Z0_oo0008o`1o057ooo]Z00?o
0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP0doookJQ;oo`00Iol0O`000ooo003ooo]Zoook
JP0?oookJP009?oonfX5o`000:Cooo]Z0_oo0008o`1o0?Cooo]ZD_oo000Ao`1o0003ool00?oonf[o
oo]Z00oooo]Z000ToookJPGo0000Y?oonfX2ool000So07l0oooonfY6oookJQ?oo`004OoonfX002Co
oo]Z1Ol0002ToookJP;oo`002?l0O`3ooookJV[ooo]Z000ToookJPGo0000Y?oonfX2ool000So07l0
oooonfYZoookJP009?oonfX5o`000:Cooo]Z0_oo0008o`1o0?oooo]ZJ_oonfX002Cooo]Z1Ol0002T
oookJP;oo`002?l0O`3ooookJV[ooo]Z000ToookJPGo0000Y?oonfX2ool000So07l0oooonfYZoook
JP009?oonfX5o`000:Cooo]Z0_oo0008o`1o0?oooo]ZJ_oonfX002Cooo]Z1Ol0002ToookJP;oo`00
2?l0O`3ooookJV[ooo]Z000ToookJPGo0000Y?oonfX2ool000So07l0oooonfYZoookJP009?oonfX5
o`000:Cooo]Z0_oo0008o`1o0?oooo]ZJ_oonfX002Cooo]Z1Ol0002ToookJP;oo`002?l0O`3ooook
JV[ooo]Z000ToookJPGo0000Y?oonfX2ool000So07l0oooonfYZoookJP009?oonfX5o`000:Cooo]Z
0_oo0008o`1o0?oooo]ZJ_oonfX002Cooo]Z1Ol0002ToookJP;oo`002?l0O`3ooookJV[ooo]Z000T
oookJPGo0000Y?oonfX2ool000So07l0oooonfYZoookJP009?oonfX5o`000:Cooo]Z0_oo0008o`1o
0?oooo]ZJ_oonfX002Cooo]Z1Ol0002ToookJP;oo`002?l0O`3ooookJV[ooo]Z000ToookJPGo0000
Y?oonfX2ool000So07l0oooonfYZoookJP009?oonfX5o`000:Cooo]Z0_oo0008o`1o0?oooo]ZJ_oo
nfX002Cooo]Z1Ol0002ToookJP;oo`002?l0O`3ooookJV[ooo]Z000ToookJPGo0000Y?oonfX2ool0
00So07l0oooonfYZoookJP009?oonfX5o`000:Cooo]Z0_oo0008o`1o0?oooo]ZJ_oonfX002Cooo]Z
1Ol0002ToookJP;oo`002?l0O`3ooookJV[ooo]Z000ToookJPGo0000Y?oonfX2ool000So07l0oooo
nfYZoookJP009?oonfX5o`000:Cooo]Z0_oo0008o`1o0?oooo]ZJ_oonfX002Cooo]Z1Ol0002Toook
JP;oo`002?l0O`3ooookJV[ooo]Z000ToookJPGo0000Y?oonfX2ool000So07l0oooonfYZoookJP00
9?oonfX5o`000:Cooo]Z0_oo0008o`1o0?oooo]ZJ_oonfX002Cooo]Z1Ol0002ToookJP;oo`002?l0
O`3ooookJV[ooo]Z000ToookJPGo0000Y?oonfX2ool000So07l0oooonfYZoookJP009?oonfX5o`00
0:Cooo]Z0_oo0008o`1o0?oooo]ZJ_oonfX002Cooo]Z1Ol0002ToookJP;oo`002?l0O`3ooookJV[o
oo]Z000ToookJPGo0000Y?oonfX2ool000So07l0oooonfYZoookJP005ooonfX3o`00O`[ooo]Z1Ol0
002ToookJP;oo`002?l0O`3ooookJV[ooo]Z000GoookJP?o001o2_oonfX5o`000:Cooo]Z0_oo0008
o`1o0?oooo]ZJ_oonfX001Oooo]Z0ol007l:oookJPGo0000Y?oonfX2ool000So07l0oooonfYZoook
JP005ooonfX3o`00O`[ooo]Z1Ol0002ToookJP;oo`002?l0O`3ooookJV[ooo]Z000GoookJP?o001o
2_oonfX6o`000:?ooo]Z0_oo0008o`1o0?oooo]ZJ_oonfX001Oooo]Z0ol007l:oookJPGo0000Y?oo
nfX2ool000So07l0oooonfYZoookJP005ooonfX3o`00O`[ooo]Z1Ol0002ToookJP;oo`002?l0O`3o
oookJV[ooo]Z000GoookJP?o001o2_oonfX5o`000:Cooo]Z0_oo0008o`1o0?oooo]ZJ_oonfX001Oo
oo]Z0ol007l:oookJPGo0000Y?oonfX2ool000So07l0oooonfYZoookJP005?oonfX6o`00O`[ooo]Z
1Ol0002ToookJP;oo`002?l0O`3ooookJV[ooo]Z000DoookJPKo001o2_oonfX5o`000:Cooo]Z0_oo
0008o`1o0?oooo]ZJ_oonfX001Kooo]Z1?l007l:oookJPGo0000Y?oonfX2ool000So07l0oooonfYZ
oookJP005ooonfX3o`00O`[ooo]Z1Ol0002ToookJP;oo`002?l0O`3ooookJV[ooo]Z000ToookJPGo
0000Y?oonfX2ool000So07l0oooonfYZoookJP009?oonfX9o`1o0:3ooo]Z0_oo0008o`1o0?oooo]Z
J_oonfX002Cooo]Z5Ol0O`2DoookJP;oo`002?l0O`3ooookJV[ooo]Z000ToookJQWo07l0T?oonfX2
ool000So07l0oooonfYZoookJP009?oonfXLo`1o08gooo]Z0_oo0008o`1o0?oooo]ZJ_oonfX002Co
oo]Z7_l0O`2;oookJP;oo`002?l0O`3ooookJV[ooo]Z000ToookJR7o07l0R?oonfX2ool000So07l0
oooonfYZoookJP009?oonfXTo`1o08Gooo]Z0_oo0008o`1o0?oooo]ZJ_oonfX002Cooo]Z9ol0O`22
oookJP;oo`002?l0O`3ooookJV[ooo]Z000ToookJP;o00009ol0O`20oookJP;oo`002?l0O`3ooook
JV[ooo]Z000ToookJPGo00002OoonfXLo`1o07oooo]Z0_oo0008o`1o0?oooo]ZJ_oonfX002Cooo]Z
1Ol0000=oookJQ[o07l0OOoonfX2ool000So07l0oooonfYZoookJP009?oonfX5o`00013ooo]Z6?l0
O`1loookJP;oo`002?l0O`3ooookJV[ooo]Z000ToookJPGo00004_oonfXHo`1o07[ooo]Z0_oo0008
o`1o0?oooo]ZJ_oonfX002Cooo]Z1Ol0000EoookJQKo07l0NOoonfX2ool000So07l0oooonfYZoook
JP009?oonfX5o`0001Sooo]Z5?l0O`1hoookJP;oo`002?l0O`3ooookJV[ooo]Z000ToookJPGo0000
6ooonfXBo`1o07Oooo]Z0_oo0008o`1o0?oooo]ZJ_oonfX002Cooo]Z1Ol0000MoookJQ;o07l0MOoo
nfX2ool000So07l0oooonfYZoookJP009?oonfX5o`0001kooo]Z4_l0O`1doookJP;oo`002?l0O`3o
oookJV[ooo]Z000ToookJPGo00008?oonfXAo`1o07?ooo]Z0_oo0008o`1o0?oooo]ZJ_oonfX002Co
oo]Z1Ol0000QoookJQ7o07l0L_oonfX2ool000So07l0oooonfYZoookJP009?oonfX5o`0002?ooo]Z
4?l0O`1aoookJP;oo`002?l0O`3ooookJV[ooo]Z000ToookJPGo00009?oonfX@o`1o073ooo]Z0_oo
0008o`1o0?oooo]ZJ_oonfX002Cooo]Z1Ol0000UoookJQ3o07l0KooonfX2ool000So07l0oooonfYZ
oookJP009?oonfX5o`0002Kooo]Z4?l0O`1^oookJP;oo`002?l0O`3ooookJV[ooo]Z000ToookJPGo
0000:?oonfX?o`1o06gooo]Z0_oo0008o`1o0?oooo]ZJ_oonfX002Cooo]Z1Ol0000YoookJPoo07l0
K?oonfX2ool000So07l0oooonfYZoookJP009?oonfX5o`0002[ooo]Z3ol0O`1[oookJP;oo`002?l0
O`3ooookJV[ooo]Z000ToookJPGo0000:ooonfX>o`1o06_ooo]Z0_oo0008o`1o0?oooo]ZJ_oonfX0
01?ooo]Z2Ol007l8oookJPGo0000;?oonfX>o`1o06[ooo]Z0_oo0008o`1o0?oooo]ZJ_oonfX001?o
oo]Z2Ol007l8oookJPGo0000;OoonfX>o`1o06Wooo]Z0_oo0008o`1o0?oooo]ZJ_oonfX001?ooo]Z
1?l007l=oookJPGo0000;_oonfX>o`1o06Sooo]Z0_oo0008o`1o0?oooo]ZJ_oonfX001Cooo]Z1?l0
07l<oookJPGo0000;ooonfX=o`1o06Sooo]Z0_oo0008o`1o0?oooo]ZJ_oonfX001Gooo]Z1Ol007l:
oookJPKo0000;ooonfX=o`1o06Oooo]Z0_oo0008o`1o0?oooo]ZJ_oonfX001Oooo]Z1?l007l9oook
JPGo0000<OoonfX=o`1o06Kooo]Z0_oo0008o`1o0?oooo]ZJ_oonfX001Sooo]Z0ol007l9oookJPGo
0000<OoonfX>o`1o06Gooo]Z0_oo0008o`1o0?oooo]ZJ_oonfX001Wooo]Z0ol007l8oookJPGo0000
<_oonfX=o`1o06Gooo]Z0_oo0008o`1o0?oooo]ZJ_oonfX001?ooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`0003?ooo]Z3Ol0O`1ToookJP;oo`002?l0O`3ooookJV[ooo]Z000CoookJP?o001o0ooonfX3
o`00O`Sooo]Z1Ol0000doookJPco07l0I?oonfX2ool000So07l0oooonfYZoookJP004ooonfX4o`00
O`;ooo]Z0ol007l8oookJPGo0000=?oonfX=o`1o06?ooo]Z0_oo0008o`1o0?oooo]ZJ_oonfX001Co
oo]Z1ol007l9oookJPGo0000=OoonfX=o`1o06;ooo]Z0_oo0008o`1o0?oooo]ZJ_oonfX001Gooo]Z
1Ol007l:oookJPGo0000=_oonfX<o`1o06;ooo]Z0_oo0008o`1o0?oooo]ZJ_oonfX002Cooo]Z1Ol0
000goookJPco07l0HOoonfX2ool000So07l0oooonfYZoookJP009?oonfX5o`0003Oooo]Z3?l0O`1Q
oookJP;oo`002?l0O`3ooookJV[ooo]Z000ToookJPGo0000>?oonfX<o`1o063ooo]Z0_oo0008o`1o
0?oooo]ZJ_oonfX002Cooo]Z1Ol0000hoookJPco07l0H?oonfX2ool000So07l0oooonfYZoookJP00
9?oonfX5o`0003Wooo]Z3?l0O`1OoookJP;oo`002?l0O`3ooookJV[ooo]Z000ToookJPGo0000>_oo
nfX;o`1o05oooo]Z0_oo0008o`1o0?oooo]ZJ_oonfX002Cooo]Z1Ol0000joookJPco07l0G_oonfX2
ool000So07l0oooonfYZoookJP009?oonfX5o`0003_ooo]Z2ol0O`1NoookJP;oo`002?l0O`3ooook
JV[ooo]Z000ToookJPGo0000>ooonfX<o`1o05gooo]Z0_oo0008o`1o0?oooo]ZJ_oonfX002Cooo]Z
1Ol0000loookJP_o07l0GOoonfX2ool000So07l0oooonfYZoookJP009?oonfX5o`0003cooo]Z3?l0
O`1LoookJP;oo`002?l0O`3ooookJV[ooo]Z000ToookJPGo0000?OoonfX;o`1o05cooo]Z0_oo0008
o`1o0?oooo]ZJ_oonfX002Cooo]Z1Ol0000moookJPco07l0FooonfX2ool000So07l0oooonfYZoook
JP009?oonfX5o`0003kooo]Z2ol0O`1KoookJP;oo`002?l0O`3ooookJV[ooo]Z000ToookJPGo0000
?_oonfX<o`1o05[ooo]Z0_oo0008o`1o0?oooo]ZJ_oonfX002Cooo]Z1Ol0000ooookJP_o07l0F_oo
nfX2ool000So07l0oooonfYZoookJP009?oonfX5o`0003oooo]Z3?l0O`1IoookJP;oo`002?l0O`3o
oookJV[ooo]Z000ToookJPGo0000@?oonfX;o`1o05Wooo]Z0_oo0008o`1o0?oooo]ZJ_oonfX002Co
oo]Z1Ol00010oookJP_o07l0FOoonfX2ool000So07l0oooonfYZoookJP009?oonfX5o`00047ooo]Z
2ol0O`1HoookJP;oo`002?l0O`3ooookJV[ooo]Z000ToookJPGo0000@OoonfX;o`1o05Sooo]Z0_oo
0008o`1o0?oooo]ZJ_oonfX002Cooo]Z1Ol00012oookJP_o07l0EooonfX2ool000So07l0oooonfYZ
oookJP009?oonfX5o`0004;ooo]Z2ol0O`1GoookJP;oo`002?l0O`3ooookJV[ooo]Z000ToookJPGo
0000@ooonfX;o`1o05Kooo]Z0_oo0008o`1o0?oooo]ZJ_oonfX002Cooo]Z1Ol00013oookJP_o07l0
E_oonfX2ool000So07l0oooonfYZoookJP009?oonfX5o`0004?ooo]Z2ol0O`1FoookJP;oo`002?l0
O`3ooookJV[ooo]Z000ToookJPGo0000A?oonfX;o`1o05Gooo]Z0_oo0008o`1o0?oooo]ZJ_oonfX0
02Cooo]Z1Ol00014oookJP_o07l0EOoonfX2ool000So07l0oooonfYZoookJP005OoonfX5o`00O`[o
oo]Z1Ol00015oookJP_o07l0E?oonfX2ool000So07l0oooonfYZoookJP005?oonfX7o`00O`Wooo]Z
1Ol00015oookJP_o07l0E?oonfX2ool000So07l0oooonfYZoookJP004ooonfX3o`00O`?ooo]Z0ol0
07l8oookJPGo0000A_oonfX:o`1o05Cooo]Z0_oo0008o`1o0?oooo]ZJ_oonfX001?ooo]Z0ol007l3
oookJP?o001o2?oonfX5o`0004Kooo]Z2_l0O`1DoookJP;oo`002?l0O`3ooookJV[ooo]Z000Ioook
JP?o001o2?oonfX6o`0004Gooo]Z2_l0O`1DoookJP;oo`002?l0O`3ooookJV[ooo]Z000IoookJP?o
001o2?oonfX5o`000?oooo]ZoooonfXIoookJP005ooonfX4o`00O`Wooo]Z1Ol0003ooookJ_oooo]Z
6OoonfX001Oooo]Z0ol007oooookJ_oooo]Z:?oonfX001Wooo]Z0_l007oooookJ_oooo]Z9ooonfX0
01?ooo]Z0ol007l3oookJP?o001ooooonf[ooookJRKooo]Z000CoookJP?o001o0ooonfX3o`00Oooo
oo]ZoooonfXVoookJP005?oonfX7o`00Oooooo]ZoooonfXWoookJP005OoonfX5o`00Oooooo]Zoooo
nfXXoookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00001\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-0.223684, -5.23889, \
0.00581247, 0.0238852}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The plot above shows the London potential vs radial distance for the same \
",
  StyleBox["z",
    FontSlant->"Italic"],
  " values as in the previous plot, but for a much smaller range of potential \
values (-1, 0), to show the ",
  StyleBox["z",
    FontSlant->"Italic"],
  " dependence of the potential more clearly."
}], "Text"],

Cell["Visualize potential at fixed altitudes above cylinder", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TopOfCylinder\  = 
      Plot[{LondonCylinderPotential[dist, 1.1, 1, 1], 
          LondonCylinderPotential[dist, 1.2, 1, 1], 
          LondonCylinderPotential[dist, 1.3, 1, 1], 
          LondonCylinderPotential[dist, 1.4, 1, 1]}, {dist, 0, 3}, 
        PlotStyle \[Rule] {{Thickness[0.02], 
              RGBColor[1, 0, 0]}, {Thickness[0.015], \ 
              RGBColor[0, 0.5, 0]}, \ {Thickness[0.01], 
              RGBColor[0, 0, 1]}, {Thickness[0.005], 
              RGBColor[1, 0, 1]}}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.603319 0.30669 [
[.18254 .59082 -14.5 -20 ]
[.18254 .59082 14.5 0 ]
[.34127 .59082 -7 -20 ]
[.34127 .59082 7 0 ]
[.5 .59082 -14.5 -20 ]
[.5 .59082 14.5 0 ]
[.65873 .59082 -7 -20 ]
[.65873 .59082 7 0 ]
[.81746 .59082 -14.5 -20 ]
[.81746 .59082 14.5 0 ]
[.97619 .59082 -7 -20 ]
[.97619 .59082 7 0 ]
[.01131 .14328 -41.9375 -10 ]
[.01131 .14328 0 10 ]
[.01131 .29663 -26.9375 -10 ]
[.01131 .29663 0 10 ]
[.01131 .44997 -41.9375 -10 ]
[.01131 .44997 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .60332 m
.18254 .60957 L
s
gsave
.18254 .59082 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.34127 .60332 m
.34127 .60957 L
s
gsave
.34127 .59082 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .60332 m
.5 .60957 L
s
gsave
.5 .59082 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.65873 .60332 m
.65873 .60957 L
s
gsave
.65873 .59082 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.81746 .60332 m
.81746 .60957 L
s
gsave
.81746 .59082 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2.5) show
1.000 setlinewidth
grestore
.97619 .60332 m
.97619 .60957 L
s
gsave
.97619 .59082 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.125 Mabswid
.05556 .60332 m
.05556 .60707 L
s
.0873 .60332 m
.0873 .60707 L
s
.11905 .60332 m
.11905 .60707 L
s
.15079 .60332 m
.15079 .60707 L
s
.21429 .60332 m
.21429 .60707 L
s
.24603 .60332 m
.24603 .60707 L
s
.27778 .60332 m
.27778 .60707 L
s
.30952 .60332 m
.30952 .60707 L
s
.37302 .60332 m
.37302 .60707 L
s
.40476 .60332 m
.40476 .60707 L
s
.43651 .60332 m
.43651 .60707 L
s
.46825 .60332 m
.46825 .60707 L
s
.53175 .60332 m
.53175 .60707 L
s
.56349 .60332 m
.56349 .60707 L
s
.59524 .60332 m
.59524 .60707 L
s
.62698 .60332 m
.62698 .60707 L
s
.69048 .60332 m
.69048 .60707 L
s
.72222 .60332 m
.72222 .60707 L
s
.75397 .60332 m
.75397 .60707 L
s
.78571 .60332 m
.78571 .60707 L
s
.84921 .60332 m
.84921 .60707 L
s
.88095 .60332 m
.88095 .60707 L
s
.9127 .60332 m
.9127 .60707 L
s
.94444 .60332 m
.94444 .60707 L
s
.01 w
0 .60332 m
1 .60332 L
s
.25 Mabswid
.02381 .14328 m
.03006 .14328 L
s
gsave
.01131 .14328 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.02381 .29663 m
.03006 .29663 L
s
gsave
.01131 .29663 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.02381 .44997 m
.03006 .44997 L
s
gsave
.01131 .44997 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .17395 m
.02756 .17395 L
s
.02381 .20462 m
.02756 .20462 L
s
.02381 .23529 m
.02756 .23529 L
s
.02381 .26596 m
.02756 .26596 L
s
.02381 .3273 m
.02756 .3273 L
s
.02381 .35797 m
.02756 .35797 L
s
.02381 .38864 m
.02756 .38864 L
s
.02381 .4193 m
.02756 .4193 L
s
.02381 .48064 m
.02756 .48064 L
s
.02381 .51131 m
.02756 .51131 L
s
.02381 .54198 m
.02756 .54198 L
s
.02381 .57265 m
.02756 .57265 L
s
.02381 .11262 m
.02756 .11262 L
s
.02381 .08195 m
.02756 .08195 L
s
.02381 .05128 m
.02756 .05128 L
s
.02381 .02061 m
.02756 .02061 L
s
.01 w
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.02 w
.02381 .01472 m
.02499 .01472 L
.02605 .01473 L
.02729 .01474 L
.02846 .01476 L
.03053 .01481 L
.03279 .01489 L
.03527 .015 L
.0379 .01514 L
.04262 .01548 L
.04749 .01592 L
.05205 .01644 L
.06244 .01795 L
.07305 .02 L
.08274 .02234 L
.10458 .02933 L
.12357 .03748 L
.14429 .04886 L
.16561 .0636 L
.18493 .07994 L
.22406 .12294 L
.26413 .18193 L
.30268 .25149 L
.34368 .33209 L
.38317 .40538 L
.42114 .46368 L
.44229 .48977 L
.46157 .5097 L
.50048 .54021 L
.51956 .55127 L
.54032 .56102 L
.55971 .56837 L
.5811 .57491 L
.62037 .58367 L
.63972 .58684 L
.66057 .58962 L
.68022 .59177 L
.70171 .5937 L
.74134 .59636 L
.76095 .59736 L
.7819 .59825 L
.8234 .5996 L
.86338 .60052 L
.90184 .60117 L
.94276 .60168 L
.97619 .60199 L
s
0 .5 0 r
.015 w
.02381 .26312 m
.02499 .26312 L
.02605 .26312 L
.02729 .26313 L
.02846 .26315 L
.03053 .26318 L
.03279 .26323 L
.03527 .26331 L
.0379 .2634 L
.04262 .26363 L
.04749 .26394 L
.05205 .26428 L
.06244 .26531 L
.07305 .26669 L
.08274 .26826 L
.10458 .2729 L
.12357 .27826 L
.14429 .2856 L
.18493 .30498 L
.22406 .33046 L
.26565 .36489 L
.30571 .40372 L
.34426 .44311 L
.38527 .48273 L
.42475 .51513 L
.46273 .5396 L
.50315 .55881 L
.54206 .57188 L
.5633 .57728 L
.58342 .58149 L
.62175 .58762 L
.64152 .59003 L
.66253 .59214 L
.70028 .59507 L
.74048 .59727 L
.77917 .59879 L
.82031 .59994 L
.85994 .60075 L
.89804 .60132 L
.93861 .60178 L
.97619 .60209 L
s
0 0 1 r
.01 w
.02381 .39566 m
.02499 .39567 L
.02605 .39567 L
.02729 .39568 L
.02846 .39569 L
.03053 .39571 L
.03279 .39574 L
.03527 .39579 L
.0379 .39586 L
.04262 .39601 L
.04749 .39622 L
.05205 .39645 L
.06244 .39714 L
.07305 .39807 L
.08274 .39912 L
.10458 .4022 L
.12357 .40572 L
.14429 .41048 L
.18493 .42274 L
.22406 .43827 L
.26565 .45845 L
.30571 .4805 L
.34426 .50253 L
.38527 .52485 L
.42475 .54364 L
.46273 .55844 L
.50315 .57065 L
.54206 .5794 L
.58342 .58615 L
.62326 .59079 L
.66159 .594 L
.70238 .59646 L
.74164 .59817 L
.77939 .59937 L
.8196 .60032 L
.85828 .601 L
.89942 .60153 L
.93905 .60192 L
.97619 .6022 L
s
1 0 1 r
.005 w
.02381 .47111 m
.02499 .47111 L
.02605 .47111 L
.02729 .47111 L
.02846 .47112 L
.03053 .47114 L
.03279 .47116 L
.03527 .47119 L
.0379 .47124 L
.04262 .47134 L
.04749 .47148 L
.05205 .47164 L
.06244 .4721 L
.07305 .47273 L
.08274 .47343 L
.10458 .47548 L
.12357 .47781 L
.14429 .48092 L
.18493 .4888 L
.22406 .49851 L
.26565 .5108 L
.30571 .52396 L
.34426 .53701 L
.38527 .5503 L
.42475 .56174 L
.46273 .57105 L
.50315 .57903 L
.54206 .58499 L
.58342 .58977 L
.62326 .59318 L
.66159 .59562 L
.70238 .59754 L
.74164 .59891 L
.77939 .59989 L
.8196 .60068 L
.85828 .60125 L
.89942 .60171 L
.93905 .60205 L
.97619 .60229 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oo
oo]Z@_oonfX00?oooo]ZoooonfY2oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5
o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oo
oo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Zoooo
nfX?oookJP00:ooonfXCool00?oooo]ZoooonfX4oookJP00:ooonfXLool00?oooo]Zn_oonfX002_o
oo]Z8_oo003ooookJ_Cooo]Z000[oookJRSoo`00oooonf[^oookJP00:ooonfX[ool00?oooo]Zjooo
nfX002_ooo]Z;_oo003ooookJ^Sooo]Z000[oookJS7oo`00oooonf[UoookJP00:ooonfXdool00?oo
oo]Zh_oonfX002_ooo]Z=_oo003ooookJ^3ooo]Z000[oookJSWoo`00oooonf[MoookJP00;_oonfX5
o`0000;ooo]Z<_oo003ooookJ][ooo]Z000^oookJPGo00002ooonfX/ool00?oooo]ZeooonfX002ko
oo]Z1Ol0000AoookJRSoo`00oooonf[EoookJP00;_oonfX5o`0001Oooo]Z9?oo003ooookJ]?ooo]Z
000^oookJPGo00006_oonfXSool00?oooo]ZdOoonfX002kooo]Z1Ol0000MoookJR7oo`00oooonf[@
oookJP00;_oonfX5o`00023ooo]Z8?oo003ooookJ/kooo]Z000^oookJPGo00008ooonfXOool00?oo
oo]Zc?oonfX002kooo]Z1Ol0000UoookJQooo`00oooonf[:oookJP00;_oonfX5o`0002Sooo]Z7Ooo
003ooookJ/Wooo]Z000^oookJPGo0000:ooonfXKool00?oooo]Zb?oonfX002kooo]Z1Ol0000^oook
JQ[oo`00oooonf[6oookJP00;_oonfX5o`00033ooo]Z6Ooo003ooookJ/Gooo]Z000^oookJPGo0000
<_oonfXIool00?oooo]Z`ooonfX002kooo]Z1Ol0000doookJQSoo`00oooonf[2oookJP00;_oonfX5
o`0003Gooo]Z6?oo003ooookJ/7ooo]Z000^oookJPGo0000=ooonfXHool00?oooo]Z_ooonfX002ko
oo]Z1Ol0000ioookJQOoo`00oooonfZnoookJP00;_oonfX5o`0003_ooo]Z5_oo003ooookJ[gooo]Z
000^oookJPGo0000??oonfXFool00?oooo]Z_?oonfX002kooo]Z1Ol0000moookJQOoo`00oooonfZj
oookJP00;_oonfX5o`0003oooo]Z5_oo003ooookJ[Wooo]Z000^oookJPGo0000@?oonfXFool00?oo
oo]Z^?oonfX002kooo]Z1Ol00012oookJQGoo`00oooonfZgoookJP00;_oonfX5o`0004?ooo]Z5Ooo
003ooookJ[Kooo]Z000^oookJPGo0000A?oonfXEool00?oooo]Z]OoonfX002kooo]Z1Ol00016oook
JQ?oo`00oooonfZeoookJP00;_oonfX5o`0004Oooo]Z4ooo003ooookJ[Cooo]Z000^oookJPGo0000
B?oonfXCool00?oooo]Z/ooonfX002kooo]Z1Ol00019oookJQ?oo`00oooonfZboookJP00;_oonfX5
o`0004_ooo]Z4_oo003ooookJ[7ooo]Z000^oookJPGo0000C?oonfXBool00?oooo]Z/?oonfX002ko
oo]Z1Ol0001=oookJQ;oo`00oooonfZ_oookJP00;_oonfX5o`0004kooo]Z4_oo003ooookJZkooo]Z
000^oookJPGo0000CooonfXBool00?oooo]Z[OoonfX002kooo]Z1Ol0001?oookJQ?oo`00oooonfZ/
oookJP00;_oonfX5o`00053ooo]Z4ooo003ooookJZ_ooo]Z000^oookJPGo0000DOoonfXCool00?oo
oo]ZZ_oonfX002kooo]Z1Ol0001BoookJQ;oo`00oooonfZZoookJP00;_oonfX5o`0005?ooo]Z4_oo
003ooookJZWooo]Z000^oookJPGo0000E?oonfXBool00?oooo]ZZ?oonfX002kooo]Z1Ol0001Eoook
JQ;oo`00oooonfZWoookJP00;_oonfX5o`0005Kooo]Z4_oo003ooookJZKooo]Z000^oookJPGo0000
EooonfXBool00?oooo]ZYOoonfX002kooo]Z1Ol0001HoookJQ;oo`00oooonfZToookJP00;_oonfX5
o`0005Wooo]Z4_oo003ooookJZ?ooo]Z000^oookJPGo0000F_oonfXBool00?oooo]ZX_oonfX002ko
oo]Z1Ol0001JoookJQ?oo`00oooonfZQoookJP00;_oonfX5o`0005_ooo]Z4ooo003ooookJZ3ooo]Z
000^oookJPGo0000G?oonfXBool00?oooo]ZX?oonfX002kooo]Z1Ol0001MoookJQ;oo`00oooonfZO
oookJP00;_oonfX5o`0005kooo]Z4_oo003ooookJYkooo]Z000^oookJPGo0000GooonfXAool00?oo
oo]ZW_oonfX002kooo]Z1Ol0001PoookJQ7oo`00oooonfZMoookJP00;_oonfX5o`00067ooo]Z4Ooo
003ooookJYcooo]Z000^oookJPGo0000H_oonfX@ool00?oooo]ZW?oonfX002kooo]Z1Ol0001Soook
JQ3oo`00oooonfZKoookJP00;_oonfX5o`0006Cooo]Z4?oo003ooookJY[ooo]Z000^oookJPGo0000
I?oonfX@ool00?oooo]ZV_oonfX001?ooo]Z0ol007l4oookJP?o001o0ooonfX5o`00O`Wooo]Z1Ol0
001UoookJQ3oo`00oooonfZIoookJP004ooonfX3o`00O`Cooo]Z0ol007l2oookJPOo001o2?oonfX5
o`0006Kooo]Z4?oo003ooookJYSooo]Z000CoookJP?o001o1?oonfX3o`00O`03oookJ_l007oo001o
00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0006Kooo]Z4?oo003ooookJYSooo]Z0003oook
JP[o001o1_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o001o1ooonfX5o`0006Oooo]Z4?oo003ooook
JYOooo]Z0003oookJP[o001o1_oonfX3o`00O`kooo]Z0ol007l7oookJPOo0000I_oonfX@ool00?oo
oo]ZU_oonfX001?ooo]Z0ol007l>oookJP?o001o1ooonfX5o`0006Sooo]Z4?oo003ooookJYKooo]Z
000CoookJP?o001o2OoonfX2o`00O`;ooo]Z1?l007l7oookJPGo0000JOoonfX@ool00?oooo]ZUOoo
nfX001?ooo]Z0ol007l9oookJPOo001o2?oonfX5o`0006[ooo]Z3ooo003ooookJYGooo]Z000Coook
JP?o001o2OoonfX6o`00O`Wooo]Z1Ol0001ZoookJQ3oo`00oooonfZDoookJP004?oonfX6o`00O`Wo
oo]Z0_l007l=oookJPGo0000JooonfX@ool00?oooo]ZTooonfX0013ooo]Z1_l007l9oookJP;o001o
3OoonfX5o`0006cooo]Z3ooo003ooookJY?ooo]Z000BoookJPCo001o2_oonfX7o`00O`Oooo]Z1Ol0
001/oookJQ3oo`00oooonfZBoookJP004ooonfX3o`00O`[ooo]Z1ol007l7oookJPGo0000KOoonfX@
ool00?oooo]ZTOoonfX002kooo]Z1Ol0001^oookJPooo`00oooonfZAoookJP00;_oonfX5o`0006ko
oo]Z4?oo003ooookJY3ooo]Z000^oookJPGo0000KooonfX@ool00?oooo]ZSooonfX002kooo]Z1Ol0
001_oookJQ3oo`00oooonfZ?oookJP00;_oonfX5o`00073ooo]Z4?oo003ooookJXkooo]Z000^oook
JPGo0000LOoonfX@ool00?oooo]ZSOoonfX002kooo]Z1Ol0001aoookJQ3oo`00oooonfZ=oookJP00
;_oonfX5o`0007;ooo]Z4?oo003ooookJXcooo]Z000^oookJPGo0000LooonfX@ool00?oooo]ZRooo
nfX002kooo]Z1Ol0001coookJQ3oo`00oooonfZ;oookJP00;_oonfX5o`0007Cooo]Z4?oo003ooook
JX[ooo]Z000^oookJPGo0000MOoonfX?ool00?oooo]ZR_oonfX002kooo]Z1Ol0001eoookJQ3oo`00
oooonfZ9oookJP00;_oonfX5o`0007Kooo]Z4?oo003ooookJXSooo]Z000^oookJPGo0000MooonfX?
ool00?oooo]ZR?oonfX002kooo]Z1Ol0001goookJQ3oo`00oooonfZ7oookJP00;_oonfX5o`0007So
oo]Z3ooo003ooookJXOooo]Z000^oookJPGo0000NOoonfX?ool00?oooo]ZQ_oonfX002kooo]Z1Ol0
001ioookJPooo`00oooonfZ6oookJP00;_oonfX5o`0007[ooo]Z3ooo003ooookJXGooo]Z000^oook
JPGo0000N_oonfX@ool00?oooo]ZQ?oonfX002kooo]Z1Ol0001koookJPooo`00oooonfZ4oookJP00
;_oonfX5o`0007cooo]Z3ooo003ooookJX?ooo]Z000^oookJPGo0000O?oonfX?ool00?oooo]ZPooo
nfX002kooo]Z1Ol0001moookJPooo`00oooonfZ2oookJP00;_oonfX5o`0007gooo]Z3ooo003ooook
JX;ooo]Z000^oookJPGo0000O_oonfX?ool00?oooo]ZPOoonfX002kooo]Z1Ol0001noookJQ3oo`00
oooonfZ0oookJP00;_oonfX5o`0007oooo]Z3ooo003ooookJX3ooo]Z000^oookJPGo0000P?oonfX?
ool00?oooo]ZOooonfX002kooo]Z1Ol00020oookJPooo`00oooonfYooookJP00;_oonfX5o`00087o
oo]Z3ooo003ooookJWkooo]Z000^oookJPGo0000POoonfX?ool00?oooo]ZO_oonfX002kooo]Z1Ol0
0022oookJPooo`00oooonfYmoookJP00;_oonfX5o`0008;ooo]Z3ooo003ooookJWgooo]Z000^oook
JPGo0000PooonfX?ool00?oooo]ZO?oonfX002kooo]Z1Ol00024oookJPooo`00oooonfYkoookJP00
;_oonfX5o`0008Cooo]Z3ooo003ooookJW_ooo]Z000^oookJPGo0000QOoonfX?ool00?oooo]ZN_oo
nfX002kooo]Z1Ol00025oookJPooo`00oooonfYjoookJP00;_oonfX5o`0008Kooo]Z3ooo003ooook
JWWooo]Z000^oookJPGo0000Q_oonfX?ool00?oooo]ZNOoonfX002kooo]Z1Ol00027oookJPooo`00
oooonfYhoookJP00;_oonfX5o`0008Oooo]Z4?oo003ooookJWOooo]Z000^oookJPGo0000R?oonfX?
ool00?oooo]ZMooonfX002kooo]Z1Ol00029oookJPooo`00oooonfYfoookJP00;_oonfX5o`0008Wo
oo]Z3ooo003ooookJWKooo]Z000^oookJPGo0000R_oonfX?ool00?oooo]ZMOoonfX002kooo]Z1Ol0
002:oookJPooo`00oooonfYeoookJP00;_oonfX5o`0008_ooo]Z3ooo003ooookJWCooo]Z000^oook
JPGo0000RooonfX?ool00?oooo]ZM?oonfX002kooo]Z1Ol0002<oookJPooo`00oooonfYcoookJP00
;?oonfX=o`1o08Oooo]Z3_oo003ooookJW?ooo]Z000/oookJQ[o07l0N_oonfX?ool00?oooo]ZL_oo
nfX002cooo]Z9_l0O`1_oookJPkoo`00oooonfYboookJP00;?oonfXZo`1o06_ooo]Z3ooo003ooook
JW7ooo]Z000/oookJRko07l0J?oonfX>ool00?oooo]ZLOoonfX002cooo]Z<Ol0O`1UoookJPooo`00
oooonfY`oookJP00;?oonfXeo`1o06;ooo]Z3_oo003ooookJW3ooo]Z000/oookJSWo07l0G_oonfX?
ool00?oooo]ZKooonfX002kooo]Z1?l0000fo`1o05cooo]Z3_oo003ooookJVoooo]Z000^oookJPGo
00003?oonfX]o`1o05Sooo]Z3ooo003ooookJVkooo]Z000^oookJPGo00006?oonfXUo`1o05Gooo]Z
3_oo003ooookJVkooo]Z000^oookJPGo00007?oonfXTo`1o05;ooo]Z3ooo003ooookJVgooo]Z000^
oookJPGo00008?oonfXSo`1o053ooo]Z3_oo003ooookJVgooo]Z000^oookJPGo00008ooonfXRo`1o
04kooo]Z3ooo003ooookJVcooo]Z000^oookJPGo00009ooonfXPo`1o04gooo]Z3_oo003ooookJVco
oo]Z000^oookJPGo0000:ooonfXNo`1o04_ooo]Z3ooo003ooookJV_ooo]Z000^oookJPGo0000;_oo
nfXMo`1o04[ooo]Z3ooo003ooookJV[ooo]Z000RoookJP?o001o2OoonfX5o`0003;ooo]Z6ol0O`18
oookJPooo`00oooonfYZoookJP008_oonfX3o`00O`Wooo]Z1Ol0000foookJQWo07l0AooonfX?ool0
0?oooo]ZJOoonfX002;ooo]Z0ol007l9oookJPGo0000>OoonfXHo`1o04Gooo]Z3ooo003ooookJVWo
oo]Z000BoookJP[o001o1_oonfX3o`00O`Wooo]Z1Ol0000loookJQOo07l0A?oonfX?ool00?oooo]Z
J?oonfX001;ooo]Z2_l007l6oookJP?o001o2OoonfX7o`0003cooo]Z5ol0O`12oookJPooo`00oooo
nfYXoookJP008_oonfX3o`00O`Wooo]Z1Ol00010oookJQOo07l0@OoonfX?ool00?oooo]ZIooonfX0
02;ooo]Z0ol007l9oookJPGo0000@_oonfXGo`1o03oooo]Z3ooo003ooookJVOooo]Z000RoookJP?o
001o2OoonfX5o`0004Cooo]Z5_l0O`0ooookJPooo`00oooonfYVoookJP008_oonfX3o`00O`Wooo]Z
1Ol00016oookJQKo07l0?_oonfX>ool00?oooo]ZI_oonfX001oooo]Z1_l007l9oookJPGo0000B?oo
nfXEo`1o03gooo]Z3ooo003ooookJVGooo]Z000OoookJPKo001o2OoonfX5o`0004[ooo]Z5Ol0O`0l
oookJPkoo`00oooonfYUoookJP008OoonfX4o`00O`Wooo]Z1Ol0001<oookJQCo07l0>ooonfX?ool0
0?oooo]ZI?oonfX002;ooo]Z0ol007l9oookJPGo0000C_oonfXDo`1o03[ooo]Z3_oo003ooookJVCo
oo]Z000^oookJPGo0000D?oonfXCo`1o03Wooo]Z3ooo003ooookJV?ooo]Z000^oookJPGo0000D_oo
nfXCo`1o03Sooo]Z3_oo003ooookJV?ooo]Z000^oookJPGo0000DooonfXCo`1o03Oooo]Z3ooo003o
oookJV;ooo]Z000^oookJPGo0000EOoonfXCo`1o03Kooo]Z3_oo003ooookJV;ooo]Z000^oookJPGo
0000E_oonfXCo`1o03Gooo]Z3ooo003ooookJV7ooo]Z000^oookJPGo0000F?oonfXCo`1o03Cooo]Z
3_oo003ooookJV7ooo]Z000^oookJPGo0000FOoonfXCo`1o03?ooo]Z3ooo003ooookJV3ooo]Z000^
oookJPGo0000FooonfXCo`1o03;ooo]Z3_oo003ooookJV3ooo]Z000^oookJPGo0000G?oonfXCo`1o
037ooo]Z3ooo003ooookJUoooo]Z000^oookJPGo0000G_oonfXBo`1o037ooo]Z3_oo003ooookJUoo
oo]Z000^oookJPGo0000GooonfXBo`1o033ooo]Z3ooo003ooookJUkooo]Z000^oookJPGo0000HOoo
nfXBo`1o02oooo]Z3_oo003ooookJUkooo]Z000^oookJPGo0000H_oonfXBo`1o02kooo]Z3ooo003o
oookJUgooo]Z000^oookJPGo0000I?oonfXAo`1o02kooo]Z3_oo003ooookJUgooo]Z000^oookJPGo
0000IOoonfXAo`1o02gooo]Z3ooo003ooookJUcooo]Z000^oookJPGo0000IooonfX@o`1o02gooo]Z
3_oo003ooookJUcooo]Z000^oookJPGo0000J?oonfXAo`1o02_ooo]Z3ooo003ooookJU_ooo]Z000^
oookJPGo0000JOoonfXAo`1o02_ooo]Z3ooo003ooookJU[ooo]Z000^oookJPGo0000J_oonfXAo`1o
02[ooo]Z3ooo003ooookJU[ooo]Z000^oookJPGo0000K?oonfX@o`1o02[ooo]Z3ooo003ooookJUWo
oo]Z000^oookJPGo0000KOoonfXAo`1o02Sooo]Z3ooo003ooookJUWooo]Z000^oookJPGo0000K_oo
nfXAo`1o02Sooo]Z3ooo003ooookJUSooo]Z000^oookJPGo0000KooonfXAo`1o02Oooo]Z3ooo003o
oookJUSooo]Z000^oookJPGo0000L?oonfXAo`1o02Oooo]Z3ooo003ooookJUOooo]Z000^oookJPGo
0000L_oonfX@o`1o02Kooo]Z3ooo003ooookJUOooo]Z000^oookJPGo0000LooonfX@o`1o02Kooo]Z
3ooo003ooookJUKooo]Z000^oookJPGo0000M?oonfX@o`1o02Kooo]Z3_oo003ooookJUKooo]Z000^
oookJPGo0000MOoonfX@o`1o02Gooo]Z3ooo003ooookJUGooo]Z000^oookJPGo0000MooonfX?o`1o
02Gooo]Z3_oo003ooookJUGooo]Z000^oookJPGo0000N?oonfX?o`1o02Cooo]Z3ooo003ooookJUCo
oo]Z000^oookJPGo0000NOoonfX?o`1o02Cooo]Z3_oo003ooookJUCooo]Z000^oookJPGo0000N_oo
nfX?o`1o02?ooo]Z3ooo003ooookJU?ooo]Z000^oookJPGo0000NooonfX?o`1o02?ooo]Z3_oo003o
oookJU?ooo]Z000^oookJPGo0000O?oonfX?o`1o02;ooo]Z3ooo003ooookJU;ooo]Z000^oookJPGo
0000OOoonfX?o`1o02;ooo]Z3_oo003ooookJU;ooo]Z000^oookJPGo0000O_oonfX?o`1o027ooo]Z
3ooo003ooookJU7ooo]Z000^oookJPGo0000OooonfX?o`1o027ooo]Z3_oo003ooookJU7ooo]Z000^
oookJPGo0000P?oonfX?o`1o023ooo]Z3ooo003ooookJU3ooo]Z000^oookJPGo0000POoonfX?o`1o
023ooo]Z3ooo003ooookJToooo]Z000^oookJPGo0000P_oonfX?o`1o01oooo]Z3ooo003ooookJToo
oo]Z000^oookJPGo0000PooonfX?o`1o01oooo]Z3ooo003ooookJTkooo]Z000^oookJPGo0000Q?oo
nfX?o`1o01kooo]Z3ooo003ooookJTkooo]Z000^oookJPGo0000QOoonfX?o`1o01kooo]Z3ooo003o
oookJTgooo]Z000^oookJQgo003oK_oonfX?o`1o01gooo]Z3ooo003ooookJTgooo]Z000^oookJRSo
003oI?oonfX?o`1o01gooo]Z3ooo003ooookJTcooo]Z000^oookJRgo003oH?oonfX?o`1o01cooo]Z
3ooo003ooookJTcooo]Z000^oookJS?o003oFooonfX?o`1o01cooo]Z3ooo003ooookJT_ooo]Z000^
oookJSSo003oEooonfX?o`1o01cooo]Z3_oo003ooookJT_ooo]Z000^oookJPGo00005?oonfXUo`00
oe;ooo]Z3ol0O`0KoookJPooo`00oooonfY:oookJP00;_oonfX5o`0001oooo]Z7ol00?m>oookJPoo
07l06ooonfX?ool00?oooo]ZBOoonfX002kooo]Z1Ol0000ToookJQoo003oB_oonfX?o`1o01[ooo]Z
3ooo003ooookJTWooo]Z000^oookJPGo0000:_oonfXLo`00odSooo]Z3ol0O`0JoookJPooo`00oooo
nfY8oookJP00;_oonfX5o`0002oooo]Z6_l00?m6oookJPoo07l06OoonfX@ool00?oooo]ZAooonfX0
02kooo]Z1Ol0000eoookJQOo003oA?oonfX?o`1o01Wooo]Z3ooo003ooookJTOooo]Z000^oookJPGo
0000>_oonfXEo`00od;ooo]Z3ol0O`0HoookJQ3oo`00oooonfY6oookJP00;_oonfX5o`0003oooo]Z
4ol00?m0oookJPoo07l06?oonfX?ool00?oooo]ZA_oonfX002kooo]Z1Ol00012oookJQ?o003o?_oo
nfX?o`1o01Oooo]Z4?oo003ooookJTGooo]Z000^oookJPGo0000AOoonfXCo`00occooo]Z3ol0O`0G
oookJQ3oo`00oooonfY4oookJP00;_oonfX5o`0004Sooo]Z4ol00?ljoookJPoo07l05ooonfX?ool0
0?oooo]ZA?oonfX002kooo]Z1Ol0001;oookJQ?o003o>?oonfX?o`1o01Kooo]Z4?oo003ooookJT?o
oo]Z000^oookJPGo0000C_oonfXBo`00ocOooo]Z3ol0O`0FoookJQ3oo`00oooonfY2oookJP00;_oo
nfX5o`00057ooo]Z4_l00?leoookJPoo07l05_oonfX?ool00?oooo]Z@_oonfX002kooo]Z1Ol0001D
oookJQ7o003o=?oonfX?o`1o01Gooo]Z4?oo003ooookJT7ooo]Z000^oookJPGo0000EooonfXAo`00
oc;ooo]Z3ol0O`0EoookJQ3oo`00oooonfY0oookJP00;_oonfX5o`0005[ooo]Z4Ol00?l`oookJPoo
07l05?oonfX@ool00?oooo]Z@?oonfX002kooo]Z1Ol0001LoookJQ7o003o;ooonfX?o`1o01Cooo]Z
4?oo003ooookJSoooo]Z000^oookJPGo0000GooonfX@o`00obkooo]Z3ol0O`0DoookJQ3oo`00oooo
nfXnoookJP00;_oonfX5o`00067ooo]Z4?l00?l]oookJQ3o07l04_oonfX@ool00?oooo]Z?_oonfX0
02kooo]Z1Ol0001ToookJPoo003o;?oonfX@o`1o01;ooo]Z4?oo003ooookJSgooo]Z000^oookJPGo
0000IooonfX>o`00ob_ooo]Z4?l0O`0BoookJQ3oo`00oooonfXloookJP004OoonfX5o`00O`Cooo]Z
0ol007l3oookJPGo001o2OoonfX5o`0006Wooo]Z3_l00?lZoookJQ3o07l04OoonfX@ool00?oooo]Z
??oonfX0013ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Sooo]Z1Ol0001[oookJPko003o:Ooo
nfX@o`1o017ooo]Z4?oo003ooookJS_ooo]Z000@oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0006gooo]Z
3_l00?lXoookJQ3o07l04OoonfX?ool00?oooo]Z>ooonfX000?ooo]Z2_l007l2oookJP?o001o0ooo
nfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1ooonfX5o`0006oooo]Z3_l00?lWoookJQ3o07l04?oo
nfX@ool00?oooo]Z>_oonfX000?ooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7
oookJPOo0000KooonfX>o`00obKooo]Z4?l0O`0@oookJQ3oo`00oooonfXioookJP003ooonfX3o`00
O`?ooo]Z0ol007l<oookJP?o001o1ooonfX5o`0007?ooo]Z3_l00?lVoookJPoo07l04?oonfX?ool0
0?oooo]Z>OoonfX000oooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l7oookJPGo
0000MOoonfX>o`00obGooo]Z3ol0O`0?oookJQ3oo`00oooonfXhoookJP003ooonfX3o`00O`?ooo]Z
0ol007l7oookJPOo001o2?oonfX5o`0007Oooo]Z3_l00?lToookJPoo07l03ooonfX@ool00?oooo]Z
=ooonfX000oooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`Wooo]Z1Ol0001ioookJPgo003o9?oo
nfX?o`1o00oooo]Z3ooo003ooookJSOooo]Z000?oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l=
oookJPGo0000NooonfX=o`00ob?ooo]Z3ol0O`0>oookJQ3oo`00oooonfXfoookJP004?oonfX3o`00
O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007l=oookJPGo0000OOoonfX=o`00ob;ooo]Z3ol0O`0>
oookJQ3oo`00oooonfXeoookJP004?oonfX7o`00O`Wooo]Z1ol007l7oookJPGo0000OooonfX=o`00
ob7ooo]Z3ol0O`0=oookJQ7oo`00oooonfXdoookJP004OoonfX5o`00O`[ooo]Z1ol007l7oookJPGo
0000POoonfX<o`00ob7ooo]Z3ol0O`0=oookJQ7oo`00oooonfXcoookJP00;_oonfX5o`0008;ooo]Z
3Ol00?lPoookJPoo07l03OoonfXAool00?oooo]Z<_oonfX002kooo]Z1Ol00024oookJPgo003o7ooo
nfX?o`1o00cooo]Z4_oo003ooookJS7ooo]Z000^oookJP03o`000?oo0?ooo`3o01;oo`3oM_oonfX=
o`00oakooo]Z3ol0O`0<oookJQ7oo`00oooonfXaoookJP00;_oonfX00ol0003oo`3oool0o`0Vool0
ofCooo]Z3?l00?lNoookJPoo07l03?oonfXAool00?oooo]Z<?oonfX002kooo]Z1Ol0000?oookJQgo
o`3oGOoonfX=o`00oagooo]Z3ol0O`0;oookJQ;oo`00oooonfX_oookJP00;_oonfX5o`0002?ooo]Z
3_oo0?mJoookJPgo003o7?oonfX@o`1o00[ooo]Z4_oo003ooookJRkooo]Z000^oookJPGo0000:ooo
nfX?ool0oe?ooo]Z3Ol00?lKoookJQ3o07l02_oonfXBool00?oooo]Z;OoonfX002kooo]Z1Ol0000`
oookJQ;oo`3oCOoonfX<o`00oa_ooo]Z4?l0O`0:oookJQ;oo`00oooonfX/oookJP00;_oonfX5o`00
03Wooo]Z3_oo0?m9oookJPgo003o6_oonfX@o`1o00[ooo]Z4_oo003ooookJR_ooo]Z000^oookJPGo
0000@OoonfX<ool0odGooo]Z3Ol00?lIoookJQ3o07l02_oonfXAool00?oooo]Z:ooonfX002kooo]Z
1Ol00016oookJPcoo`3o@_oonfX=o`00oaSooo]Z4?l0O`0:oookJQ7oo`00oooonfXZoookJP00;_oo
nfX5o`0004cooo]Z2ooo0?looookJPco003o6?oonfXAo`1o00Sooo]Z4_oo003ooookJRWooo]Z000^
oookJPGo0000DOoonfX9ool0ocgooo]Z3Ol00?lGoookJQ7o07l02?oonfXBool00?oooo]Z:?oonfX0
02kooo]Z1Ol0001FoookJPSoo`3o>ooonfX=o`00oaOooo]Z4?l0O`08oookJQ;oo`00oooonfXWoook
JP00;_oonfX5o`0005Wooo]Z2?oo0?ljoookJPgo003o5_oonfX@o`1o00Sooo]Z4_oo003ooookJRKo
oo]Z000^oookJPGo0000GOoonfX8ool0ocSooo]Z3?l00?lFoookJQ3o07l02?oonfXBool00?oooo]Z
9OoonfX002kooo]Z1Ol0001PoookJPSoo`3o=_oonfX=o`00oaGooo]Z4?l0O`08oookJQ;oo`00oooo
nfXToookJP00;_oonfX5o`0006Cooo]Z2?oo0?ldoookJPgo003o5?oonfXAo`1o00Oooo]Z4_oo003o
oookJR?ooo]Z000^oookJPGo0000IooonfX9ool0oc;ooo]Z3Ol00?lCoookJQ7o07l01_oonfXCool0
0?oooo]Z8_oonfX002kooo]Z1Ol0001[oookJPSoo`3o<OoonfX=o`00oa?ooo]Z4?l0O`06oookJQCo
o`00oooonfXPoookJP00;_oonfX5o`0006oooo]Z2?oo0?l^oookJPgo003o4ooonfX@o`1o00Kooo]Z
5?oo003ooookJQoooo]Z000^oookJPGo0000L_oonfX9ool0obcooo]Z3Ol00?lBoookJQ3o07l01_oo
nfXDool00?oooo]Z7_oonfX002kooo]Z1Ol0001foookJPSoo`3o:ooonfX=o`00oa7ooo]Z4?l0O`06
oookJQGoo`00oooonfXLoookJP00;_oonfX5o`0007[ooo]Z2?oo0?lYoookJPgo003o4?oonfXAo`1o
00Gooo]Z5Ooo003ooookJQ_ooo]Z000^oookJPGo0000OOoonfX8ool0obSooo]Z3Ol00?l?oookJQ7o
07l01OoonfXEool00?oooo]Z6_oonfX002kooo]Z1Ol00021oookJPOoo`3o9_oonfX>o`00o`oooo]Z
4Ol0O`04oookJQKoo`00oooonfXHoookJP00;_oonfX5o`0008Cooo]Z1ooo0?lUoookJPgo003o3ooo
nfXBo`1o00?ooo]Z5_oo003ooookJQOooo]Z000^oookJPGo0000QooonfX7ool0obCooo]Z3Ol00?l>
oookJQ;o07l00ooonfXFool00?oooo]Z5_oonfX002kooo]Z1Ol0002:oookJPOoo`3o8ooonfX=o`00
o`gooo]Z4ol0O`02oookJQKoo`00oooonfXEoookJP00;_oonfX5o`0008gooo]Z1ooo0?lRoookJPgo
003o3?oonfXDo`1o00;ooo]Z5_oo003ooookJQ?ooo]Z000^oookJPGo0000T?oonfX7ool0ob7ooo]Z
3Ol00?l;oookJQCo07l00_oonfXFool00?oooo]Z4_oonfX002kooo]Z1Ol0002CoookJPOoo`3o7ooo
nfX>o`00o`_ooo]Z5?l0O`000ooonf[oo`00ool0000Dool00?oooo]Z4OoonfX002kooo]Z1Ol0002F
oookJPOoo`3o7_oonfX>o`00o`[ooo]Z5?l0O`02oookJQKoo`00oooonfX?oookJP00;_oonfX5o`00
09Wooo]Z1ooo0?lMoookJPko003o2_oonfXDo`1o0003oookJ_oo003oo`0001Coo`00oooonfX>oook
JP00;_oonfX5o`0009cooo]Z1ooo0?lLoookJPoo003o2OoonfXDo`1o01Koo`00oooonfX=oookJP00
;_oonfX5o`0009oooo]Z1ooo0?lKoookJPoo003o2?oonfXDo`1o0003oookJ_oo003oo`0001Coo`00
oooonfX;oookJP00;_oonfX5o`000:;ooo]Z1ooo0?lJoookJPoo003o2?oonfXDo`1o01Ooo`00oooo
nfX9oookJP00;_oonfX5o`000:Gooo]Z1ooo0?lIoookJPoo003o2?oonfXDo`1o01Koo`00oooonfX8
oookJP00;_oonfX5o`000:Sooo]Z1ooo0?lHoookJPoo003o1ooonfXEo`1o01Koo`00oooonfX6oook
JP00;_oonfX5o`000:_ooo]Z1ooo0?lHoookJPko003o1ooonfXEo`1o01Koo`00oooonfX4oookJP00
;_oonfX5o`000:kooo]Z1ooo0?lGoookJPoo003o1OoonfXFo`1o01Goo`00oooonfX3oookJP00;_oo
nfX5o`000;7ooo]Z1ooo0?lFoookJQ3o003o1?oonfXGo`1o01Coo`00oooonfX1oookJP00;_oonfX5
o`000;Cooo]Z1ooo0?lEoookJQ3o003o1?oonfXGo`1o01Coo`00o_oonfX002kooo]Z1Ol0002goook
JPOoo`3o5?oonfXAo`00o`;ooo]Z6?l0O`0Eool00?_ooo]Z000^oookJPGo0000^_oonfX8ool0oa;o
oo]Z4Ol00?l2oookJQSo07l05Ooo003ioookJP00;_oonfX5o`000;gooo]Z2?oo0?lBoookJQ7o003o
00?ooo]Zo`1o0?l0O`005_l0O`0Eool00?Oooo]Z000^oookJPGo0000`OoonfX7ool0oa;ooo]Z4Ol0
0?lIo`1o01Coo`00mOoonfX002kooo]Z1Ol00034oookJPOoo`3o4OoonfXBo`00oaWo07l05?oo003b
oookJP00;_oonfX5o`000<Oooo]Z1ooo0?lAoookJQ;o003o6Ol0O`0Dool00>oooo]Z000^oookJPGo
0000b_oonfX7ool0oa3ooo]Z5?l00?lHo`1o01Coo`00k?oonfX002kooo]Z1Ol0003=oookJPOoo`3o
4?oonfXDo`00oaSo07l04ooo003ZoookJP00;_oonfX5o`000=3ooo]Z1ooo0?l@oookJQGo003o5ol0
O`0Cool00>Oooo]Z000^oookJPGo0000B?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001oB_oonfX3
o`00Ob[ooo]Z2?oo0?l?oookJQGo003o5ol0O`0Cool002Cooo]Z2Ol007m4oookJPWo001o0_oonfX3
o`00O`?ooo]Z1Ol007m9oookJPGo001o3ooonfX002kooo]Z1Ol00017oookJPOo001o0ooonfX3o`00
O`;ooo]Z1ol007m9oookJP?o001o;OoonfX:ool0o`gooo]Z5_l00?lFo`1o01?oo`008OoonfX9o`00
OdCooo]Z2Ol007l2oookJP?o001o0_oonfX7o`00OdOooo]Z1ol007l>oookJP00;_oonfX5o`0004Oo
oo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oo
nf[o001oo`00Ool007m9oookJP?o001o<OoonfX:ool0o`gooo]Z5_l00?lFo`1o01?oo`007OoonfX4
o`00OdWooo]Z1?l007l7oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool0
07m6oookJP?o001o0ooonfX3o`00O`gooo]Z000^oookJPGo0000A_oonfX3o`00O`?ooo]Z0ol007l6
oookJP?o001o0ooonfX3o`00OdSooo]Z0ol007lfoookJPWoo`3o3?oonfXHo`00oaGo07l05?oo000I
oookJPCo001oBOoonfX4o`00O`[ooo]Z0ol007l3oookJP?o001oAOoonfX3o`00O`?ooo]Z0ol007l=
oookJP00;_oonfX5o`0004Kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00OdSooo]Z0ol007ljoook
JP[oo`3o1ooonfX3o`00O`03oookJ_l00?oo003o01Ko003o5_l0O`0Dool001Gooo]Z1Ol007m8oook
JPGo001o3_oonfX3o`00Od_ooo]Z0ol007l=oookJP00;_oonfX5o`0004Kooo]Z0ol007l3oookJP?o
001o3?oonfX3o`00OdSooo]Z0ol007lnoookJP_oo`3o0_oonfX3o`00O`Cooo]Z6Ol00?lGo`1o01Co
o`004_oonfX4o`00OdWooo]Z1?l007l=oookJP?o001oBooonfX3o`00O`gooo]Z000^oookJPGo0000
A_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00OdSooo]Z0ol007m3oookJP_oo`3o
2?oonfXJo`00oaSo07l05?oo000=oookJP?o001oB_oonfX3o`00O`Sooo]Z0_l007l2oookJPCo001o
BOoonfX4o`00O`kooo]Z000^oookJPGo0000A_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001oBOoo
nfX3o`00OdSooo]Z2ooo0?l4oookJP?o001o6ol00?lJo`1o01;oo`002OoonfX3o`00Od[ooo]Z0ol0
07l7oookJPOo001oB_oonfX3o`00O`oooo]Z000^oookJPGo0000A_oonfX3o`00O`?ooo]Z0ol007l7
oookJPKo001oB_oonfX3o`00Od_ooo]Z0_l007l=ool0o`?o001o0_oonfXLo`00oa_o07l04Ooo0003
oookJP?o001oA?oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001oCOoonfX2o`00O`kooo]Z000^oook
JPGo0000A_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001oBooonfX6o`00OdSooo]Z1_l007l4oook
JPooo`3o0_oonfXMo`00oaco07l04?oo00000ol007oooo]ZoookJP12oookJP?o001o0ooonfX3o`00
O`Oooo]Z0_l007m;oookJP?o001o0ooonfX3o`00O`gooo]Z000^oookJPGo0000AooonfX3o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z0_l007m;oookJPKo001oB?oonfX6o`00O`Wooo]Z0_l007l?ool0
ob7o003o6?l0O`0Cool003gooo]Z1?l007l2oookJP?o001o1ooonfX2o`00Od_ooo]Z0ol007l3oook
JP?o001o3OoonfX002kooo]Z1Ol00017oookJPOo001o2OoonfX7o`00OdOooo]Z1?l007m:oookJPCo
001o2_oonfX7o`00O`03oookJ_oo0?ooo`3o00goo`3o9Ol00?lFo`1o01Goo`00<ooonfX7o`00O`Wo
oo]Z1ol007m6oookJPOo001o3_oonfX002kooo]Z1Ol00018oookJPGo001o2_oonfX7o`00OdSooo]Z
0ol007m;oookJP?o001o2_oonfX7o`00O`Sooo]Z3ooo0?lXo`00oa_o07l05ooo000SoookJPGo001o
2_oonfX7o`00OdOooo]Z1Ol007l?oookJP00;_oonfX5o`000?oooo]Z6?oonfX?ool0ob_o003o8Ol0
O`0Gool008Cooo]Z000^oookJPGo0000oooonfXOoookJQOoo`3o;?l00?lLo`1o02Ooo`00JOoonfX0
02kooo]Z1Ol0003ooookJRKooo]Z8?oo0?lbo`00ob[o07l0;_oo000noookJP00;_oonfX5o`000?oo
oo]Z=OoonfXKool0occo003o;?l0O`1:ool000cooo]Z000^oookJPGo0000oooonfXooookJPGo07l0
00?o003oool0oooo0?l06Ooo0?mGo`00od[o07l000?oo`00oookJ_oonfX02_oonfX002kooo]Z1Ol0
003ooookJTCooo]Z2_l0O`000ol00?ooo`3oool0o`0Uool0oh[o003o00?o07l0ool00?oonfX02ooo
nfX0027ooo]Zool0001Oo`00017o07l000?o003oool0oooo0?l0E?oo0?m;o`00o`03o`1o0?oo003o
000000[o00000OoonfX0027ooo]Zool0001Wo`0000Ooo`006?l0O`000ol00?ooo`3oool0o`27ool0
o`;o003o00?o07l0ool00?l000002_l00001oookJP008Ooonf[oo`0007;o00003?oo000Lo`1o02co
003oB_oo0?l2o`00o`03o`1o0?oo003o000000[o00000OoonfX0027ooo]Zool00023o`0000Koo`00
??l0O`1=o`00o`03o`1o0?oo003o000000[o00000OoonfX0027ooo]Zool0002Co`0001[oo`00I_l0
O`000ooo003o0000o`000009o`00007ooo]Z000^oookJPGo0000D_oonfX00ol0003ooo]ZoookJP1B
oookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP16
oookJQGoo`00D?l0O`000ooo003ooo]ZoookJP0:oookJP00;_oonfX5o`000?oooo]ZaooonfXkool0
00cooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z
000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oook
JPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z003ooookJ_oooo]Z
@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oo
oo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2
oookJP00oooonf[ooookJT;ooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-0.285647, -2.03831, \
0.00587203, 0.00607824}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The plot above shows the London potential vs. radial distance for ",
  StyleBox["z",
    FontSlant->"Italic"],
  " values equal to and larger than the cylinder height. The cylinder height \
is 1 and its radius is 1;.the potential is plotted for ",
  StyleBox["z",
    FontSlant->"Italic"],
  " = 1.1, ",
  StyleBox["z",
    FontSlant->"Italic"],
  " = 1.2, ",
  StyleBox["z",
    FontSlant->"Italic"],
  " = 1.3, and ",
  StyleBox["z",
    FontSlant->"Italic"],
  "= 1.4.  All these ",
  StyleBox["z",
    FontSlant->"Italic"],
  " values are beyond the end of the cylinder, and the potentials do not \
diverge at ",
  StyleBox["dist",
    FontSlant->"Italic"],
  " = 1. Note that unlike the previous plots, this one extends from ",
  StyleBox["dist",
    FontSlant->"Italic"],
  " = 0 to 3."
}], "Subsubsection"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell["\<\
The contour plot below would take an enormously long time to \
compute if we had not employed all of the ``integral tricks''\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ContourPlot[
      LondonCylinderPotential[dist, height, 1, 0.25], {dist, 0.001, 
        2}, {height, 0.001, 2}, Contours -> 25, 
      ColorFunction -> \((Hue[0.6\ #] &)\)]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0187498 0.48101 0.0187498 0.48101 [
[.01875 -0.0125 -7 -20 ]
[.01875 -0.0125 7 0 ]
[.25925 -0.0125 -14.5 -20 ]
[.25925 -0.0125 14.5 0 ]
[.49976 -0.0125 -7 -20 ]
[.49976 -0.0125 7 0 ]
[.74026 -0.0125 -14.5 -20 ]
[.74026 -0.0125 14.5 0 ]
[.98077 -0.0125 -7 -20 ]
[.98077 -0.0125 7 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01875 -14 -10 ]
[-0.0125 .01875 0 10 ]
[-0.0125 .25925 -29 -10 ]
[-0.0125 .25925 0 10 ]
[-0.0125 .49976 -14 -10 ]
[-0.0125 .49976 0 10 ]
[-0.0125 .74026 -29 -10 ]
[-0.0125 .74026 0 10 ]
[-0.0125 .98077 -14 -10 ]
[-0.0125 .98077 0 10 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01875 0 m
.01875 .00625 L
s
gsave
.01875 -0.0125 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.25925 0 m
.25925 .00625 L
s
gsave
.25925 -0.0125 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.49976 0 m
.49976 .00625 L
s
gsave
.49976 -0.0125 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.74026 0 m
.74026 .00625 L
s
gsave
.74026 -0.0125 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.98077 0 m
.98077 .00625 L
s
gsave
.98077 -0.0125 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.06685 0 m
.06685 .00375 L
s
.11495 0 m
.11495 .00375 L
s
.16305 0 m
.16305 .00375 L
s
.21115 0 m
.21115 .00375 L
s
.30736 0 m
.30736 .00375 L
s
.35546 0 m
.35546 .00375 L
s
.40356 0 m
.40356 .00375 L
s
.45166 0 m
.45166 .00375 L
s
.54786 0 m
.54786 .00375 L
s
.59596 0 m
.59596 .00375 L
s
.64406 0 m
.64406 .00375 L
s
.69216 0 m
.69216 .00375 L
s
.78837 0 m
.78837 .00375 L
s
.83647 0 m
.83647 .00375 L
s
.88457 0 m
.88457 .00375 L
s
.93267 0 m
.93267 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01875 m
.00625 .01875 L
s
gsave
-0.0125 .01875 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .25925 m
.00625 .25925 L
s
gsave
-0.0125 .25925 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .49976 m
.00625 .49976 L
s
gsave
-0.0125 .49976 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .74026 m
.00625 .74026 L
s
gsave
-0.0125 .74026 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
0 .98077 m
.00625 .98077 L
s
gsave
-0.0125 .98077 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .06685 m
.00375 .06685 L
s
0 .11495 m
.00375 .11495 L
s
0 .16305 m
.00375 .16305 L
s
0 .21115 m
.00375 .21115 L
s
0 .30736 m
.00375 .30736 L
s
0 .35546 m
.00375 .35546 L
s
0 .40356 m
.00375 .40356 L
s
0 .45166 m
.00375 .45166 L
s
0 .54786 m
.00375 .54786 L
s
0 .59596 m
.00375 .59596 L
s
0 .64406 m
.00375 .64406 L
s
0 .69216 m
.00375 .69216 L
s
0 .78837 m
.00375 .78837 L
s
0 .83647 m
.00375 .83647 L
s
0 .88457 m
.00375 .88457 L
s
0 .93267 m
.00375 .93267 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01875 .99375 m
.01875 1 L
s
.25925 .99375 m
.25925 1 L
s
.49976 .99375 m
.49976 1 L
s
.74026 .99375 m
.74026 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.06685 .99625 m
.06685 1 L
s
.11495 .99625 m
.11495 1 L
s
.16305 .99625 m
.16305 1 L
s
.21115 .99625 m
.21115 1 L
s
.30736 .99625 m
.30736 1 L
s
.35546 .99625 m
.35546 1 L
s
.40356 .99625 m
.40356 1 L
s
.45166 .99625 m
.45166 1 L
s
.54786 .99625 m
.54786 1 L
s
.59596 .99625 m
.59596 1 L
s
.64406 .99625 m
.64406 1 L
s
.69216 .99625 m
.69216 1 L
s
.78837 .99625 m
.78837 1 L
s
.83647 .99625 m
.83647 1 L
s
.88457 .99625 m
.88457 1 L
s
.93267 .99625 m
.93267 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01875 m
1 .01875 L
s
.99375 .25925 m
1 .25925 L
s
.99375 .49976 m
1 .49976 L
s
.99375 .74026 m
1 .74026 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .06685 m
1 .06685 L
s
.99625 .11495 m
1 .11495 L
s
.99625 .16305 m
1 .16305 L
s
.99625 .21115 m
1 .21115 L
s
.99625 .30736 m
1 .30736 L
s
.99625 .35546 m
1 .35546 L
s
.99625 .40356 m
1 .40356 L
s
.99625 .45166 m
1 .45166 L
s
.99625 .54786 m
1 .54786 L
s
.99625 .59596 m
1 .59596 L
s
.99625 .64406 m
1 .64406 L
s
.99625 .69216 m
1 .69216 L
s
.99625 .78837 m
1 .78837 L
s
.99625 .83647 m
1 .83647 L
s
.99625 .88457 m
1 .88457 L
s
.99625 .93267 m
1 .93267 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 1 .16 r
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
0 1 .304 r
.01923 .76149 m
.05929 .76097 L
.09936 .75941 L
.13942 .75682 L
.17949 .75316 L
.21955 .74843 L
.25962 .74258 L
.27294 .74038 L
.29968 .73542 L
.33974 .72692 L
.37981 .71711 L
.41987 .70595 L
.43836 .70032 L
.45994 .69312 L
.5 .67847 L
.54006 .66216 L
.54447 .66026 L
.58013 .64348 L
.62019 .62269 L
.62473 .62019 L
.66026 .59901 L
.68936 .58013 L
.70032 .57245 L
.74038 .54227 L
.74313 .54006 L
.78045 .50767 L
.78864 .5 L
.82051 .46772 L
.82763 .45994 L
.86058 .42073 L
.86124 .41987 L
.89005 .37981 L
.90064 .36361 L
.9148 .33974 L
.93608 .29968 L
.94071 .29011 L
.95422 .25962 L
.96906 .21955 L
.98059 .17949 L
.98077 .17877 L
.98077 .98077 L
.01923 .98077 L
F
0 g
.01923 .76149 m
.05929 .76097 L
.09936 .75941 L
.13942 .75682 L
.17949 .75316 L
.21955 .74843 L
.25962 .74258 L
.27294 .74038 L
.29968 .73542 L
.33974 .72692 L
.37981 .71711 L
.41987 .70595 L
.43836 .70032 L
.45994 .69312 L
.5 .67847 L
.54006 .66216 L
.54447 .66026 L
.58013 .64348 L
.62019 .62269 L
.62473 .62019 L
.66026 .59901 L
.68936 .58013 L
.70032 .57245 L
.74038 .54227 L
.74313 .54006 L
.78045 .50767 L
.78864 .5 L
.82051 .46772 L
.82763 .45994 L
.86058 .42073 L
.86124 .41987 L
.89005 .37981 L
.90064 .36361 L
.9148 .33974 L
.93608 .29968 L
.94071 .29011 L
.95422 .25962 L
.96906 .21955 L
.98059 .17949 L
.98077 .17877 L
s
0 1 .016 r
.01923 .49768 m
.05929 .49732 L
.09936 .49625 L
.13942 .49442 L
.17949 .49178 L
.21955 .48824 L
.25962 .48371 L
.29968 .47808 L
.33974 .47126 L
.37981 .46317 L
.39422 .45994 L
.41987 .4529 L
.45994 .44026 L
.5 .42574 L
.5149 .41987 L
.54006 .40785 L
.58013 .3865 L
.59175 .37981 L
.62019 .36032 L
.64741 .33974 L
.66026 .32853 L
.6899 .29968 L
.70032 .2882 L
.72284 .25962 L
.74038 .23443 L
.74879 .21955 L
.76878 .17949 L
.78045 .15144 L
.78395 .13942 L
.79354 .09936 L
.79957 .05929 L
.80165 .01923 L
.01923 .01923 L
F
0 g
.01923 .49768 m
.05929 .49732 L
.09936 .49625 L
.13942 .49442 L
.17949 .49178 L
.21955 .48824 L
.25962 .48371 L
.29968 .47808 L
.33974 .47126 L
.37981 .46317 L
.39422 .45994 L
.41987 .4529 L
.45994 .44026 L
.5 .42574 L
.5149 .41987 L
.54006 .40785 L
.58013 .3865 L
.59175 .37981 L
.62019 .36032 L
.64741 .33974 L
.66026 .32853 L
.6899 .29968 L
.70032 .2882 L
.72284 .25962 L
.74038 .23443 L
.74879 .21955 L
.76878 .17949 L
.78045 .15144 L
.78395 .13942 L
.79354 .09936 L
.79957 .05929 L
.80165 .01923 L
s
.128 1 0 r
.01923 .43663 m
.05929 .43635 L
.09936 .43553 L
.13942 .43413 L
.17949 .43209 L
.21955 .42933 L
.25962 .42577 L
.29968 .42132 L
.31116 .41987 L
.33974 .41515 L
.37981 .40714 L
.41987 .39738 L
.45994 .38595 L
.47957 .37981 L
.5 .37146 L
.54006 .35295 L
.56623 .33974 L
.58013 .3309 L
.62019 .3028 L
.62425 .29968 L
.66026 .26613 L
.66627 .25962 L
.6982 .21955 L
.70032 .21656 L
.72086 .17949 L
.73943 .13942 L
.74038 .1371 L
.74979 .09936 L
.75639 .05929 L
.75873 .01923 L
.01923 .01923 L
F
0 g
.01923 .43663 m
.05929 .43635 L
.09936 .43553 L
.13942 .43413 L
.17949 .43209 L
.21955 .42933 L
.25962 .42577 L
.29968 .42132 L
.31116 .41987 L
.33974 .41515 L
.37981 .40714 L
.41987 .39738 L
.45994 .38595 L
.47957 .37981 L
.5 .37146 L
.54006 .35295 L
.56623 .33974 L
.58013 .3309 L
.62019 .3028 L
.62425 .29968 L
.66026 .26613 L
.66627 .25962 L
.6982 .21955 L
.70032 .21656 L
.72086 .17949 L
.73943 .13942 L
.74038 .1371 L
.74979 .09936 L
.75639 .05929 L
.75873 .01923 L
s
.272 1 0 r
.01923 .40307 m
.05929 .40284 L
.09936 .40213 L
.13942 .40091 L
.17949 .39911 L
.21955 .39664 L
.25962 .39339 L
.29968 .38923 L
.33974 .38407 L
.36795 .37981 L
.37981 .37735 L
.41987 .36769 L
.45994 .35586 L
.5 .34233 L
.50727 .33974 L
.54006 .32336 L
.58013 .30103 L
.58241 .29968 L
.62019 .27028 L
.63236 .25962 L
.66026 .23014 L
.66835 .21955 L
.69527 .17949 L
.70032 .17098 L
.71286 .13942 L
.72606 .09936 L
.73456 .05929 L
.73738 .01923 L
.01923 .01923 L
F
0 g
.01923 .40307 m
.05929 .40284 L
.09936 .40213 L
.13942 .40091 L
.17949 .39911 L
.21955 .39664 L
.25962 .39339 L
.29968 .38923 L
.33974 .38407 L
.36795 .37981 L
.37981 .37735 L
.41987 .36769 L
.45994 .35586 L
.5 .34233 L
.50727 .33974 L
.54006 .32336 L
.58013 .30103 L
.58241 .29968 L
.62019 .27028 L
.63236 .25962 L
.66026 .23014 L
.66835 .21955 L
.69527 .17949 L
.70032 .17098 L
.71286 .13942 L
.72606 .09936 L
.73456 .05929 L
.73738 .01923 L
s
.416 1 0 r
.01923 .38103 m
.05929 .38085 L
.09936 .38033 L
.12544 .37981 L
.13942 .37933 L
.17949 .37769 L
.21955 .37539 L
.25962 .37226 L
.29968 .36811 L
.33974 .36269 L
.37981 .35583 L
.41987 .34749 L
.45275 .33974 L
.45994 .33731 L
.5 .3218 L
.54006 .30407 L
.54961 .29968 L
.58013 .27964 L
.60806 .25962 L
.62019 .24864 L
.64806 .21955 L
.66026 .20477 L
.67592 .17949 L
.69784 .13942 L
.70032 .13429 L
.70938 .09936 L
.71858 .05929 L
.72105 .01923 L
.01923 .01923 L
F
0 g
.01923 .38103 m
.05929 .38085 L
.09936 .38033 L
.12544 .37981 L
.13942 .37933 L
.17949 .37769 L
.21955 .37539 L
.25962 .37226 L
.29968 .36811 L
.33974 .36269 L
.37981 .35583 L
.41987 .34749 L
.45275 .33974 L
.45994 .33731 L
.5 .3218 L
.54006 .30407 L
.54961 .29968 L
.58013 .27964 L
.60806 .25962 L
.62019 .24864 L
.64806 .21955 L
.66026 .20477 L
.67592 .17949 L
.69784 .13942 L
.70032 .13429 L
.70938 .09936 L
.71858 .05929 L
.72105 .01923 L
s
.56 1 0 r
.01923 .36334 m
.05929 .36316 L
.09936 .36261 L
.13942 .36165 L
.17949 .36021 L
.21955 .3582 L
.25962 .35547 L
.29968 .3519 L
.33974 .34733 L
.37981 .34174 L
.39272 .33974 L
.41987 .33323 L
.45994 .32139 L
.5 .30742 L
.52124 .29968 L
.54006 .28932 L
.58013 .26499 L
.58849 .25962 L
.62019 .23182 L
.63208 .21955 L
.66026 .18496 L
.66328 .17949 L
.68357 .13942 L
.70008 .09936 L
.70032 .09902 L
.70781 .05929 L
.7103 .01923 L
.01923 .01923 L
F
0 g
.01923 .36334 m
.05929 .36316 L
.09936 .36261 L
.13942 .36165 L
.17949 .36021 L
.21955 .3582 L
.25962 .35547 L
.29968 .3519 L
.33974 .34733 L
.37981 .34174 L
.39272 .33974 L
.41987 .33323 L
.45994 .32139 L
.5 .30742 L
.52124 .29968 L
.54006 .28932 L
.58013 .26499 L
.58849 .25962 L
.62019 .23182 L
.63208 .21955 L
.66026 .18496 L
.66328 .17949 L
.68357 .13942 L
.70008 .09936 L
.70032 .09902 L
.70781 .05929 L
.7103 .01923 L
s
.704 1 0 r
.01923 .34992 m
.05929 .34977 L
.09936 .34932 L
.13942 .34853 L
.17949 .34735 L
.21955 .3457 L
.25962 .34348 L
.29968 .34062 L
.31031 .33974 L
.33974 .33594 L
.37981 .32926 L
.41987 .32051 L
.45994 .30981 L
.49487 .29968 L
.5 .29731 L
.54006 .27698 L
.57208 .25962 L
.58013 .25348 L
.62019 .21971 L
.62035 .21955 L
.65232 .17949 L
.66026 .16827 L
.67297 .13942 L
.68914 .09936 L
.69905 .05929 L
.70032 .04933 L
.70212 .01923 L
.01923 .01923 L
F
0 g
.01923 .34992 m
.05929 .34977 L
.09936 .34932 L
.13942 .34853 L
.17949 .34735 L
.21955 .3457 L
.25962 .34348 L
.29968 .34062 L
.31031 .33974 L
.33974 .33594 L
.37981 .32926 L
.41987 .32051 L
.45994 .30981 L
.49487 .29968 L
.5 .29731 L
.54006 .27698 L
.57208 .25962 L
.58013 .25348 L
.62019 .21971 L
.62035 .21955 L
.65232 .17949 L
.66026 .16827 L
.67297 .13942 L
.68914 .09936 L
.69905 .05929 L
.70032 .04933 L
.70212 .01923 L
s
.848 1 0 r
.01923 .34003 m
.05929 .33991 L
.08147 .33974 L
.09936 .3395 L
.13942 .33868 L
.17949 .33744 L
.21955 .33564 L
.25962 .33313 L
.29968 .32967 L
.33974 .32496 L
.37981 .31871 L
.41987 .31082 L
.45994 .30174 L
.46883 .29968 L
.5 .28724 L
.54006 .26784 L
.55732 .25962 L
.58013 .24275 L
.60891 .21955 L
.62019 .20802 L
.64231 .17949 L
.66026 .15358 L
.66551 .13942 L
.68134 .09936 L
.68973 .05929 L
.6929 .01923 L
.01923 .01923 L
F
0 g
.01923 .34003 m
.05929 .33991 L
.08147 .33974 L
.09936 .3395 L
.13942 .33868 L
.17949 .33744 L
.21955 .33564 L
.25962 .33313 L
.29968 .32967 L
.33974 .32496 L
.37981 .31871 L
.41987 .31082 L
.45994 .30174 L
.46883 .29968 L
.5 .28724 L
.54006 .26784 L
.55732 .25962 L
.58013 .24275 L
.60891 .21955 L
.62019 .20802 L
.64231 .17949 L
.66026 .15358 L
.66551 .13942 L
.68134 .09936 L
.68973 .05929 L
.6929 .01923 L
s
.992 1 0 r
.01923 .33004 m
.05929 .3299 L
.09936 .32947 L
.13942 .32872 L
.17949 .32756 L
.21955 .32589 L
.25962 .32356 L
.29968 .32035 L
.33974 .31604 L
.37981 .31045 L
.41987 .30367 L
.44188 .29968 L
.45994 .29376 L
.5 .27947 L
.54006 .26133 L
.54423 .25962 L
.58013 .23412 L
.59917 .21955 L
.62019 .19823 L
.63423 .17949 L
.66026 .14063 L
.66062 .13942 L
.67523 .09936 L
.68318 .05929 L
.68592 .01923 L
.01923 .01923 L
F
0 g
.01923 .33004 m
.05929 .3299 L
.09936 .32947 L
.13942 .32872 L
.17949 .32756 L
.21955 .32589 L
.25962 .32356 L
.29968 .32035 L
.33974 .31604 L
.37981 .31045 L
.41987 .30367 L
.44188 .29968 L
.45994 .29376 L
.5 .27947 L
.54006 .26133 L
.54423 .25962 L
.58013 .23412 L
.59917 .21955 L
.62019 .19823 L
.63423 .17949 L
.66026 .14063 L
.66062 .13942 L
.67523 .09936 L
.68318 .05929 L
.68592 .01923 L
s
1 .864 0 r
.01923 .3215 m
.05929 .32137 L
.09936 .32098 L
.13942 .3203 L
.17949 .31925 L
.21955 .31773 L
.25962 .31562 L
.29968 .31274 L
.33974 .30893 L
.37981 .30413 L
.41226 .29968 L
.41987 .29774 L
.45994 .2865 L
.5 .27314 L
.53192 .25962 L
.54006 .25444 L
.58013 .22732 L
.59092 .21955 L
.62019 .19009 L
.62783 .17949 L
.65396 .13942 L
.66026 .12838 L
.67016 .09936 L
.67807 .05929 L
.68067 .01923 L
.01923 .01923 L
F
0 g
.01923 .3215 m
.05929 .32137 L
.09936 .32098 L
.13942 .3203 L
.17949 .31925 L
.21955 .31773 L
.25962 .31562 L
.29968 .31274 L
.33974 .30893 L
.37981 .30413 L
.41226 .29968 L
.41987 .29774 L
.45994 .2865 L
.5 .27314 L
.53192 .25962 L
.54006 .25444 L
.58013 .22732 L
.59092 .21955 L
.62019 .19009 L
.62783 .17949 L
.65396 .13942 L
.66026 .12838 L
.67016 .09936 L
.67807 .05929 L
.68067 .01923 L
s
1 .72 0 r
.01923 .31432 m
.05929 .31421 L
.09936 .31386 L
.13942 .31326 L
.17949 .31233 L
.21955 .31099 L
.25962 .30914 L
.29968 .30663 L
.33974 .30338 L
.37742 .29968 L
.37981 .29924 L
.41987 .2909 L
.45994 .28061 L
.5 .26776 L
.52017 .25962 L
.54006 .24797 L
.58013 .22207 L
.58388 .21955 L
.62019 .18333 L
.62283 .17949 L
.64826 .13942 L
.66026 .11663 L
.6658 .09936 L
.67384 .05929 L
.67641 .01923 L
.01923 .01923 L
F
0 g
.01923 .31432 m
.05929 .31421 L
.09936 .31386 L
.13942 .31326 L
.17949 .31233 L
.21955 .31099 L
.25962 .30914 L
.29968 .30663 L
.33974 .30338 L
.37742 .29968 L
.37981 .29924 L
.41987 .2909 L
.45994 .28061 L
.5 .26776 L
.52017 .25962 L
.54006 .24797 L
.58013 .22207 L
.58388 .21955 L
.62019 .18333 L
.62283 .17949 L
.64826 .13942 L
.66026 .11663 L
.6658 .09936 L
.67384 .05929 L
.67641 .01923 L
s
1 .576 0 r
.01923 .30836 m
.05929 .30826 L
.09936 .30796 L
.13942 .30744 L
.17949 .30664 L
.21955 .30549 L
.25962 .30391 L
.29968 .30181 L
.33239 .29968 L
.33974 .29877 L
.37981 .29293 L
.41987 .2853 L
.45994 .27564 L
.5 .26307 L
.50895 .25962 L
.54006 .24265 L
.57731 .21955 L
.58013 .2171 L
.6182 .17949 L
.62019 .17716 L
.6435 .13942 L
.66026 .10501 L
.66195 .09936 L
.67019 .05929 L
.67279 .01923 L
.01923 .01923 L
F
0 g
.01923 .30836 m
.05929 .30826 L
.09936 .30796 L
.13942 .30744 L
.17949 .30664 L
.21955 .30549 L
.25962 .30391 L
.29968 .30181 L
.33239 .29968 L
.33974 .29877 L
.37981 .29293 L
.41987 .2853 L
.45994 .27564 L
.5 .26307 L
.50895 .25962 L
.54006 .24265 L
.57731 .21955 L
.58013 .2171 L
.6182 .17949 L
.62019 .17716 L
.6435 .13942 L
.66026 .10501 L
.66195 .09936 L
.67019 .05929 L
.67279 .01923 L
s
1 .432 0 r
.01923 .30346 m
.05929 .30338 L
.09936 .30313 L
.13942 .30269 L
.17949 .30202 L
.21955 .30106 L
.25962 .29976 L
.26181 .29968 L
.29968 .29696 L
.33974 .29301 L
.37981 .28764 L
.41987 .28055 L
.45994 .27133 L
.49802 .25962 L
.5 .25843 L
.54006 .23813 L
.57066 .21955 L
.58013 .21138 L
.61269 .17949 L
.62019 .17073 L
.63941 .13942 L
.65666 .09936 L
.66026 .09548 L
.66698 .05929 L
.66962 .01923 L
.01923 .01923 L
F
0 g
.01923 .30346 m
.05929 .30338 L
.09936 .30313 L
.13942 .30269 L
.17949 .30202 L
.21955 .30106 L
.25962 .29976 L
.26181 .29968 L
.29968 .29696 L
.33974 .29301 L
.37981 .28764 L
.41987 .28055 L
.45994 .27133 L
.49802 .25962 L
.5 .25843 L
.54006 .23813 L
.57066 .21955 L
.58013 .21138 L
.61269 .17949 L
.62019 .17073 L
.63941 .13942 L
.65666 .09936 L
.66026 .09548 L
.66698 .05929 L
.66962 .01923 L
s
1 .288 0 r
.01923 .29936 m
.05929 .29926 L
.09936 .29894 L
.13942 .29837 L
.17949 .29749 L
.21955 .2962 L
.25962 .29435 L
.29968 .29174 L
.33974 .2881 L
.37981 .28312 L
.41987 .27643 L
.45994 .2675 L
.48711 .25962 L
.5 .25284 L
.54006 .23419 L
.56453 .21955 L
.58013 .20621 L
.60768 .17949 L
.62019 .16487 L
.6358 .13942 L
.65152 .09936 L
.66026 .08567 L
.66409 .05929 L
.66679 .01923 L
.01923 .01923 L
F
0 g
.01923 .29936 m
.05929 .29926 L
.09936 .29894 L
.13942 .29837 L
.17949 .29749 L
.21955 .2962 L
.25962 .29435 L
.29968 .29174 L
.33974 .2881 L
.37981 .28312 L
.41987 .27643 L
.45994 .2675 L
.48711 .25962 L
.5 .25284 L
.54006 .23419 L
.56453 .21955 L
.58013 .20621 L
.60768 .17949 L
.62019 .16487 L
.6358 .13942 L
.65152 .09936 L
.66026 .08567 L
.66409 .05929 L
.66679 .01923 L
s
1 .144 0 r
.01923 .29419 m
.05929 .2941 L
.09936 .29381 L
.13942 .29329 L
.17949 .29249 L
.21955 .29131 L
.25962 .28962 L
.29968 .28722 L
.33974 .28384 L
.37981 .27916 L
.41987 .27277 L
.45994 .26406 L
.47614 .25962 L
.5 .2484 L
.54006 .23069 L
.55888 .21955 L
.58013 .20157 L
.60314 .17949 L
.62019 .15954 L
.63257 .13942 L
.64767 .09936 L
.66026 .06995 L
.66145 .05929 L
.66422 .01923 L
.01923 .01923 L
F
0 g
.01923 .29419 m
.05929 .2941 L
.09936 .29381 L
.13942 .29329 L
.17949 .29249 L
.21955 .29131 L
.25962 .28962 L
.29968 .28722 L
.33974 .28384 L
.37981 .27916 L
.41987 .27277 L
.45994 .26406 L
.47614 .25962 L
.5 .2484 L
.54006 .23069 L
.55888 .21955 L
.58013 .20157 L
.60314 .17949 L
.62019 .15954 L
.63257 .13942 L
.64767 .09936 L
.66026 .06995 L
.66145 .05929 L
.66422 .01923 L
s
1 0 0 r
.01923 .28966 m
.05929 .28958 L
.09936 .28932 L
.13942 .28885 L
.17949 .28812 L
.21955 .28703 L
.25962 .28547 L
.29968 .28324 L
.33974 .28007 L
.37981 .27563 L
.41987 .26948 L
.45994 .26091 L
.46495 .25962 L
.5 .24472 L
.54006 .22752 L
.55365 .21955 L
.58013 .19741 L
.59905 .17949 L
.62019 .15468 L
.62963 .13942 L
.64454 .09936 L
.65501 .05929 L
.66026 .04501 L
.66186 .01923 L
.01923 .01923 L
F
0 g
.01923 .28966 m
.05929 .28958 L
.09936 .28932 L
.13942 .28885 L
.17949 .28812 L
.21955 .28703 L
.25962 .28547 L
.29968 .28324 L
.33974 .28007 L
.37981 .27563 L
.41987 .26948 L
.45994 .26091 L
.46495 .25962 L
.5 .24472 L
.54006 .22752 L
.55365 .21955 L
.58013 .19741 L
.59905 .17949 L
.62019 .15468 L
.62963 .13942 L
.64454 .09936 L
.65501 .05929 L
.66026 .04501 L
.66186 .01923 L
s
1 .144 0 r
.01923 .08075 m
.05929 .08075 L
.09936 .08075 L
.13942 .08075 L
.17949 .08075 L
.21955 .08075 L
.25962 .08076 L
.29968 .08076 L
.33974 .08077 L
.37981 .08079 L
.41987 .08089 L
.45994 .08184 L
.45994 .05929 L
.45994 .01923 L
.01923 .01923 L
F
0 g
.01923 .08075 m
.05929 .08075 L
.09936 .08075 L
.13942 .08075 L
.17949 .08075 L
.21955 .08075 L
.25962 .08076 L
.29968 .08076 L
.33974 .08077 L
.37981 .08079 L
.41987 .08089 L
.45994 .08184 L
.45994 .05929 L
.45994 .01923 L
s
1 .288 0 r
.01923 .08075 m
.05929 .08075 L
.09936 .08075 L
.13942 .08075 L
.17949 .08075 L
.21955 .08075 L
.25962 .08076 L
.29968 .08076 L
.33974 .08077 L
.37981 .08079 L
.41987 .08089 L
.45994 .08184 L
.45994 .05929 L
.45994 .01923 L
.01923 .01923 L
F
0 g
.01923 .08075 m
.05929 .08075 L
.09936 .08075 L
.13942 .08075 L
.17949 .08075 L
.21955 .08075 L
.25962 .08076 L
.29968 .08076 L
.33974 .08077 L
.37981 .08079 L
.41987 .08089 L
.45994 .08184 L
.45994 .05929 L
.45994 .01923 L
s
1 .432 0 r
.01923 .08075 m
.05929 .08075 L
.09936 .08075 L
.13942 .08075 L
.17949 .08075 L
.21955 .08075 L
.25962 .08075 L
.29968 .08076 L
.33974 .08077 L
.37981 .08079 L
.41987 .08089 L
.45994 .08184 L
.45994 .05929 L
.45994 .01923 L
.01923 .01923 L
F
0 g
.01923 .08075 m
.05929 .08075 L
.09936 .08075 L
.13942 .08075 L
.17949 .08075 L
.21955 .08075 L
.25962 .08075 L
.29968 .08076 L
.33974 .08077 L
.37981 .08079 L
.41987 .08089 L
.45994 .08184 L
.45994 .05929 L
.45994 .01923 L
s
1 .576 0 r
.01923 .08075 m
.05929 .08075 L
.09936 .08075 L
.13942 .08075 L
.17949 .08075 L
.21955 .08075 L
.25962 .08075 L
.29968 .08076 L
.33974 .08076 L
.37981 .08079 L
.41987 .08089 L
.45994 .08184 L
.45994 .05929 L
.45994 .01923 L
.01923 .01923 L
F
0 g
.01923 .08075 m
.05929 .08075 L
.09936 .08075 L
.13942 .08075 L
.17949 .08075 L
.21955 .08075 L
.25962 .08075 L
.29968 .08076 L
.33974 .08076 L
.37981 .08079 L
.41987 .08089 L
.45994 .08184 L
.45994 .05929 L
.45994 .01923 L
s
1 .72 0 r
.01923 .08075 m
.05929 .08075 L
.09936 .08075 L
.13942 .08075 L
.17949 .08075 L
.21955 .08075 L
.25962 .08075 L
.29968 .08076 L
.33974 .08076 L
.37981 .08079 L
.41987 .08089 L
.45994 .08184 L
.45994 .05929 L
.45994 .01923 L
.01923 .01923 L
F
0 g
.01923 .08075 m
.05929 .08075 L
.09936 .08075 L
.13942 .08075 L
.17949 .08075 L
.21955 .08075 L
.25962 .08075 L
.29968 .08076 L
.33974 .08076 L
.37981 .08079 L
.41987 .08089 L
.45994 .08184 L
.45994 .05929 L
.45994 .01923 L
s
1 .864 0 r
.01923 .08075 m
.05929 .08075 L
.09936 .08075 L
.13942 .08075 L
.17949 .08075 L
.21955 .08075 L
.25962 .08075 L
.29968 .08076 L
.33974 .08076 L
.37981 .08079 L
.41987 .08089 L
.45994 .08184 L
.45994 .05929 L
.45994 .01923 L
.01923 .01923 L
F
0 g
.01923 .08075 m
.05929 .08075 L
.09936 .08075 L
.13942 .08075 L
.17949 .08075 L
.21955 .08075 L
.25962 .08075 L
.29968 .08076 L
.33974 .08076 L
.37981 .08079 L
.41987 .08089 L
.45994 .08184 L
.45994 .05929 L
.45994 .01923 L
s
.992 1 0 r
.01923 .08075 m
.05929 .08075 L
.09936 .08075 L
.13942 .08075 L
.17949 .08075 L
.21955 .08075 L
.25962 .08075 L
.29968 .08076 L
.33974 .08076 L
.37981 .08079 L
.41987 .08089 L
.45994 .08184 L
.45994 .05929 L
.45994 .01923 L
.01923 .01923 L
F
0 g
.01923 .08075 m
.05929 .08075 L
.09936 .08075 L
.13942 .08075 L
.17949 .08075 L
.21955 .08075 L
.25962 .08075 L
.29968 .08076 L
.33974 .08076 L
.37981 .08079 L
.41987 .08089 L
.45994 .08184 L
.45994 .05929 L
.45994 .01923 L
s
.848 1 0 r
.01923 .08075 m
.05929 .08075 L
.09936 .08075 L
.13942 .08075 L
.17949 .08075 L
.21955 .08075 L
.25962 .08075 L
.29968 .08075 L
.33974 .08076 L
.37981 .08079 L
.41987 .08088 L
.45994 .08184 L
.45994 .05929 L
.45994 .01923 L
.01923 .01923 L
F
0 g
.01923 .08075 m
.05929 .08075 L
.09936 .08075 L
.13942 .08075 L
.17949 .08075 L
.21955 .08075 L
.25962 .08075 L
.29968 .08075 L
.33974 .08076 L
.37981 .08079 L
.41987 .08088 L
.45994 .08184 L
.45994 .05929 L
.45994 .01923 L
s
.704 1 0 r
.01923 .08075 m
.05929 .08075 L
.09936 .08075 L
.13942 .08075 L
.17949 .08075 L
.21955 .08075 L
.25962 .08075 L
.29968 .08075 L
.33974 .08076 L
.37981 .08078 L
.41987 .08088 L
.45994 .08184 L
.45994 .05929 L
.45994 .01923 L
.01923 .01923 L
F
0 g
.01923 .08075 m
.05929 .08075 L
.09936 .08075 L
.13942 .08075 L
.17949 .08075 L
.21955 .08075 L
.25962 .08075 L
.29968 .08075 L
.33974 .08076 L
.37981 .08078 L
.41987 .08088 L
.45994 .08184 L
.45994 .05929 L
.45994 .01923 L
s
.56 1 0 r
.01923 .08075 m
.05929 .08075 L
.09936 .08075 L
.13942 .08075 L
.17949 .08075 L
.21955 .08075 L
.25962 .08075 L
.29968 .08075 L
.33974 .08076 L
.37981 .08078 L
.41987 .08088 L
.45994 .08184 L
.45994 .05929 L
.45994 .01923 L
.01923 .01923 L
F
0 g
.01923 .08075 m
.05929 .08075 L
.09936 .08075 L
.13942 .08075 L
.17949 .08075 L
.21955 .08075 L
.25962 .08075 L
.29968 .08075 L
.33974 .08076 L
.37981 .08078 L
.41987 .08088 L
.45994 .08184 L
.45994 .05929 L
.45994 .01923 L
s
.416 1 0 r
.01923 .08075 m
.05929 .08075 L
.09936 .08075 L
.13942 .08075 L
.17949 .08075 L
.21955 .08075 L
.25962 .08075 L
.29968 .08075 L
.33974 .08076 L
.37981 .08078 L
.41987 .08088 L
.45994 .08183 L
.45994 .05929 L
.45994 .01923 L
.01923 .01923 L
F
0 g
.01923 .08075 m
.05929 .08075 L
.09936 .08075 L
.13942 .08075 L
.17949 .08075 L
.21955 .08075 L
.25962 .08075 L
.29968 .08075 L
.33974 .08076 L
.37981 .08078 L
.41987 .08088 L
.45994 .08183 L
.45994 .05929 L
.45994 .01923 L
s
.272 1 0 r
.01923 .08075 m
.05929 .08075 L
.09936 .08075 L
.13942 .08075 L
.17949 .08075 L
.21955 .08075 L
.25962 .08075 L
.29968 .08075 L
.33974 .08076 L
.37981 .08078 L
.41987 .08088 L
.45994 .08183 L
.45994 .05929 L
.45994 .01923 L
.01923 .01923 L
F
0 g
.01923 .08075 m
.05929 .08075 L
.09936 .08075 L
.13942 .08075 L
.17949 .08075 L
.21955 .08075 L
.25962 .08075 L
.29968 .08075 L
.33974 .08076 L
.37981 .08078 L
.41987 .08088 L
.45994 .08183 L
.45994 .05929 L
.45994 .01923 L
s
.128 1 0 r
.01923 .08074 m
.05929 .08074 L
.09936 .08074 L
.13942 .08074 L
.17949 .08075 L
.21955 .08075 L
.25962 .08075 L
.29968 .08075 L
.33974 .08076 L
.37981 .08078 L
.41987 .08088 L
.45994 .08183 L
.45994 .05929 L
.45994 .01923 L
.01923 .01923 L
F
0 g
.01923 .08074 m
.05929 .08074 L
.09936 .08074 L
.13942 .08074 L
.17949 .08075 L
.21955 .08075 L
.25962 .08075 L
.29968 .08075 L
.33974 .08076 L
.37981 .08078 L
.41987 .08088 L
.45994 .08183 L
.45994 .05929 L
.45994 .01923 L
s
0 1 .016 r
.01923 .08074 m
.05929 .08074 L
.09936 .08074 L
.13942 .08074 L
.17949 .08074 L
.21955 .08075 L
.25962 .08075 L
.29968 .08075 L
.33974 .08076 L
.37981 .08078 L
.41987 .08088 L
.45994 .08183 L
.45994 .05929 L
.45994 .01923 L
.01923 .01923 L
F
0 g
.01923 .08074 m
.05929 .08074 L
.09936 .08074 L
.13942 .08074 L
.17949 .08074 L
.21955 .08075 L
.25962 .08075 L
.29968 .08075 L
.33974 .08076 L
.37981 .08078 L
.41987 .08088 L
.45994 .08183 L
.45994 .05929 L
.45994 .01923 L
s
0 1 .16 r
.01923 .08074 m
.05929 .08074 L
.09936 .08074 L
.13942 .08074 L
.17949 .08074 L
.21955 .08074 L
.25962 .08075 L
.29968 .08075 L
.33974 .08076 L
.37981 .08078 L
.41987 .08088 L
.45994 .08183 L
.45994 .05929 L
.45994 .01923 L
.01923 .01923 L
F
0 g
.01923 .08074 m
.05929 .08074 L
.09936 .08074 L
.13942 .08074 L
.17949 .08074 L
.21955 .08074 L
.25962 .08075 L
.29968 .08075 L
.33974 .08076 L
.37981 .08078 L
.41987 .08088 L
.45994 .08183 L
.45994 .05929 L
.45994 .01923 L
s
0 1 .304 r
.01923 .08074 m
.05929 .08074 L
.09936 .08074 L
.13942 .08074 L
.17949 .08074 L
.21955 .08074 L
.25962 .08075 L
.29968 .08075 L
.33974 .08076 L
.37981 .08078 L
.41987 .08088 L
.45994 .08183 L
.45994 .05929 L
.45994 .01923 L
.01923 .01923 L
F
0 g
.01923 .08074 m
.05929 .08074 L
.09936 .08074 L
.13942 .08074 L
.17949 .08074 L
.21955 .08074 L
.25962 .08075 L
.29968 .08075 L
.33974 .08076 L
.37981 .08078 L
.41987 .08088 L
.45994 .08183 L
.45994 .05929 L
.45994 .01923 L
s
0 1 .448 r
.01923 .08074 m
.05929 .08074 L
.09936 .08074 L
.13942 .08074 L
.17949 .08074 L
.21955 .08074 L
.25962 .08074 L
.29968 .08075 L
.33974 .08076 L
.37981 .08078 L
.41987 .08088 L
.45994 .08183 L
.45994 .05929 L
.45994 .01923 L
.01923 .01923 L
F
0 g
.01923 .08074 m
.05929 .08074 L
.09936 .08074 L
.13942 .08074 L
.17949 .08074 L
.21955 .08074 L
.25962 .08074 L
.29968 .08075 L
.33974 .08076 L
.37981 .08078 L
.41987 .08088 L
.45994 .08183 L
.45994 .05929 L
.45994 .01923 L
s
0 1 .592 r
.01923 .08074 m
.05929 .08074 L
.09936 .08074 L
.13942 .08074 L
.17949 .08074 L
.21955 .08074 L
.25962 .08074 L
.29968 .08075 L
.33974 .08076 L
.37981 .08078 L
.41987 .08088 L
.45994 .08183 L
.45994 .05929 L
.45994 .01923 L
.01923 .01923 L
F
0 g
.01923 .08074 m
.05929 .08074 L
.09936 .08074 L
.13942 .08074 L
.17949 .08074 L
.21955 .08074 L
.25962 .08074 L
.29968 .08075 L
.33974 .08076 L
.37981 .08078 L
.41987 .08088 L
.45994 .08183 L
.45994 .05929 L
.45994 .01923 L
s
0 1 .736 r
.01923 .08074 m
.05929 .08074 L
.09936 .08074 L
.13942 .08074 L
.17949 .08074 L
.21955 .08074 L
.25962 .08074 L
.29968 .08075 L
.33974 .08075 L
.37981 .08078 L
.41987 .08088 L
.45994 .08183 L
.45994 .05929 L
.45994 .01923 L
.01923 .01923 L
F
0 g
.01923 .08074 m
.05929 .08074 L
.09936 .08074 L
.13942 .08074 L
.17949 .08074 L
.21955 .08074 L
.25962 .08074 L
.29968 .08075 L
.33974 .08075 L
.37981 .08078 L
.41987 .08088 L
.45994 .08183 L
.45994 .05929 L
.45994 .01923 L
s
0 1 .88 r
.01923 .08074 m
.05929 .08074 L
.09936 .08074 L
.13942 .08074 L
.17949 .08074 L
.21955 .08074 L
.25962 .08074 L
.29968 .08075 L
.33974 .08075 L
.37981 .08078 L
.41987 .08088 L
.45994 .08183 L
.45994 .05929 L
.45994 .01923 L
.01923 .01923 L
F
0 g
.01923 .08074 m
.05929 .08074 L
.09936 .08074 L
.13942 .08074 L
.17949 .08074 L
.21955 .08074 L
.25962 .08074 L
.29968 .08075 L
.33974 .08075 L
.37981 .08078 L
.41987 .08088 L
.45994 .08183 L
.45994 .05929 L
.45994 .01923 L
s
0 .976 1 r
.01923 .08074 m
.05929 .08074 L
.09936 .08074 L
.13942 .08074 L
.17949 .08074 L
.21955 .08074 L
.25962 .08074 L
.29968 .08075 L
.33974 .08075 L
.37981 .08078 L
.41987 .08088 L
.45994 .08183 L
.45994 .05929 L
.45994 .01923 L
.01923 .01923 L
F
0 g
.01923 .08074 m
.05929 .08074 L
.09936 .08074 L
.13942 .08074 L
.17949 .08074 L
.21955 .08074 L
.25962 .08074 L
.29968 .08075 L
.33974 .08075 L
.37981 .08078 L
.41987 .08088 L
.45994 .08183 L
.45994 .05929 L
.45994 .01923 L
s
0 .832 1 r
.01923 .08074 m
.05929 .08074 L
.09936 .08074 L
.13942 .08074 L
.17949 .08074 L
.21955 .08074 L
.25962 .08074 L
.29968 .08074 L
.33974 .08075 L
.37981 .08078 L
.41987 .08087 L
.45994 .08183 L
.45994 .05929 L
.45994 .01923 L
.01923 .01923 L
F
0 g
.01923 .08074 m
.05929 .08074 L
.09936 .08074 L
.13942 .08074 L
.17949 .08074 L
.21955 .08074 L
.25962 .08074 L
.29968 .08074 L
.33974 .08075 L
.37981 .08078 L
.41987 .08087 L
.45994 .08183 L
.45994 .05929 L
.45994 .01923 L
s
0 .688 1 r
.01923 .08074 m
.05929 .08074 L
.09936 .08074 L
.13942 .08074 L
.17949 .08074 L
.21955 .08074 L
.25962 .08074 L
.29968 .08074 L
.33974 .08075 L
.37981 .08077 L
.41987 .08087 L
.45994 .08183 L
.45994 .05929 L
.45994 .01923 L
.01923 .01923 L
F
0 g
.01923 .08074 m
.05929 .08074 L
.09936 .08074 L
.13942 .08074 L
.17949 .08074 L
.21955 .08074 L
.25962 .08074 L
.29968 .08074 L
.33974 .08075 L
.37981 .08077 L
.41987 .08087 L
.45994 .08183 L
.45994 .05929 L
.45994 .01923 L
s
0 .544 1 r
.01923 .08074 m
.05929 .08074 L
.09936 .08074 L
.13942 .08074 L
.17949 .08074 L
.21955 .08074 L
.25962 .08074 L
.29968 .08074 L
.33974 .08075 L
.37981 .08077 L
.41987 .08087 L
.45994 .08183 L
.45994 .05929 L
.45994 .01923 L
.01923 .01923 L
F
0 g
.01923 .08074 m
.05929 .08074 L
.09936 .08074 L
.13942 .08074 L
.17949 .08074 L
.21955 .08074 L
.25962 .08074 L
.29968 .08074 L
.33974 .08075 L
.37981 .08077 L
.41987 .08087 L
.45994 .08183 L
.45994 .05929 L
.45994 .01923 L
s
0 .4 1 r
.01923 .08074 m
.05929 .08074 L
.09936 .08074 L
.13942 .08074 L
.17949 .08074 L
.21955 .08074 L
.25962 .08074 L
.29968 .08074 L
.33974 .08075 L
.37981 .08077 L
.41987 .08087 L
.45994 .08182 L
.45994 .05929 L
.45994 .01923 L
.01923 .01923 L
F
0 g
.01923 .08074 m
.05929 .08074 L
.09936 .08074 L
.13942 .08074 L
.17949 .08074 L
.21955 .08074 L
.25962 .08074 L
.29968 .08074 L
.33974 .08075 L
.37981 .08077 L
.41987 .08087 L
.45994 .08182 L
.45994 .05929 L
.45994 .01923 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 576},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900002@2000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oo
oo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX0
02[ooo]Z1Ol007mfoookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007mgoookJP?o001oMooonfX3o`00
O`Cooo]Z0ol007l3oookJPGo001oLooonfX9o`00O`Sooo]Z000YoookJPOo001oM?oonfX7o`00O`?o
oo]Z0ol007l2oookJPOo001oM_oonfX3o`00OgOooo]Z0ol007l4oookJP?o001o0_oonfX7o`00Og;o
oo]Z2Ol007l8oookJP00:OoonfX3o`00O`04oookJ_l007oo001oo`00OgCooo]Z0ol007l01?oonf[o
001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007mf
oookJP?o001oMooonfX3o`00O`Cooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo
001oo`00Og;ooo]Z1?l007l=oookJP00:?oonfX3o`00O`?ooo]Z0ol007mboookJP?o001o0ooonfX3
o`00O`Kooo]Z0ol007l3oookJP?o001oMOoonfX3o`00OgOooo]Z0ol007l8oookJP?o001o0ooonfX3
o`00Og;ooo]Z1?l007l<oookJP00:?oonfX3o`00O`?ooo]Z0ol007mboookJP?o001o0ooonfX3o`00
O`cooo]Z0ol007meoookJP?o001oMooonfX3o`00O`kooo]Z0ol007mcoookJPGo001o2_oonfX002So
oo]Z0ol007l3oookJP?o001oL_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001oMOoonfX3o`00OgOo
oo]Z0ol007l>oookJP?o001oMOoonfX4o`00O`Wooo]Z000XoookJP?o001o0ooonfX3o`00Og;ooo]Z
0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007meoookJP?o001oMooonfX3o`00O`Wooo]Z
0_l007l2oookJPCo001oM_oonfX3o`00O`Wooo]Z000XoookJP?o001o0ooonfX3o`00Og;ooo]Z0ol0
07l3oookJP?o001o1ooonfX7o`00OgKooo]Z0ol007mgoookJP?o001o2OoonfX7o`00OgSooo]Z0ol0
07l8oookJP00:?oonfX3o`00O`?ooo]Z0ol007mboookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007mg
oookJP?o001oMooonfX3o`00O`Wooo]Z1_l007mcoookJP?o001o0ooonfX3o`00O`Sooo]Z000Xoook
JP?o001o0ooonfX3o`00Og;ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00OgSooo]Z1_l007mdoook
JPKo001o2OoonfX2o`00OgOooo]Z0ol007l3oookJP?o001o2?oonfX002Wooo]Z0ol007l01?oonf[o
001oo`00Ool007mdoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00OgSooo]Z1_l007md
oookJPKo001o2OoonfX2o`00OgOooo]Z1?l007l2oookJP?o001o2?oonfX002Wooo]Z1ol007mdoook
JPOo001o2OoonfX7o`00OgCooo]Z1?l007mfoookJPCo001o2_oonfX7o`00Og;ooo]Z1ol007l9oook
JP00:_oonfX5o`00OgKooo]Z1Ol007l:oookJPOo001oMOoonfX3o`00OgOooo]Z0ol007l:oookJPOo
001oLooonfX5o`00O`[ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP008ooonf[oo`000?oo00007_l00001oook
JP008ooonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP07oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX0
1ooonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0
5ooonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0
5ooonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0
5ooonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0
5ooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0
5ooonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0
5ooonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0
1ooonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX0Oooo
nfX00ol0003ooo]ZoookJP1ooookJP03o`000?oonf[ooo]Z07kooo]Z00?o0000oookJ_oonfX0Oooo
nfX00ol0003ooo]ZoookJP07oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX0oooonf[o
oookJQ[ooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]ZoookJP3ooookJ_oooo]Z6_oonfX1o`00
007ooo]Z000CoookJPGo001o2ooonfX00ol0003ooo]ZoookJP3ooookJ_oooo]Z6_oonfX1o`00007o
oo]Z000BoookJPOo001o2_oonfX00ol0003ooo]ZoookJP3ooookJ_oooo]Z6_oonfX1o`00007ooo]Z
000BoookJP?o001o00Cooo]Zo`00Ool007oo001o2_oonfX00ol0003ooo]ZoookJP3ooookJ_oooo]Z
6_oonfX1o`00007ooo]Z000AoookJP?o001o0ooonfX3o`00O`Wooo]Z00?o0000oookJ_oonfX0oooo
nf[ooookJQ[ooo]Z0Ol00001oookJP004OoonfX3o`00O`?ooo]Z0ol007l9oookJPGo0000looonfX0
0ol0003ooo]ZoookJP1ZoookJP;o000000Wooo]Zo`000?l0003ooo]Zo`000?oonf[o0000oookJ_l0
00000_oonfX01Ol0003ooo]ZoookJ_oonf[o000000Cooo]Z00Go0000oookJ_oonf[ooo]Zo`000005
oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0D
oookJP03o`000?oonf[ooo]Z06Gooo]Z1?l00001oookJP004OoonfX3o`00O`?ooo]Z0ol007l9oook
JP03o`000?oonf[ooo]Z00Sooo]ZkOl0I_l00ol0003oo`00ool0001Zool000;o000000WoodT0o`00
0?l0003ooi<0o`000?oo^03o0000oooM0?l000000_omo`001Ol0003ofOl0omWo0?oIo`3o000000Co
]?l000Go0000ohoo0?n?o`3oSol0o`000005of[o0003o`000?m5o`3oAOl000KoAOl000?o0000ob3o
0?lPo`002?lPo`000ol0003o0?l4o`3o100Do`3o1003o`000?l0obSo0?lX05ko0?lX2_oonfX1o`00
007ooo]Z000AoookJP?o001o0ooonfX3o`00O`Wooo]Z00?o0000oookJ_oonfX02?oonf[]o`1Vo`03
o`000?oo003oo`0006[oo`000_l000002OooB@3o0000o`000?ooT`3o0000oonh0?l0003oomd0o`00
0002oogo0005o`000?oIo`3ofOl0omWo0?l000001?ndo`001Ol0003oSol0ohoo0?n?o`3o000000Go
J_l000?o0000odGo0?m5o`001_m5o`000ol0003o8?l0ob3o0008ob3o0003o`000?l0o`Co0?l401Co
0?l400?o0000o`3o:?l0obP0G_l0obP:oookJP7o00000OoonfX0017ooo]Z0ol007l3oookJP?o001o
2OoonfX00ol0003ooo]ZoookJP08oookJ^go06Ko00?o0000ool00?oo0000J_oo0002o`000009oom9
0?l0003o0000oonC0?l0003ookP0o`000?oog@3o000000;ooOl000Go0000omWo0?oIo`3ofOl0o`00
0004okCo0005o`000?n?o`3oSol0ohoo0?l000001OmZo`000ol0003oAOl0odGo0006odGo0003o`00
0?lPo`3o8?l000So8?l000?o0000o`3o1?l0o`@05?l0o`@00ol0003o0?lXo`3o:01No`3o:0[ooo]Z
0Ol00001oookJP004OoonfX3o`00O`?ooo]Z0ol007l9oookJP03o`000?oonf[ooo]Z00Sooo]ZkOl0
I_l00ol0003oo`00ool0001Zool000;o000000WoodT0o`000?l0003ooi<0o`000?oo^03o0000oooM
0?l000000_omo`001Ol0003ofOl0omWo0?oIo`3o000000Co]?l000Go0000ohoo0?n?o`3oSol0o`00
0005of[o0003o`000?m5o`3oAOl000KoAOl000?o0000ob3o0?lPo`002?lPo`000ol0003o0?l4o`3o
100Do`3o1003o`000?l0obSo0?lX05ko0?lX2_oonfX1o`00007ooo]Z000AoookJP?o001o0ooonfX3
o`00O`Wooo]Z00?o0000oookJ_oonfX02?oonf[]o`1Vo`03o`000?oo003oo`0006[oo`000_l00000
2OooB@3o0000o`000?ooT`3o0000oonh0?l0003oomd0o`000002oogo0005o`000?oIo`3ofOl0omWo
0?l000001?ndo`001Ol0003oSol0ohoo0?n?o`3o000000GoJ_l000?o0000odGo0?m5o`001_m5o`00
0ol0003o8?l0ob3o0008ob3o0003o`000?l0o`Co0?l401Co0?l400?o0000o`3o:?l0obP0G_l0obP:
oookJP7o00000OoonfX001;ooo]Z0ol007l01?oonf[o001oo`00Ool007l:oookJP03o`000?oonf[o
oo]Z00Sooo]ZkOl0I_l00ol0003oo`00ool0001Zool000?o000000Soofh0o`000?ooT`3o0000oonh
0?l0003oomd0o`0000;ooOl000Co0000omWo0?oIo`3o00001Ondo`001Ol0003oSol0ohoo0?n?o`3o
000000GoJ_l000?o0000odGo0?m5o`001Om5o`000ol0003o8?l0ob3o0009ob3o0003o`000?l0o`Co
0?l401Co0?l400?o0000o`3o:?l0obP0G_l0obP:oookJP7o00000OoonfX001;ooo]Z1ol007l:oook
JP03o`000?oonf[ooo]Z00Sooo]ZkOl0I_l00ol0003oo`00ool0001Zool000?o000000Soofh0o`00
0?ooT`3o0000oonh0?l0003oomd0o`0000;ooOl000Co0000omWo0?oIo`3o00001Ondo`001Ol0003o
Sol0ohoo0?n?o`3o000000GoJ_l000?o0000odGo0?m5o`001Om5o`000ol0003o8?l0ob3o0009ob3o
0003o`000?l0o`Co0?l401Co0?l400?o0000o`3o:?l0obP0G_l0obP:oookJP7o00000OoonfX001?o
oo]Z1Ol007l;oookJP03o`000?oonf[ooo]Z00Sooo]ZkOl0I_l00ol0003oo`00ool0001Yool0000<
o`000?oo903o0000o`000?ooKP3o0000oonC0?l0003ookP0o`000?oog@3o00000_omo`001?l0003o
fOl0omWo0?l00005okCo0005o`000?n?o`3oSol0ohoo0?l000001OmZo`000ol0003oAOl0odGo0005
odGo0003o`000?lPo`3o8?l000Wo8?l000?o0000o`3o1?l0o`@05?l0o`@00ol0003o0?lXo`3o:01N
o`3o:0[ooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08oookJ^go06Ko00?o0000ool0
0?oo0000JOoo00003?l0003oob@0o`000?l0003oofh0o`000?ooT`3o0000oonh0?l0003oomd0o`00
00;ooOl000Co0000omWo0?oIo`3o00001?ndo`000ol0003oSol0ohoo0002ohoo0003o`000?mZo`3o
J_l000?oJ_l000?o0000odGo0?m5o`001Om5o`000ol0003o8?l0ob3o0009ob3o0003o`000?l0o`Co
0?l401Co0?l400?o0000o`3o:?l0obP0G_l0obP:oookJP7o00000OoonfX002?ooo]Z00?o0000oook
J_oonfX02?oonf[]o`1Vo`03o`000?oo003oo`0006Woo`0000co0000oolT0?l0003o0000oom^0?l0
003ooi<0o`000?oo^03o0000oooM0?l00002oogo0004o`000?oIo`3ofOl0o`0000Co]?l000?o0000
ohoo0?n?o`000_n?o`000ol0003oJ_l0of[o0003of[o0003o`000?m5o`3oAOl000GoAOl000?o0000
ob3o0?lPo`002OlPo`000ol0003o0?l4o`3o100Do`3o1003o`000?l0obSo0?lX05ko0?lX2_oonfX1
o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]ZkOl0I_l00ol0003oo`00ool0001Yool0
000<o`000?oo903o0000o`000?ooKP3o0000oonC0?l0003ookP0o`000?oog@3o00000_omo`001?l0
003ofOl0omWo0?l00004okCo0003o`000?n?o`3oSol000;oSol000?o0000of[o0?mZo`000omZo`00
0ol0003oAOl0odGo0005odGo0003o`000?lPo`3o8?l000Wo8?l000?o0000o`3o1?l0o`@05?l0o`@0
0ol0003o0?lXo`3o:01No`3o:0[ooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08oook
J^go06Ko00?o0000ool00?oo0000JOoo0002o`000009oom90?l0003o0000oonC0?l0003ookP0o`00
0?oog@3o000000;ooOl000Go0000omWo0?oIo`3ofOl0o`000004okCo0005o`000?n?o`3oSol0ohoo
0?l000001OmZo`000ol0003oAOl0odGo0006odGo0003o`000?lPo`3o8?l000So8?l000?o0000o`3o
1?l0o`@05?l0o`@00ol0003o0?lXo`3o:01Oo`3o:0[ooo]Z0Ol00001oookJP008ooonfX00ol0003o
oo]ZoookJP08oookJ^go06Ko00?o0000ool00?oo0000JOoo0002o`000009oom90?l0003o0000oonC
0?l0003ookP0o`000?oog@3o000000;ooOl000Go0000omWo0?oIo`3ofOl0o`000004okCo0005o`00
0?n?o`3oSol0ohoo0?l000001OmZo`000ol0003oAOl0odGo0006odGo0003o`000?lPo`3o8?l000So
8?l000?o0000o`3o1?l0o`@05?l0o`@00ol0003o0?lXo`3o:01Oo`3o:0[ooo]Z0Ol00001oookJP00
8ooonfX00ol0003ooo]ZoookJP08oookJ^go06Ko00?o0000ool00?oo0000JOoo0002o`000009oom9
0?l0003o0000oonC0?l0003ookP0o`000?oog@3o000000;ooOl000Go0000omWo0?oIo`3ofOl0o`00
0004okCo0005o`000?n?o`3oSol0ohoo0?l000001OmZo`000ol0003oAOl0odGo0006odGo0003o`00
0?lPo`3o8?l000So8?l000?o0000o`3o1?l0o`@05?l0o`@00ol0003o0?lXo`3o:01Oo`3o:0[ooo]Z
0Ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08oookJ^go06Ko00?o0000ool00?oo0000JOoo
0002o`000009oom90?l0003o0000oonC0?l0003ookP0o`000?oog@3o000000;ooOl000Go0000omWo
0?oIo`3ofOl0o`000004okCo0005o`000?n?o`3oSol0ohoo0?l000001OmZo`000ol0003oAOl0odGo
0006odGo0003o`000?lPo`3o8?l000So8?l000?o0000o`3o1?l0o`@05?l0o`@00ol0003o0?lXo`3o
:01Oo`3o:0[ooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08oookJ^go06Ko00?o0000
ool00?oo0000J?oo00001?l0003oob@0o`000?ooB@02o`000006oonC0?l0003ookP0o`000?oog@3o
00000_omo`001Ol0003ofOl0omWo0?oIo`3o000000Co]?l000Go0000ohoo0?n?o`3oSol0o`000005
of[o0003o`000?m5o`3oAOl000KoAOl000?o0000ob3o0?lPo`002?lPo`000ol0003o0?l4o`3o100D
o`3o1003o`000?l0obSo0?lX05oo0?lX2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z
00Sooo]ZkOl0I_l00ol0003oo`00ool0001Xool0000<o`000?oo903o0000o`000?ooKP3o0000oonC
0?l0003ookP0o`000?oog@3o00000_omo`001?l0003ofOl0omWo0?l00005okCo0005o`000?n?o`3o
Sol0ohoo0?l000001OmZo`000ol0003oAOl0odGo0005odGo0003o`000?lPo`3o8?l000Wo8?l000?o
0000o`3o1?l0o`@05?l0o`@00ol0003o0?lXo`3o:01Oo`3o:0[ooo]Z0Ol00001oookJP008ooonfX0
0ol0003ooo]ZoookJP08oookJ^go06Ko00?o0000ool00?oo0000J?oo00003?l0003oob@0o`000?l0
003oofh0o`000?ooT`3o0000oonh0?l0003oomd0o`0000;ooOl000Co0000omWo0?oIo`3o00001Ond
o`001Ol0003oSol0ohoo0?n?o`3o000000GoJ_l000?o0000odGo0?m5o`001Om5o`000ol0003o8?l0
ob3o0009ob3o0003o`000?l0o`Co0?l401Co0?l400?o0000o`3o:?l0obP0Gol0obP:oookJP7o0000
0OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[]o`1Vo`03o`000?oo003oo`0006Ooo`0000?o
0000oolT0?oo90000_l000002?ooKP3o0000oonC0?l0003ookP0o`000?oog@3o00000_omo`001?l0
003ofOl0omWo0?l00005okCo0005o`000?n?o`3oSol0ohoo0?l000001OmZo`000ol0003oAOl0odGo
0005odGo0003o`000?lPo`3o8?l000Wo8?l000?o0000o`3o1?l0o`@05?l0o`@00ol0003o0?lXo`3o
:01Oo`3o:0[ooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08oookJ^go06Ko00?o0000
ool00?oo0000Iooo00000ol0003oob@0oolT0002o`000008oom^0?l0003ooi<0o`000?oo^03o0000
oooM0?l00002oogo0004o`000?oIo`3ofOl0o`0000Co]?l000?o0000ohoo0?n?o`000_n?o`000ol0
003oJ_l0of[o0003of[o0003o`000?m5o`3oAOl000GoAOl000?o0000ob3o0?lPo`002OlPo`000ol0
003o0?l4o`3o100Do`3o1003o`000?l0obSo0?lX05oo0?lX2_oonfX1o`00007ooo]Z000SoookJP03
o`000?oonf[ooo]Z00Sooo]ZkOl0I_l00ol0003oo`00ool0001Wool00003o`000?oo903oob@000;o
000000Soofh0o`000?ooT`3o0000oonh0?l0003oomd0o`0000;ooOl000Co0000omWo0?oIo`3o0000
1?ndo`000ol0003oSol0ohoo0002ohoo0003o`000?mZo`3oJ_l000?oJ_l000?o0000odGo0?m5o`00
1Om5o`000ol0003o8?l0ob3o0009ob3o0003o`000?l0o`Co0?l401Co0?l400?o0000o`3o:?l0obP0
Gol0obP:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[]o`1Vo`03o`000?oo
003oo`0006Koo`0000Co0000oolT0?oo903oob@00_l000002?ooKP3o0000oonC0?l0003ookP0o`00
0?oog@3o00000_omo`001?l0003ofOl0omWo0?l00004okCo0003o`000?n?o`3oSol000;oSol000?o
0000of[o0?mZo`000omZo`000ol0003oAOl0odGo0005odGo0003o`000?lPo`3o8?l000Wo8?l000?o
0000o`3o1?l0o`@05?l0o`@00ol0003o0?lXo`3o:01Oo`3o:0[ooo]Z0Ol00001oookJP008ooonfX0
0ol0003ooo]ZoookJP08oookJ^go06Ko00?o0000ool00?oo0000I_oo00001?l0003oob@0oolT0?oo
9002o`000008oom^0?l0003ooi<0o`000?oo^03o0000oooM0?l00002oogo0004o`000?oIo`3ofOl0
o`0000Co]?l000?o0000ohoo0?n?o`000_n?o`000ol0003oJ_l0of[o0003of[o0003o`000?m5o`3o
AOl000GoAOl000?o0000ob3o0?lPo`002OlPo`000ol0003o0?l4o`3o100Do`3o1003o`000?l0obSo
0?lX05oo0?lX2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]ZkOl0I_l00ol0
003oo`00ool0001Vool00004o`000?oo903oob@0oolT00;o000000Soofh0o`000?ooT`3o0000oonh
0?l0003oomd0o`0000;ooOl000Co0000omWo0?oIo`3o00001?ndo`000ol0003oSol0ohoo0002ohoo
0003o`000?mZo`3oJ_l000?oJ_l000?o0000odGo0?m5o`001Om5o`000ol0003o8?l0ob3o0009ob3o
0003o`000?l0o`Co0?l401Co0?l400?o0000o`3o:?l0obP0Gol0obP:oookJP7o00000OoonfX002?o
oo]Z00?o0000oookJ_oonfX02?oonf[]o`1Vo`03o`000?oo003oo`0006Goo`0000?o0000oolT0?oo
90000_oo9003o`000004oonC0?l0003ookP0o`0000;oomd000?o0000oogo0?l000000ooIo`001Ol0
003o]?l0okCo0?ndo`3o000000GoSol000?o0000of[o0?mZo`000_mZo`000ol0003oAOl0odGo0006
odGo0003o`000?lPo`3o8?l000Wo8?l000?o0000o`3o1?l0o`@05?l0o`@00ol0003o0?lXo`3o:01O
o`3o:0[ooo]Z0Ol00001oookJP008ooonfX3o`0000Sooo]ZkOl0I_l00ol0003oo`00ool0001Uool0
0004o`000?oo903oob@0oolT00;o000000Soofh0o`000?ooT`3o0000oonh0?l0003oomd0o`0000;o
oOl000Co0000omWo0?oIo`3o00001?ndo`000ol0003oSol0ohoo0002ohoo0003o`000?mZo`3oJ_l0
00?oJ_l000?o0000odGo0?m5o`001Om5o`000ol0003o8?l0ob3o0009ob3o0003o`000?l0o`Co0?l4
01Co0?l400?o0000o`3o:?l0obP0H?l0obP8oookJP?o00000OoonfX002?ooo]Z00?o0000oookJ_oo
nfX02?oonf[]o`1Vo`03o`000?oo003oo`0006Goo`0000Co0000oolT0?oo903oob@00_l000002?oo
KP3o0000oonC0?l0003ookP0o`000?oog@3o00000_omo`001?l0003ofOl0omWo0?l00004okCo0003
o`000?n?o`3oSol000;oSol000?o0000of[o0?mZo`000omZo`000ol0003oAOl0odGo0005odGo0003
o`000?lPo`3o8?l000Wo8?l000?o0000o`3o1?l0o`@05?l0o`@00ol0003o0?lXo`3o:01Po`3o:0[o
oo]Z0Ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08oookJ^go06Ko00?o0000ool00?oo0000
IOoo00001?l0003oob@0oolT0?oo9002o`000008oom^0?l0003ooi<0o`000?oo^03o0000oooM0?l0
0002oogo0004o`000?oIo`3ofOl0o`0000Co]?l000?o0000ohoo0?n?o`000_n?o`000ol0003oJ_l0
of[o0003of[o0003o`000?m5o`3oAOl000GoAOl000?o0000ob3o0?lPo`002OlPo`000ol0003o0?l4
o`3o100Do`3o1003o`000?l0obSo0?lX063o0?lX2_oonfX1o`00007ooo]Z000SoookJP03o`000?oo
nf[ooo]Z00Sooo]ZkOl0I_l00ol0003oo`00ool0001Tool00003o`000?oo903oob@000;oob@00_l0
00001OooKP3o0000o`000?oo^03o000000;oomd000?o0000oogo0?l000000ooIo`001Ol0003o]?l0
okCo0?ndo`3o000000GoSol000?o0000of[o0?mZo`000_mZo`000ol0003oAOl0odGo0006odGo0003
o`000?lPo`3o8?l000Wo8?l000?o0000o`3o1?l0o`@05?l0o`@00ol0003o0?lXo`3o:01Po`3o:0[o
oo]Z0Ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08oookJ^go06Ko00?o0000ool00?oo0000
I?oo00001_l0003oob@0oolT0?oo903o0000oom900;o000000Cooi<0o`000?oo^03o00000_oog@00
0ol0003ooOl0o`000003omWo0005o`000?ndo`3o]?l0okCo0?l000001On?o`000ol0003oJ_l0of[o
0002of[o0003o`000?m5o`3oAOl000KoAOl000?o0000ob3o0?lPo`002OlPo`000ol0003o0?l4o`3o
100Do`3o1003o`000?l0obSo0?lX063o0?lX2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[o
oo]Z00Sooo]ZkOl0I_l00ol0003oo`00ool0001Tool00006o`000?oo903oob@0oolT0?l0003oodT0
0_l000001_ooT`3o0000oonh0?l0003oomd0o`0000;ooOl000Co0000omWo0?oIo`3o00001?ndo`00
0ol0003oSol0ohoo0002ohoo0003o`000?mZo`3oJ_l000?oJ_l000?o0000odGo0?m5o`001Om5o`00
0ol0003o8?l0ob3o0009ob3o0003o`000?l0o`Co0?l401Go0?l400?o0000o`3o:?l0obP0H?l0obP:
oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[]o`1Vo`03o`000?oo003oo`00
06Coo`0000Co0000oolT0?oo903o00000_ooB@02o`000006oonC0?l0003ookP0o`000?oog@3o0000
0_omo`001?l0003ofOl0omWo0?l00004okCo0003o`000?n?o`3oSol000;oSol000?o0000of[o0?mZ
o`000omZo`000ol0003oAOl0odGo0005odGo0003o`000?lPo`3o8?l000Wo8?l000?o0000o`3o1?l0
o`@05Ol0o`@00ol0003o0?lXo`3o:01Po`3o:0[ooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]Z
oookJP08oookJ^Co00002Ol0I_l00ol0003oo`00ool0001Sool00008o`000?oo903oob@0oolT0?l0
003oodT0o`000?ooKP02o`000007oonh0?l0003oomd0oooM0?l0003ooOl0o`000003omWo0005o`00
0?ndo`3o]?l0okCo0?l000001On?o`000ol0003oJ_l0of[o0002of[o0003o`000?m5o`3oAOl000Ko
AOl000?o0000ob3o0?lPo`002OlPo`000ol0003o0?l4o`3o100Do`3o1003o`000?l0obSo0?lX067o
0?lX2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Zi?oo000:o`0006Goo`00
00Co0000oolT0?oo903o00000_ooB@001_l0003oofh0o`000?l0003ookP0o`0000;oomd000?o0000
oogo0?l000000ooIo`001Ol0003o]?l0okCo0?ndo`3o000000GoSol000?o0000of[o0?mZo`000_mZ
o`000ol0003oAOl0odGo0006odGo0003o`000?lPo`3o8?l000Wo8?l000?o0000o`3o1?l0o`@05?l0
o`@00ol0003o0?lXo`3o:01Qo`3o:0[ooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08
oookJ_ooo`00E?oo00001?l0003oob@0oolT0?l00002oom900;o000000Cooi<0o`000?oo^03o0000
0_oog@000ol0003ooOl0o`000003omWo0005o`000?ndo`3o]?l0okCo0?l000001On?o`000ol0003o
J_l0of[o0002of[o0003o`000?m5o`3oAOl000KoAOl000?o0000ob3o0?lPo`002OlPo`000ol0003o
0?l4o`3o100Do`3o1003o`000?l0obSo0?lX067o0?lX2_oonfX1o`00007ooo]Z000SoookJP03o`00
0?oonf[ooo]Z00Sooo]Zoooo001Dool00003o`000?oo903o000000?oodT00_l000001_ooT`3o0000
oonh0?l0003oomd0o`0000;ooOl000Co0000omWo0?oIo`3o00001?ndo`000ol0003oSol0ohoo0002
ohoo0003o`000?mZo`3oJ_l000?oJ_l000?o0000odGo0?m5o`001Om5o`000ol0003o8?l0ob3o0009
ob3o0003o`000?l0o`Co0?l401Go0?l400?o0000o`3o:?l0obP0HOl0obP:oookJP7o00000OoonfX0
02?ooo]Z00?o0000oookJ_oonfX02?oonf[oool005Coo`0000?o0000oolT0?l000000oooB@02o`00
0006oonC0?l0003ookP0o`000?oog@3o00000_omo`001?l0003ofOl0omWo0?l00004okCo0003o`00
0?n?o`3oSol000;oSol000?o0000of[o0?mZo`000omZo`000ol0003oAOl0odGo0005odGo0003o`00
0?lPo`3o8?l000Wo8?l000?o0000o`3o1?l0o`@05Ol0o`@00ol0003o0?lXo`3o:01Qo`3o:0[ooo]Z
0Ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08oookJ_ooo`00Dooo00001?l0003oob@0oolT
0?l00002oom90006o`000?ooKP3o0000o`000?oo^03o00000_oog@000ol0003ooOl0o`000003omWo
0005o`000?ndo`3o]?l0okCo0?l000001On?o`000ol0003oJ_l0of[o0002of[o0003o`000?m5o`3o
AOl000KoAOl000?o0000ob3o0?lPo`002OlPo`000ol0003o0?l4o`3o100Eo`3o1003o`000?l0obSo
0?lX067o0?lX2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Zoooo001Cool0
0003o`000?oo903o000000;oodT000?o0000oom^0?ooKP000_l000001ooo^03o0000oooM0?oog@3o
0000oogo0?l000000ooIo`001Ol0003o]?l0okCo0?ndo`3o000000GoSol000?o0000of[o0?mZo`00
0_mZo`000ol0003oAOl0odGo0006odGo0003o`000?lPo`3o8?l000Wo8?l000?o0000o`3o1?l0o`@0
5Ol0o`@00ol0003o0?lXo`3o:01Qo`3o:0[ooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]Zoook
JP08oookJ_ooo`00Dooo00001Ol0003oob@0o`000?ooB@3o000000;oofh000Go0000oonC0?l0003o
okP0o`000002oooM0003o`000?omo`3o000000?ofOl000Go0000okCo0?ndo`3o]?l0o`000005ohoo
0003o`000?mZo`3oJ_l000;oJ_l000?o0000odGo0?m5o`001_m5o`000ol0003o8?l0ob3o0009ob3o
0003o`000?l0o`Co0?l401Co0?l400?o0000o`3o:?l0obP0H_l0obP:oookJP7o00000OoonfX002?o
oo]Z00?o0000oookJ_oonfX02?oonf[oool005?oo`000_l00002oom9000:o`000?ooKP3oofh0o`00
0?ooT`3o0000oonh0?l0003oomd0o`0000;ooOl000Co0000omWo0?oIo`3o00001?ndo`000ol0003o
Sol0ohoo0002ohoo0003o`000?mZo`3oJ_l000?oJ_l000?o0000odGo0?m5o`001Om5o`000ol0003o
8?l0ob3o0009ob3o0003o`000?l0o`Co0?l401Go0?l400?o0000o`3o:?l0obP0H_l0obP:oookJP7o
00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[oool005;oo`0000Go0000oolT0?l0003o
odT0o`000002oom^0005o`000?ooT`3o0000oonh0?l000000_oog@000ol0003ooOl0o`000003omWo
0005o`000?ndo`3o]?l0okCo0?l000001On?o`000ol0003oJ_l0of[o0002of[o0003o`000?m5o`3o
AOl000KoAOl000?o0000ob3o0?lPo`002OlPo`000ol0003o0?l4o`3o100Eo`3o1003o`000?l0obSo
0?lX06;o0?lX2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Zoooo001Bool0
00;o000000GoodT0o`000?ooKP3oofh0o`000002oonC0003o`000?oo^03o000000;oomd000?o0000
oogo0?l000000ooIo`001Ol0003o]?l0okCo0?ndo`3o000000GoSol000?o0000of[o0?mZo`000_mZ
o`000ol0003oAOl0odGo0006odGo0003o`000?lPo`3o8?l000Wo8?l000?o0000o`3o1?l0o`@05Ol0
o`@00ol0003o0?lXo`3o:01Ro`3o:0[ooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08
oookJ_ooo`00D_oo0002o`000005oom90?l0003oofh0oom^0?l000000_ooT`000ol0003ookP0o`00
0002oooM0003o`000?omo`3o000000?ofOl000Go0000okCo0?ndo`3o]?l0o`000005ohoo0003o`00
0?mZo`3oJ_l000;oJ_l000?o0000odGo0?m5o`001_m5o`000ol0003o8?l0ob3o0009ob3o0003o`00
0?l0o`Co0?l401Go0?l400?o0000o`3o:?l0obP0H_l0obP:oookJP7o00000OoonfX002?ooo]Z00?o
0000oookJ_oonfX02?oonf[oool0057oo`000_l000001OooB@3o0000oom^0?ooKP3o000000;ooi<0
00So0000oonh0?oo^03o0000oooM0?l0003ooOl0o`0000?ofOl000Go0000okCo0?ndo`3o]?l0o`00
0005ohoo0003o`000?mZo`3oJ_l000?oJ_l000?o0000odGo0?m5o`001_m5o`000ol0003o8?l0ob3o
0009ob3o0003o`000?l0o`Co0?l401Go0?l400?o0000o`3o:?l0obP0H_l0obP:oookJP7o00000Ooo
nfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[oool0057oo`000_l000001OooB@3o0000oom^0?oo
KP3o000000;ooi<000?o0000oonh0?l000000_oog@000ol0003ooOl0o`000003omWo0005o`000?nd
o`3o]?l0okCo0?l000001On?o`000ol0003oJ_l0of[o0002of[o0003o`000?m5o`3oAOl000KoAOl0
00?o0000ob3o0?lPo`002OlPo`000ol0003o0?l4o`3o100Eo`3o1003o`000?l0obSo0?lX06?o0?lX
2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Zoooo001Aool000;o000000Go
odT0o`000?ooKP3oofh0o`000002oonC0003o`000?oo^03o000000;oomd000?o0000oogo0?l00000
0ooIo`001Ol0003o]?l0okCo0?ndo`3o000000GoSol000?o0000of[o0?mZo`000_mZo`000ol0003o
AOl0odGo0006odGo0003o`000?lPo`3o8?l000Wo8?l000?o0000o`3o1?l0o`@05Ol0o`@00ol0003o
0?lXo`3o:01So`3o:0[ooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08oookJ_ooo`00
D?oo0002o`000005oom90?l0003oofh0oom^0?l000000_ooT`002?l0003ookP0oonh0?l0003oomd0
o`000?omo`3o00000ooIo`001Ol0003o]?l0okCo0?ndo`3o000000GoSol000?o0000of[o0?mZo`00
0omZo`000ol0003oAOl0odGo0006odGo0003o`000?lPo`3o8?l000Wo8?l000?o0000o`3o1?l0o`@0
5Ol0o`@00ol0003o0?lXo`3o:01So`3o:0[ooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]Zoook
JP08oookJ_ooo`00D?oo0002o`000005oom90?l0003oofh0oom^0?l000000_ooT`000ol0003ookP0
o`000002oooM0003o`000?omo`3o000000?ofOl000Go0000okCo0?ndo`3o]?l0o`000005ohoo0003
o`000?mZo`3oJ_l000?oJ_l000?o0000odGo0?m5o`001Om5o`000ol0003o8?l0ob3o000:ob3o0003
o`000?l0o`Co0?l401Go0?l400?o0000o`3o:?l0obP0Hol0obP:oookJP7o00000OoonfX002?ooo]Z
00?o0000oookJ_oonfX02?oonf[oool0053oo`000_l000001?ooB@3o0000oom^0?l00002oonC0004
o`000?oo^03ookP0o`0000;oomd000?o0000oogo0?l000000_oIo`001Ol0003o]?l0okCo0?ndo`3o
000000GoSol000?o0000of[o0?mZo`000omZo`000ol0003oAOl0odGo0006odGo0003o`000?lPo`3o
8?l000Wo8?l000?o0000o`3o1?l0o`@05_l0o`@00ol0003o0?lXo`3o:01So`3o:0[ooo]Z0Ol00001
oookJP008ooonfX00ol0003ooo]ZoookJP08oookJ_ooo`00Cooo0002o`000005oom90?l0003oofh0
oom^0?l000000_ooT`002?l0003ookP0oonh0?l0003oomd0o`000?omo`3o00000ooIo`001Ol0003o
]?l0okCo0?ndo`3o000000GoSol000?o0000of[o0?mZo`000omZo`000ol0003oAOl0odGo0006odGo
0003o`000?lPo`3o8?l000Wo8?l000?o0000o`3o1?l0o`@05Ol0o`@00ol0003o0?lXo`3o:01To`3o
:0[ooo]Z0Ol00001oookJP008ooonfX3o`0000Sooo]Zoooo001?ool000;o000000OoodT0o`000?oo
KP3oofh0o`000?ooT`3o000000;ookP000Ko0000oooM0?oog@3o0000oogo0?l00003omWo0005o`00
0?ndo`3o]?l0okCo0?l000001On?o`000ol0003oJ_l0of[o0003of[o0003o`000?m5o`3oAOl000Go
AOl000?o0000ob3o0?lPo`002_lPo`000ol0003o0?l4o`3o100Eo`3o1003o`000?l0obSo0?lX06Co
0?lX2?oonfX3o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Zoooo001?ool000;o0000
00CoodT0o`000?ooKP3o00000_ooT`001_l0003ookP0oonh0?l0003oomd0o`0000;ooOl000Co0000
omWo0?oIo`3o00000ondo`000ol0003oSol0ohoo0003ohoo0003o`000?mZo`3oJ_l000?oJ_l000?o
0000odGo0?m5o`001_m5o`000ol0003o8?l0ob3o000:ob3o0003o`000?l0o`Co0?l401Go0?l400?o
0000o`3o:?l0obP0I?l0obP:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[o
ool004koo`000_l000001oooB@3o0000oom^0?ooKP3o0000oonC0?l000000ooo^0001Ol0003oomd0
o`000?omo`3o000000?ofOl000Go0000okCo0?ndo`3o]?l0o`000005ohoo0003o`000?mZo`3oJ_l0
00?oJ_l000?o0000odGo0?m5o`001_m5o`000ol0003o8?l0ob3o0009ob3o0003o`000?l0o`Co0?l4
01Ko0?l400?o0000o`3o:?l0obP0I?l0obP:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oo
nfX02?oonf[oool004koo`000_l000001?ooB@3o0000oom^0?l00002oonC0004o`000?oo^03ookP0
o`0000;oomd000?o0000oogo0?l000000_oIo`001Ol0003o]?l0okCo0?ndo`3o000000GoSol000?o
0000of[o0?mZo`001?mZo`000ol0003oAOl0odGo0005odGo0003o`000?lPo`3o8?l000[o8?l000?o
0000o`3o1?l0o`@05Ol0o`@00ol0003o0?lXo`3o:01Uo`3o:0[ooo]Z0Ol00001oookJP008ooonfX0
0ol0003ooo]ZoookJP08oookJ_ooo`00COoo0002o`000007oom90?l0003oofh0oom^0?l0003ooi<0
o`000003oonh0005o`000?oog@3o0000oogo0?l000000ooIo`001Ol0003o]?l0okCo0?ndo`3o0000
00GoSol000?o0000of[o0?mZo`001?mZo`000ol0003oAOl0odGo0005odGo0003o`000?lPo`3o8?l0
00[o8?l000?o0000o`3o1?l0o`@05Ol0o`@00ol0003o0?lXo`3o:01Uo`3o:0[ooo]Z0Ol00001oook
JP008ooonfX00ol0003ooo]ZoookJP08oookJ_ooo`00COoo0002o`000004oom90?l0003oofh0o`00
00;ooi<000Co0000oonh0?oo^03o00000_oog@000ol0003ooOl0o`000002omWo0005o`000?ndo`3o
]?l0okCo0?l000001On?o`000ol0003oJ_l0of[o0004of[o0003o`000?m5o`3oAOl000KoAOl000?o
0000ob3o0?lPo`002_lPo`000ol0003o0?l4o`3o100Eo`3o1003o`000?l0obSo0?lX06Go0?lX2_oo
nfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Zoooo001=ool000;o000000CoodT0
o`000?ooKP3o00000_ooT`001?l0003ookP0oonh0?l00002oooM0003o`000?omo`3o000000;ofOl0
00Go0000okCo0?ndo`3o]?l0o`000005ohoo0003o`000?mZo`3oJ_l000CoJ_l000?o0000odGo0?m5
o`001Om5o`000ol0003o8?l0ob3o000;ob3o0003o`000?l0o`Co0?l401Go0?l400?o0000o`3o:?l0
obP0IOl0obP:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[oool004coo`00
0_l000001oooB@3o0000oom^0?ooKP3o0000oonC0?l000000_oo^0001_l0003oomd0oooM0?l0003o
oOl0o`0000?ofOl000Go0000okCo0?ndo`3o]?l0o`000005ohoo0003o`000?mZo`3oJ_l000CoJ_l0
00?o0000odGo0?m5o`001Om5o`000ol0003o8?l0ob3o000:ob3o0003o`000?l0o`Co0?l401Go0?l4
00?o0000o`3o:?l0obP0I_l0obP:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oo
nf[oool004coo`000_l000001?ooB@3o0000oom^0?l00002oonC0004o`000?oo^03ookP0o`0000;o
omd000?o0000oogo0?l000000_oIo`001Ol0003o]?l0okCo0?ndo`3o000000GoSol000?o0000of[o
0?mZo`001OmZo`000ol0003oAOl0odGo0005odGo0003o`000?lPo`3o8?l000[o8?l000?o0000o`3o
1?l0o`@05Ol0o`@00ol0003o0?lXo`3o:01Vo`3o:0[ooo]Z0Ol00001oookJP008ooonfX00ol0003o
oo]ZoookJP08oookJ_ooo`00C?oo0002o`000006oom90?l0003oofh0o`000?ooT`3o00000_oo^000
1?l0003oomd0oooM0?l00002oogo0004o`000?oIo`3ofOl0o`0000?o]?l000?o0000ohoo0?n?o`00
0on?o`000ol0003oJ_l0of[o0004of[o0003o`000?m5o`3oAOl000GoAOl000?o0000ob3o0?lPo`00
2olPo`000ol0003o0?l4o`3o100Eo`3o1003o`000?l0obSo0?lX06Ko0?lX2_oonfX1o`00007ooo]Z
000SoookJP03o`000?oonf[ooo]Z00Sooo]Zoooo001;ool000;o000000CoodT0o`000?ooKP3o0000
0_ooT`001?l0003ookP0oonh0?l00002oooM0003o`000?omo`3o000000;ofOl000Go0000okCo0?nd
o`3o]?l0o`000005ohoo0003o`000?mZo`3oJ_l000GoJ_l000?o0000odGo0?m5o`001Om5o`000ol0
003o8?l0ob3o000;ob3o0003o`000?l0o`Co0?l401Go0?l400?o0000o`3o:?l0obP0I_l0obP:oook
JP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[oool004_oo`000_l000001_ooB@3o
0000oom^0?l0003ooi<0o`0000;ookP000Co0000oooM0?oog@3o00000_omo`001?l0003ofOl0omWo
0?l00003okCo0003o`000?n?o`3oSol000?oSol000?o0000of[o0?mZo`001OmZo`000ol0003oAOl0
odGo0005odGo0003o`000?lPo`3o8?l000[o8?l000?o0000o`3o1?l0o`@05_l0o`@00ol0003o0?lX
o`3o:01Vo`3o:0[ooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08oookJ_ooo`00Booo
0002o`000006oom90?l0003oofh0o`000?ooT`3o00000_oo^0001?l0003oomd0oooM0?l00002oogo
0004o`000?oIo`3ofOl0o`0000?o]?l000?o0000ohoo0?n?o`000on?o`000ol0003oJ_l0of[o0004
of[o0003o`000?m5o`3oAOl000GoAOl000?o0000ob3o0?lPo`002olPo`000ol0003o0?l4o`3o100E
o`3o1003o`000?l0obSo0?lX06Oo0?lX2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z
00Sooo]Zoooo001:ool000;o000000KoodT0o`000?ooKP3o0000oonC0?l00002oonh0004o`000?oo
g@3oomd0o`0000;ooOl000Co0000omWo0?oIo`3o00000ondo`000ol0003oSol0ohoo0003ohoo0003
o`000?mZo`3oJ_l000CoJ_l000?o0000odGo0?m5o`001_m5o`000ol0003o8?l0ob3o000;ob3o0003
o`000?l0o`Co0?l401Go0?l400?o0000o`3o:?l0obP0Iol0obP:oookJP7o00000OoonfX002?ooo]Z
00?o0000oookJ_oonfX02?oonf[oool004[oo`000_l000001_ooB@3o0000oom^0?l0003ooi<0o`00
00;ookP000Co0000oooM0?oog@3o00000_omo`001?l0003ofOl0omWo0?l00003okCo0003o`000?n?
o`3oSol000?oSol000?o0000of[o0?mZo`001?mZo`000ol0003oAOl0odGo0006odGo0003o`000?lP
o`3o8?l000_o8?l000?o0000o`3o1?l0o`@05Ol0o`@00ol0003o0?lXo`3o:01Wo`3o:0[ooo]Z0Ol0
0001oookJP008ooonfX00ol0003ooo]ZoookJP08oookJ_ooo`00BOoo0002o`000006oom90?l0003o
ofh0o`000?ooT`3o00000_oo^0001?l0003oomd0oooM0?l00003oogo0003o`000?oIo`3o000000?o
]?l000?o0000ohoo0?n?o`000on?o`000ol0003oJ_l0of[o0004of[o0003o`000?m5o`3oAOl000Ko
AOl000?o0000ob3o0?lPo`002olPo`000ol0003o0?l4o`3o100Eo`3o1003o`000?l0obSo0?lX06So
0?lX2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Zoooo0018ool00006o`00
0?oo903o0000oom90?l0003oofh00_l00002oonh0004o`000?oog@3oomd0o`0000?ooOl000Co0000
omWo0?oIo`3o00000ondo`000ol0003oSol0ohoo0003ohoo0003o`000?mZo`3oJ_l000CoJ_l000?o
0000odGo0?m5o`001_m5o`000ol0003o8?l0ob3o000;ob3o0003o`000?l0o`Co0?l401Go0?l400?o
0000o`3o:?l0obP0J?l0obP:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[o
ool004Soo`000_l000001_ooB@3o0000oom^0?l0003ooi<0o`0000;ookP000Co0000oooM0?oog@3o
00000_omo`001Ol0003ofOl0omWo0?oIo`3o000000;o]?l000?o0000ohoo0?n?o`000on?o`000ol0
003oJ_l0of[o0004of[o0003o`000?m5o`3oAOl000OoAOl000?o0000ob3o0?lPo`002_lPo`000ol0
003o0?l4o`3o100Fo`3o1003o`000?l0obSo0?lX06So0?lX2_oonfX1o`00007ooo]Z000SoookJP03
o`000?oonf[ooo]Z00Sooo]Zoooo0017ool00008o`000?oo903o0000o`000?ooKP3o0000oonC0?l0
0002oonh0004o`000?oog@3oomd0o`0000?ooOl000Co0000omWo0?oIo`3o00000ondo`000ol0003o
Sol0ohoo0003ohoo0003o`000?mZo`3oJ_l000CoJ_l000?o0000odGo0?m5o`001_m5o`000ol0003o
8?l0ob3o000;ob3o0003o`000?l0o`Co0?l401Go0?l400?o0000o`3o:?l0obP0JOl0obP:oookJP7o
00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[oool004Ooo`000_l000002?ooB@3o0000
oom^0?l0003ooi<0o`000?oo^03o00000_oog@001Ol0003ooOl0oogo0?omo`3o000000?ofOl000Go
0000okCo0?ndo`3o]?l0o`000004ohoo0003o`000?mZo`3oJ_l000CoJ_l000?o0000odGo0?m5o`00
1om5o`000ol0003o8?l0ob3o000:ob3o0003o`000?l0o`Co0?l401Ko0?l400?o0000o`3o:?l0obP0
JOl0obP:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[oool004Koo`000_l0
00001_ooB@3o0000oom^0?l0003ooi<0o`0000;ookP000Co0000oooM0?oog@3o00000_omo`000ol0
003ofOl0omWo0002omWo0004o`000?ndo`3o]?l0o`0000GoSol000?o0000of[o0?mZo`001?mZo`00
0ol0003oAOl0odGo0006odGo0003o`000?lPo`3o8?l000_o8?l000?o0000o`3o1?l0o`@05_l0o`@0
0ol0003o0?lXo`3o:01Yo`3o:0[ooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08oook
J_ooo`00AOoo00001_l0003oob@0o`000?ooB@3o0000oom^00;o00000_oo^0001?l0003oomd0oooM
0?l00003oogo0005o`000?oIo`3ofOl0omWo0?l000000ondo`000ol0003oSol0ohoo0002ohoo0003
o`000?mZo`3oJ_l000CoJ_l000?o0000odGo0?m5o`001om5o`000ol0003o8?l0ob3o000;ob3o0003
o`000?l0o`Co0?l401Go0?l400?o0000o`3o:?l0obP0J_l0obP:oookJP7o00000OoonfX002?ooo]Z
00?o0000oookJ_oonfX02?oonf[oool004Goo`000_l000001_ooB@3o0000oom^0?l0003ooi<0o`00
00;ookP000Co0000oooM0?oog@3o00000_omo`000ol0003ofOl0omWo0002omWo0004o`000?ndo`3o
]?l0o`0000GoSol000?o0000of[o0?mZo`001?mZo`000ol0003oAOl0odGo0006odGo0003o`000?lP
o`3o8?l000_o8?l000?o0000o`3o1?l0o`@05_l0o`@00ol0003o0?lXo`3o:01Zo`3o:0[ooo]Z0Ol0
0001oookJP008ooonfX00ol0003ooo]ZoookJP08oookJ_ooo`00A?oo00001?l0003oob@0o`000?oo
B@02o`000005oonC0?l0003ookP0oonh0?l000000_oog@001?l0003ooOl0oogo0?l00004omWo0005
o`000?ndo`3o]?l0okCo0?l000001?n?o`000ol0003oJ_l0of[o0004of[o0003o`000?m5o`3oAOl0
00OoAOl000?o0000ob3o0?lPo`002olPo`000ol0003o0?l4o`3o100Fo`3o1003o`000?l0obSo0?lX
06[o0?lX2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Zoooo0013ool0000;
o`000?oo903o0000oom90?l0003oofh0o`000?ooT`3o0000oonh0?l000000_oog@001Ol0003ooOl0
oogo0?omo`3o000000?ofOl000Go0000okCo0?ndo`3o]?l0o`000005ohoo0003o`000?mZo`3oJ_l0
00CoJ_l000?o0000odGo0?m5o`001om5o`000ol0003o8?l0ob3o000:ob3o0003o`000?l0o`Co0?l4
01Ko0?l400?o0000o`3o:?l0obP0Jol0obP:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oo
nfX02?oonf[oool004;oo`0000?o0000oolT0?oo90000_l000001?ooKP3o0000oonC0?l00002oonh
0004o`000?oog@3oomd0o`0000;ooOl000?o0000omWo0?oIo`000_oIo`001Ol0003o]?l0okCo0?nd
o`3o000000CoSol000?o0000of[o0?mZo`001?mZo`000ol0003oAOl0odGo0007odGo0003o`000?lP
o`3o8?l000_o8?l000?o0000o`3o1?l0o`@05_l0o`@00ol0003o0?lXo`3o:01[o`3o:0[ooo]Z0Ol0
0001oookJP008ooonfX3o`0000Sooo]Zoooo0011ool00007o`000?oo903oob@0o`000?ooB@3o0000
oom^0002o`0000;ookP000Co0000oooM0?oog@3o00000_omo`000ol0003ofOl0omWo0002omWo0003
o`000?ndo`3o]?l000;o]?l000?o0000ohoo0?n?o`000_n?o`000ol0003oJ_l0of[o0004of[o0003
o`000?m5o`3oAOl000OoAOl000?o0000ob3o0?lPo`002_lPo`000ol0003o0?l4o`3o100Go`3o1003
o`000?l0obSo0?lX06_o0?lX2?oonfX3o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Z
oooo0010ool0000<o`000?oo903oob@0o`000?ooB@3o0000oom^0?l0003ooi<0o`000?oo^03o0000
0_oog@001Ol0003ooOl0oogo0?omo`3o000000?ofOl000?o0000okCo0?ndo`000_ndo`000ol0003o
Sol0ohoo0002ohoo0003o`000?mZo`3oJ_l000CoJ_l000?o0000odGo0?m5o`001om5o`000ol0003o
8?l0ob3o000;ob3o0003o`000?l0o`Co0?l401Ko0?l400?o0000o`3o:?l0obP0K?l0obP:oookJP7o
00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[oool003ooo`0000Co0000oolT0?oo903o
00000_ooB@02o`000005oonC0?l0003ookP0oonh0?l000000_oog@001?l0003ooOl0oogo0?l00004
omWo0003o`000?ndo`3o]?l000;o]?l000?o0000ohoo0?n?o`000_n?o`000ol0003oJ_l0of[o0004
of[o0003o`000?m5o`3oAOl000OoAOl000?o0000ob3o0?lPo`002_lPo`000ol0003o0?l4o`3o100G
o`3o1003o`000?l0obSo0?lX06co0?lX2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z
00Sooo]Zoooo000oool00003o`000?oo903o000000;oodT000Oo0000oom^0?l0003ooi<0o`000?oo
^03o000000;oomd000Co0000oogo0?omo`3o00001?oIo`000ol0003o]?l0okCo0002okCo0003o`00
0?n?o`3oSol000;oSol000?o0000of[o0?mZo`001?mZo`000ol0003oAOl0odGo0008odGo0003o`00
0?lPo`3o8?l000[o8?l000?o0000o`3o1?l0o`@05_l0o`@00ol0003o0?lXo`3o:01]o`3o:0[ooo]Z
0Ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08oookJ_ooo`00?_oo00000ol0003oob@0o`00
0002oom90007o`000?ooKP3o0000oonC0?l0003ookP0o`000002oooM0005o`000?omo`3ooOl0oogo
0?l000001?oIo`000ol0003o]?l0okCo0002okCo0003o`000?n?o`3oSol000;oSol000?o0000of[o
0?mZo`001?mZo`000ol0003oAOl0odGo0007odGo0003o`000?lPo`3o8?l000[o8?l000?o0000o`3o
1?l0o`@05ol0o`@00ol0003o0?lXo`3o:01]o`3o:0[ooo]Z0Ol00001oookJP008ooonfX00ol0003o
oo]ZoookJP08oookJ_ooo`00?Ooo00000ol0003oob@0o`000002oom90003o`000?ooKP3oofh000;o
00000_oo^0001?l0003oomd0oooM0?l00002oogo0003o`000?oIo`3ofOl000;ofOl000?o0000okCo
0?ndo`000_ndo`000ol0003oSol0ohoo0002ohoo0003o`000?mZo`3oJ_l000CoJ_l000?o0000odGo
0?m5o`002?m5o`000ol0003o8?l0ob3o000:ob3o0003o`000?l0o`Co0?l401Oo0?l400?o0000o`3o
:?l0obP0KOl0obP:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[oool003co
o`0000?o0000oolT0?l000000_ooB@002?l0003oofh0oom^0?l0003ooi<0o`000?oo^03o00000_oo
g@001?l0003ooOl0oogo0?l00004omWo0003o`000?ndo`3o]?l000;o]?l000?o0000ohoo0?n?o`00
0on?o`000ol0003oJ_l0of[o0004of[o0003o`000?m5o`3oAOl000OoAOl000?o0000ob3o0?lPo`00
2olPo`000ol0003o0?l4o`3o100Fo`3o1003o`000?l0obSo0?lX06ko0?lX2_oonfX1o`00007ooo]Z
000SoookJP03o`000?oonf[ooo]Z00Sooo]Zoooo000kool00003o`000?oo903o000000;oodT000Ko
0000oom^0?ooKP3o0000oonC0?l00002oonh0004o`000?oog@3oomd0o`0000;ooOl000?o0000omWo
0?oIo`000_oIo`000ol0003o]?l0okCo0002okCo0003o`000?n?o`3oSol000;oSol000?o0000of[o
0?mZo`001?mZo`000ol0003oAOl0odGo0007odGo0003o`000?lPo`3o8?l000_o8?l000?o0000o`3o
1?l0o`@05ol0o`@00ol0003o0?lXo`3o:01^o`3o:0[ooo]Z0Ol00001oookJP008ooonfX00ol0003o
oo]ZoookJP08oookJ_ooo`00>_oo00000ol0003oob@0o`000002oom90004o`000?ooKP3oofh0o`00
00;ooi<000?o0000oonh0?l000000_oog@001?l0003ooOl0oogo0?l00004omWo0003o`000?ndo`3o
]?l000;o]?l000?o0000ohoo0?n?o`000on?o`000ol0003oJ_l0of[o0004of[o0003o`000?m5o`3o
AOl000OoAOl000?o0000ob3o0?lPo`002olPo`000ol0003o0?l4o`3o100Go`3o1003o`000?l0obSo
0?lX06ko0?lX00?o0000oookJ_oonfX01ooonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z
00Sooo]Zoooo000hool000Co000000CoodT0o`000?l0003oofh00_l000001OooT`3o0000o`000?oo
^03o000000;oomd000Co0000oogo0?omo`3o00001?oIo`000ol0003o]?l0okCo0002okCo0003o`00
0?n?o`3oSol000?oSol000?o0000of[o0?mZo`001?mZo`000ol0003oAOl0odGo0007odGo0003o`00
0?lPo`3o8?l000_o8?l000?o0000o`3o1?l0o`@05ol0o`@00ol0003o0?lXo`3o:01_o`3o:003o`00
0?oonf[ooo]Z00Oooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08oookJ_ooo`00=ooo
00000ol0003oob@0o`000002oom90004o`000?ooKP3oofh0o`0000;ooi<000Go0000oonh0?oo^03o
okP0o`000002oooM0004o`000?omo`3ooOl0o`0000CofOl000?o0000okCo0?ndo`000_ndo`000ol0
003oSol0ohoo0003ohoo0003o`000?mZo`3oJ_l000CoJ_l000?o0000odGo0?m5o`001om5o`000ol0
003o8?l0ob3o000;ob3o0003o`000?l0o`Co0?l401Oo0?l400?o0000o`3o:?l0obP0Kol0obP00ol0
003ooo]ZoookJP07oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[oool003Ko
o`0000?o0000oolT0?l000000_ooB@001?l0003oofh0oom^0?l00002oonC0003o`000?oo^03ookP0
00;o00000_oog@001?l0003ooOl0oogo0?l00004omWo0003o`000?ndo`3o]?l000;o]?l000?o0000
ohoo0?n?o`000on?o`000ol0003oJ_l0of[o0004of[o0003o`000?m5o`3oAOl000OoAOl000?o0000
ob3o0?lPo`002olPo`000ol0003o0?l4o`3o100Go`3o1003o`000?l0obSo0?lX073o0?lX00?o0000
oookJ_oonfX01ooonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Zoooo000eool0
0003o`000?oo903o000000;oodT000Co0000oom^0?ooKP3o00000_ooT`001?l0003ookP0oonh0?l0
0003oooM0004o`000?omo`3ooOl0o`0000CofOl000?o0000okCo0?ndo`000_ndo`000ol0003oSol0
ohoo0003ohoo0003o`000?mZo`3oJ_l000CoJ_l000?o0000odGo0?m5o`001om5o`000ol0003o8?l0
ob3o000<ob3o0003o`000?l0o`Co0?l401Oo0?l400?o0000o`3o:?l0obP0Kol0obP00ol0003ooo]Z
oookJP08oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[oool003Coo`0000?o
0000oolT0?l000000_ooB@001?l0003oofh0oom^0?l00002oonC0004o`000?oo^03ookP0o`0000?o
omd000Go0000oogo0?omo`3ooOl0o`000003omWo0003o`000?ndo`3o]?l000;o]?l000?o0000ohoo
0?n?o`001?n?o`000ol0003oJ_l0of[o0004of[o0003o`000?m5o`3oAOl000OoAOl000?o0000ob3o
0?lPo`002olPo`000ol0003o0?l4o`3o100Go`3o1003o`000?l0obSo0?lX073o0?lX00?o0000oook
J_oonfX02?oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Zoooo000cool00003
o`000?oo903o000000;oodT000Co0000oom^0?ooKP3o00000_ooT`001?l0003ookP0oonh0?l00003
oooM0005o`000?omo`3ooOl0oogo0?l000000ooIo`000ol0003o]?l0okCo0002okCo0003o`000?n?
o`3oSol000CoSol000?o0000of[o0?mZo`001?mZo`000ol0003oAOl0odGo0007odGo0003o`000?lP
o`3o8?l000co8?l000?o0000o`3o1?l0o`@05ol0o`@00ol0003o0?lXo`3o:01`o`3o:003o`000?oo
nf[ooo]Z00Sooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08oookJ_ooo`00<_oo0000
0ol0003oob@0o`000002oom90004o`000?ooKP3oofh0o`0000;ooi<000Co0000oonh0?oo^03o0000
0ooog@001Ol0003ooOl0oogo0?omo`3o000000CofOl000?o0000okCo0?ndo`000_ndo`000ol0003o
Sol0ohoo0003ohoo0003o`000?mZo`3oJ_l000CoJ_l000?o0000odGo0?m5o`001om5o`000ol0003o
8?l0ob3o000<ob3o0003o`000?l0o`Co0?l401Oo0?l400?o0000o`3o:?l0obP0L?l0obP00ol0003o
0?m=oookJP09oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[oool0037oo`00
00?o0000oolT0?l000000_ooB@001?l0003oofh0oom^0?l00002oonC0004o`000?oo^03ookP0o`00
00?oomd000Go0000oogo0?omo`3ooOl0o`000004omWo0003o`000?ndo`3o]?l000;o]?l000?o0000
ohoo0?n?o`000on?o`000ol0003oJ_l0of[o0004of[o0003o`000?m5o`3oAOl000SoAOl000?o0000
ob3o0?lPo`002olPo`000ol0003o0?l4o`3o100Ho`3o1003o`000?l0obSo0?lX073o0?lX00?o0000
o`3oCOoonfX02OoonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Zoooo000`ool0
0003o`000?oo903o000000;oodT000Co0000oom^0?ooKP3o00000_ooT`001?l0003ookP0oonh0?l0
0003oooM0003o`000?omo`3ooOl000;ooOl000Go0000omWo0?oIo`3ofOl0o`000004okCo0003o`00
0?n?o`3oSol000?oSol000?o0000of[o0?mZo`001OmZo`000ol0003oAOl0odGo0007odGo0003o`00
0?lPo`3o8?l000co8?l000?o0000o`3o1?l0o`@05ol0o`@00ol0003o0?lXo`3o:01ao`3o:003o`00
0?l0odgooo]Z00Wooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08oookJ_ooo`00;_oo
0002o`000005oolT0?l0003oodT0oom90?l000000_ooKP001?l0003ooi<0oonC0?l00002oonh0005
o`000?oog@3oomd0oooM0?l000001?omo`001Ol0003ofOl0omWo0?oIo`3o000000Co]?l000?o0000
ohoo0?n?o`000on?o`000ol0003oJ_l0of[o0005of[o0003o`000?m5o`3oAOl000OoAOl000?o0000
ob3o0?lPo`003?lPo`000ol0003o0?l4o`3o100Ho`3o1003o`000?l0obSo0?lX077o0?lX00?o0000
o`3oCOoonfX02OoonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Zoooo000]ool0
0004o`000?oo903oob@0o`0000;oodT000Co0000oom^0?ooKP3o00000_ooT`001?l0003ookP0oonh
0?l00003oooM0004o`000?omo`3ooOl0oogo00;o00000ooIo`000ol0003o]?l0okCo0002okCo0003
o`000?n?o`3oSol000CoSol000?o0000of[o0?mZo`001?mZo`000ol0003oAOl0odGo0008odGo0003
o`000?lPo`3o8?l000co8?l000?o0000o`3o1?l0o`@05ol0o`@00ol0003o0?lXo`3o:01ao`3o:003
o`000?l0odgo0?m=00[ooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08oookJ_ooo`00
;?oo00001?l0003oob@0o`000?l00002oom90004o`000?ooKP3oofh0o`0000;ooi<000Co0000oonh
0?oo^03o00000ooog@001Ol0003ooOl0oogo0?omo`3o000000GofOl000Go0000okCo0?ndo`3o]?l0
o`000006ohoo0003o`000?mZo`3oJ_l000GoJ_l000?o0000odGo0?m5o`001om5o`000ol0003o8?l0
ob3o000<ob3o0003o`000?l0o`Co0?l401Oo0?l400?o0000o`3o:?l0obP0L_l0obP00ol0003o0?m=
o`3oC@0:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[oool002_oo`0000?o
0000oolT0?l000000oooB@001?l0003oofh0oom^0?l00002oonC0004o`000?oo^03ookP0o`0000?o
omd000Go0000oogo0?omo`3ooOl0o`000005omWo0003o`000?ndo`3o]?l000;o]?l000?o0000ohoo
0?n?o`000on?o`000ol0003oJ_l0of[o0005of[o0003o`000?m5o`3oAOl000OoAOl000?o0000ob3o
0?lPo`003OlPo`000ol0003o0?l4o`3o100Go`3o1003o`000?l0obSo0?lX07;o0?lX00?o0000o`3o
COl0odd02_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Zoooo000Zool00003
o`000?oo903o000000?oodT000Co0000oom^0?ooKP3o00000_ooT`001?l0003ookP0oonh0?l00003
oooM0005o`000?omo`3ooOl0oogo0?l000001OoIo`000ol0003o]?l0okCo0002okCo0003o`000?n?
o`3oSol000?oSol000?o0000of[o0?mZo`001OmZo`000ol0003oAOl0odGo0008odGo0003o`000?lP
o`3o8?l000co8?l000?o0000o`3o1?l0o`@05ol0o`@00ol0003o0?lXo`3o:01bo`3o:004o`000?l0
odgo0?m=o`3oC@[ooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08oookJ_ooo`00:Ooo
00000ol0003oob@0o`000002oom900;o00000_ooKP001?l0003ooi<0oonC0?l00002oonh0005o`00
0?oog@3oomd0oooM0?l000000oomo`000ol0003ofOl0omWo0003omWo0003o`000?ndo`3o]?l000;o
]?l000?o0000ohoo0?n?o`000on?o`000ol0003oJ_l0of[o0006of[o0003o`000?m5o`3oAOl000Oo
AOl000?o0000ob3o0?lPo`003OlPo`000ol0003o0?l4o`3o100Go`3o1003o`000?l0obSo0?lX07;o
0?lX00Co0000o`3oCOl0odgo0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00So
oo]Zoooo000Wool000;o000000Goob@0o`000?ooB@3oodT0o`000003oom^0004o`000?ooT`3ooi<0
o`0000;ookP000Go0000oooM0?oog@3oomd0o`000003oogo0003o`000?oIo`3ofOl000?ofOl000?o
0000okCo0?ndo`000_ndo`000ol0003oSol0ohoo0003ohoo0003o`000?mZo`3oJ_l000KoJ_l000?o
0000odGo0?m5o`001om5o`000ol0003o8?l0ob3o000=ob3o0003o`000?l0o`Co0?l401Oo0?l400?o
0000o`3o:?l0obP0Lol0obP01?l0003o0?m=o`3oCOl0odd:oookJP7o00000OoonfX002?ooo]Z00?o
0000oookJ_oonfX02?oonf[oool002Koo`0000Co0000oolT0?oo903o00000_ooB@001Ol0003oofh0
oom^0?ooKP3o000000;ooi<000Co0000oonh0?oo^03o00000ooog@001Ol0003ooOl0oogo0?omo`3o
000000GofOl000?o0000okCo0?ndo`000_ndo`000ol0003oSol0ohoo0004ohoo0003o`000?mZo`3o
J_l000GoJ_l000?o0000odGo0?m5o`002?m5o`000ol0003o8?l0ob3o000<ob3o0003o`000?l0o`Co
0?l401So0?l400?o0000o`3o:?l0obP0Lol0obP01?l0003o0?m=o`3oCOl0odd:oookJP7o00000Ooo
nfX002?ooo]Z0ol00008oookJ_ooo`009Ooo00001?l0003oob@0oolT0?l00002oom90003o`000?oo
KP3oofh000;o00000_ooT`001?l0003ookP0oonh0?l00003oooM0005o`000?omo`3ooOl0oogo0?l0
00001OoIo`000ol0003o]?l0okCo0003okCo0003o`000?n?o`3oSol000?oSol000?o0000of[o0?mZ
o`001OmZo`000ol0003oAOl0odGo0008odGo0003o`000?lPo`3o8?l000go8?l000?o0000o`3o1?l0
o`@05ol0o`@00ol0003o0?lXo`3o:01co`3o:003o`000?l0odgo0?m=00;o0?m=2?oonfX3o`00007o
oo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Zoooo000Tool00004o`000?oo903oob@0o`0000;o
odT000Co0000oom^0?ooKP3o00000oooT`001?l0003ookP0oonh0?l00003oooM0005o`000?omo`3o
oOl0oogo0?l000001OoIo`000ol0003o]?l0okCo0003okCo0003o`000?n?o`3oSol000?oSol000?o
0000of[o0?mZo`001_mZo`000ol0003oAOl0odGo0007odGo0003o`000?lPo`3o8?l000go8?l000?o
0000o`3o1?l0o`@06?l0o`@00ol0003o0?lXo`3o:01co`3o:003o`000?l0odgo0?m=00;o0?m=2_oo
nfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Zoooo000Sool00004o`000?oo903o
ob@0o`0000;oodT000Co0000oom^0?ooKP3o00000oooT`001?l0003ookP0oonh0?l00003oooM0005
o`000?omo`3ooOl0oogo0?l000001OoIo`000ol0003o]?l0okCo0003okCo0003o`000?n?o`3oSol0
00?oSol000?o0000of[o0?mZo`001_mZo`000ol0003oAOl0odGo0008odGo0003o`000?lPo`3o8?l0
00go8?l000?o0000o`3o1?l0o`@05ol0o`@00ol0003o0?lXo`3o:01do`3o:003o`000?l0odgo0?m=
00;o0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Zoooo000Rool00004
o`000?oo903oob@0o`0000;oodT000Co0000oom^0?ooKP3o00000_ooT`02o`0000;ookP000Go0000
oooM0?oog@3oomd0o`000003oogo0003o`000?oIo`3ofOl000?ofOl000?o0000okCo0?ndo`000ond
o`000ol0003oSol0ohoo0003ohoo0003o`000?mZo`3oJ_l000KoJ_l000?o0000odGo0?m5o`002?m5
o`000ol0003o8?l0ob3o000=ob3o0003o`000?l0o`Co0?l401So0?l400?o0000o`3o:?l0obP0Lol0
obP00ol0003o0?m=o`3oC@03o`3oC@[ooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08
oookJ_ooo`008?oo0002o`000004oolT0?l0003o0000oom900;o000000Coofh0o`000?l0003ooi<0
0_l00003oonh0003o`000?oog@3oomd000;o00000_omo`02o`0000CofOl00_l00004okCo00;o0000
1On?o`000ol0003oJ_l0of[o0006of[o0003o`000?m5o`3oAOl000SoAOl000?o0000ob3o0?lPo`00
3OlPo`000ol0003o0?l4o`3o100Ho`3o1003o`000?l0obSo0?lX07Co0?lX00?o0000o`3oCOl0odd0
0ol0odd:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[oool001koo`000_l0
00001?oo903o0000o`000?ooB@02o`000003oom^0?l0003o000000;ooi<000?o0000oonh0?oo^000
0_oo^0001?l0003oomd0oooM0?l00003oogo0003o`000?oIo`3ofOl000?ofOl000?o0000okCo0?nd
o`000ondo`000ol0003oSol0ohoo0005ohoo0003o`000?mZo`3oJ_l000KoJ_l000?o0000odGo0?m5
o`002?m5o`000ol0003o8?l0ob3o000=ob3o0003o`000?l0o`Co0?l401So0?l400?o0000o`3o:?l0
obP0M?l0obP00ol0003o0?m=o`3oC@03o`3oC@[ooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]Z
oookJP08oookJ_ooo`007?oo0002o`000003oolT0?l0003o000000;oodT000Co0000oom^0?ooKP3o
00000_ooT`02o`0000?ookP00_l000000ooog@3o0000o`000003oogo0003o`000?oIo`3ofOl000?o
fOl000?o0000okCo0?ndo`000ondo`000ol0003oSol0ohoo0005ohoo0003o`000?mZo`3oJ_l000Ko
J_l000?o0000odGo0?m5o`002?m5o`000ol0003o8?l0ob3o000=ob3o0003o`000?l0o`Co0?l401So
0?l400?o0000o`3o:?l0obP0M?l0obP00ol0003o0?m=o`3oC@04o`3oC@[ooo]Z0Ol00001oookJP00
8ooonfX00ol0003ooo]ZoookJP08oookJ_ooo`006_oo0002o`0000;oob@000?o0000oom90?ooB@00
0_l000000oooKP3o0000o`000002oonC0004o`000?oo^03ookP0oonh00;o00000_oog@000ol0003o
oOl0oogo0002oogo0003o`000?oIo`3ofOl000?ofOl000?o0000okCo0?ndo`000ondo`000ol0003o
Sol0ohoo0005ohoo0003o`000?mZo`3oJ_l000KoJ_l000?o0000odGo0?m5o`002?m5o`000ol0003o
8?l0ob3o000=ob3o0003o`000?l0o`Co0?l401So0?l400?o0000o`3o:?l0obP0MOl0obP00ol0003o
0?m=o`3oC@04o`3oC@[ooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08oookJ_ooo`00
6?oo0002o`0000;oob@00_l000001?ooB@3o0000o`000?ooKP02o`0000;ooi<00_l00003oonh0003
o`000?oog@3oomd000;o00000oomo`02o`0000CofOl00_l00004okCo00;o00001on?o`000ol0003o
J_l0of[o0006of[o0003o`000?m5o`3oAOl000SoAOl000?o0000ob3o0?lPo`003OlPo`000ol0003o
0?l4o`3o100Io`3o1003o`000?l0obSo0?lX07Go0?lX00?o0000o`3oCOl0odd01?l0odd:oookJP7o
00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[oool001Koo`000_l00002oolT00;o0000
00?oodT0o`000?l000000_ooKP001Ol0003ooi<0oonC0?ooT`3o000000?ookP00_l00002oooM0003
o`000?omo`3ooOl000;ooOl000?o0000omWo0?oIo`000ooIo`000ol0003o]?l0okCo0003okCo0003
o`000?n?o`3oSol000KoSol000?o0000of[o0?mZo`001_mZo`000ol0003oAOl0odGo0008odGo0003
o`000?lPo`3o8?l000go8?l000?o0000o`3o1?l0o`@06Ol0o`@00ol0003o0?lXo`3o:01eo`3o:003
o`000?l0odgo0?m=00Go0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Z
oooo000Dool000;o00000_oo9002o`0000;oodT000?o0000oom^0?ooKP000_l00002oonC00;o0000
0_oo^002o`0000;oomd00_l00004oogo0003o`000?oIo`3ofOl000?ofOl000?o0000okCo0?ndo`00
0ondo`000ol0003oSol0ohoo0006ohoo0003o`000?mZo`3oJ_l000KoJ_l000?o0000odGo0?m5o`00
2?m5o`000ol0003o8?l0ob3o000=ob3o0003o`000?l0o`Co0?l401[o0?l400?o0000o`3o:?l0obP0
MOl0obP00ol0003o0?m=o`3oC@05o`3oC@[ooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]Zoook
JP08oookJ_ooo`004_oo0002o`0000;oob@00_l00002oom900;o000000?oofh0o`000?l000000_oo
T`02o`0000?ookP000Go0000oooM0?oog@3oomd0o`000005oogo0003o`000?oIo`3ofOl000?ofOl0
00?o0000okCo0?ndo`000ondo`000ol0003oSol0ohoo0005ohoo00;o00002?mZo`000ol0003oAOl0
odGo0009odGo0003o`000?lPo`3o8?l000go8?l000?o0000o`3o1?l0o`@06Ol0o`@00ol0003o0?lX
o`3o:01fo`3o:003o`000?l0odgo0?m=00Go0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`000?oo
nf[ooo]Z00Sooo]Zoooo000@ool000;o00000_oo9002o`0000;oodT00_l00002oom^0005o`000?oo
T`3ooi<0oonC0?l000000ooo^002o`0000;oomd00_l00004oogo00;o00001OoIo`000ol0003o]?l0
okCo0003okCo0003o`000?n?o`3oSol000GoSol000?o0000of[o0?mZo`001omZo`000ol0003oAOl0
odGo0009odGo0003o`000?lPo`3o8?l000go8?l000?o0000o`3o1?l0o`@06Ol0o`@00ol0003o0?lX
o`3o:01fo`3o:003o`000?l0odgo0?m=00Ko0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`000?oo
nf[ooo]Z00Sooo]Zoooo000=ool000?o00000_oo9002o`0000;oodT00_l00002oom^00;o00000_oo
T`02o`0000;ookP00_l00003oooM0003o`000?omo`3ooOl000?ooOl000?o0000omWo0?oIo`000ooI
o`02o`0000Co]?l00_l00007ohoo0003o`000?mZo`3oJ_l000OoJ_l000?o0000odGo0?m5o`002Om5
o`000ol0003o8?l0ob3o000=ob3o0003o`000?l0o`Co0?l401[o0?l400?o0000o`3o:?l0obP0M_l0
obP00ol0003o0?m=o`3oC@06o`3oC@[ooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08
oookJ_ooo`002ooo0002o`0000?oob@00_l00002oom900;o00000_ooKP02o`0000?ooi<000Go0000
oonh0?oo^03ookP0o`000003oooM00;o00001Oomo`000ol0003ofOl0omWo0003omWo0003o`000?nd
o`3o]?l000?o]?l000?o0000ohoo0?n?o`001_n?o`000ol0003oJ_l0of[o0007of[o0003o`000?m5
o`3oAOl000WoAOl000?o0000ob3o0?lPo`003OlPo`000ol0003o0?l4o`3o100Jo`3o1003o`000?l0
obSo0?lX07Oo0?lX00?o0000o`3oCOl0odd01_l0odd:oookJP7o00000OoonfX002?ooo]Z00?o0000
oookJ_oonfX02?oonf[oool000Woo`000_l00002oolT00?o00000_ooB@02o`0000;oofh00_l00003
oonC00;o00000_oo^002o`0000?oomd000?o0000oogo0?omo`000oomo`02o`0000GofOl000?o0000
okCo0?ndo`000ondo`000ol0003oSol0ohoo0006ohoo0003o`000?mZo`3oJ_l000OoJ_l000?o0000
odGo0?m5o`002Om5o`000ol0003o8?l0ob3o000=ob3o0003o`000?l0o`Co0?l401[o0?l400?o0000
o`3o:?l0obP0Mol0obP00ol0003o0?m=o`3oC@07o`3oC@[ooo]Z0Ol00001oookJP008ooonfX00ol0
003ooo]ZoookJP08oookJ_ooo`001ooo0002o`0000;oob@00_l00003oom900;o00000_ooKP02o`00
00Cooi<000?o0000oonh0?oo^0000_l00004oooM0003o`000?omo`3ooOl000?ooOl000?o0000omWo
0?oIo`001?oIo`000ol0003o]?l0okCo0003okCo0003o`000?n?o`3oSol000KoSol000?o0000of[o
0?mZo`001omZo`000ol0003oAOl0odGo0009odGo0003o`000?lPo`3o8?l000ko8?l000?o0000o`3o
1?l0o`@06_l0o`@00ol0003o0?lXo`3o:01go`3o:003o`000?l0odgo0?m=00Oo0?m=2_oonfX1o`00
007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Zoooo0005ool000;o00000_oo9002o`0000;o
odT00ol00002oom^00;o00001?ooT`02o`0000;ookP000?o0000oooM0?oog@000_oog@02o`0000Go
oOl000?o0000omWo0?oIo`000ooIo`02o`0000Co]?l00_l00008ohoo0003o`000?mZo`3oJ_l000Oo
J_l000?o0000odGo0?m5o`002Om5o`000ol0003o8?l0ob3o000>ob3o0003o`000?l0o`Co0?l401[o
0?l400?o0000o`3o:?l0obP0Mol0obP00ol0003o0?m=o`3oC@08o`3oC@[ooo]Z0Ol00001oookJP00
8ooonfX00ol0003ooo]ZoookJP08oookJ_ooo`000ooo0002o`0000;oob@00_l00002oom900;o0000
0oooKP02o`0000Cooi<00_l00002oonh00;o00001?oog@000ol0003ooOl0oogo0003oogo00;o0000
1OoIo`000ol0003o]?l0okCo0003okCo0003o`000?n?o`3oSol000KoSol00_l00009of[o0003o`00
0?m5o`3oAOl000WoAOl000?o0000ob3o0?lPo`003_lPo`000ol0003o0?l4o`3o100Jo`3o1003o`00
0?l0obSo0?lX07So0?lX00?o0000o`3oCOl0odd02?l0odd:oookJP7o00000OoonfX002?ooo]Z00?o
0000oookJ_oonfX02?oonf[oool000?o00000_oo9002o`0000;oodT00_l00003oom^00;o00001Ooo
T`000ol0003ookP0oonh0002o`0000Coomd00_l00005oogo0003o`000?oIo`3ofOl000CofOl000?o
0000okCo0?ndo`000ondo`000ol0003oSol0ohoo0006ohoo0003o`000?mZo`3oJ_l000SoJ_l000?o
0000odGo0?m5o`002Om5o`000ol0003o8?l0ob3o000>ob3o0003o`000?l0o`Co0?l401_o0?l400?o
0000o`3o:?l0obP0N?l0obP00ol0003o0?m=o`3oC@08o`3oC@[ooo]Z0Ol00001oookJP008ooonfX0
0ol0003ooo]ZoookJP08oookJ_goo`000_l00003oolT00;o00000_ooB@02o`0000Coofh000?o0000
oonC0?ooT`000oooT`02o`0000;ookP000?o0000oooM0?oog@000ooog@000ol0003ooOl0oogo0003
oogo00;o00001OoIo`02o`0000Go]?l000?o0000ohoo0?n?o`001_n?o`000ol0003oJ_l0of[o0007
of[o00;o00002om5o`000ol0003o8?l0ob3o000>ob3o0003o`000?l0o`Co0?l401_o0?l400?o0000
o`3o:?l0obP0N?l0obP00ol0003o0?m=o`3oC@09o`3oC@[ooo]Z0Ol00001oookJP008ooonfX00ol0
003ooo]ZoookJP08oookJ__oo`000_l00003oolT00;o00000_ooB@02o`0000Coofh00_l00004oonC
00;o00000_oo^002o`0000Coomd00_l00005oogo0003o`000?oIo`3ofOl000CofOl000?o0000okCo
0?ndo`001?ndo`000ol0003oSol0ohoo0006ohoo0003o`000?mZo`3oJ_l000OoJ_l000?o0000odGo
0?m5o`002_m5o`000ol0003o8?l0ob3o000>ob3o0003o`000?l0o`Co0?l401co0?l400?o0000o`3o
:?l0obP0N?l0obP00ol0003o0?m=o`3oC@09o`3oC@[ooo]Z0Ol00001oookJP001?oonfX5o`00O`Co
oo]Z0ol007l3oookJPGo001o2ooonfX00ol0003ooo]ZoookJP08oookJ_Soo`000ol00003oolT00;o
00000_ooB@02o`0000Coofh00_l00004oonC00;o00000ooo^0000ol0003oomd0oooM0003oooM0003
o`000?omo`3ooOl000CooOl000?o0000omWo0?oIo`001?oIo`000ol0003o]?l0okCo0004okCo0003
o`000?n?o`3oSol000KoSol000?o0000of[o0?mZo`001omZo`000ol0003oAOl0odGo000:odGo0003
o`000?lPo`3o8?l000oo8?l000?o0000o`3o1?l0o`@06ol0o`@00ol0003o0?lXo`3o:01io`3o:003
o`000?l0odgo0?m=00Wo0?m=2_oonfX1o`00007ooo]Z0003oookJPOo001o0ooonfX3o`00O`;ooo]Z
1ol007l:oookJP03o`000?oonf[ooo]Z00Sooo]Zm_oo0002o`0000?oob@00ol00002oom900;o0000
1?ooKP02o`0000Cooi<00_l00004oonh0003o`000?oog@3oomd000;oomd00_l00005oogo00;o0000
1OoIo`02o`0000Ko]?l000?o0000ohoo0?n?o`001_n?o`000ol0003oJ_l0of[o0007of[o0003o`00
0?m5o`3oAOl000[oAOl000?o0000ob3o0?lPo`003olPo`000ol0003o0?l4o`3o100Ko`3o1003o`00
0?l0obSo0?lX07Wo0?lX00?o0000o`3oCOl0odd02_l0odd:oookJP7o00000OoonfX000?ooo]Z0ol0
07l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001o
o`00Ool007l:oookJP03o`000?oonf[ooo]Z00Sooo]Zm?oo0002o`0000?oob@00_l00004oom90003
o`000?ooKP3oofh000;oofh00_l00005oonC0003o`000?oo^03ookP000;ookP00_l00004oooM0003
o`000?omo`3ooOl000CooOl000?o0000omWo0?oIo`001?oIo`000ol0003o]?l0okCo0005okCo0003
o`000?n?o`3oSol000KoSol000?o0000of[o0?mZo`001omZo`000ol0003oAOl0odGo000:odGo0003
o`000?lPo`3o8?l000oo8?l000?o0000o`3o1?l0o`@07?l0o`@00ol0003o0?lXo`3o:01io`3o:003
o`000?l0odgo0?m=00[o0?m=2_oonfX1o`00007ooo]Z0002oookJP?o001o0ooonfX3o`00O`Kooo]Z
0ol007l3oookJP?o001o2OoonfX00ol0003ooo]ZoookJP08oookJ_7oo`000ol00003oolT00;o0000
1?ooB@02o`0000Coofh000?o0000oonC0?ooT`000oooT`02o`0000CookP000?o0000oooM0?oog@00
0ooog@000ol0003ooOl0oogo0004oogo0003o`000?oIo`3ofOl000CofOl000?o0000okCo0?ndo`00
1Ondo`000ol0003oSol0ohoo0006ohoo0003o`000?mZo`3oJ_l000OoJ_l000?o0000odGo0?m5o`00
2_m5o`000ol0003o8?l0ob3o000?ob3o0003o`000?l0o`Co0?l401co0?l400?o0000o`3o:?l0obP0
N_l0obP00ol0003o0?m=o`3oC@0:o`3oC@[ooo]Z0Ol00001oookJP000_oonfX3o`00O`?ooo]Z0ol0
07l<oookJP?o001o2OoonfX5o`0000Kooo]Zjooo0006o`0000?oob@00ol00003oom900?o00000ooo
KP03o`0000Cooi<00_l00004oonh00;o00001?oog@02o`0000GooOl00_l00005omWo00;o00001_nd
o`02o`0000OoSol00_l00008of[o00;o00003?m5o`000ol0003o8?l0ob3o000?ob3o0003o`000?l0
o`Co0?l401co0?l400?o0000o`3o:?l0obP0N_l0obP00ol0003o0?m=o`3oC@0;o`3oC@Oooo]Z1?l0
0001oookJP000_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o2OoonfX00ol0003ooo]ZoookJP08
oookJ^Ooo`001?l00004oolT00Go00000_ooB@04o`0000?oofh00ol00004oonC00?o00000ooo^003
o`0000?oomd00ol00004oogo00?o00001?oIo`03o`0000Ko]?l00_l00007ohoo00;o00002OmZo`00
0ol0003oAOl0odGo000;odGo0003o`000?lPo`3o8?l000oo8?l000?o0000o`3o1?l0o`@07Ol0o`@0
0ol0003o0?lXo`3o:01jo`3o:003o`000?l0odgo0?m=00_o0?m=2_oonfX1o`00007ooo]Z0002oook
JP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o2OoonfX00ol0003ooo]ZoookJP08oook
J^;oo`001Ol00004oolT00Co00001?ooB@03o`0000?oofh01?l00004oonC00?o00000ooo^003o`00
00Coomd00_l00004oogo00?o00001OoIo`02o`0000Oo]?l00_l00008ohoo0003o`000?mZo`3oJ_l0
00SoJ_l000?o0000odGo0?m5o`002om5o`000ol0003o8?l0ob3o000?ob3o0003o`000?l0o`Co0?l4
01go0?l400?o0000o`3o:?l0obP0N_l0obP00ol0003o0?m=o`3oC@0<o`3oC@[ooo]Z0Ol00001oook
JP000_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2_oonfX00ol0003ooo]ZoookJP08oookJ]ko
o`001?l00005oolT00Co00001?ooB@04o`0000?oofh00ol00004oonC00Co00000ooo^003o`0000Co
omd00ol00004oogo00;o00001OoIo`03o`0000Oo]?l00_l00008ohoo00;o00002OmZo`02o`0000go
AOl000?o0000ob3o0?lPo`003_lPo`02o`0001oo0?l400?o0000o`3o:?l0obP0Nol0obP00ol0003o
0?m=o`3oC@0<o`3oC@[ooo]Z0Ol00001oookJP000_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o
2ooonfX00ol0003ooo]ZoookJP08oookJ][oo`001?l00004oolT00Go00001?ooB@04o`0000?oofh0
1?l00004oonC00?o00001?oo^003o`0000Goomd00_l00005oogo00;o00001OoIo`02o`0000So]?l0
0_l00008ohoo00;o00002_mZo`000ol0003oAOl0odGo000<odGo0003o`000?lPo`3o8?l000ko8?l0
00?o0000o`3o1?l0o`@07_l0o`@00ol0003o0?lXo`3o:01ko`3o:003o`000?l0odgo0?m=00go0?m=
2_oonfX1o`00007ooo]Z0002oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l?oookJP03o`000?oo
nf[ooo]Z00Sooo]Ze?oo0006o`0000Coob@01?l00005oom900Co00001?ooKP03o`0000Cooi<01?l0
0004oonh00?o00001_oog@02o`0000CooOl00ol00005omWo00;o00002?ndo`02o`0000WoSol000?o
0000of[o0?mZo`002?mZo`02o`0000koAOl000?o0000ob3o0?lPo`003_lPo`000ol0003o0?l4o`3o
100No`3o1003o`000?l0obSo0?lX07co0?lX00?o0000o`3oCOl0odd03Ol0odd:oookJP7o00000Ooo
nfX000?ooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001o3ooonfX00ol0003ooo]Zoook
JP08oookJ/goo`001ol00006oolT00Co00001?ooB@05o`0000Coofh01?l00003oonC00Co00001Ooo
^003o`0000Koomd00ol00004oogo00;o00001_oIo`02o`0000So]?l00_l00009ohoo00;o00002_mZ
o`000ol0003oAOl0odGo000<odGo00;o00004?lPo`000ol0003o0?l4o`3o100Oo`3o1003o`000?l0
obSo0?lX07_o0?lX00?o0000o`3oCOl0odd03_l0odd:oookJP7o00000OoonfX000?ooo]Z1ol007l9
oookJPOo001o2OoonfX00ol0003ooo]ZoookJP08oookJ/Koo`001ol00007oolT00Ko00001?ooB@04
o`0000Goofh01?l00004oonC00?o00001_oo^003o`0000Koomd00ol00005oogo00;o00001_oIo`02
o`0000So]?l00_l00009ohoo00;o00002omZo`000ol0003oAOl0odGo000<odGo0003o`000?lPo`3o
8?l000oo8?l000?o0000o`3o1?l0o`@07ol0o`@00ol0003o0?lXo`3o:01lo`3o:003o`000?l0odgo
0?m=00ko0?m=2_oonfX1o`00007ooo]Z0004oookJPGo001o2_oonfX7o`00O`Wooo]Z00?o0000oook
J_oonfX02?oonfZnool000So00001ooo9007o`0000KoodT01?l00004oom^00Go00001?ooT`04o`00
00KookP00ol00006oooM00?o00001Oomo`03o`0000KofOl00_l00008okCo00;o00002_n?o`000ol0
003oJ_l0of[o0009of[o00;o00003Om5o`02o`00017o8?l000?o0000o`3o1?l0o`@07ol0o`@00ol0
003o0?lXo`3o:01lo`3o:003o`000?l0odgo0?m=00oo0?m=2_oonfX1o`00007ooo]Z000SoookJP03
o`000?oonf[ooo]Z00Sooo]Z]ooo0007o`0000Soob@01ol00007oom900Ko00001?ooKP04o`0000Ko
oi<00ol00007oonh00?o00001_oog@03o`0000KooOl00_l00007omWo00;o00002?ndo`02o`0000[o
Sol00_l0000;of[o0003o`000?m5o`3oAOl000coAOl000?o0000ob3o0?lPo`004?lPo`000ol0003o
0?l4o`3o100Oo`3o1003o`000?l0obSo0?lX07go0?lX00?o0000o`3oCOl0odd03ol0odd:oookJP7o
00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonfZ`ool000Oo00001ooo9008o`0000OoodT0
1ol00006oom^00Co00001_ooT`04o`0000OookP00ol00006oooM00?o00001oomo`02o`0000SofOl0
00?o0000okCo0?ndo`001_ndo`02o`0000[oSol00_l0000<of[o0003o`000?m5o`3oAOl000coAOl0
00?o0000ob3o0?lPo`004?lPo`000ol0003o0?l4o`3o100Oo`3o1003o`000?l0obSo0?lX07go0?lX
00?o0000o`3oCOl0odd04?l0odd:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oo
nfZWool000Wo00001ooo9007o`0000SoodT01ol00008oom^00Go00001oooT`03o`0000OookP01?l0
0006oooM00?o00001oomo`03o`0000SofOl00_l00007okCo00;o00002on?o`000ol0003oJ_l0of[o
000:of[o00;o00003Om5o`02o`0001;o8?l000?o0000o`3o1?l0o`@08?l0o`@00ol0003o0?lXo`3o
:01mo`3o:003o`000?l0odgo0?m=013o0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[o
oo]Z00Sooo]ZW?oo000;o`0000Woob@01ol00007oom900So00002_ooKP05o`0000Sooi<01?l00007
oonh00?o00001ooog@03o`0000OooOl00ol00009omWo00;o00001ondo`02o`0000_oSol00_l0000<
of[o0003o`000?m5o`3oAOl000coAOl000?o0000ob3o0?lPo`004OlPo`000ol0003o0?l4o`3o100P
o`3o1003o`000?l0obSo0?lX07go0?lX00?o0000o`3oCOl0odd04Ol0odd:oookJP7o00000OoonfX0
02?ooo]Z00?o0000oookJ_oonfX02?oonfZ<ool0013o00002ooo9009o`0000OoodT01ol0000<oom^
00Ko00002_ooT`03o`0000OookP01?l00007oooM00?o00001oomo`03o`0000[ofOl00_l00007okCo
00;o00002on?o`02o`0000coJ_l00_l0000=odGo00;o00004olPo`000ol0003o0?l4o`3o100Po`3o
1003o`000?l0obSo0?lX07ko0?lX00?o0000o`3oCOl0odd04Ol0odd:oookJP7o00000OoonfX002?o
oo]Z00?o0000oookJ_oonfX02?oonfYgool001Go00004?oo900;o`0000WoodT01ol0000>oom^00Go
00002oooT`05o`0000OookP00ol00007oooM00Co00002?omo`02o`0000_ofOl00_l00007okCo00;o
00003?n?o`000ol0003oJ_l0of[o000:of[o00;o00003_m5o`000ol0003o8?l0ob3o000Bob3o0003
o`000?l0o`Co0?l4023o0?l400?o0000o`3o:?l0obP0O_l0obP00ol0003o0?m=o`3oC@0Bo`3oC@[o
oo]Z0Ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08oookJT_oo`00;?l0000EoolT013o0000
2oooB@09o`0000koofh01ol0000;oonC00Go00002?oo^004o`0000Ooomd00ol00009oogo00?o0000
2ooIo`02o`0000So]?l000?o0000ohoo0?n?o`002_n?o`02o`0000coJ_l000?o0000odGo0?m5o`00
3Om5o`000ol0003o8?l0ob3o000Bob3o0003o`000?l0o`Co0?l4023o0?l400?o0000o`3o:?l0obP0
Ool0obP00ol0003o0?m=o`3oC@0Bo`3oC@[ooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]Zoook
JP08oookJT_o0000;?oo900Eo`00013oodT02ol0000@oom^00Oo00003?ooT`06o`0000[ookP00ol0
0007oooM00Co00002Oomo`03o`0000_ofOl00ol00008okCo00;o00002on?o`02o`0000coJ_l00_l0
000>odGo00;o00005?lPo`000ol0003o0?l4o`3o100Po`3o1003o`000?l0obSo0?lX07oo0?lX00?o
0000o`3oCOl0odd04ol0odd:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonfY;
oolT02co00005OooB@0@o`0001Coofh01ol0000>oonC00Go00002ooo^005o`0000Ooomd00ol0000:
oogo00?o00002ooIo`03o`0000Wo]?l00_l0000;ohoo00;o00003OmZo`000ol0003oAOl0odGo000=
odGo0003o`000?lPo`3o8?l001?o8?l000?o0000o`3o1?l0o`@08?l0o`@00ol0003o0?lXo`3o:020
o`3o:003o`000?l0odgo0?m=01?o0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z
00Sooo]ZBol0000/oom901Go00006oooKP09o`0000kooi<01ol0000;oonh00Go00002?oog@04o`00
00[ooOl00ol0000;omWo00?o00002_ndo`02o`0000_oSol00_l0000=of[o00;o00003_m5o`02o`00
01Go8?l000?o0000o`3o1?l0o`@08?l0o`@00ol0003o0?lXo`3o:020o`3o:003o`000?l0odgo0?m=
01Co0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]ZHOooB@0Fo`0002Go
ofh02ol0000@oonC00Oo00003?oo^006o`0000[oomd00ol0000;oogo00?o00002ooIo`03o`0000_o
]?l00_l0000;ohoo00;o00003OmZo`02o`0000ooAOl000?o0000ob3o0?lPo`005?lPo`000ol0003o
0?l4o`3o100Po`3o1003o`000?l0obSo0?lX087o0?lX00?o0000o`3oCOl0odd05?l0odd:oookJP7o
00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonfY;oom901Ko0000;?ooKP0?o`0001Cooi<0
1ol0000>oonh00Go00003?oog@04o`0000_ooOl00ol0000;omWo00?o00003?ndo`02o`0000_oSol0
0_l0000>of[o0003o`000?m5o`3oAOl000koAOl000?o0000ob3o0?lPo`005?lPo`000ol0003o0?l4
o`3o100Po`3o1003o`000?l0obSo0?lX08;o0?lX00?o0000o`3oCOl0odd05?l0odd:oookJP7o0000
0OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonfY;o`0002coofh05_l0000GoonC00co00003?oo
^009o`0000coomd01Ol0000;oogo00Co00002ooIo`03o`0000_o]?l01?l0000;ohoo00;o00003_mZ
o`02o`00013oAOl000?o0000ob3o0?lPo`005?lPo`000ol0003o0?l4o`3o100Po`3o1003o`000?l0
obSo0?lX08;o0?lX00?o0000o`3oCOl0odd05Ol0odd:oookJP7o00000OoonfX002?ooo]Z00?o0000
oookJ_oonfX02?oonfYQoom^01Ko00009?ooT`09o`0000gookP02ol0000?oooM00Ko00003?omo`04
o`0000[ofOl01Ol0000;okCo00?o00003On?o`02o`0000koJ_l00_l0000@odGo00;o00005_lPo`00
0ol0003o0?l4o`3o100Po`3o1003o`000?l0obSo0?lX08?o0?lX00?o0000o`3oCOl0odd05Ol0odd:
oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonfYQo`0002_ooi<03ol0000<oonh
00[o00005?oog@06o`0000oooOl00ol0000:omWo00Co00003Ondo`03o`0000goSol00ol0000>of[o
00;o00004?m5o`02o`0001Ko8?l00_l0000Ro`3o1003o`000?l0obSo0?lX08?o0?lX00?o0000o`3o
COl0odd05_l0odd:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonfYgoonC01Go
00004?oo^00;o`0001Koomd02?l0000?oogo00Ko00002?oIo`05o`0000ko]?l00ol0000>ohoo00;o
00003omZo`02o`00013oAOl00_l0000Gob3o0003o`000?l0o`Co0?l4027o0?l400?o0000o`3o:?l0
obP0Q?l0obP00ol0003o0?m=o`3oC@0Fo`3oC@[ooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]Z
oookJP08oookJT_ooi<0;?l0000Eoonh013o00005_oog@0;o`00013ooOl01ol0000:omWo00Co0000
4?ndo`03o`0000ooSol00_l0000>of[o00?o00004Om5o`000ol0003o8?l0ob3o000Eob3o00;o0000
8ol0o`@00ol0003o0?lXo`3o:024o`3o:003o`000?l0odgo0?m=01Oo0?m=2_oonfX1o`00007ooo]Z
000SoookJP?o00002?oonfY;o`0002cookP05Ol0000KoooM00_o00005?omo`07o`0000gofOl01?l0
000AokCo00?o00003on?o`03o`0000koJ_l00_l0000BodGo00;o00005olPo`000ol0003o0?l4o`3o
100Ro`3o1003o`000?l0obSo0?lX08Go0?lX00?o0000o`3oCOl0odd05ol0odd8oookJP?o00000Ooo
nfX002?ooo]Z00?o0000oookJ_oonfX02?oonfYQoonh01Ko00009Ooog@0;o`0001OooOl02?l0000@
omWo00Co00004Ondo`04o`0000ooSol00ol0000?of[o00;o00004_m5o`02o`0001Oo8?l00_l0000T
o`3o1003o`000?l0obSo0?lX08Go0?lX00?o0000o`3oCOl0odd06?l0odd:oookJP7o00000OoonfX0
02?ooo]Z00?o0000oookJ_oonfX02?oonfY;oonh01Ko0000<Ooog@0:o`0001_ooOl01ol0000ComWo
00Go00004_ndo`03o`00013oSol00ol0000?of[o00?o00004_m5o`02o`0001So8?l000?o0000o`3o
1?l0o`@08ol0o`@00ol0003o0?lXo`3o:025o`3o:003o`000?l0odgo0?m=01Wo0?m=2_oonfX1o`00
007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]ZBol0000loooM00_o00007_omo`07o`0001Ko
fOl01?l0000CokCo00Co00004?n?o`03o`00013oJ_l00_l0000CodGo00;o00006?lPo`02o`0002Go
0?l400?o0000o`3o:?l0obP0Q_l0obP00ol0003o0?m=o`3oC@0Io`3oC@[ooo]Z0Ol00001oookJP00
8ooonfX00ol0003ooo]ZoookJP08oookJWOoomd04?l0000Roogo00Oo00006OoIo`04o`0001Co]?l0
0ol0000Aohoo00?o00004OmZo`02o`0001?oAOl00_l0000Iob3o0003o`000?l0o`Co0?l402Co0?l4
00?o0000o`3o:?l0obP0Q_l0obP00ol0003o0?m=o`3oC@0Jo`3oC@[ooo]Z0Ol00001oookJP008ooo
nfX00ol0003ooo]ZoookJP08oookJV7oomd05_l0000[oogo00Oo00006ooIo`05o`0001Co]?l01?l0
000Aohoo00?o00004OmZo`03o`0001CoAOl000?o0000ob3o0?lPo`006?lPo`000ol0003o0?l4o`3o
100To`3o1003o`000?l0obSo0?lX08Oo0?lX00?o0000o`3oCOl0odd06_l0odd:oookJP7o00000Ooo
nfX002?ooo]Z00?o0000oookJ_oonfX02?oonfXfoooM02_o0000>_omo`07o`0001cofOl01_l0000F
okCo00?o00004_n?o`03o`0001;oJ_l00_l0000EodGo00;o00006OlPo`02o`0002Ko0?l400?o0000
o`3o:?l0obP0Qol0obP00ol0003o0?m=o`3oC@0Ko`3oC@[ooo]Z0Ol00001oookJP008ooonfX00ol0
003ooo]ZoookJP08oookJSKo0000E_omo`0?o`0001cofOl01ol0000GokCo00Go00004On?o`04o`00
01?oJ_l00_l0000EodGo00;o00006_lPo`000ol0003o0?l4o`3o100Uo`3o1003o`000?l0obSo0?lX
08So0?lX00?o0000o`3oCOl0odd06ol0odd:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oo
nfX02?oonfYgoogo01Go00009?oIo`07o`0001Wo]?l01Ol0000Cohoo00?o00005?mZo`03o`0001Go
AOl00_l0000Job3o00;o00009ol0o`@00ol0003o0?lXo`3o:028o`3o:003o`000?l0odgo0?m=01co
0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]ZHOomo`0Fo`0003;ofOl0
1ol0000JokCo00Ko00005?n?o`04o`0001GoJ_l00_l0000FodGo00;o00006olPo`000ol0003o0?l4
o`3o100Vo`3o1003o`000?l0obSo0?lX08Wo0?lX00?o0000o`3oCOl0odd07?l0odd:oookJP7o0000
0OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonfY;oogo01Ko0000@OoIo`07o`0001co]?l01Ol0
000Gohoo00?o00005_mZo`03o`0001KoAOl00_l0000Kob3o00;o0000:?l0o`@00ol0003o0?lXo`3o
:029o`3o:003o`000?l0odgo0?m=01go0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[o
oo]Z00Sooo]Z8?omo`0[o`00053ofOl01ol0000MokCo00Ko00006?n?o`04o`0001OoJ_l00_l0000G
odGo00;o00007?lPo`000ol0003o0?l4o`3o100Vo`3o10;o0000S?l0obP00ol0003o0?m=o`3oC@0M
o`3oC@[ooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08oookJR3o0000K?oIo`0?o`00
01oo]?l01Ol0000Kohoo00?o00006OmZo`02o`0001OoAOl00_l0000Lob3o00;o0000:?l0o`@00ol0
003o0?lXo`3o:02;o`3o:003o`000?l0odgo0?m=01ko0?m=2_oonfX1o`00007ooo]Z000SoookJP03
o`000?oonf[ooo]Z00Sooo]ZO?oIo`0@o`0002So]?l01_l0000Lohoo00Co00006OmZo`03o`0001So
AOl000?o0000ob3o0?lPo`006olPo`000ol0003o0?l4o`3o100Wo`3o1003o`000?l0obSo0?lX08_o
0?lX00?o0000o`3oCOl0odd07ol0odd:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX0
2?oonfYaomWo00_o0000<ondo`05o`0001koSol01?l0000Kof[o00;o00006Om5o`02o`0001co8?l0
0_l0000Yo`3o1003o`000?l0obSo0?lX08co0?lX00?o0000o`3oCOl0odd07ol0odd:oookJP7o0000
0OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonfYQomWo013o0000=ondo`07o`00023oSol00ol0
000Lof[o00?o00006Om5o`02o`0001go8?l000?o0000o`3o1?l0o`@0:?l0o`@00ol0003o0?lXo`3o
:02<o`3o:003o`000?l0odgo0?m=023o0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[o
oo]Z00Sooo]Z=_oIo`0[o`00043o]?l01ol0000Sohoo00Co00007?mZo`03o`0001[oAOl00_l0000N
ob3o0003o`000?l0o`Co0?l402So0?l400?o0000o`3o:?l0obP0SOl0obP00ol0003o0?m=o`3oC@0P
o`3oC@[ooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08oookJSKo0000G?ndo`0?o`00
02GoSol01Ol0000Lof[o00Co00006_m5o`03o`0001ko8?l00_l0000Yo`3o10;o0000Sol0obP00ol0
003o0?m=o`3oC@0Qo`3oC@[ooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08oookJXOo
]?l02ol0000/ohoo00So00007OmZo`04o`0001_oAOl00ol0000Oob3o00;o0000:_l0o`@00ol0003o
0?lXo`3o:02?o`3o:003o`000?l0odgo0?m=027o0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`00
0?oonf[ooo]Z00Sooo]ZMondo`0@o`00033oSol01ol0000Pof[o00Go00007?m5o`03o`00023o8?l0
0_l0000[o`3o1003o`000?l0obSo0?lX08oo0?lX00?o0000o`3oCOl0odd08_l0odd:oookJP7o0000
0OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonfYQokCo01Ko0000>On?o`07o`0002?oJ_l01?l0
000NodGo00?o00008?lPo`03o`0002co0?l400?o0000o`3o:?l0obP0T?l0obP00ol0003o0?m=o`3o
C@0Ro`3oC@[ooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08oookJT_o]?l05_l00018
ohoo00Oo00009_mZo`04o`0001ooAOl00ol0000Qob3o00;o0000;Ol0o`@2o`0009;o0?lX00?o0000
o`3oCOl0odd08ol0odd:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonfY;o`00
05OoSol01ol0000Xof[o00Go00008Om5o`02o`0002;o8?l00_l0000^o`3o1003o`000?l0obSo0?lX
09;o0?lX00?o0000o`3oCOl0odd08ol0odd:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oo
nfX02?oonfZKohoo00Oo0000:omZo`04o`0002?oAOl00ol0000Rob3o00;o0000;ol0o`@00ol0003o
0?lXo`3o:02Bo`3o:003o`000?l0odgo0?m=02Co0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`00
0?oonf[ooo]Z00Sooo]ZS?n?o`0?o`0002koJ_l01?l0000TodGo00?o00008olPo`02o`0002oo0?l4
0_l0002Do`3o:003o`000?l0odgo0?m=02Go0?m=2_oonfX1o`00007ooo]Z000SoookJP?o00002?oo
nfYlohoo013o0000>?mZo`05o`0002GoAOl00ol0000Tob3o00;o0000<?l0o`@00ol0003o0?lXo`3o
:02Do`3o:003o`000?l0odgo0?m=02Go0?m=2?oonfX3o`00007ooo]Z000SoookJP03o`000?oonf[o
oo]Z00Sooo]ZLOn?o`0;o`0004;oJ_l01_l0000WodGo00?o00009OlPo`02o`00037o0?l400?o0000
o`3o:?l0obP0U?l0obP00ol0003o0?m=o`3oC@0Vo`3oC@[ooo]Z0Ol00001oookJP008ooonfX00ol0
003ooo]ZoookJP08oookJV7oSol04?l00016of[o00Oo0000:_m5o`03o`0002Ko8?l00_l0000bo`3o
1003o`000?l0obSo0?lX09Go0?lX00?o0000o`3oCOl0odd09_l0odd:oookJP7o00000OoonfX002?o
oo]Z00?o0000oookJ_oonfX02?oonfY;ohoo01Ko0000ComZo`07o`0002goAOl01?l0000Wob3o00;o
0000<_l0o`@2o`0009Oo0?lX00?o0000o`3oCOl0odd09ol0odd:oookJP7o00000OoonfX002?ooo]Z
00?o0000oookJ_oonfX02?oonfXPohoo02_o0000G_mZo`07o`00037oAOl00ol0000Xob3o00?o0000
<ol0o`@00ol0003o0?lXo`3o:02Go`3o:003o`000?l0odgo0?m=02Oo0?m=2_oonfX1o`00007ooo]Z
000SoookJP03o`000?oonf[ooo]Z00Sooo]Z8?l00022of[o00Oo0000=?m5o`04o`0002Wo8?l00_l0
000do`3o10;o0000VOl0obP00ol0003o0?m=o`3oC@0Xo`3oC@[ooo]Z0Ol00001oookJP008ooonfX0
0ol0003ooo]ZoookJP08oookJY_oJ_l01ol0000hodGo00?o0000:olPo`02o`0003Go0?l400?o0000
o`3o:?l0obP0VOl0obP00ol0003o0?m=o`3oC@0Xo`3oC@[ooo]Z0Ol00001oookJP008ooonfX00ol0
003ooo]ZoookJP08oookJY;oJ_l02Ol0000kodGo00Co0000;?lPo`02o`0003Go0?l40_l0002Ko`3o
:003o`000?l0odgo0?m=02Wo0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00So
oo]ZQomZo`0;o`0003ooAOl01Ol0000^ob3o00;o0000=_l0o`@00ol0003o0?lXo`3o:02Jo`3o:003
o`000?l0odgo0?m=02[o0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Z
O?mZo`0;o`0004KoAOl01?l0000aob3o00;o0000=ol0o`@00ol0003o0?lXo`3o:02Ko`3o:003o`00
0?l0odgo0?m=02[o0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]ZLOmZ
o`0;o`0004goAOl01?l0000cob3o00;o0000=ol0o`@2o`0009go0?lX00?o0000o`3oCOl0odd0:ol0
odd:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonfYQof[o013o0000Dom5o`05
o`0003Co8?l00ol0000ho`3o1003o`000?l0obSo0?lX09co0?lX00?o0000o`3oCOl0odd0;?l0odd:
oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonfY;of[o01Ko0000H?m5o`03o`00
03Oo8?l00_l0000io`3o10;o0000Wol0obP00ol0003o0?m=o`3oC@0/o`3oC@[ooo]Z0Ol00001oook
JP008ooonfX00ol0003ooo]ZoookJP08oookJSgoJ_l03_l0001codGo00?o0000>?lPo`02o`0003[o
0?l400?o0000o`3o:?l0obP0W_l0obP00ol0003o0?m=o`3oC@0]o`3oC@[ooo]Z0Ol00001oookJP00
8ooonfX00ol0003ooo]ZoookJP08oookJSgo0000Nom5o`06o`0003So8?l00ol0000jo`3o10;o0000
X?l0obP00ol0003o0?m=o`3oC@0^o`3oC@[ooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]Zoook
JP08oookJ[3oAOl02?l0000job3o00Co0000>ol0o`@2o`000:;o0?lX00?o0000o`3oCOl0odd0;_l0
odd:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonfZYodGo00Oo0000?olPo`03
o`0003go0?l40_l0002So`3o:003o`000?l0odgo0?m=02oo0?m=2_oonfX1o`00007ooo]Z000Soook
JP03o`000?oonf[ooo]Z00Sooo]ZX_m5o`07o`0004;o8?l01?l0000no`3o10;o0000Y?l0obP00ol0
003o0?m=o`3oC@0`o`3oC@[ooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08oookJY_o
AOl01ol00016ob3o00?o0000@?l0o`@2o`000:Go0?lX00?o0000o`3oCOl0odd0<Ol0odd:oookJP7o
00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonfZBodGo00Wo0000BOlPo`04o`00047o0?l4
0_l0002Wo`3o:003o`000?l0odgo0?m=037o0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`000?oo
nf[ooo]Z00Sooo]ZQom5o`0;o`0004oo8?l00ol00014o`3o1003o`000?l0obSo0?lX0:Ko0?lX00?o
0000o`3oCOl0odd0<_l0odd:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonfYl
odGo00_o0000E_lPo`04o`0004Go0?l40_l0002Xo`3o:003o`000?l0odgo0?m=03?o0?m=2_oonfX1
o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]ZLOm5o`0;o`0005ko8?l00ol00017o`3o
10;o0000Z_l0obP00ol0003o0?m=o`3oC@0co`3oC@[ooo]Z0Ol00001oookJP008ooonfX00ol0003o
oo]ZoookJP08oookJV7oAOl04?l0001Uob3o00Co0000B?l0o`@2o`000:_o0?lX00?o0000o`3oCOl0
odd0=?l0odd:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonfY;odGo01Ko0000
L?lPo`05o`0004[o0?l40_l0002/o`3o:003o`000?l0odgo0?m=03Go0?m=2_oonfX1o`00007ooo]Z
000SoookJP03o`000?oonf[ooo]Z00Sooo]Z=_m5o`0Eo`0008;o8?l01?l0001=o`3o10;o0000[Ol0
obP00ol0003o0?m=o`3oC@0fo`3oC@[ooo]Z0Ol00001oookJP008ooonfX3o`0000Sooo]Z=_l0002C
ob3o00Co0000D?l0o`@00ol0003o0?lXo`3o:02]o`3o:003o`000?l0odgo0?m=03Ko0?m=2?oonfX3
o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Za?lPo`05o`0005;o0?l40_l0002_o`3o
:003o`000?l0odgo0?m=03Oo0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00So
oo]Z`?lPo`04o`0005Go0?l40_l0002`o`3o:003o`000?l0odgo0?m=03So0?m=2_oonfX1o`00007o
oo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Z^olPo`05o`0005Oo0?l40_l0002bo`3o:003o`00
0?l0odgo0?m=03So0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Z]olP
o`04o`0005[o0?l40_l0002co`3o:003o`000?l0odgo0?m=03Wo0?m=2_oonfX1o`00007ooo]Z000S
oookJP03o`000?oonf[ooo]Z00Sooo]Z/olPo`04o`0005co0?l40_l0002do`3o:003o`000?l0odgo
0?m=03[o0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Z[_lPo`05o`00
05go0?l40ol0002eo`3o:003o`000?l0odgo0?m=03_o0?m=2_oonfX1o`00007ooo]Z000SoookJP03
o`000?oonf[ooo]Z00Sooo]ZZ?lPo`06o`00063o0?l40_l0002ho`3o:003o`000?l0odgo0?m=03_o
0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]ZXOlPo`07o`0006Co0?l4
0_l0002io`3o:003o`000?l0odgo0?m=03co0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`000?oo
nf[ooo]Z00Sooo]ZV_lPo`07o`0006Wo0?l40_l0002jo`3o:003o`000?l0odgo0?m=03go0?m=2_oo
nfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]ZT_lPo`08o`0006go0?l40ol0002k
o`3o:003o`000?l0odgo0?m=03ko0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z
00Sooo]ZQolPo`0;o`0007;o0?l40ol0002no`3o:003o`000?l0odgo0?m=03ko0?m=2_oonfX1o`00
007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]ZO?lPo`0;o`0007_o0?l40_l00030o`3o:003
o`000?l0odgo0?m=03oo0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Z
LOlPo`0;o`0008?o0?l40ol00031o`3o:003o`000?l0odgo0?m=043o0?m=2_oonfX1o`00007ooo]Z
000SoookJP03o`000?oonf[ooo]Z00Sooo]ZIolPo`0:o`0008_o0?l40ol00033o`3o:003o`000?l0
odgo0?m=047o0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]ZG?lPo`0;
o`0009;o0?l40ol00035o`3o:003o`000?l0odgo0?m=04;o0?m=2_oonfX1o`00007ooo]Z000Soook
JP03o`000?oonf[ooo]Z00Sooo]ZBolPo`0Ao`0009_o0?l40_l00037o`3o:003o`000?l0odgo0?m=
04?o0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Z=_lPo`0Eo`000:Wo
0?l40ol00038o`3o:003o`000?l0odgo0?m=04Co0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`00
0?oonf[ooo]Z00Sooo]Z=_l0002ko`3o10?o0000bol0obP00ol0003o0?m=o`3oC@14o`3oC@[ooo]Z
0Ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08oookJ^ko0?l40ol0003=o`3o:003o`000?l0
odgo0?m=04Go0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Zk?l0o`@2
o`000<oo0?lX00?o0000o`3oCOl0odd0A_l0odd:oookJP7o00000OoonfX002?ooo]Z00?o0000oook
J_oonfX02?oonf[Yo`3o10?o0000d?l0obP00ol0003o0?m=o`3oC@17o`3oC@[ooo]Z0Ol00001oook
JP008ooonfX00ol0003ooo]ZoookJP08oookJ^Ko0?l40ol0003Bo`3o:003o`000?l0odgo0?m=04So
0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Zhol0o`@3o`000=Co0?lX
00?o0000o`3oCOl0odd0BOl0odd:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oo
nf[Po`3o10?o0000e_l0obP00ol0003o0?m=o`3oC@1:o`3oC@[ooo]Z0Ol00001oookJP008ooonfX0
0ol0003ooo]ZoookJP08oookJ]go0?l40ol0003Io`3o:003o`000?l0odgo0?m=04[o0?m=2_oonfX1
o`00007ooo]Z000SoookJP?o00002?oonf[Jo`3o10?o0000fol0obP00ol0003o0?m=o`3oC@1;o`3o
C@Sooo]Z0ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08oookJ]Ko0?l41?l0003Mo`3o:003
o`000?l0odgo0?m=04co0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Z
dol0o`@3o`000>3o0?lX00?o0000o`3oCOl0odd0COl0odd:oookJP7o00000OoonfX002?ooo]Z00?o
0000oookJ_oonfX02?oonf[?o`3o10Co0000h_l0obP00ol0003o0?m=o`3oC@1>o`3oC@[ooo]Z0Ol0
0001oookJP008ooonfX00ol0003ooo]ZoookJP08oookJ/co0?l40ol0003Uo`3o:003o`000?l0odgo
0?m=04oo0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Zb?l0o`@4o`00
0>Oo0?lX00?o0000o`3oCOl0odd0D?l0odd:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oo
nfX02?oonf[4o`3o10Co0000jol0obP00ol0003o0?m=o`3oC@1@o`3oC@[ooo]Z0Ol00001oookJP00
8ooonfX00ol0003ooo]ZoookJP08oookJ[oo0?l41Ol0003^o`3o:003o`000?l0odgo0?m=057o0?m=
2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Z^_l0o`@5o`000?;o0?lX00?o
0000o`3oCOl0odd0D_l0odd:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonfZd
o`3o10Ko0000mOl0obP2o`0005Go0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z
00Sooo]Z[ol0o`@5o`000?[o0?lX00?o0000o`3oCOl0odd0EOl0odd:oookJP7o00000OoonfX002?o
oo]Z00?o0000oookJ_oonfX02?oonfZYo`3o10Ko0000o_l0obP00ol0003o0?m=o`3oC@1Fo`3oC@[o
oo]Z0Ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08oookJZCo0?l41Ol0003oo`3o:0Co0?lX
00?o0000o`3oCOl0odd0Eol0odd:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oo
nfZOo`3o10Go0000ool0obP8o`3o:003o`000?l0odgo0?m=05So0?m=2_oonfX1o`00007ooo]Z000S
oookJP03o`000?oonf[ooo]Z00Sooo]ZV_l0o`@5o`000?oo0?lX3?l0obP00ol0003o0?m=o`3oC@1I
o`3oC@[ooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08oookJY?o0?l41ol0003oo`3o
:13o0?lX00?o0000o`3oCOl0odd0F_l0odd:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oo
nfX02?oonfZ<o`3o10Oo0000ool0obPFo`3o:003o`000?l0odgo0?m=05_o0?m=2_oonfX1o`00007o
oo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]ZQOl0o`@7o`000?oo0?lX7?l0obP00ol0003o0?m=
o`3oC@1Lo`3oC@[ooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08oookJWco0?l42Ol0
003oo`3o:2;o0?lX00?o0000o`3oCOl0odd0GOl0odd:oookJP7o00000OoonfX002?ooo]Z00?o0000
oookJ_oonfX02?oonfYao`3o10_o0000ool0obPZo`3o:003o`000?l0odgo0?m=05ko0?m=2_oonfX1
o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]ZIol0o`@:o`000?oo0?lX=?l0obP00ol0
003o0?m=o`3oC@1Oo`3oC@[ooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08oookJUco
0?l42ol0003oo`3o:3go0?lX00?o0000o`3oCOl0odd0H?l0odd:oookJP7o00000OoonfX001Gooo]Z
0ol007l;oookJP03o`000?oonf[ooo]Z00Sooo]ZBol0o`@Ao`000?oo0?lXAol0obP00ol0003o0?m=
o`3oC@1Qo`3oC@[ooo]Z0Ol00001oookJP005OoonfX3o`00O`_ooo]Z00?o0000oookJ_oonfX02?oo
nfXfo`3o11Go0000ool0obQGo`3o:003o`000?l0odgo0?m=06;o0?m=2_oonfX1o`00007ooo]Z000E
oookJP?o001o2ooonfX00ol0003ooo]ZoookJP08oookJR3o0?l45_l0003oo`3o:6_o0?lX00?o0000
o`3oCOl0odd0Hol0odd:oookJP7o00000OoonfX001Gooo]Z0ol007l;oookJP03o`000?oonf[ooo]Z
00Sooo]Z8?l0003oo`3o:83o0?lX00?o0000o`3oCOl0odd0I?l0odd:oookJP7o00000OoonfX001Go
oo]Z0ol007l;oookJPGo00001_oonf[oo`3o:9oo0?lX00?o0000o`3oCOl0odd0IOl0odd7oookJPCo
00000OoonfX001Gooo]Z0ol007l;oookJP03o`000?oonf[ooo]Z00Sooo]Zool0obROo`3o:003o`00
0?l0odgo0?m=06Go0?m=2_oonfX1o`00007ooo]Z000EoookJP?o001o2ooonfX00ol0003ooo]Zoook
JP08oookJ_oo0?lXW_l0obP00ol0003o0?m=o`3oC@1Vo`3oC@[ooo]Z0Ol00001oookJP005OoonfX3
o`00O`_ooo]Z00?o0000oookJ_oonfX02?oonf[oo`3o:9go0?lX00?o0000o`3oCOl0odd0Iol0odd:
oookJP7o00000OoonfX001Gooo]Z0ol007l;oookJP03o`000?oonf[ooo]Z00Sooo]Zool0obRLo`3o
:003o`000?l0odgo0?m=06So0?m=2_oonfX1o`00007ooo]Z000BoookJPKo001o2ooonfX00ol0003o
oo]ZoookJP08oookJ_oo0?lXV_l0obP2o`0006_o0?m=2_oonfX1o`00007ooo]Z000BoookJPKo001o
2ooonfX00ol0003ooo]ZoookJP08oookJ_oo0?lXVOl0obP00ol0003o0?m=o`3oC@1[o`3oC@[ooo]Z
0Ol00001oookJP005?oonfX4o`00O`_ooo]Z00?o0000oookJ_oonfX02?oonf[oo`3o:9So0?lX00?o
0000o`3oCOl0odd0K?l0odd:oookJP7o00000OoonfX001Gooo]Z0ol007l;oookJP03o`000?oonf[o
oo]Z00Sooo]Zool0obRGo`3o:003o`000?l0odgo0?m=06go0?m=2_oonfX1o`00007ooo]Z000Soook
JP03o`000?oonf[ooo]Z00Sooo]Zool0obRFo`3o:003o`000?l0odgo0?m=06ko0?m=2_oonfX1o`00
007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Zool0obREo`3o:003o`000?l0odgo0?m=06oo
0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Zool0obRCo`3o:0;o0000
L_l0odd:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[oo`3o:9;o0?lX00?o
0000o`3oCOl0odd0L_l0odd:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[o
o`3o:97o0?lX00?o0000o`3oCOl0odd0Lol0odd:oookJP7o00000OoonfX002?ooo]Z00?o0000oook
J_oonfX02?oonf[oo`3o:93o0?lX00?o0000o`3oCOl0odd0M?l0odd:oookJP7o00000OoonfX002?o
oo]Z00?o0000oookJ_oonfX02?oonf[oo`3o:8oo0?lX00?o0000o`3oCOl0odd0MOl0odd:oookJP7o
00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[oo`3o:8go0?lX0_l0001ho`3oC@[ooo]Z
0Ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08oookJ_oo0?lXS?l0obP00ol0003o0?m=o`3o
C@1ho`3oC@[ooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08oookJ_oo0?lXRol0obP0
0ol0003o0?m=o`3oC@1io`3oC@[ooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08oook
J_oo0?lXR_l0obP00ol0003o0?m=o`3oC@1jo`3oC@[ooo]Z0Ol00001oookJP008ooonfX00ol0003o
oo]ZoookJP08oookJ_oo0?lXROl0obP00ol0003o0?m=o`3oC@1ko`3oC@[ooo]Z0Ol00001oookJP00
8ooonfX00ol0003ooo]ZoookJP08oookJ_oo0?lXR?l0obP00ol0003o0?m=o`3oC@1lo`3oC@[ooo]Z
0Ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08oookJ_oo0?lXQ_l0obP2o`0007oo0?m=2_oo
nfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Zool0obR4o`3o:0;o0000POl0odd:
oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[oo`3o:8?o0?lX00?o0000o`3o
COl0odd0POl0odd:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[oo`3o:8;o
0?lX00?o0000o`3oCOl0odd0P_l0odd:oookJP7o00000OoonfX002?ooo]Z0ol00008oookJ_oo0?lX
P?l0obP2o`0008Go0?m=2?oonfX3o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Zool0
obQoo`3o:003o`000?l0odgo0?m=08Go0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[o
oo]Z00Sooo]Zool0obQno`3o:003o`000?l0odgo0?m=08Ko0?m=2_oonfX1o`00007ooo]Z000Soook
JP03o`000?oonf[ooo]Z00Sooo]Zool0obQlo`3o:0;o0000ROl0odd:oookJP7o00000OoonfX002?o
oo]Z00?o0000oookJ_oonfX02?oonf[oo`3o:7_o0?lX00?o0000o`3oCOl0odd0ROl0odd:oookJP7o
00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[oo`3o:7[o0?lX00?o0000o`3oCOl0odd0
R_l0odd:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[oo`3o:7Wo0?lX00?o
0000o`3oCOl0odd0Rol0odd:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[o
o`3o:7Oo0?lX0_l0002>o`3oC@[ooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08oook
J_oo0?lXM_l0obP00ol0003o0?m=o`3oC@2>o`3oC@[ooo]Z0Ol00001oookJP008ooonfX00ol0003o
oo]ZoookJP08oookJ_oo0?lXMOl0obP00ol0003o0?m=o`3oC@2?o`3oC@[ooo]Z0Ol00001oookJP00
8ooonfX00ol0003ooo]ZoookJP08oookJ_oo0?lXLol0obP2o`0009;o0?m=2_oonfX1o`00007ooo]Z
000SoookJP03o`000?oonf[ooo]Z00Sooo]Zool0obQbo`3o:003o`000?l0odgo0?m=09;o0?m=2_oo
nfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Zool0obQao`3o:003o`000?l0odgo
0?m=09?o0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Zool0obQ_o`3o
:0;o0000U_l0odd:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[oo`3o:6ko
0?lX00?o0000o`3oCOl0odd0U_l0odd:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX0
2?oonf[oo`3o:6go0?lX00?o0000o`3oCOl0odd0Uol0odd:oookJP7o00000OoonfX002?ooo]Z00?o
0000oookJ_oonfX02?oonf[oo`3o:6co0?lX00?o0000o`3oCOl0odd0V?l0odd:oookJP7o00000Ooo
nfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[oo`3o:6_o0?lX00?o0000o`3oCOl0odd0VOl0odd:
oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[oo`3o:6Wo0?lX0_l0002Lo`3o
C@[ooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08oookJ_oo0?lXJ?l0obP00ol0003o
0?m=o`3oC@2Lo`3oC@[ooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08oookJ_oo0?lX
I_l0obP2o`0009oo0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Zool0
obQTo`3o:0;o0000XOl0odd:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[o
o`3o:6?o0?lX00?o0000o`3oCOl0odd0XOl0odd:oookJP7o00000OoonfX002?ooo]Z00?o0000oook
J_oonfX02?oonf[oo`3o:67o0?lX0_l0002To`3oC@[ooo]Z0Ol00001oookJP008ooonfX00ol0003o
oo]ZoookJP08oookJ_oo0?lXH?l0obP00ol0003o0?m=o`3oC@2To`3oC@[ooo]Z0Ol00001oookJP00
8ooonfX00ol0003ooo]ZoookJP08oookJ_oo0?lXG_l0obP2o`000:Oo0?m=2_oonfX1o`00007ooo]Z
000SoookJP?o00002?oonf[oo`3o:5co0?lX0_l0002Yo`3oC@Sooo]Z0ol00001oookJP008ooonfX0
0ol0003ooo]ZoookJP08oookJ_oo0?lXFol0obP00ol0003o0?m=o`3oC@2Yo`3oC@[ooo]Z0Ol00001
oookJP008ooonfX00ol0003ooo]ZoookJP08oookJ_oo0?lXFOl0obP2o`000:co0?m=2_oonfX1o`00
007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Zool0obQGo`3o:0;o0000[_l0odd:oookJP7o
00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[oo`3o:5Ko0?lX00?o0000o`3oCOl0odd0
[_l0odd:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[oo`3o:5Co0?lX0_l0
002ao`3oC@[ooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08oookJ_oo0?lXD_l0obP2
o`000;?o0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Zool0obQ@o`3o
:0;o0000]Ol0odd:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[oo`3o:4oo
0?lX00?o0000o`3oCOl0odd0]Ol0odd:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX0
2?oonf[oo`3o:4go0?lX0_l0002ho`3oC@[ooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]Zoook
JP08oookJ_oo0?lXBol0obP2o`000;[o0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[o
oo]Z00Sooo]Zool0obQ:o`3o:003o`000?l0odgo0?m=0;[o0?m=2_oonfX1o`00007ooo]Z000Soook
JP03o`000?oonf[ooo]Z00Sooo]Zool0obQ8o`3o:0;o0000_Ol0odd:oookJP7o00000OoonfX002?o
oo]Z00?o0000oookJ_oonfX02?oonf[oo`3o:4Oo0?lX00?o0000o`3oCOl0odd0_Ol0odd:oookJP7o
00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[oo`3o:4Ko0?lX00?o0000o`3oCOl0odd0
__l0odd:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[oo`3o:4Co0?lX0_l0
0031o`3oC@[ooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08oookJ_oo0?lX@_l0obP2
o`000<?o0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Zool0obQ0o`3o
:0;o0000aOl0odd:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[oo`3o:3ko
0?lX0_l00037o`3oC@[ooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08oookJ_oo0?lX
??l0obP2o`000<Wo0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Zool0
obPjo`3o:0;o0000bol0odd:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[o
o`3o:3So0?lX0_l0003=o`3oC@[ooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08oook
J_oo0?lX=_l0obP2o`000<oo0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00So
oo]Zool0obPdo`3o:0;o0000dOl0odd:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX0
2?oonf[oo`3o:3;o0?lX0_l0003Co`3oC@[ooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]Zoook
JP08oookJ_oo0?lX<?l0obP2o`000=Go0?m=2_oonfX1o`00007ooo]Z000SoookJP?o00002?oonf[o
o`3o:2ko0?lX0_l0003Go`3oC@Sooo]Z0ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08oook
J_oo0?lX;?l0obP2o`000=Wo0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00So
oo]Zool0obPZo`3o:0;o0000fol0odd:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX0
2?oonf[oo`3o:2So0?lX0_l0003Mo`3oC@[ooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]Zoook
JP08oookJ_oo0?lX9Ol0obP3o`000=oo0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[o
oo]Z00Sooo]Zool0obPSo`3o:0;o0000h_l0odd:oookJP7o00000OoonfX002?ooo]Z00?o0000oook
J_oonfX02?oonf[oo`3o:27o0?lX0_l0003To`3oC@[ooo]Z0Ol00001oookJP008ooonfX00ol0003o
oo]ZoookJP08oookJ_oo0?lX7ol0obP2o`000>Ko0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`00
0?oonf[ooo]Z00Sooo]Zool0obPMo`3o:0;o0000j?l0odd:oookJP7o00000OoonfX002?ooo]Z00?o
0000oookJ_oonfX02?oonf[oo`3o:1_o0?lX0_l0003Zo`3oC@[ooo]Z0Ol00001oookJP008ooonfX0
0ol0003ooo]ZoookJP08oookJ_oo0?lX6?l0obP3o`000>co0?m=2_oonfX1o`00007ooo]Z000Soook
JP03o`000?oonf[ooo]Z00Sooo]Zool0obPEo`3o:0?o0000kol0odd:oookJP7o00000OoonfX002?o
oo]Z00?o0000oookJ_oonfX02?oonf[oo`3o:1?o0?lX0_l0003bo`3oC@[ooo]Z0Ol00001oookJP00
8ooonfX00ol0003ooo]ZoookJP08oookJ_oo0?lX4Ol0obP2o`000?Co0?m=2_oonfX1o`00007ooo]Z
000SoookJP03o`000?oonf[ooo]Z00Sooo]Zool0obP>o`3o:0?o0000m_l0odd:oookJP7o00000Ooo
nfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[oo`3o:0co0?lX0_l0003io`3oC@[ooo]Z0Ol00001
oookJP008ooonfX00ol0003ooo]ZoookJP08oookJ_oo0?lX2_l0obP2o`000?_o0?m=2_oonfX1o`00
007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Zool0obP7o`3o:0?o0000oOl0odd:oookJP7o
00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[oo`3o:0Go0?lX0_l0003oo`3oC@7o0?m=
2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Zool0obP2o`3o:0?o0000ool0
odd3o`3oC@[ooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08oookJ_ko0?lX0ol0003o
o`3oC@Ko0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Znol0obP3o`00
0?oo0?m=2Ol0odd:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[ho`3o:0?o
0000ool0odd<o`3oC@[ooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08oookJ_Go0?lX
0ol0003oo`3oC@oo0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Zl_l0
obP3o`000?oo0?m=4_l0odd:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[_
o`3o:0?o0000ool0oddEo`3oC@[ooo]Z0Ol00001oookJP008ooonfX3o`0000Sooo]Zk?l0obP3o`00
0?oo0?m=6?l0odd8oookJP?o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[Yo`3o:0?o
0000ool0oddKo`3oC@[ooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08oookJ^Ko0?lX
0ol0003oo`3oCAko0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Zhol0
obP3o`000?oo0?m=8Ol0odd:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[P
o`3o:0?o0000ool0oddTo`3oC@[ooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08oook
J]go0?lX0ol0003oo`3oCBOo0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00So
oo]Zf_l0obP3o`000?oo0?m=:_l0odd:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX0
2?oonf[Fo`3o:0Co0000ool0odd]o`3oC@[ooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]Zoook
JP08oookJ];o0?lX1?l0003oo`3oCC7o0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[o
oo]Z00Sooo]Zcol0obP3o`000?oo0?m==Ol0odd:oookJP7o00000OoonfX002?ooo]Z00?o0000oook
J_oonfX02?oonf[;o`3o:0Co0000ool0oddho`3oC@[ooo]Z0Ol00001oookJP008ooonfX00ol0003o
oo]ZoookJP08oookJ/Oo0?lX1?l0003oo`3oCCco0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`00
0?oonf[ooo]Z00Sooo]Za?l0obP3o`000?oo0?m=@?l0odd:oookJP7o00000OoonfX002?ooo]Z00?o
0000oookJ_oonfX02?oonf[0o`3o:0Co0000ool0ode3o`3oC@[ooo]Z0Ol00001oookJP008ooonfX0
0ol0003ooo]ZoookJP08oookJ[co0?lX1?l0003oo`3oCDOo0?m=2_oonfX1o`00007ooo]Z000Soook
JP03o`000?oonf[ooo]Z00Sooo]Z^Ol0obP3o`000?oo0?m=Bol0odd:oookJP7o00000OoonfX002?o
oo]Z00?o0000oookJ_oonfX02?oonfZeo`3o:0Co0000ool0ode>o`3oC@[ooo]Z0Ol00001oookJP00
8ooonfX00ol0003ooo]ZoookJP08oookJ[7o0?lX1?l0003oo`3oCE;o0?m=2_oonfX1o`00007ooo]Z
000SoookJP03o`000?oonf[ooo]Z00Sooo]Z[_l0obP3o`000?oo0?m=E_l0odd:oookJP7o00000Ooo
nfX002?ooo]Z00?o0000oookJ_oonfX02?oonfZYo`3o:0Go0000ool0odeIo`3oC@[ooo]Z0Ol00001
oookJP008ooonfX00ol0003ooo]ZoookJP08oookJZCo0?lX1Ol0003oo`3oCEko0?m=2_oonfX1o`00
007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]ZWol0obP5o`000?oo0?m=Hol0odd:oookJP7o
00000OoonfX000Kooo]Z0ol007l4oookJP?o001o0ooonfX5o`00O`_ooo]Z00?o0000oookJ_oonfX0
2?oonfZJo`3o:0Go0000ool0odeXo`3oC@[ooo]Z0Ol00001oookJP001_oonfX3o`00O`Cooo]Z0ol0
07l2oookJPOo001o2_oonfX00ol0003ooo]ZoookJP08oookJYGo0?lX1Ol0003oo`3oCFgo0?m=2_oo
nfX1o`00007ooo]Z0006oookJP?o001o1?oonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Z
o`00Ool007oo001o2_oonfX00ol0003ooo]ZoookJP08oookJY3o0?lX1Ol0003oo`3oCG;o0?m=2_oo
nfX1o`00007ooo]Z0006oookJP?o001o2?oonfX3o`00O`?ooo]Z0ol007l9oookJP03o`000?oonf[o
oo]Z00Sooo]ZRol0obP5o`000?oo0?m=Mol0odd:oookJP7o00000OoonfX000Kooo]Z0ol007l>oook
JP?o001o2OoonfX5o`0000Kooo]ZQOl0obP6o`000?oo0?m=O?l0odd7oookJPCo00000OoonfX000Ko
oo]Z0ol007l>oookJP?o001o2OoonfX00ol0003ooo]ZoookJP08oookJWko0?lX1ol0003oo`3oCH;o
0?m=2_oonfX1o`00007ooo]Z0006oookJP?o001o2OoonfX2o`00O`;ooo]Z1?l007l9oookJP03o`00
0?oonf[ooo]Z00Sooo]ZMol0obP7o`000?oo0?m=ROl0odd:oookJP7o00000OoonfX000Kooo]Z0ol0
07l9oookJPOo001o2_oonfX00ol0003ooo]ZoookJP08oookJW3o0?lX1ol0003oo`3oCI3o0?m=2_oo
nfX1o`00007ooo]Z0006oookJP?o001o2OoonfX6o`00O`_ooo]Z00?o0000oookJ_oonfX02?oonfYX
o`3o:0So0000ool0odfGo`3oC@[ooo]Z0Ol00001oookJP000ooonfX6o`00O`Wooo]Z0_l007l?oook
JP03o`000?oonf[ooo]Z00Sooo]ZHOl0obP7o`000?oo0?m=Wol0odd:oookJP7o00000OoonfX000?o
oo]Z1_l007l9oookJP;o001o3ooonfX00ol0003ooo]ZoookJP08oookJU[o0?lX1ol0003oo`3oCJKo
0?m=2_oonfX1o`00007ooo]Z0005oookJPCo001o2_oonfX7o`00O`Wooo]Z00?o0000oookJ_oonfX0
2?oonfYAo`3o:0Wo0000ool0odf]o`3oC@[ooo]Z0Ol00001oookJP001_oonfX3o`00O`[ooo]Z1ol0
07l9oookJP03o`000?oonf[ooo]Z00Sooo]ZA_l0obP;o`000?oo0?m=]_l0odd:oookJP7o00000Ooo
nfX002?ooo]Z00?o0000oookJ_oonfX02?oonfXfo`3o:13o0000ool0odg1o`3oC@[ooo]Z0Ol00001
oookJP008ooonfX00ol0003ooo]ZoookJP08oookJR3o0?lX5_l0003oo`3oCM7o0?m=2_oonfX1o`00
007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Z8?l0003oo`3oCNOo0?m=2_oonfX1o`00007o
oo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Zool0odgoo`3oC@So0?m=2_oonfX1o`00007ooo]Z
000SoookJP03o`000?oonf[ooo]Z00Sooo]Zool0odgoo`3oC@So0?m=2_oonfX1o`00007ooo]Z000S
oookJP03o`000?oonf[ooo]Z00Sooo]Zool0odgoo`3oC@So0?m=2_oonfX1o`00007ooo]Z000Soook
JP03o`000?oonf[ooo]Z00Sooo]Zool0odgoo`3oC@So0?m=2_oonfX1o`00007ooo]Z000SoookJP03
o`000?oonf[ooo]Z00Sooo]Zool0odgoo`3oC@So0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`00
0?oonf[ooo]Z00Sooo]Zool0odgoo`3oC@So0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`000?oo
nf[ooo]Z00Sooo]Zool0odgoo`3oC@So0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[o
oo]Z00Sooo]Zool0odgoo`3oC@So0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z
00Sooo]Zool0odgoo`3oC@So0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00So
oo]Zool0odgoo`3oC@So0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Z
ool0odgoo`3oC@So0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Zool0
odgoo`3oC@So0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Zool0odgo
o`3oC@So0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Zool0odgoo`3o
C@So0?m=2_oonfX1o`00007ooo]Z000SoookJP?o00002?oonf[oo`3oCOoo0?m=2?l0odd8oookJP?o
00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[oo`3oCOoo0?m=2?l0odd:oookJP7o0000
0OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[oo`3oCOoo0?m=2?l0odd:oookJP7o00000Ooo
nfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[oo`3oCOoo0?m=2?l0odd:oookJP7o00000OoonfX0
02?ooo]Z00?o0000oookJ_oonfX02?oonf[oo`3oCOoo0?m=2?l0odd:oookJP7o00000OoonfX002?o
oo]Z00?o0000oookJ_oonfX02?oonf[oo`3oCOoo0?m=2?l0odd:oookJP7o00000OoonfX002?ooo]Z
00?o0000oookJ_oonfX02?oonf[oo`3oCOoo0?m=2?l0odd:oookJP7o00000OoonfX002?ooo]Z00?o
0000oookJ_oonfX02?oonf[oo`3oCOoo0?m=2?l0odd:oookJP7o00000OoonfX002?ooo]Z00?o0000
oookJ_oonfX02?oonf[oo`3oCOoo0?m=2?l0odd:oookJP7o00000OoonfX002?ooo]Z00?o0000oook
J_oonfX02?oonf[oo`3oCOoo0?m=2?l0odd:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oo
nfX02?oonf[oo`3oCOoo0?m=2?l0odd:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX0
2?oonf[oo`3oCOoo0?m=2?l0odd:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oo
nf[oo`3oCOoo0?m=2?l0odd:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[o
o`3oCOoo0?m=2?l0odd:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[oo`3o
COoo0?m=2?l0odd:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[oo`3oCOoo
0?m=2?l0odd:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[oo`3oCOoo0?m=
2?l0odd:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[oo`3oCOoo0?m=2?l0
odd:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[oo`3oCOoo0?m=2?l0odd:
oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[oo`3oCOoo0?m=2?l0odd:oook
JP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[oo`3oCOoo0?m=2?l0odd:oookJP7o
00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[oo`3oCOoo0?m=2?l0odd:oookJP7o0000
0OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[oo`3oCOoo0?m=2?l0odd:oookJP7o00000Ooo
nfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[oo`3oCOoo0?m=2?l0odd:oookJP7o00000OoonfX0
02?ooo]Z00?o0000oookJ_oonfX02?oonf[oo`3oCOoo0?m=2?l0odd:oookJP7o00000OoonfX002?o
oo]Z00?o0000oookJ_oonfX02?oonf[oo`3oCOoo0?m=2?l0odd:oookJP7o00000OoonfX002?ooo]Z
0ol00008oookJ_oo0?m=ool0odd8o`3oC@Sooo]Z0ol00001oookJP008ooonfX00ol0003ooo]Zoook
JP08oookJ_oo0?m=ool0odd8o`3oC@[ooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08
oookJ_oo0?m=ool0odd8o`3oC@[ooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08oook
J_oo0?m=ool0odd8o`3oC@[ooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08oookJ_oo
0?m=ool0odd8o`3oC@[ooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08oookJ_oo0?m=
ool0odd8o`3oC@[ooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08oookJ_oo0?m=ool0
odd8o`3oC@[ooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08oookJ_oo0?m=ool0odd8
o`3oC@[ooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08oookJ_oo0?m=ool0odd8o`3o
C@[ooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08oookJ_oo0?m=ool0odd8o`3oC@[o
oo]Z0Ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08oookJ_oo0?m=ool0odd8o`3oC@[ooo]Z
0Ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08oookJ_oo0?m=ool0odd8o`3oC@[ooo]Z0Ol0
0001oookJP008ooonfX00ol0003ooo]ZoookJP08oookJ_oo0?m=ool0odd8o`3oC@[ooo]Z0Ol00001
oookJP008ooonfX00ol0003ooo]ZoookJP08oookJ_oo0?m=ool0odd8o`3oC@[ooo]Z0Ol00001oook
JP008ooonfX00ol0003ooo]ZoookJP08oookJ_oo0?m=ool0odd8o`3oC@[ooo]Z0Ol00001oookJP00
8ooonfX00ol0003ooo]ZoookJP08oookJ_oo0?m=ool0odd8o`3oC@[ooo]Z0Ol00001oookJP008ooo
nfX00ol0003ooo]ZoookJP08oookJ_oo0?m=ool0odd8o`3oC@[ooo]Z0Ol00001oookJP008ooonfX0
0ol0003ooo]ZoookJP08oookJ_oo0?m=ool0odd8o`3oC@[ooo]Z0Ol00001oookJP008ooonfX00ol0
003ooo]ZoookJP08oookJ_oo0?m=ool0odd8o`3oC@[ooo]Z0Ol00001oookJP008ooonfX00ol0003o
oo]ZoookJP08oookJ_oo0?m=ool0odd8o`3oC@[ooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]Z
oookJP08oookJ_oo0?m=ool0odd8o`3oC@[ooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]Zoook
JP08oookJ_oo0?m=ool0odd8o`3oC@[ooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08
oookJ_oo0?m=ool0odd8o`3oC@[ooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08oook
J_oo0?m=ool0odd8o`3oC@[ooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08oookJ_oo
0?m=ool0odd8o`3oC@[ooo]Z0Ol00001oookJP008ooonfX00ol0003ooo]ZoookJP08oookJ_oo0?m=
ool0odd8o`3oC@[ooo]Z0Ol00001oookJP008ooonfX3o`0000Sooo]Zool0odgoo`3oC@So0?m=2?oo
nfX3o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Zool0odgoo`3oC@So0?m=2_oonfX1
o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Zool0odgoo`3oC@So0?m=2_oonfX1o`00
007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Zool0odgoo`3oC@So0?m=2_oonfX1o`00007o
oo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Zool0odgoo`3oC@So0?m=2_oonfX1o`00007ooo]Z
000SoookJP03o`000?oonf[ooo]Z00Sooo]Zool0odgoo`3oC@So0?m=2_oonfX1o`00007ooo]Z000S
oookJP03o`000?oonf[ooo]Z00Sooo]Zool0odgoo`3oC@So0?m=2_oonfX1o`00007ooo]Z000Soook
JP03o`000?oonf[ooo]Z00Sooo]Zool0odgoo`3oC@So0?m=2_oonfX1o`00007ooo]Z000SoookJP03
o`000?oonf[ooo]Z00Sooo]Zool0odgoo`3oC@So0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`00
0?oonf[ooo]Z00Sooo]Zool0odgoo`3oC@So0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`000?oo
nf[ooo]Z00Sooo]Zool0odgoo`3oC@So0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[o
oo]Z00Sooo]Zool0odgoo`3oC@So0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z
00Sooo]Zool0odgoo`3oC@So0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00So
oo]Zool0odgoo`3oC@So0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Z
ool0odgoo`3oC@So0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Zool0
odgoo`3oC@So0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Zool0odgo
o`3oC@So0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Zool0odgoo`3o
C@So0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Zool0odgoo`3oC@So
0?m=2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Zool0odgoo`3oC@So0?m=
2_oonfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Zool0odgoo`3oC@So0?m=2_oo
nfX1o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Zool0odgoo`3oC@So0?m=2_oonfX1
o`00007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Zool0odgoo`3oC@So0?m=2_oonfX1o`00
007ooo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Zool0odgoo`3oC@So0?m=2_oonfX1o`00007o
oo]Z000SoookJP03o`000?oonf[ooo]Z00Sooo]Zool0odgoo`3oC@So0?m=2_oonfX1o`00007ooo]Z
000SoookJP03o`000?oonf[ooo]Z00Sooo]Zool0odgoo`3oC@So0?m=2_oonfX1o`00007ooo]Z000S
oookJP?o00002?oonf[oo`3oCOoo0?m=2?l0odd8oookJP?o00000OoonfX002?ooo]Z00?o0000oook
J_oonfX02?oonf[oo`3oCOoo0?m=2?l0odd:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oo
nfX02?oonf[oo`3oCOoo0?m=2?l0odd:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX0
2?oonf[oo`3oCOoo0?m=2?l0odd:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oo
nf[oo`3oCOoo0?m=2?l0odd:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[o
o`3oCOoo0?m=2?l0odd:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[oo`3o
COoo0?m=2?l0odd:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[oo`3oCOoo
0?m=2?l0odd:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[oo`3oCOoo0?m=
2?l0odd:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[oo`3oCOoo0?m=2?l0
odd:oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[oo`3oCOoo0?m=2?l0odd:
oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[oo`3oCOoo0?m=2?l0odd:oook
JP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[oo`3oCOoo0?m=2?l0odd:oookJP7o
00000OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[oo`3oCOoo0?m=2?l0odd:oookJP7o0000
0OoonfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[oo`3oCOoo0?m=2?l0odd:oookJP7o00000Ooo
nfX002?ooo]Z00?o0000oookJ_oonfX02?oonf[oo`3oCOoo0?m=2?l0odd:oookJP7o00000OoonfX0
02?ooo]Z00?o0000oookJ_oonfX02?oonf[oo`3oCOoo0?m=2?l0odd:oookJP7o00000OoonfX002?o
oo]Z00?o0000oookJ_oonfX02?oonf[oo`3oCOoo0?m=2?l0odd:oookJP7o00000OoonfX002?ooo]Z
00?o0000oookJ_oonfX02?oonf[oo`3oCOoo0?m=2?l0odd:oookJP7o00000OoonfX002?ooo]Z00?o
0000oookJ_oonfX02?oonf[oo`3oCOoo0?m=2?l0odd:oookJP7o00000OoonfX002?ooo]Z00?o0000
oookJ_oonfX02?oonf[oo`3oCOoo0?m=2?l0odd:oookJP7o00000OoonfX002?ooo]Z00?o0000oook
J_oonfX02?oonf[oo`3oCOoo0?m=2?l0odd:oookJP7o00000OoonfX0017ooo]Z2Ol007l9oookJP03
o`000?oonf[ooo]Z00Sooo]Zool0odgoo`3oC@So0?m=2_oonfX1o`00007ooo]Z000AoookJPWo001o
2OoonfX00ol0003ooo]ZoookJP08oookJ_oo0?m=ool0odd8o`3oC@[ooo]Z0Ol00001oookJP004Ooo
nfX4o`00O`kooo]Z00?o0000oookJ_oonfX02?oonf[oo`3oCOoo0?m=2?l0odd:oookJP7o00000Ooo
nfX001;ooo]Z1?l007l=oookJP03o`000?oonf[ooo]Z00Sooo]Zool0odgoo`3oC@So0?m=2_oonfX1
o`00007ooo]Z000CoookJPGo001o2ooonfX5o`0000Kooo]Zool0odgoo`3oC@So0?m=1ooonfX4o`00
007ooo]Z000EoookJPCo001o2_oonfX00ol0003ooo]ZoookJP3ooookJ_oooo]Z6_oonfX1o`00007o
oo]Z000FoookJP?o001o2_oonfX00ol0003ooo]ZoookJP3ooookJ_oooo]Z6_oonfX1o`00007ooo]Z
000GoookJP?o001o2OoonfX00ol0003ooo]ZoookJP3ooookJ_oooo]Z6_oonfX1o`00007ooo]Z000A
oookJP?o001o0ooonfX3o`00O`Wooo]Z00?o0000oookJ_oonfX0oooonf[ooookJQ[ooo]Z0Ol00001
oookJP004OoonfX3o`00O`?ooo]Z0ol007l9oookJP03o`000?oonf[ooo]Z0?oooo]ZoooonfXJoook
JP7o00000OoonfX0017ooo]Z1?l007l2oookJP?o001o2OoonfX00ol0003ooo]ZoookJP3ooookJ_oo
oo]Z6_oonfX1o`00007ooo]Z000BoookJPOo001o2_oonfX00ol0003ooo]ZoookJP07oookJP03o`00
0?oonf[ooo]Z07oooo]Z00?o0000oookJ_oonfX0OooonfX00ol0003ooo]ZoookJP1noookJP03o`00
0?oonf[ooo]Z07oooo]Z00?o0000oookJ_oonfX01ooonfX1o`00007ooo]Z000CoookJPGo001o2ooo
nfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX05ooo
nfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX05ooo
nfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX05ooo
nfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX05ooo
nfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX05ooo
nfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX05ooo
nfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX05ooo
nfX00ol0003ooo]ZoookJP07oookJP7o00000OoonfX002?ooo]Z00?o0000oookJ_oonfX01ooonfX0
0ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX05ooonfX0
0ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX05ooonfX0
0ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX05ooonfX0
0ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX05ooonfX0
0ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX05ooonfX0
0ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX05ooonfX0
0ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX01ooonfX1
o`00007ooo]Z000SoookJ_oo0000ool0000No`00007ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]Z
oooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00001\
\>"],
  ImageRangeCache->{{{0, 575}, {575, 0}} -> {-0.176805, -0.159694, \
0.00385613, 0.00385613}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  ContourGraphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
},
FrontEndVersion->"5.2 for Macintosh",
ScreenRectangle->{{4, 1920}, {0, 1178}},
ScreenStyleEnvironment->"Presentation",
CellGrouping->Manual,
WindowSize->{1430, 938},
WindowMargins->{{40, Automatic}, {Automatic, 7}},
ShowSelection->True,
CellLabelAutoDelete->True,
StyleDefinitions -> "3016_Carter.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "mmtag:16:divergence_theorem"->{
    Cell[1754, 51, 134, 4, 60, "Title",
      CellTags->"mmtag:16:divergence_theorem"]},
  "mmtag:16:pointwise_interaction_between_two_volumes"->{
    Cell[2052, 64, 1573, 26, 354, "Subsection",
      CellTags->{
      "mmtag:16:pointwise_interaction_between_two_volumes", 
        "mmtag:16:numerical_integration__reducing_the_amount_of_brute_force", 
        "mmtag:16:brute_force__reducing_in_numerical_integration"}]},
  "mmtag:16:numerical_integration__reducing_the_amount_of_brute_force"->{
    Cell[2052, 64, 1573, 26, 354, "Subsection",
      CellTags->{
      "mmtag:16:pointwise_interaction_between_two_volumes", 
        "mmtag:16:numerical_integration__reducing_the_amount_of_brute_force", 
        "mmtag:16:brute_force__reducing_in_numerical_integration"}]},
  "mmtag:16:brute_force__reducing_in_numerical_integration"->{
    Cell[2052, 64, 1573, 26, 354, "Subsection",
      CellTags->{
      "mmtag:16:pointwise_interaction_between_two_volumes", 
        "mmtag:16:numerical_integration__reducing_the_amount_of_brute_force", 
        "mmtag:16:brute_force__reducing_in_numerical_integration"}]},
  "mmtag:16:divergence_theorem__example_usage_to_convert_volume_integration_\
to_surface_integrals"->{
    Cell[3628, 92, 1077, 31, 125, "Text",
      CellTags->{
      "mmtag:16:divergence_theorem__example_usage_to_convert_volume_\
integration_to_surface_integrals", 
        "mmtag:16:dipole_interaction_between_cylinder_and_pont"}]},
  "mmtag:16:dipole_interaction_between_cylinder_and_pont"->{
    Cell[3628, 92, 1077, 31, 125, "Text",
      CellTags->{
      "mmtag:16:divergence_theorem__example_usage_to_convert_volume_\
integration_to_surface_integrals", 
        "mmtag:16:dipole_interaction_between_cylinder_and_pont"}]},
  "mmtag:16:London_interaction__vector_potential"->{
    Cell[4879, 132, 258, 4, 91, "Input",
      CellTags->"mmtag:16:London_interaction__vector_potential"],
    Cell[5140, 138, 454, 6, 106, "Output",
      CellTags->"mmtag:16:London_interaction__vector_potential"]},
  "mmtag:16:Div[]"->{
    Cell[5791, 157, 134, 3, 59, "Input",
      CellTags->"mmtag:16:Div[]"],
    Cell[5928, 162, 150, 3, 106, "Output",
      CellTags->"mmtag:16:Div[]"]},
  "mmtag:16:integral__over_cylinder"->{
    Cell[6958, 192, 499, 14, 161, "Text",
      CellTags->"mmtag:16:integral__over_cylinder"]},
  "mmtag:16:surface_normal__example"->{
    Cell[9024, 264, 470, 13, 98, "Text",
      CellTags->"mmtag:16:surface_normal__example"]},
  "mmtag:16:Cross[]"->{
    Cell[9519, 281, 115, 2, 59, "Input",
      CellTags->"mmtag:16:Cross[]"],
    Cell[9637, 285, 91, 2, 74, "Output",
      CellTags->"mmtag:16:Cross[]"]},
  "mmtag:16:numerical_integration__reducing_the_amount_of_brute_force_even_\
more_with_finesse"->{
    Cell[11806, 349, 348, 8, 55, "Subsubsection",
      CellTags->{
      "mmtag:16:numerical_integration__reducing_the_amount_of_brute_force_\
even_more_with_finesse", 
        "mmtag:16:brute_force__finesse_and_reducing_in_numerical_integration"}\
]},
  "mmtag:16:brute_force__finesse_and_reducing_in_numerical_integration"->{
    Cell[11806, 349, 348, 8, 55, "Subsubsection",
      CellTags->{
      "mmtag:16:numerical_integration__reducing_the_amount_of_brute_force_\
even_more_with_finesse", 
        "mmtag:16:brute_force__finesse_and_reducing_in_numerical_integration"}\
]},
  "mmtag:16:Evaluate[]__in_function_definitions"->{
    Cell[13200, 383, 418, 9, 59, "Text",
      CellTags->{
      "mmtag:16:Evaluate[]__in_function_definitions", 
        "mmtag:16:defining_functions_from_previously_evaluated_functions", 
        "mmtag:16:functions__definiting_from_previously_defined_expressions_\
without_using_replacement_rules"}]},
  "mmtag:16:defining_functions_from_previously_evaluated_functions"->{
    Cell[13200, 383, 418, 9, 59, "Text",
      CellTags->{
      "mmtag:16:Evaluate[]__in_function_definitions", 
        "mmtag:16:defining_functions_from_previously_evaluated_functions", 
        "mmtag:16:functions__definiting_from_previously_defined_expressions_\
without_using_replacement_rules"}]},
  "mmtag:16:functions__definiting_from_previously_defined_expressions_without_\
using_replacement_rules"->{
    Cell[13200, 383, 418, 9, 59, "Text",
      CellTags->{
      "mmtag:16:Evaluate[]__in_function_definitions", 
        "mmtag:16:defining_functions_from_previously_evaluated_functions", 
        "mmtag:16:functions__definiting_from_previously_defined_expressions_\
without_using_replacement_rules"}]},
  "Info3339740806-1604724"->{
    Cell[14098, 418, 63, 1, 70, "Print",
      CellTags->"Info3339740806-1604724"],
    Cell[14164, 421, 1121, 24, 70, "Print",
      CellTags->"Info3339740806-1604724"]},
  "Info3339740806-3383149"->{
    Cell[15364, 453, 63, 1, 70, "Print",
      CellTags->"Info3339740806-3383149"],
    Cell[15430, 456, 544, 15, 70, "Print",
      CellTags->"Info3339740806-3383149"]},
  "mmtag:16:NIntegrate[]"->{
    Cell[17042, 506, 270, 6, 59, "Input",
      CellTags->"mmtag:16:NIntegrate[]"]},
  "mmtag:16:functions_overloading"->{
    Cell[17315, 514, 315, 6, 103, "Text",
      CellTags->"mmtag:16:functions_overloading"]},
  "mmtag:16:dipole_interaction_between_cylinder_and_pont__function_for"->{
    Cell[29737, 889, 363, 6, 80, "Input",
      CellTags->
      "mmtag:16:dipole_interaction_between_cylinder_and_pont__function_for"]},\

  "mmtag:16:dipole_interaction_between_cylinder_and_pont__visualization_of"->{\

    Cell[30632, 923, 188, 5, 59, "Text",
      CellTags->
      "mmtag:16:dipole_interaction_between_cylinder_and_pont__visualization_\
of"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"mmtag:16:divergence_theorem", 306406, 8303},
  {"mmtag:16:pointwise_interaction_between_two_volumes", 306553, 8306},
  {"mmtag:16:numerical_integration__reducing_the_amount_of_brute_force", \
306903, 8312},
  {"mmtag:16:brute_force__reducing_in_numerical_integration", 307242, 8318},
  {"mmtag:16:divergence_theorem__example_usage_to_convert_volume_integration_\
to_surface_integrals", 307621, 8325},
  {"mmtag:16:dipole_interaction_between_cylinder_and_pont", 307916, 8331},
  {"mmtag:16:London_interaction__vector_potential", 308203, 8337},
  {"mmtag:16:Div[]", 308442, 8342},
  {"mmtag:16:integral__over_cylinder", 308637, 8347},
  {"mmtag:16:surface_normal__example", 308773, 8350},
  {"mmtag:16:Cross[]", 308892, 8353},
  {"mmtag:16:numerical_integration__reducing_the_amount_of_brute_force_even_\
more_with_finesse", 309148, 8359},
  {"mmtag:16:brute_force__finesse_and_reducing_in_numerical_integration", \
309477, 8366},
  {"mmtag:16:Evaluate[]__in_function_definitions", 309783, 8373},
  {"mmtag:16:defining_functions_from_previously_evaluated_functions", 310159, \
8380},
  {"mmtag:16:functions__definiting_from_previously_defined_expressions_\
without_using_replacement_rules", 310572, 8388},
  {"Info3339740806-1604724", 310907, 8395},
  {"Info3339740806-3383149", 311109, 8400},
  {"mmtag:16:NIntegrate[]", 311309, 8405},
  {"mmtag:16:functions_overloading", 311432, 8408},
  {"mmtag:16:dipole_interaction_between_cylinder_and_pont__function_for", \
311601, 8411},
  {"mmtag:16:dipole_interaction_between_cylinder_and_pont__visualization_of", \
311820, 8416}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 134, 4, 60, "Title",
  CellTags->"mmtag:16:divergence_theorem"],
Cell[1891, 57, 136, 3, 52, "Subtitle"],

Cell[CellGroupData[{
Cell[2052, 64, 1573, 26, 354, "Subsection",
  CellTags->{
  "mmtag:16:pointwise_interaction_between_two_volumes", 
    "mmtag:16:numerical_integration__reducing_the_amount_of_brute_force", 
    "mmtag:16:brute_force__reducing_in_numerical_integration"}],
Cell[3628, 92, 1077, 31, 125, "Text",
  CellTags->{
  "mmtag:16:divergence_theorem__example_usage_to_convert_volume_integration_\
to_surface_integrals", 
    "mmtag:16:dipole_interaction_between_cylinder_and_pont"}],
Cell[4708, 125, 146, 3, 59, "Text"],

Cell[CellGroupData[{
Cell[4879, 132, 258, 4, 91, "Input",
  CellTags->"mmtag:16:London_interaction__vector_potential"],
Cell[5140, 138, 454, 6, 106, "Output",
  CellTags->"mmtag:16:London_interaction__vector_potential"]
}, Open  ]],
Cell[5609, 147, 60, 1, 59, "Input"],
Cell[5672, 150, 94, 3, 59, "Text"],

Cell[CellGroupData[{
Cell[5791, 157, 134, 3, 59, "Input",
  CellTags->"mmtag:16:Div[]"],
Cell[5928, 162, 150, 3, 106, "Output",
  CellTags->"mmtag:16:Div[]"]
}, Open  ]],
Cell[6093, 168, 862, 22, 141, "Text"],
Cell[6958, 192, 499, 14, 161, "Text",
  CellTags->"mmtag:16:integral__over_cylinder"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7494, 211, 71, 0, 84, "Section"],
Cell[7568, 213, 169, 4, 59, "Text"],

Cell[CellGroupData[{
Cell[7762, 221, 82, 1, 59, "Input"],
Cell[7847, 224, 65, 1, 74, "Output"]
}, Open  ]],
Cell[7927, 228, 402, 12, 65, "Text"],

Cell[CellGroupData[{
Cell[8354, 244, 171, 3, 101, "Input"],
Cell[8528, 249, 64, 1, 74, "Output"],
Cell[8595, 252, 368, 6, 26, "Message"],
Cell[8966, 260, 43, 1, 74, "Output"]
}, Open  ]],
Cell[9024, 264, 470, 13, 98, "Text",
  CellTags->"mmtag:16:surface_normal__example"],

Cell[CellGroupData[{
Cell[9519, 281, 115, 2, 59, "Input",
  CellTags->"mmtag:16:Cross[]"],
Cell[9637, 285, 91, 2, 74, "Output",
  CellTags->"mmtag:16:Cross[]"]
}, Open  ]],
Cell[9743, 290, 119, 3, 59, "Text"],

Cell[CellGroupData[{
Cell[9887, 297, 217, 4, 59, "Input"],
Cell[10107, 303, 169, 2, 106, "Output"]
}, Open  ]],
Cell[10291, 308, 708, 12, 269, "Text"],

Cell[CellGroupData[{
Cell[11024, 324, 110, 3, 55, "Subsubsection"],

Cell[CellGroupData[{
Cell[11159, 331, 265, 5, 59, "Input"],
Cell[11427, 338, 330, 5, 106, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[11806, 349, 348, 8, 55, "Subsubsection",
  CellTags->{
  "mmtag:16:numerical_integration__reducing_the_amount_of_brute_force_even_\
more_with_finesse", 
    "mmtag:16:brute_force__finesse_and_reducing_in_numerical_integration"}],

Cell[CellGroupData[{
Cell[12179, 361, 331, 6, 80, "Input"],
Cell[12513, 369, 650, 9, 283, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13200, 383, 418, 9, 59, "Text",
  CellTags->{
  "mmtag:16:Evaluate[]__in_function_definitions", 
    "mmtag:16:defining_functions_from_previously_evaluated_functions", 
    "mmtag:16:functions__definiting_from_previously_defined_expressions_\
without_using_replacement_rules"}],

Cell[CellGroupData[{
Cell[13643, 396, 104, 2, 50, "Input"],
Cell[13750, 400, 68, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13855, 406, 87, 1, 50, "Input"],
Cell[13945, 409, 74, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14056, 415, 39, 1, 50, "Input"],
Cell[14098, 418, 63, 1, 70, "Print",
  CellTags->"Info3339740806-1604724"],
Cell[14164, 421, 1121, 24, 70, "Print",
  CellTags->"Info3339740806-1604724"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15322, 450, 39, 1, 50, "Input"],
Cell[15364, 453, 63, 1, 70, "Print",
  CellTags->"Info3339740806-3383149"],
Cell[15430, 456, 544, 15, 70, "Print",
  CellTags->"Info3339740806-3383149"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16011, 476, 47, 1, 50, "Input"],
Cell[16061, 479, 159, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16257, 486, 47, 1, 50, "Input"],
Cell[16307, 489, 157, 2, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[16491, 495, 548, 9, 95, "Input"],
Cell[17042, 506, 270, 6, 59, "Input",
  CellTags->"mmtag:16:NIntegrate[]"],
Cell[17315, 514, 315, 6, 103, "Text",
  CellTags->"mmtag:16:functions_overloading"],
Cell[17633, 522, 231, 5, 59, "Input"],
Cell[17867, 529, 95, 3, 59, "Text"],

Cell[CellGroupData[{
Cell[17987, 536, 70, 1, 59, "Input"],
Cell[18060, 539, 60, 1, 74, "Output"]
}, Open  ]],
Cell[18135, 543, 96, 3, 59, "Text"],

Cell[CellGroupData[{
Cell[18256, 550, 76, 1, 59, "Input"],
Cell[18335, 553, 59, 1, 74, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[18443, 560, 114, 3, 59, "Text"],

Cell[CellGroupData[{
Cell[18582, 567, 75, 1, 85, "Input"],
Cell[18660, 570, 62, 1, 100, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18759, 576, 165, 3, 101, "Input"],
Cell[18927, 581, 64, 1, 74, "Output"],
Cell[18994, 584, 368, 6, 26, "Message"],
Cell[19365, 592, 53, 1, 74, "Output"]
}, Open  ]],
Cell[19433, 596, 176, 3, 64, "Text"],

Cell[CellGroupData[{
Cell[19634, 603, 104, 2, 59, "Input"],
Cell[19741, 607, 43, 1, 74, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19821, 613, 237, 4, 59, "Input"],
Cell[20061, 619, 148, 2, 117, "Output"]
}, Open  ]],
Cell[20224, 624, 196, 4, 86, "Text"],

Cell[CellGroupData[{
Cell[20445, 632, 136, 3, 55, "Subsubsection"],

Cell[CellGroupData[{
Cell[20606, 639, 297, 6, 59, "Input"],
Cell[20906, 647, 389, 5, 26, "Message"],
Cell[21298, 654, 310, 5, 99, "Output"],
Cell[21611, 661, 64, 1, 74, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[21724, 668, 53, 0, 55, "Subsubsection"],

Cell[CellGroupData[{
Cell[21802, 672, 310, 6, 59, "Input"],
Cell[22115, 680, 1130, 16, 302, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23282, 701, 272, 4, 80, "Input"],
Cell[23557, 707, 389, 5, 26, "Message"]
}, Open  ]],
Cell[23961, 715, 243, 5, 59, "Input"],
Cell[24207, 722, 231, 5, 59, "Input"],

Cell[CellGroupData[{
Cell[24463, 731, 77, 1, 59, "Input"],
Cell[24543, 734, 55, 1, 74, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[24635, 740, 62, 1, 59, "Input"],
Cell[24700, 743, 53, 1, 74, "Output"]
}, Open  ]],
Cell[24768, 747, 70, 0, 59, "Text"],

Cell[CellGroupData[{
Cell[24863, 751, 80, 1, 85, "Input"],
Cell[24946, 754, 71, 1, 100, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[25054, 760, 165, 3, 101, "Input"],
Cell[25222, 765, 64, 1, 74, "Output"],
Cell[25289, 768, 368, 6, 26, "Message"],
Cell[25660, 776, 53, 1, 74, "Output"]
}, Open  ]],
Cell[25728, 780, 179, 3, 64, "Text"],

Cell[CellGroupData[{
Cell[25932, 787, 104, 2, 59, "Input"],
Cell[26039, 791, 48, 1, 74, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[26124, 797, 251, 5, 59, "Input"],
Cell[26378, 804, 162, 2, 106, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[26577, 811, 310, 6, 59, "Input"],
Cell[26890, 819, 1255, 17, 343, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28182, 841, 272, 4, 80, "Input"],
Cell[28457, 847, 389, 5, 26, "Message"]
}, Open  ]],
Cell[28861, 855, 243, 5, 59, "Input"],
Cell[29107, 862, 231, 5, 59, "Input"],

Cell[CellGroupData[{
Cell[29363, 871, 77, 1, 59, "Input"],
Cell[29443, 874, 55, 1, 74, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29535, 880, 62, 1, 59, "Input"],
Cell[29600, 883, 55, 1, 74, "Output"]
}, Open  ]],
Cell[29670, 887, 64, 0, 59, "Text"],
Cell[29737, 889, 363, 6, 80, "Input",
  CellTags->
  "mmtag:16:dipole_interaction_between_cylinder_and_pont__function_for"],

Cell[CellGroupData[{
Cell[30125, 899, 70, 1, 59, "Input"],
Cell[30198, 902, 57, 1, 74, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[30292, 908, 73, 1, 59, "Input"],
Cell[30368, 911, 53, 1, 74, "Output"]
}, Open  ]],
Cell[30436, 915, 136, 3, 59, "Input"],
Cell[30575, 920, 54, 1, 59, "Input"],
Cell[30632, 923, 188, 5, 59, "Text",
  CellTags->
  "mmtag:16:dipole_interaction_between_cylinder_and_pont__visualization_of"],

Cell[CellGroupData[{
Cell[30845, 932, 583, 11, 143, "Input"],
Cell[31431, 945, 44682, 1173, 364, 15663, 810, "GraphicsData", "PostScript", \
"Graphics"],
Cell[76116, 2120, 130, 3, 74, "Output"]
}, Open  ]],
Cell[76261, 2126, 385, 10, 86, "Text"],

Cell[CellGroupData[{
Cell[76671, 2140, 80, 1, 59, "Input"],
Cell[76754, 2143, 48605, 1329, 364, 20438, 977, "GraphicsData", "PostScript", \
"Graphics"],
Cell[125362, 3474, 130, 3, 74, "Output"]
}, Open  ]],
Cell[125507, 3480, 351, 10, 86, "Text"],
Cell[125861, 3492, 69, 0, 59, "Text"],

Cell[CellGroupData[{
Cell[125955, 3496, 528, 10, 143, "Input"],
Cell[126486, 3508, 37294, 1005, 364, 14500, 719, "GraphicsData", \
"PostScript", "Graphics"],
Cell[163783, 4515, 130, 3, 74, "Output"]
}, Open  ]],
Cell[163928, 4521, 832, 28, 97, "Subsubsection"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[164799, 4554, 148, 3, 59, "Text"],

Cell[CellGroupData[{
Cell[164972, 4561, 207, 4, 59, "Input"],
Cell[165182, 4567, 140314, 3708, 584, 39492, 2459, "GraphicsData", \
"PostScript", "Graphics"],
Cell[305499, 8277, 137, 3, 74, "Output"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

