(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   1526413,      61891]*)
(*NotebookOutlinePosition[   1532976,      62038]*)
(*  CellTagsIndexPosition[   1531521,      62009]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Higher-Order Ordinary Differential Equations", "Title"],

Cell["Background: Another example of for Forward Differencing", "Subtitle"],

Cell[TextData[{
  "Recall how we used forward finite differencing to simulate the behavior of \
a function that changed proportional to its current size in Lecture 19.  \
Consider now a function that changes \"",
  StyleBox["how fast it changes",
    FontSlant->"Italic"],
  "\" proportional to its current change and its current value--in other \
words its current acceleration is proportional to its velocity and to its \
size:"
}], "Text"],

Cell["Let's work out how to find a finite differencing function:", "Text"],

Cell["This is the current change or approximation to velocity", "Text"],

Cell[BoxData[
    \(CurrentChangePerDelta[F_, \ 
        i_, \ \[CapitalDelta]_]\  := \ \(F[i + 1]\  - \ F[i]\)\/\
\[CapitalDelta]\)], "Input",
  CellTags->{
  "mmtag:21:foward_differencing__higher_order_ODEs", 
    "mmtag:21:foward_differencing__example_function"}],

Cell["\<\
This is the current change in change or approximation to \
acceleration\
\>", "Text"],

Cell[BoxData[
    \(CurrentChangeinCurrentChangeperDelta[F_, \ 
        i_, \ \[CapitalDelta]_]\  := \ \
\[IndentingNewLine]Simplify[\(CurrentChangePerDelta[F, i + 1, \
\[CapitalDelta]]\  - \ CurrentChangePerDelta[F, i, \[CapitalDelta]]\)\/\
\[CapitalDelta]]\)], "Input",
  CellTags->{
  "mmtag:21:discrete_approximation_to_derivative", 
    "mmtag:21:derivatives__discrete_approximation"}],

Cell["\<\
Our model is that the acceleration is proportional to  size of the \
current function and its velocity, let these proportions be: -\[Alpha] and -\
\[Beta]\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DifferenceRelation\  = \ 
      CurrentChangeinCurrentChangeperDelta[F, 
            i, \[CapitalDelta]]\  + \ \[Beta]\ \ CurrentChangePerDelta[F, 
              i, \[CapitalDelta]] + \ \[Alpha]\ F[i] \[Equal] 0\)], "Input",
  CellTags->{
  "mmtag:21:derivatives__discrete_approximation_second_derivative", 
    "mmtag:21:second_derivatives__discrete_approximation"}],

Cell[BoxData[
    \(\[Alpha]\ F[
            i] + \(\[Beta]\ \((\(-F[i]\) + F[1 + i])\)\)\/\[CapitalDelta] + \
\(F[i] - 2\ F[1 + i] + F[2 + i]\)\/\[CapitalDelta]\^2 \[Equal] 0\)], "Output"]
}, Open  ]],

Cell["Solve this for the \"latest\" values", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ForDiffSol\  = \ 
      Solve[DifferenceRelation, F[i + 2]] // Flatten\)], "Input"],

Cell[BoxData[
    \({F[2 + 
            i] \[Rule] \(-F[i]\) + \[Beta]\ \[CapitalDelta]\ F[
              i] - \[Alpha]\ \[CapitalDelta]\^2\ F[i] + 
          2\ F[1 + i] - \[Beta]\ \[CapitalDelta]\ F[1 + i]}\)], "Output"]
}, Open  ]],

Cell["Replace to find the form of the solution", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ForDiffSolV2\  = \ ForDiffSol /. i \[Rule] \ j - 2\)], "Input"],

Cell[BoxData[
    \({F[j] \[Rule] \(-F[\(-2\) + j]\) + \[Beta]\ \[CapitalDelta]\ F[\(-2\) + 
                j] - \[Alpha]\ \[CapitalDelta]\^2\ F[\(-2\) + j] + 
          2\ F[\(-1\) + j] - \[Beta]\ \[CapitalDelta]\ F[\(-1\) + 
                j]}\)], "Output"]
}, Open  ]],

Cell["\<\
Notice that this forward differnce needs TWO consectutive past \
values before it can calculate the current value, create a function to \
Appends the current value to a list by using the last two values:\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
The fact that TWO consecutive values are needed is not surprising. \
Because this iteration procedure is giving an approximation to the solution \
of a second-order ODE, we need to make a numerical approximation to a second \
derivative. THREE points\[LongDash]the two consecutive ones and the current \
one\[LongDash]are needed to do this. (If only two points were used, you could \
only compute the slope of the straight line connecting the points; if three \
points are used, a circle can be fit to the three points and the inverse of \
its radius gives the curvature.)\
\>", "Subsubsection"],

Cell[BoxData[
    \(GrowListGeneral[
        ValuesList_List, \ \[CapitalDelta]_\ , \ \[Alpha]_\ , \ \[Beta]_]\  := 
      Module[{Minus1 = ValuesList[\([\(-1\)]\)], \ 
          Minus2\  = \ ValuesList[\([\(-2\)]\)]}, \[IndentingNewLine]Append[
          ValuesList, \[IndentingNewLine]2*Minus1\  - \ 
            Minus2\  + \ \[CapitalDelta]\ *\((\[Beta]*\((Minus2\  - \ 
                        Minus1)\)\  - \[Alpha]*\[CapitalDelta]*
                    Minus2)\)]]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(result\  = \ GrowListGeneral[{1, 1},  .001, 1,  .1]\)], "Input"],

Cell[BoxData[
    \({1, 1, 0.999999`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(result\  = \ GrowListGeneral[result,  .001, 1,  .1]\)], "Input"],

Cell[BoxData[
    \({1, 1, 0.999999`, 0.9999970000999999`}\)], "Output"]
}, Open  ]],

Cell["\<\
Define a function for specific parameters of the General case, and \
use it to generate a sequence of length 20\
\>", "Text"],

Cell[BoxData[
    \(GrowListSpecific[InitialList_List]\ \  := \ 
      GrowListGeneral[InitialList,  .001, 1,  .1]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Nest[GrowListSpecific, {1, 1}, 20]\)], "Input"],

Cell[BoxData[
    \({1, 1, 0.999999`, 0.9999970000999999`, 0.9999940004009898`, 
      0.9999900010049496`, 0.9999850020148486`, 0.9999790035346456`, 
      0.9999720056692887`, 0.9999640085247147`, 0.9999550122078494`, 
      0.9999450168266074`, 0.9999340224898913`, 0.999922029307592`, 
      0.9999090373905885`, 0.9998950468507473`, 0.9998800578009227`, 
      0.9998640703549563`, 0.9998470846276767`, 0.9998291007348995`, 
      0.999810118793427`, 0.9997901389210478`}\)], "Output"]
}, Open  ]],

Cell["\<\
Visualize results (it takes about 45 seconds to visualize 20000 \
iterations)\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[Nest[GrowListSpecific, {1, 1}, 20000]]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 4.76143e-05 0.286151 0.317168 [
[.26188 .27365 -22 -20 ]
[.26188 .27365 22 0 ]
[.49995 .27365 -27 -20 ]
[.49995 .27365 27 0 ]
[.73802 .27365 -27 -20 ]
[.73802 .27365 27 0 ]
[.9761 .27365 -27 -20 ]
[.9761 .27365 27 0 ]
[.01131 .04828 -51.9375 -10 ]
[.01131 .04828 0 10 ]
[.01131 .12757 -41.9375 -10 ]
[.01131 .12757 0 10 ]
[.01131 .20686 -51.9375 -10 ]
[.01131 .20686 0 10 ]
[.01131 .36544 -39 -10 ]
[.01131 .36544 0 10 ]
[.01131 .44474 -29 -10 ]
[.01131 .44474 0 10 ]
[.01131 .52403 -39 -10 ]
[.01131 .52403 0 10 ]
[.01131 .60332 -14 -10 ]
[.01131 .60332 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.26188 .28615 m
.26188 .2924 L
s
gsave
.26188 .27365 -83 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5000) show
1.000 setlinewidth
grestore
.49995 .28615 m
.49995 .2924 L
s
gsave
.49995 .27365 -88 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10000) show
1.000 setlinewidth
grestore
.73802 .28615 m
.73802 .2924 L
s
gsave
.73802 .27365 -88 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15000) show
1.000 setlinewidth
grestore
.9761 .28615 m
.9761 .2924 L
s
gsave
.9761 .27365 -88 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(20000) show
1.000 setlinewidth
grestore
.125 Mabswid
.07142 .28615 m
.07142 .2899 L
s
.11904 .28615 m
.11904 .2899 L
s
.16665 .28615 m
.16665 .2899 L
s
.21427 .28615 m
.21427 .2899 L
s
.3095 .28615 m
.3095 .2899 L
s
.35711 .28615 m
.35711 .2899 L
s
.40472 .28615 m
.40472 .2899 L
s
.45234 .28615 m
.45234 .2899 L
s
.54757 .28615 m
.54757 .2899 L
s
.59518 .28615 m
.59518 .2899 L
s
.6428 .28615 m
.6428 .2899 L
s
.69041 .28615 m
.69041 .2899 L
s
.78564 .28615 m
.78564 .2899 L
s
.83325 .28615 m
.83325 .2899 L
s
.88087 .28615 m
.88087 .2899 L
s
.92848 .28615 m
.92848 .2899 L
s
.01 w
0 .28615 m
1 .28615 L
s
.25 Mabswid
.02381 .04828 m
.03006 .04828 L
s
gsave
.01131 .04828 -112.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
.02381 .12757 m
.03006 .12757 L
s
gsave
.01131 .12757 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.02381 .20686 m
.03006 .20686 L
s
gsave
.01131 .20686 -112.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.02381 .36544 m
.03006 .36544 L
s
gsave
.01131 .36544 -100 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.02381 .44474 m
.03006 .44474 L
s
gsave
.01131 .44474 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.02381 .52403 m
.03006 .52403 L
s
gsave
.01131 .52403 -100 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
.02381 .60332 m
.03006 .60332 L
s
gsave
.01131 .60332 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .06413 m
.02756 .06413 L
s
.02381 .07999 m
.02756 .07999 L
s
.02381 .09585 m
.02756 .09585 L
s
.02381 .11171 m
.02756 .11171 L
s
.02381 .14343 m
.02756 .14343 L
s
.02381 .15928 m
.02756 .15928 L
s
.02381 .17514 m
.02756 .17514 L
s
.02381 .191 m
.02756 .191 L
s
.02381 .22272 m
.02756 .22272 L
s
.02381 .23858 m
.02756 .23858 L
s
.02381 .25443 m
.02756 .25443 L
s
.02381 .27029 m
.02756 .27029 L
s
.02381 .30201 m
.02756 .30201 L
s
.02381 .31787 m
.02756 .31787 L
s
.02381 .33373 m
.02756 .33373 L
s
.02381 .34958 m
.02756 .34958 L
s
.02381 .3813 m
.02756 .3813 L
s
.02381 .39716 m
.02756 .39716 L
s
.02381 .41302 m
.02756 .41302 L
s
.02381 .42888 m
.02756 .42888 L
s
.02381 .46059 m
.02756 .46059 L
s
.02381 .47645 m
.02756 .47645 L
s
.02381 .49231 m
.02756 .49231 L
s
.02381 .50817 m
.02756 .50817 L
s
.02381 .53989 m
.02756 .53989 L
s
.02381 .55574 m
.02756 .55574 L
s
.02381 .5716 m
.02756 .5716 L
s
.02381 .58746 m
.02756 .58746 L
s
.02381 .03242 m
.02756 .03242 L
s
.02381 .01656 m
.02756 .01656 L
s
.02381 .0007 m
.02756 .0007 L
s
.01 w
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02386 .60332 Mdot
.0239 .60332 Mdot
.02395 .60332 Mdot
.024 .60332 Mdot
.02405 .60332 Mdot
.0241 .60332 Mdot
.02414 .60331 Mdot
.02419 .60331 Mdot
.02424 .60331 Mdot
.02429 .60331 Mdot
.02433 .6033 Mdot
.02438 .6033 Mdot
.02443 .6033 Mdot
.02448 .60329 Mdot
.02452 .60329 Mdot
.02457 .60329 Mdot
.02462 .60328 Mdot
.02467 .60328 Mdot
.02471 .60327 Mdot
.02476 .60326 Mdot
.02481 .60326 Mdot
.02486 .60325 Mdot
.0249 .60325 Mdot
.02495 .60324 Mdot
.025 .60323 Mdot
.02505 .60322 Mdot
.0251 .60322 Mdot
.02514 .60321 Mdot
.02519 .6032 Mdot
.02524 .60319 Mdot
.02529 .60318 Mdot
.02533 .60317 Mdot
.02538 .60316 Mdot
.02543 .60315 Mdot
.02548 .60314 Mdot
.02552 .60313 Mdot
.02557 .60312 Mdot
.02562 .60311 Mdot
.02567 .6031 Mdot
.02571 .60308 Mdot
.02576 .60307 Mdot
.02581 .60306 Mdot
.02586 .60305 Mdot
.0259 .60303 Mdot
.02595 .60302 Mdot
.026 .60301 Mdot
.02605 .60299 Mdot
.0261 .60298 Mdot
.02614 .60296 Mdot
.02619 .60295 Mdot
.02624 .60293 Mdot
.02629 .60292 Mdot
.02633 .6029 Mdot
.02638 .60288 Mdot
.02643 .60287 Mdot
.02648 .60285 Mdot
.02652 .60283 Mdot
.02657 .60281 Mdot
.02662 .6028 Mdot
.02667 .60278 Mdot
.02671 .60276 Mdot
.02676 .60274 Mdot
.02681 .60272 Mdot
.02686 .6027 Mdot
.0269 .60268 Mdot
.02695 .60266 Mdot
.027 .60264 Mdot
.02705 .60262 Mdot
.02709 .6026 Mdot
.02714 .60258 Mdot
.02719 .60255 Mdot
.02724 .60253 Mdot
.02729 .60251 Mdot
.02733 .60249 Mdot
.02738 .60246 Mdot
.02743 .60244 Mdot
.02748 .60242 Mdot
.02752 .60239 Mdot
.02757 .60237 Mdot
.02762 .60234 Mdot
.02767 .60232 Mdot
.02771 .60229 Mdot
.02776 .60227 Mdot
.02781 .60224 Mdot
.02786 .60222 Mdot
.0279 .60219 Mdot
.02795 .60216 Mdot
.028 .60214 Mdot
.02805 .60211 Mdot
.02809 .60208 Mdot
.02814 .60205 Mdot
.02819 .60202 Mdot
.02824 .602 Mdot
.02829 .60197 Mdot
.02833 .60194 Mdot
.02838 .60191 Mdot
.02843 .60188 Mdot
.02848 .60185 Mdot
.02852 .60182 Mdot
.02857 .60179 Mdot
.02862 .60176 Mdot
.02867 .60172 Mdot
.02871 .60169 Mdot
.02876 .60166 Mdot
.02881 .60163 Mdot
.02886 .60159 Mdot
.0289 .60156 Mdot
.02895 .60153 Mdot
.029 .60149 Mdot
.02905 .60146 Mdot
.02909 .60143 Mdot
.02914 .60139 Mdot
.02919 .60136 Mdot
.02924 .60132 Mdot
.02929 .60129 Mdot
.02933 .60125 Mdot
.02938 .60121 Mdot
.02943 .60118 Mdot
.02948 .60114 Mdot
.02952 .6011 Mdot
.02957 .60107 Mdot
.02962 .60103 Mdot
.02967 .60099 Mdot
.02971 .60095 Mdot
.02976 .60091 Mdot
.02981 .60087 Mdot
.02986 .60083 Mdot
.0299 .6008 Mdot
.02995 .60076 Mdot
.03 .60071 Mdot
.03005 .60067 Mdot
.03009 .60063 Mdot
.03014 .60059 Mdot
.03019 .60055 Mdot
.03024 .60051 Mdot
.03029 .60047 Mdot
.03033 .60042 Mdot
.03038 .60038 Mdot
.03043 .60034 Mdot
.03048 .6003 Mdot
.03052 .60025 Mdot
.03057 .60021 Mdot
.03062 .60016 Mdot
.03067 .60012 Mdot
.03071 .60007 Mdot
.03076 .60003 Mdot
.03081 .59998 Mdot
.03086 .59994 Mdot
.0309 .59989 Mdot
.03095 .59985 Mdot
.031 .5998 Mdot
.03105 .59975 Mdot
.03109 .5997 Mdot
.03114 .59966 Mdot
.03119 .59961 Mdot
.03124 .59956 Mdot
.03128 .59951 Mdot
.03133 .59946 Mdot
.03138 .59941 Mdot
.03143 .59936 Mdot
.03148 .59931 Mdot
.03152 .59926 Mdot
.03157 .59921 Mdot
.03162 .59916 Mdot
.03167 .59911 Mdot
.03171 .59906 Mdot
.03176 .59901 Mdot
.03181 .59896 Mdot
.03186 .5989 Mdot
.0319 .59885 Mdot
.03195 .5988 Mdot
.032 .59875 Mdot
.03205 .59869 Mdot
.03209 .59864 Mdot
.03214 .59858 Mdot
.03219 .59853 Mdot
.03224 .59847 Mdot
.03228 .59842 Mdot
.03233 .59836 Mdot
.03238 .59831 Mdot
.03243 .59825 Mdot
.03248 .5982 Mdot
.03252 .59814 Mdot
.03257 .59808 Mdot
.03262 .59803 Mdot
.03267 .59797 Mdot
.03271 .59791 Mdot
.03276 .59785 Mdot
.03281 .59779 Mdot
.03286 .59774 Mdot
.0329 .59768 Mdot
.03295 .59762 Mdot
.033 .59756 Mdot
.03305 .5975 Mdot
.03309 .59744 Mdot
.03314 .59738 Mdot
.03319 .59732 Mdot
.03324 .59725 Mdot
.03328 .59719 Mdot
.03333 .59713 Mdot
.03338 .59707 Mdot
.03343 .59701 Mdot
.03348 .59694 Mdot
.03352 .59688 Mdot
.03357 .59682 Mdot
.03362 .59675 Mdot
.03367 .59669 Mdot
.03371 .59663 Mdot
.03376 .59656 Mdot
.03381 .5965 Mdot
.03386 .59643 Mdot
.0339 .59637 Mdot
.03395 .5963 Mdot
.034 .59623 Mdot
.03405 .59617 Mdot
.03409 .5961 Mdot
.03414 .59603 Mdot
.03419 .59597 Mdot
.03424 .5959 Mdot
.03428 .59583 Mdot
.03433 .59576 Mdot
.03438 .59569 Mdot
.03443 .59563 Mdot
.03448 .59556 Mdot
.03452 .59549 Mdot
.03457 .59542 Mdot
.03462 .59535 Mdot
.03467 .59528 Mdot
.03471 .59521 Mdot
.03476 .59514 Mdot
.03481 .59507 Mdot
.03486 .59499 Mdot
.0349 .59492 Mdot
.03495 .59485 Mdot
.035 .59478 Mdot
.03505 .5947 Mdot
.03509 .59463 Mdot
.03514 .59456 Mdot
.03519 .59448 Mdot
.03524 .59441 Mdot
.03528 .59434 Mdot
.03533 .59426 Mdot
.03538 .59419 Mdot
.03543 .59411 Mdot
.03548 .59404 Mdot
.03552 .59396 Mdot
.03557 .59388 Mdot
.03562 .59381 Mdot
.03567 .59373 Mdot
.03571 .59366 Mdot
.03576 .59358 Mdot
.03581 .5935 Mdot
.03586 .59342 Mdot
.0359 .59334 Mdot
.03595 .59327 Mdot
.036 .59319 Mdot
.03605 .59311 Mdot
.03609 .59303 Mdot
.03614 .59295 Mdot
.03619 .59287 Mdot
.03624 .59279 Mdot
.03628 .59271 Mdot
.03633 .59263 Mdot
.03638 .59255 Mdot
.03643 .59247 Mdot
.03647 .59238 Mdot
.03652 .5923 Mdot
.03657 .59222 Mdot
.03662 .59214 Mdot
.03667 .59205 Mdot
.03671 .59197 Mdot
.03676 .59189 Mdot
.03681 .5918 Mdot
.03686 .59172 Mdot
.0369 .59164 Mdot
.03695 .59155 Mdot
.037 .59147 Mdot
.03705 .59138 Mdot
.03709 .59129 Mdot
.03714 .59121 Mdot
.03719 .59112 Mdot
.03724 .59104 Mdot
.03728 .59095 Mdot
.03733 .59086 Mdot
.03738 .59078 Mdot
.03743 .59069 Mdot
.03747 .5906 Mdot
.03752 .59051 Mdot
.03757 .59042 Mdot
.03762 .59033 Mdot
.03767 .59024 Mdot
.03771 .59016 Mdot
.03776 .59007 Mdot
.03781 .58998 Mdot
.03786 .58989 Mdot
.0379 .58979 Mdot
.03795 .5897 Mdot
.038 .58961 Mdot
.03805 .58952 Mdot
.03809 .58943 Mdot
.03814 .58934 Mdot
.03819 .58925 Mdot
.03824 .58915 Mdot
.03828 .58906 Mdot
.03833 .58897 Mdot
.03838 .58887 Mdot
.03843 .58878 Mdot
.03847 .58868 Mdot
.03852 .58859 Mdot
.03857 .5885 Mdot
.03862 .5884 Mdot
.03867 .58831 Mdot
.03871 .58821 Mdot
.03876 .58811 Mdot
.03881 .58802 Mdot
.03886 .58792 Mdot
.0389 .58782 Mdot
.03895 .58773 Mdot
.039 .58763 Mdot
.03905 .58753 Mdot
.03909 .58743 Mdot
.03914 .58734 Mdot
.03919 .58724 Mdot
.03924 .58714 Mdot
.03928 .58704 Mdot
.03933 .58694 Mdot
.03938 .58684 Mdot
.03943 .58674 Mdot
.03947 .58664 Mdot
.03952 .58654 Mdot
.03957 .58644 Mdot
.03962 .58634 Mdot
.03967 .58624 Mdot
.03971 .58614 Mdot
.03976 .58603 Mdot
.03981 .58593 Mdot
.03986 .58583 Mdot
.0399 .58573 Mdot
.03995 .58562 Mdot
.04 .58552 Mdot
.04005 .58542 Mdot
.04009 .58531 Mdot
.04014 .58521 Mdot
.04019 .5851 Mdot
.04024 .585 Mdot
.04028 .58489 Mdot
.04033 .58479 Mdot
.04038 .58468 Mdot
.04043 .58458 Mdot
.04047 .58447 Mdot
.04052 .58436 Mdot
.04057 .58426 Mdot
.04062 .58415 Mdot
.04066 .58404 Mdot
.04071 .58393 Mdot
.04076 .58382 Mdot
.04081 .58372 Mdot
.04086 .58361 Mdot
.0409 .5835 Mdot
.04095 .58339 Mdot
.041 .58328 Mdot
.04105 .58317 Mdot
.04109 .58306 Mdot
.04114 .58295 Mdot
.04119 .58284 Mdot
.04124 .58273 Mdot
.04128 .58262 Mdot
.04133 .58251 Mdot
.04138 .58239 Mdot
.04143 .58228 Mdot
.04147 .58217 Mdot
.04152 .58206 Mdot
.04157 .58194 Mdot
.04162 .58183 Mdot
.04166 .58172 Mdot
.04171 .5816 Mdot
.04176 .58149 Mdot
.04181 .58138 Mdot
.04186 .58126 Mdot
.0419 .58115 Mdot
.04195 .58103 Mdot
.042 .58092 Mdot
.04205 .5808 Mdot
.04209 .58068 Mdot
.04214 .58057 Mdot
.04219 .58045 Mdot
.04224 .58033 Mdot
.04228 .58022 Mdot
.04233 .5801 Mdot
.04238 .57998 Mdot
.04243 .57986 Mdot
.04247 .57975 Mdot
.04252 .57963 Mdot
.04257 .57951 Mdot
.04262 .57939 Mdot
.04266 .57927 Mdot
.04271 .57915 Mdot
.04276 .57903 Mdot
.04281 .57891 Mdot
.04286 .57879 Mdot
.0429 .57867 Mdot
.04295 .57855 Mdot
.043 .57843 Mdot
.04305 .5783 Mdot
.04309 .57818 Mdot
.04314 .57806 Mdot
.04319 .57794 Mdot
.04324 .57781 Mdot
.04328 .57769 Mdot
.04333 .57757 Mdot
.04338 .57744 Mdot
.04343 .57732 Mdot
.04347 .5772 Mdot
.04352 .57707 Mdot
.04357 .57695 Mdot
.04362 .57682 Mdot
.04366 .5767 Mdot
.04371 .57657 Mdot
.04376 .57645 Mdot
.04381 .57632 Mdot
.04386 .57619 Mdot
.0439 .57607 Mdot
.04395 .57594 Mdot
.044 .57581 Mdot
.04405 .57568 Mdot
.04409 .57556 Mdot
.04414 .57543 Mdot
.04419 .5753 Mdot
.04424 .57517 Mdot
.04428 .57504 Mdot
.04433 .57491 Mdot
.04438 .57478 Mdot
.04443 .57465 Mdot
.04447 .57452 Mdot
.04452 .57439 Mdot
.04457 .57426 Mdot
.04462 .57413 Mdot
.04466 .574 Mdot
.04471 .57387 Mdot
.04476 .57374 Mdot
.04481 .57361 Mdot
.04486 .57347 Mdot
.0449 .57334 Mdot
.04495 .57321 Mdot
.045 .57308 Mdot
.04505 .57294 Mdot
.04509 .57281 Mdot
.04514 .57268 Mdot
.04519 .57254 Mdot
.04524 .57241 Mdot
.04528 .57227 Mdot
.04533 .57214 Mdot
.04538 .572 Mdot
.04543 .57187 Mdot
.04547 .57173 Mdot
.04552 .57159 Mdot
.04557 .57146 Mdot
.04562 .57132 Mdot
.04566 .57118 Mdot
.04571 .57105 Mdot
.04576 .57091 Mdot
.04581 .57077 Mdot
.04585 .57063 Mdot
.0459 .5705 Mdot
.04595 .57036 Mdot
.046 .57022 Mdot
.04605 .57008 Mdot
.04609 .56994 Mdot
.04614 .5698 Mdot
.04619 .56966 Mdot
.04624 .56952 Mdot
.04628 .56938 Mdot
.04633 .56924 Mdot
.04638 .5691 Mdot
.04643 .56896 Mdot
.04647 .56882 Mdot
.04652 .56868 Mdot
.04657 .56853 Mdot
.04662 .56839 Mdot
.04666 .56825 Mdot
.04671 .56811 Mdot
.04676 .56796 Mdot
.04681 .56782 Mdot
.04685 .56768 Mdot
.0469 .56753 Mdot
.04695 .56739 Mdot
.047 .56724 Mdot
.04705 .5671 Mdot
.04709 .56695 Mdot
.04714 .56681 Mdot
.04719 .56666 Mdot
.04724 .56652 Mdot
.04728 .56637 Mdot
.04733 .56623 Mdot
.04738 .56608 Mdot
.04743 .56593 Mdot
.04747 .56579 Mdot
.04752 .56564 Mdot
.04757 .56549 Mdot
.04762 .56534 Mdot
.04766 .56519 Mdot
.04771 .56505 Mdot
.04776 .5649 Mdot
.04781 .56475 Mdot
.04785 .5646 Mdot
.0479 .56445 Mdot
.04795 .5643 Mdot
.048 .56415 Mdot
.04805 .564 Mdot
.04809 .56385 Mdot
.04814 .5637 Mdot
.04819 .56355 Mdot
.04824 .5634 Mdot
.04828 .56325 Mdot
.04833 .56309 Mdot
.04838 .56294 Mdot
.04843 .56279 Mdot
.04847 .56264 Mdot
.04852 .56248 Mdot
.04857 .56233 Mdot
.04862 .56218 Mdot
.04866 .56202 Mdot
.04871 .56187 Mdot
.04876 .56172 Mdot
.04881 .56156 Mdot
.04885 .56141 Mdot
.0489 .56125 Mdot
.04895 .5611 Mdot
.049 .56094 Mdot
.04905 .56079 Mdot
.04909 .56063 Mdot
.04914 .56047 Mdot
.04919 .56032 Mdot
.04924 .56016 Mdot
.04928 .56 Mdot
.04933 .55985 Mdot
.04938 .55969 Mdot
.04943 .55953 Mdot
.04947 .55937 Mdot
.04952 .55921 Mdot
.04957 .55906 Mdot
.04962 .5589 Mdot
.04966 .55874 Mdot
.04971 .55858 Mdot
.04976 .55842 Mdot
.04981 .55826 Mdot
.04985 .5581 Mdot
.0499 .55794 Mdot
.04995 .55778 Mdot
.05 .55762 Mdot
.05004 .55746 Mdot
.05009 .55729 Mdot
.05014 .55713 Mdot
.05019 .55697 Mdot
.05024 .55681 Mdot
.05028 .55665 Mdot
.05033 .55648 Mdot
.05038 .55632 Mdot
.05043 .55616 Mdot
.05047 .55599 Mdot
.05052 .55583 Mdot
.05057 .55567 Mdot
.05062 .5555 Mdot
.05066 .55534 Mdot
.05071 .55517 Mdot
.05076 .55501 Mdot
.05081 .55484 Mdot
.05085 .55468 Mdot
.0509 .55451 Mdot
.05095 .55435 Mdot
.051 .55418 Mdot
.05104 .55401 Mdot
.05109 .55385 Mdot
.05114 .55368 Mdot
.05119 .55351 Mdot
.05124 .55335 Mdot
.05128 .55318 Mdot
.05133 .55301 Mdot
.05138 .55284 Mdot
.05143 .55267 Mdot
.05147 .55251 Mdot
.05152 .55234 Mdot
.05157 .55217 Mdot
.05162 .552 Mdot
.05166 .55183 Mdot
.05171 .55166 Mdot
.05176 .55149 Mdot
.05181 .55132 Mdot
.05185 .55115 Mdot
.0519 .55098 Mdot
.05195 .5508 Mdot
.052 .55063 Mdot
.05204 .55046 Mdot
.05209 .55029 Mdot
.05214 .55012 Mdot
.05219 .54995 Mdot
.05224 .54977 Mdot
.05228 .5496 Mdot
.05233 .54943 Mdot
.05238 .54925 Mdot
.05243 .54908 Mdot
.05247 .54891 Mdot
.05252 .54873 Mdot
.05257 .54856 Mdot
.05262 .54838 Mdot
.05266 .54821 Mdot
.05271 .54803 Mdot
.05276 .54786 Mdot
.05281 .54768 Mdot
.05285 .54751 Mdot
.0529 .54733 Mdot
.05295 .54715 Mdot
.053 .54698 Mdot
.05304 .5468 Mdot
.05309 .54662 Mdot
.05314 .54645 Mdot
.05319 .54627 Mdot
.05324 .54609 Mdot
.05328 .54591 Mdot
.05333 .54573 Mdot
.05338 .54556 Mdot
.05343 .54538 Mdot
.05347 .5452 Mdot
.05352 .54502 Mdot
.05357 .54484 Mdot
.05362 .54466 Mdot
.05366 .54448 Mdot
.05371 .5443 Mdot
.05376 .54412 Mdot
.05381 .54394 Mdot
.05385 .54376 Mdot
.0539 .54358 Mdot
.05395 .54339 Mdot
.054 .54321 Mdot
.05404 .54303 Mdot
.05409 .54285 Mdot
.05414 .54267 Mdot
.05419 .54248 Mdot
.05424 .5423 Mdot
.05428 .54212 Mdot
.05433 .54193 Mdot
.05438 .54175 Mdot
.05443 .54157 Mdot
.05447 .54138 Mdot
.05452 .5412 Mdot
.05457 .54101 Mdot
.05462 .54083 Mdot
.05466 .54065 Mdot
.05471 .54046 Mdot
.05476 .54027 Mdot
.05481 .54009 Mdot
.05485 .5399 Mdot
.0549 .53972 Mdot
.05495 .53953 Mdot
.055 .53934 Mdot
.05504 .53916 Mdot
.05509 .53897 Mdot
.05514 .53878 Mdot
.05519 .53859 Mdot
.05523 .53841 Mdot
.05528 .53822 Mdot
.05533 .53803 Mdot
.05538 .53784 Mdot
.05543 .53765 Mdot
.05547 .53746 Mdot
.05552 .53728 Mdot
.05557 .53709 Mdot
.05562 .5369 Mdot
.05566 .53671 Mdot
.05571 .53652 Mdot
.05576 .53633 Mdot
.05581 .53614 Mdot
.05585 .53594 Mdot
.0559 .53575 Mdot
.05595 .53556 Mdot
.056 .53537 Mdot
.05604 .53518 Mdot
.05609 .53499 Mdot
.05614 .5348 Mdot
.05619 .5346 Mdot
.05623 .53441 Mdot
.05628 .53422 Mdot
.05633 .53402 Mdot
.05638 .53383 Mdot
.05643 .53364 Mdot
.05647 .53344 Mdot
.05652 .53325 Mdot
.05657 .53306 Mdot
.05662 .53286 Mdot
.05666 .53267 Mdot
.05671 .53247 Mdot
.05676 .53228 Mdot
.05681 .53208 Mdot
.05685 .53188 Mdot
.0569 .53169 Mdot
.05695 .53149 Mdot
.057 .5313 Mdot
.05704 .5311 Mdot
.05709 .5309 Mdot
.05714 .53071 Mdot
.05719 .53051 Mdot
.05723 .53031 Mdot
.05728 .53011 Mdot
.05733 .52992 Mdot
.05738 .52972 Mdot
.05743 .52952 Mdot
.05747 .52932 Mdot
.05752 .52912 Mdot
.05757 .52892 Mdot
.05762 .52872 Mdot
.05766 .52852 Mdot
.05771 .52833 Mdot
.05776 .52813 Mdot
.05781 .52793 Mdot
.05785 .52772 Mdot
.0579 .52752 Mdot
.05795 .52732 Mdot
.058 .52712 Mdot
.05804 .52692 Mdot
.05809 .52672 Mdot
.05814 .52652 Mdot
.05819 .52632 Mdot
.05823 .52611 Mdot
.05828 .52591 Mdot
.05833 .52571 Mdot
.05838 .52551 Mdot
.05843 .5253 Mdot
.05847 .5251 Mdot
.05852 .5249 Mdot
.05857 .52469 Mdot
.05862 .52449 Mdot
.05866 .52429 Mdot
.05871 .52408 Mdot
.05876 .52388 Mdot
.05881 .52367 Mdot
.05885 .52347 Mdot
.0589 .52326 Mdot
.05895 .52306 Mdot
.059 .52285 Mdot
.05904 .52265 Mdot
.05909 .52244 Mdot
.05914 .52223 Mdot
.05919 .52203 Mdot
.05923 .52182 Mdot
.05928 .52161 Mdot
.05933 .52141 Mdot
.05938 .5212 Mdot
.05943 .52099 Mdot
.05947 .52078 Mdot
.05952 .52058 Mdot
.05957 .52037 Mdot
.05962 .52016 Mdot
.05966 .51995 Mdot
.05971 .51974 Mdot
.05976 .51953 Mdot
.05981 .51932 Mdot
.05985 .51911 Mdot
.0599 .5189 Mdot
.05995 .51869 Mdot
.06 .51848 Mdot
.06004 .51827 Mdot
.06009 .51806 Mdot
.06014 .51785 Mdot
.06019 .51764 Mdot
.06023 .51743 Mdot
.06028 .51722 Mdot
.06033 .51701 Mdot
.06038 .5168 Mdot
.06042 .51658 Mdot
.06047 .51637 Mdot
.06052 .51616 Mdot
.06057 .51595 Mdot
.06062 .51573 Mdot
.06066 .51552 Mdot
.06071 .51531 Mdot
.06076 .51509 Mdot
.06081 .51488 Mdot
.06085 .51467 Mdot
.0609 .51445 Mdot
.06095 .51424 Mdot
.061 .51402 Mdot
.06104 .51381 Mdot
.06109 .51359 Mdot
.06114 .51338 Mdot
.06119 .51316 Mdot
.06123 .51295 Mdot
.06128 .51273 Mdot
.06133 .51252 Mdot
.06138 .5123 Mdot
.06142 .51209 Mdot
.06147 .51187 Mdot
.06152 .51165 Mdot
.06157 .51143 Mdot
.06162 .51122 Mdot
.06166 .511 Mdot
.06171 .51078 Mdot
.06176 .51057 Mdot
.06181 .51035 Mdot
.06185 .51013 Mdot
.0619 .50991 Mdot
.06195 .50969 Mdot
.062 .50947 Mdot
.06204 .50925 Mdot
.06209 .50904 Mdot
.06214 .50882 Mdot
.06219 .5086 Mdot
.06223 .50838 Mdot
.06228 .50816 Mdot
.06233 .50794 Mdot
.06238 .50772 Mdot
.06242 .5075 Mdot
.06247 .50727 Mdot
.06252 .50705 Mdot
.06257 .50683 Mdot
.06262 .50661 Mdot
.06266 .50639 Mdot
.06271 .50617 Mdot
.06276 .50595 Mdot
.06281 .50572 Mdot
.06285 .5055 Mdot
.0629 .50528 Mdot
.06295 .50506 Mdot
.063 .50483 Mdot
.06304 .50461 Mdot
.06309 .50439 Mdot
.06314 .50416 Mdot
.06319 .50394 Mdot
.06323 .50372 Mdot
.06328 .50349 Mdot
.06333 .50327 Mdot
.06338 .50304 Mdot
.06342 .50282 Mdot
.06347 .50259 Mdot
.06352 .50237 Mdot
.06357 .50214 Mdot
.06362 .50192 Mdot
.06366 .50169 Mdot
.06371 .50147 Mdot
.06376 .50124 Mdot
.06381 .50101 Mdot
.06385 .50079 Mdot
.0639 .50056 Mdot
.06395 .50033 Mdot
.064 .50011 Mdot
.06404 .49988 Mdot
.06409 .49965 Mdot
.06414 .49942 Mdot
.06419 .4992 Mdot
.06423 .49897 Mdot
.06428 .49874 Mdot
.06433 .49851 Mdot
.06438 .49828 Mdot
.06442 .49805 Mdot
.06447 .49783 Mdot
.06452 .4976 Mdot
.06457 .49737 Mdot
.06461 .49714 Mdot
.06466 .49691 Mdot
.06471 .49668 Mdot
.06476 .49645 Mdot
.06481 .49622 Mdot
.06485 .49599 Mdot
.0649 .49576 Mdot
.06495 .49553 Mdot
.065 .4953 Mdot
.06504 .49506 Mdot
.06509 .49483 Mdot
.06514 .4946 Mdot
.06519 .49437 Mdot
.06523 .49414 Mdot
.06528 .49391 Mdot
.06533 .49367 Mdot
.06538 .49344 Mdot
.06542 .49321 Mdot
.06547 .49297 Mdot
.06552 .49274 Mdot
.06557 .49251 Mdot
.06561 .49228 Mdot
.06566 .49204 Mdot
.06571 .49181 Mdot
.06576 .49157 Mdot
.06581 .49134 Mdot
.06585 .49111 Mdot
.0659 .49087 Mdot
.06595 .49064 Mdot
.066 .4904 Mdot
.06604 .49017 Mdot
.06609 .48993 Mdot
.06614 .4897 Mdot
.06619 .48946 Mdot
.06623 .48922 Mdot
.06628 .48899 Mdot
.06633 .48875 Mdot
.06638 .48852 Mdot
.06642 .48828 Mdot
.06647 .48804 Mdot
.06652 .48781 Mdot
.06657 .48757 Mdot
.06661 .48733 Mdot
.06666 .48709 Mdot
.06671 .48686 Mdot
.06676 .48662 Mdot
.06681 .48638 Mdot
.06685 .48614 Mdot
.0669 .48591 Mdot
.06695 .48567 Mdot
.067 .48543 Mdot
.06704 .48519 Mdot
.06709 .48495 Mdot
.06714 .48471 Mdot
.06719 .48447 Mdot
.06723 .48423 Mdot
.06728 .48399 Mdot
.06733 .48375 Mdot
.06738 .48351 Mdot
.06742 .48327 Mdot
.06747 .48303 Mdot
.06752 .48279 Mdot
.06757 .48255 Mdot
.06761 .48231 Mdot
.06766 .48207 Mdot
.06771 .48183 Mdot
.06776 .48159 Mdot
.06781 .48135 Mdot
.06785 .4811 Mdot
.0679 .48086 Mdot
.06795 .48062 Mdot
.068 .48038 Mdot
.06804 .48014 Mdot
.06809 .47989 Mdot
.06814 .47965 Mdot
.06819 .47941 Mdot
.06823 .47916 Mdot
.06828 .47892 Mdot
.06833 .47868 Mdot
.06838 .47843 Mdot
.06842 .47819 Mdot
.06847 .47795 Mdot
.06852 .4777 Mdot
.06857 .47746 Mdot
.06861 .47721 Mdot
.06866 .47697 Mdot
.06871 .47672 Mdot
.06876 .47648 Mdot
.06881 .47623 Mdot
.06885 .47599 Mdot
.0689 .47574 Mdot
.06895 .4755 Mdot
.069 .47525 Mdot
.06904 .47501 Mdot
.06909 .47476 Mdot
.06914 .47451 Mdot
.06919 .47427 Mdot
.06923 .47402 Mdot
.06928 .47377 Mdot
.06933 .47353 Mdot
.06938 .47328 Mdot
.06942 .47303 Mdot
.06947 .47279 Mdot
.06952 .47254 Mdot
.06957 .47229 Mdot
.06961 .47204 Mdot
.06966 .47179 Mdot
.06971 .47155 Mdot
.06976 .4713 Mdot
.0698 .47105 Mdot
.06985 .4708 Mdot
.0699 .47055 Mdot
.06995 .4703 Mdot
.07 .47005 Mdot
.07004 .4698 Mdot
.07009 .46955 Mdot
.07014 .46931 Mdot
.07019 .46906 Mdot
.07023 .46881 Mdot
.07028 .46856 Mdot
.07033 .46831 Mdot
.07038 .46805 Mdot
.07042 .4678 Mdot
.07047 .46755 Mdot
.07052 .4673 Mdot
.07057 .46705 Mdot
.07061 .4668 Mdot
.07066 .46655 Mdot
.07071 .4663 Mdot
.07076 .46605 Mdot
.0708 .46579 Mdot
.07085 .46554 Mdot
.0709 .46529 Mdot
.07095 .46504 Mdot
.071 .46478 Mdot
.07104 .46453 Mdot
.07109 .46428 Mdot
.07114 .46403 Mdot
.07119 .46377 Mdot
.07123 .46352 Mdot
.07128 .46327 Mdot
.07133 .46301 Mdot
.07138 .46276 Mdot
.07142 .46251 Mdot
.07147 .46225 Mdot
.07152 .462 Mdot
.07157 .46174 Mdot
.07161 .46149 Mdot
.07166 .46123 Mdot
.07171 .46098 Mdot
.07176 .46073 Mdot
.0718 .46047 Mdot
.07185 .46021 Mdot
.0719 .45996 Mdot
.07195 .4597 Mdot
.072 .45945 Mdot
.07204 .45919 Mdot
.07209 .45894 Mdot
.07214 .45868 Mdot
.07219 .45842 Mdot
.07223 .45817 Mdot
.07228 .45791 Mdot
.07233 .45766 Mdot
.07238 .4574 Mdot
.07242 .45714 Mdot
.07247 .45688 Mdot
.07252 .45663 Mdot
.07257 .45637 Mdot
.07261 .45611 Mdot
.07266 .45585 Mdot
.07271 .4556 Mdot
.07276 .45534 Mdot
.0728 .45508 Mdot
.07285 .45482 Mdot
.0729 .45456 Mdot
.07295 .45431 Mdot
.073 .45405 Mdot
.07304 .45379 Mdot
.07309 .45353 Mdot
.07314 .45327 Mdot
.07319 .45301 Mdot
.07323 .45275 Mdot
.07328 .45249 Mdot
.07333 .45223 Mdot
.07338 .45197 Mdot
.07342 .45171 Mdot
.07347 .45145 Mdot
.07352 .45119 Mdot
.07357 .45093 Mdot
.07361 .45067 Mdot
.07366 .45041 Mdot
.07371 .45015 Mdot
.07376 .44989 Mdot
.0738 .44963 Mdot
.07385 .44937 Mdot
.0739 .44911 Mdot
.07395 .44884 Mdot
.07399 .44858 Mdot
.07404 .44832 Mdot
.07409 .44806 Mdot
.07414 .4478 Mdot
.07419 .44753 Mdot
.07423 .44727 Mdot
.07428 .44701 Mdot
.07433 .44675 Mdot
.07438 .44648 Mdot
.07442 .44622 Mdot
.07447 .44596 Mdot
.07452 .4457 Mdot
.07457 .44543 Mdot
.07461 .44517 Mdot
.07466 .44491 Mdot
.07471 .44464 Mdot
.07476 .44438 Mdot
.0748 .44411 Mdot
.07485 .44385 Mdot
.0749 .44359 Mdot
.07495 .44332 Mdot
.07499 .44306 Mdot
.07504 .44279 Mdot
.07509 .44253 Mdot
.07514 .44226 Mdot
.07519 .442 Mdot
.07523 .44173 Mdot
.07528 .44147 Mdot
.07533 .4412 Mdot
.07538 .44094 Mdot
.07542 .44067 Mdot
.07547 .44041 Mdot
.07552 .44014 Mdot
.07557 .43987 Mdot
.07561 .43961 Mdot
.07566 .43934 Mdot
.07571 .43908 Mdot
.07576 .43881 Mdot
.0758 .43854 Mdot
.07585 .43828 Mdot
.0759 .43801 Mdot
.07595 .43774 Mdot
.07599 .43748 Mdot
.07604 .43721 Mdot
.07609 .43694 Mdot
.07614 .43667 Mdot
.07619 .43641 Mdot
.07623 .43614 Mdot
.07628 .43587 Mdot
.07633 .4356 Mdot
.07638 .43533 Mdot
.07642 .43507 Mdot
.07647 .4348 Mdot
.07652 .43453 Mdot
.07657 .43426 Mdot
.07661 .43399 Mdot
.07666 .43372 Mdot
.07671 .43345 Mdot
.07676 .43319 Mdot
.0768 .43292 Mdot
.07685 .43265 Mdot
.0769 .43238 Mdot
.07695 .43211 Mdot
.07699 .43184 Mdot
.07704 .43157 Mdot
.07709 .4313 Mdot
.07714 .43103 Mdot
.07719 .43076 Mdot
.07723 .43049 Mdot
.07728 .43022 Mdot
.07733 .42995 Mdot
.07738 .42968 Mdot
.07742 .42941 Mdot
.07747 .42914 Mdot
.07752 .42886 Mdot
.07757 .42859 Mdot
.07761 .42832 Mdot
.07766 .42805 Mdot
.07771 .42778 Mdot
.07776 .42751 Mdot
.0778 .42724 Mdot
.07785 .42696 Mdot
.0779 .42669 Mdot
.07795 .42642 Mdot
.07799 .42615 Mdot
.07804 .42588 Mdot
.07809 .4256 Mdot
.07814 .42533 Mdot
.07819 .42506 Mdot
.07823 .42479 Mdot
.07828 .42451 Mdot
.07833 .42424 Mdot
.07838 .42397 Mdot
.07842 .42369 Mdot
.07847 .42342 Mdot
.07852 .42315 Mdot
.07857 .42287 Mdot
.07861 .4226 Mdot
.07866 .42233 Mdot
.07871 .42205 Mdot
.07876 .42178 Mdot
.0788 .42151 Mdot
.07885 .42123 Mdot
.0789 .42096 Mdot
.07895 .42068 Mdot
.07899 .42041 Mdot
.07904 .42013 Mdot
.07909 .41986 Mdot
.07914 .41958 Mdot
.07918 .41931 Mdot
.07923 .41904 Mdot
.07928 .41876 Mdot
.07933 .41848 Mdot
.07938 .41821 Mdot
.07942 .41793 Mdot
.07947 .41766 Mdot
.07952 .41738 Mdot
.07957 .41711 Mdot
.07961 .41683 Mdot
.07966 .41656 Mdot
.07971 .41628 Mdot
.07976 .416 Mdot
.0798 .41573 Mdot
.07985 .41545 Mdot
.0799 .41517 Mdot
.07995 .4149 Mdot
.07999 .41462 Mdot
.08004 .41435 Mdot
.08009 .41407 Mdot
.08014 .41379 Mdot
.08018 .41351 Mdot
.08023 .41324 Mdot
.08028 .41296 Mdot
.08033 .41268 Mdot
.08038 .41241 Mdot
.08042 .41213 Mdot
.08047 .41185 Mdot
.08052 .41157 Mdot
.08057 .41129 Mdot
.08061 .41102 Mdot
.08066 .41074 Mdot
.08071 .41046 Mdot
.08076 .41018 Mdot
.0808 .4099 Mdot
.08085 .40963 Mdot
.0809 .40935 Mdot
.08095 .40907 Mdot
.08099 .40879 Mdot
.08104 .40851 Mdot
.08109 .40823 Mdot
.08114 .40795 Mdot
.08118 .40767 Mdot
.08123 .4074 Mdot
.08128 .40712 Mdot
.08133 .40684 Mdot
.08138 .40656 Mdot
.08142 .40628 Mdot
.08147 .406 Mdot
.08152 .40572 Mdot
.08157 .40544 Mdot
.08161 .40516 Mdot
.08166 .40488 Mdot
.08171 .4046 Mdot
.08176 .40432 Mdot
.0818 .40404 Mdot
.08185 .40376 Mdot
.0819 .40348 Mdot
.08195 .4032 Mdot
.08199 .40292 Mdot
.08204 .40264 Mdot
.08209 .40236 Mdot
.08214 .40207 Mdot
.08218 .40179 Mdot
.08223 .40151 Mdot
.08228 .40123 Mdot
.08233 .40095 Mdot
.08238 .40067 Mdot
.08242 .40039 Mdot
.08247 .40011 Mdot
.08252 .39982 Mdot
.08257 .39954 Mdot
.08261 .39926 Mdot
.08266 .39898 Mdot
.08271 .3987 Mdot
.08276 .39842 Mdot
.0828 .39813 Mdot
.08285 .39785 Mdot
.0829 .39757 Mdot
.08295 .39729 Mdot
.08299 .397 Mdot
.08304 .39672 Mdot
.08309 .39644 Mdot
.08314 .39616 Mdot
.08318 .39587 Mdot
.08323 .39559 Mdot
.08328 .39531 Mdot
.08333 .39503 Mdot
.08337 .39474 Mdot
.08342 .39446 Mdot
.08347 .39418 Mdot
.08352 .39389 Mdot
.08357 .39361 Mdot
.08361 .39333 Mdot
.08366 .39304 Mdot
.08371 .39276 Mdot
.08376 .39247 Mdot
.0838 .39219 Mdot
.08385 .39191 Mdot
.0839 .39162 Mdot
.08395 .39134 Mdot
.08399 .39106 Mdot
.08404 .39077 Mdot
.08409 .39049 Mdot
.08414 .3902 Mdot
.08418 .38992 Mdot
.08423 .38963 Mdot
.08428 .38935 Mdot
.08433 .38906 Mdot
.08437 .38878 Mdot
.08442 .38849 Mdot
.08447 .38821 Mdot
.08452 .38793 Mdot
.08457 .38764 Mdot
.08461 .38736 Mdot
.08466 .38707 Mdot
.08471 .38678 Mdot
.08476 .3865 Mdot
.0848 .38621 Mdot
.08485 .38593 Mdot
.0849 .38564 Mdot
.08495 .38536 Mdot
.08499 .38507 Mdot
.08504 .38479 Mdot
.08509 .3845 Mdot
.08514 .38421 Mdot
.08518 .38393 Mdot
.08523 .38364 Mdot
.08528 .38336 Mdot
.08533 .38307 Mdot
.08537 .38278 Mdot
.08542 .3825 Mdot
.08547 .38221 Mdot
.08552 .38193 Mdot
.08557 .38164 Mdot
.08561 .38135 Mdot
.08566 .38107 Mdot
.08571 .38078 Mdot
.08576 .38049 Mdot
.0858 .38021 Mdot
.08585 .37992 Mdot
.0859 .37963 Mdot
.08595 .37934 Mdot
.08599 .37906 Mdot
.08604 .37877 Mdot
.08609 .37848 Mdot
.08614 .3782 Mdot
.08618 .37791 Mdot
.08623 .37762 Mdot
.08628 .37733 Mdot
.08633 .37705 Mdot
.08637 .37676 Mdot
.08642 .37647 Mdot
.08647 .37618 Mdot
.08652 .3759 Mdot
.08657 .37561 Mdot
.08661 .37532 Mdot
.08666 .37503 Mdot
.08671 .37474 Mdot
.08676 .37446 Mdot
.0868 .37417 Mdot
.08685 .37388 Mdot
.0869 .37359 Mdot
.08695 .3733 Mdot
.08699 .37302 Mdot
.08704 .37273 Mdot
.08709 .37244 Mdot
.08714 .37215 Mdot
.08718 .37186 Mdot
.08723 .37157 Mdot
.08728 .37128 Mdot
.08733 .371 Mdot
.08737 .37071 Mdot
.08742 .37042 Mdot
.08747 .37013 Mdot
.08752 .36984 Mdot
.08757 .36955 Mdot
.08761 .36926 Mdot
.08766 .36897 Mdot
.08771 .36868 Mdot
.08776 .36839 Mdot
.0878 .3681 Mdot
.08785 .36782 Mdot
.0879 .36753 Mdot
.08795 .36724 Mdot
.08799 .36695 Mdot
.08804 .36666 Mdot
.08809 .36637 Mdot
.08814 .36608 Mdot
.08818 .36579 Mdot
.08823 .3655 Mdot
.08828 .36521 Mdot
.08833 .36492 Mdot
.08837 .36463 Mdot
.08842 .36434 Mdot
.08847 .36405 Mdot
.08852 .36376 Mdot
.08856 .36347 Mdot
.08861 .36318 Mdot
.08866 .36289 Mdot
.08871 .3626 Mdot
.08876 .36231 Mdot
.0888 .36202 Mdot
.08885 .36173 Mdot
.0889 .36144 Mdot
.08895 .36115 Mdot
.08899 .36086 Mdot
.08904 .36056 Mdot
.08909 .36027 Mdot
.08914 .35998 Mdot
.08918 .35969 Mdot
.08923 .3594 Mdot
.08928 .35911 Mdot
.08933 .35882 Mdot
.08937 .35853 Mdot
.08942 .35824 Mdot
.08947 .35795 Mdot
.08952 .35766 Mdot
.08956 .35737 Mdot
.08961 .35707 Mdot
.08966 .35678 Mdot
.08971 .35649 Mdot
.08976 .3562 Mdot
.0898 .35591 Mdot
.08985 .35562 Mdot
.0899 .35533 Mdot
.08995 .35504 Mdot
.08999 .35474 Mdot
.09004 .35445 Mdot
.09009 .35416 Mdot
.09014 .35387 Mdot
.09018 .35358 Mdot
.09023 .35329 Mdot
.09028 .35299 Mdot
.09033 .3527 Mdot
.09037 .35241 Mdot
.09042 .35212 Mdot
.09047 .35183 Mdot
.09052 .35154 Mdot
.09056 .35124 Mdot
.09061 .35095 Mdot
.09066 .35066 Mdot
.09071 .35037 Mdot
.09076 .35008 Mdot
.0908 .34978 Mdot
.09085 .34949 Mdot
.0909 .3492 Mdot
.09095 .34891 Mdot
.09099 .34861 Mdot
.09104 .34832 Mdot
.09109 .34803 Mdot
.09114 .34774 Mdot
.09118 .34745 Mdot
.09123 .34715 Mdot
.09128 .34686 Mdot
.09133 .34657 Mdot
.09137 .34628 Mdot
.09142 .34598 Mdot
.09147 .34569 Mdot
.09152 .3454 Mdot
.09156 .34511 Mdot
.09161 .34481 Mdot
.09166 .34452 Mdot
.09171 .34423 Mdot
.09176 .34393 Mdot
.0918 .34364 Mdot
.09185 .34335 Mdot
.0919 .34306 Mdot
.09195 .34276 Mdot
.09199 .34247 Mdot
.09204 .34218 Mdot
.09209 .34189 Mdot
.09214 .34159 Mdot
.09218 .3413 Mdot
.09223 .34101 Mdot
.09228 .34071 Mdot
.09233 .34042 Mdot
.09237 .34013 Mdot
.09242 .33983 Mdot
.09247 .33954 Mdot
.09252 .33925 Mdot
.09256 .33895 Mdot
.09261 .33866 Mdot
.09266 .33837 Mdot
.09271 .33807 Mdot
.09276 .33778 Mdot
.0928 .33749 Mdot
.09285 .33719 Mdot
.0929 .3369 Mdot
.09295 .33661 Mdot
.09299 .33631 Mdot
.09304 .33602 Mdot
.09309 .33573 Mdot
.09314 .33543 Mdot
.09318 .33514 Mdot
.09323 .33485 Mdot
.09328 .33455 Mdot
.09333 .33426 Mdot
.09337 .33397 Mdot
.09342 .33367 Mdot
.09347 .33338 Mdot
.09352 .33309 Mdot
.09356 .33279 Mdot
.09361 .3325 Mdot
.09366 .33221 Mdot
.09371 .33191 Mdot
.09375 .33162 Mdot
.0938 .33132 Mdot
.09385 .33103 Mdot
.0939 .33074 Mdot
.09395 .33044 Mdot
.09399 .33015 Mdot
.09404 .32986 Mdot
.09409 .32956 Mdot
.09414 .32927 Mdot
.09418 .32897 Mdot
.09423 .32868 Mdot
.09428 .32839 Mdot
.09433 .32809 Mdot
.09437 .3278 Mdot
.09442 .32751 Mdot
.09447 .32721 Mdot
.09452 .32692 Mdot
.09456 .32662 Mdot
.09461 .32633 Mdot
.09466 .32604 Mdot
.09471 .32574 Mdot
.09475 .32545 Mdot
.0948 .32515 Mdot
.09485 .32486 Mdot
.0949 .32457 Mdot
.09495 .32427 Mdot
.09499 .32398 Mdot
.09504 .32368 Mdot
.09509 .32339 Mdot
.09514 .3231 Mdot
.09518 .3228 Mdot
.09523 .32251 Mdot
.09528 .32221 Mdot
.09533 .32192 Mdot
.09537 .32163 Mdot
.09542 .32133 Mdot
.09547 .32104 Mdot
.09552 .32074 Mdot
.09556 .32045 Mdot
.09561 .32015 Mdot
.09566 .31986 Mdot
.09571 .31957 Mdot
.09575 .31927 Mdot
.0958 .31898 Mdot
.09585 .31868 Mdot
.0959 .31839 Mdot
.09595 .3181 Mdot
.09599 .3178 Mdot
.09604 .31751 Mdot
.09609 .31721 Mdot
.09614 .31692 Mdot
.09618 .31663 Mdot
.09623 .31633 Mdot
.09628 .31604 Mdot
.09633 .31574 Mdot
.09637 .31545 Mdot
.09642 .31515 Mdot
.09647 .31486 Mdot
.09652 .31457 Mdot
.09656 .31427 Mdot
.09661 .31398 Mdot
.09666 .31368 Mdot
.09671 .31339 Mdot
.09675 .3131 Mdot
.0968 .3128 Mdot
.09685 .31251 Mdot
.0969 .31221 Mdot
.09695 .31192 Mdot
.09699 .31163 Mdot
.09704 .31133 Mdot
.09709 .31104 Mdot
.09714 .31074 Mdot
.09718 .31045 Mdot
.09723 .31015 Mdot
.09728 .30986 Mdot
.09733 .30957 Mdot
.09737 .30927 Mdot
.09742 .30898 Mdot
.09747 .30868 Mdot
.09752 .30839 Mdot
.09756 .3081 Mdot
.09761 .3078 Mdot
.09766 .30751 Mdot
.09771 .30721 Mdot
.09775 .30692 Mdot
.0978 .30663 Mdot
.09785 .30633 Mdot
.0979 .30604 Mdot
.09794 .30574 Mdot
.09799 .30545 Mdot
.09804 .30516 Mdot
.09809 .30486 Mdot
.09814 .30457 Mdot
.09818 .30427 Mdot
.09823 .30398 Mdot
.09828 .30369 Mdot
.09833 .30339 Mdot
.09837 .3031 Mdot
.09842 .3028 Mdot
.09847 .30251 Mdot
.09852 .30222 Mdot
.09856 .30192 Mdot
.09861 .30163 Mdot
.09866 .30134 Mdot
.09871 .30104 Mdot
.09875 .30075 Mdot
.0988 .30045 Mdot
.09885 .30016 Mdot
.0989 .29987 Mdot
.09894 .29957 Mdot
.09899 .29928 Mdot
.09904 .29899 Mdot
.09909 .29869 Mdot
.09914 .2984 Mdot
.09918 .2981 Mdot
.09923 .29781 Mdot
.09928 .29752 Mdot
.09933 .29722 Mdot
.09937 .29693 Mdot
.09942 .29664 Mdot
.09947 .29634 Mdot
.09952 .29605 Mdot
.09956 .29576 Mdot
.09961 .29546 Mdot
.09966 .29517 Mdot
.09971 .29488 Mdot
.09975 .29458 Mdot
.0998 .29429 Mdot
.09985 .294 Mdot
.0999 .2937 Mdot
.09994 .29341 Mdot
.09999 .29312 Mdot
.10004 .29282 Mdot
.10009 .29253 Mdot
.10014 .29224 Mdot
.10018 .29194 Mdot
.10023 .29165 Mdot
.10028 .29136 Mdot
.10033 .29106 Mdot
.10037 .29077 Mdot
.10042 .29048 Mdot
.10047 .29018 Mdot
.10052 .28989 Mdot
.10056 .2896 Mdot
.10061 .2893 Mdot
.10066 .28901 Mdot
.10071 .28872 Mdot
.10075 .28843 Mdot
.1008 .28813 Mdot
.10085 .28784 Mdot
.1009 .28755 Mdot
.10094 .28725 Mdot
.10099 .28696 Mdot
.10104 .28667 Mdot
.10109 .28638 Mdot
.10114 .28608 Mdot
.10118 .28579 Mdot
.10123 .2855 Mdot
.10128 .2852 Mdot
.10133 .28491 Mdot
.10137 .28462 Mdot
.10142 .28433 Mdot
.10147 .28403 Mdot
.10152 .28374 Mdot
.10156 .28345 Mdot
.10161 .28316 Mdot
.10166 .28287 Mdot
.10171 .28257 Mdot
.10175 .28228 Mdot
.1018 .28199 Mdot
.10185 .2817 Mdot
.1019 .2814 Mdot
.10194 .28111 Mdot
.10199 .28082 Mdot
.10204 .28053 Mdot
.10209 .28024 Mdot
.10214 .27994 Mdot
.10218 .27965 Mdot
.10223 .27936 Mdot
.10228 .27907 Mdot
.10233 .27878 Mdot
.10237 .27848 Mdot
.10242 .27819 Mdot
.10247 .2779 Mdot
.10252 .27761 Mdot
.10256 .27732 Mdot
.10261 .27702 Mdot
.10266 .27673 Mdot
.10271 .27644 Mdot
.10275 .27615 Mdot
.1028 .27586 Mdot
.10285 .27557 Mdot
.1029 .27528 Mdot
.10294 .27498 Mdot
.10299 .27469 Mdot
.10304 .2744 Mdot
.10309 .27411 Mdot
.10313 .27382 Mdot
.10318 .27353 Mdot
.10323 .27324 Mdot
.10328 .27295 Mdot
.10333 .27265 Mdot
.10337 .27236 Mdot
.10342 .27207 Mdot
.10347 .27178 Mdot
.10352 .27149 Mdot
.10356 .2712 Mdot
.10361 .27091 Mdot
.10366 .27062 Mdot
.10371 .27033 Mdot
.10375 .27004 Mdot
.1038 .26975 Mdot
.10385 .26946 Mdot
.1039 .26916 Mdot
.10394 .26887 Mdot
.10399 .26858 Mdot
.10404 .26829 Mdot
.10409 .268 Mdot
.10413 .26771 Mdot
.10418 .26742 Mdot
.10423 .26713 Mdot
.10428 .26684 Mdot
.10433 .26655 Mdot
.10437 .26626 Mdot
.10442 .26597 Mdot
.10447 .26568 Mdot
.10452 .26539 Mdot
.10456 .2651 Mdot
.10461 .26481 Mdot
.10466 .26452 Mdot
.10471 .26423 Mdot
.10475 .26394 Mdot
.1048 .26365 Mdot
.10485 .26336 Mdot
.1049 .26307 Mdot
.10494 .26278 Mdot
.10499 .2625 Mdot
.10504 .26221 Mdot
.10509 .26192 Mdot
.10513 .26163 Mdot
.10518 .26134 Mdot
.10523 .26105 Mdot
.10528 .26076 Mdot
.10533 .26047 Mdot
.10537 .26018 Mdot
.10542 .25989 Mdot
.10547 .2596 Mdot
.10552 .25932 Mdot
.10556 .25903 Mdot
.10561 .25874 Mdot
.10566 .25845 Mdot
.10571 .25816 Mdot
.10575 .25787 Mdot
.1058 .25758 Mdot
.10585 .2573 Mdot
.1059 .25701 Mdot
.10594 .25672 Mdot
.10599 .25643 Mdot
.10604 .25614 Mdot
.10609 .25585 Mdot
.10613 .25557 Mdot
.10618 .25528 Mdot
.10623 .25499 Mdot
.10628 .2547 Mdot
.10633 .25441 Mdot
.10637 .25413 Mdot
.10642 .25384 Mdot
.10647 .25355 Mdot
.10652 .25326 Mdot
.10656 .25298 Mdot
.10661 .25269 Mdot
.10666 .2524 Mdot
.10671 .25211 Mdot
.10675 .25183 Mdot
.1068 .25154 Mdot
.10685 .25125 Mdot
.1069 .25096 Mdot
.10694 .25068 Mdot
.10699 .25039 Mdot
.10704 .2501 Mdot
.10709 .24982 Mdot
.10713 .24953 Mdot
.10718 .24924 Mdot
.10723 .24896 Mdot
.10728 .24867 Mdot
.10732 .24838 Mdot
.10737 .2481 Mdot
.10742 .24781 Mdot
.10747 .24752 Mdot
.10752 .24724 Mdot
.10756 .24695 Mdot
.10761 .24667 Mdot
.10766 .24638 Mdot
.10771 .24609 Mdot
.10775 .24581 Mdot
.1078 .24552 Mdot
.10785 .24524 Mdot
.1079 .24495 Mdot
.10794 .24466 Mdot
.10799 .24438 Mdot
.10804 .24409 Mdot
.10809 .24381 Mdot
.10813 .24352 Mdot
.10818 .24324 Mdot
.10823 .24295 Mdot
.10828 .24267 Mdot
.10832 .24238 Mdot
.10837 .2421 Mdot
.10842 .24181 Mdot
.10847 .24153 Mdot
.10852 .24124 Mdot
.10856 .24096 Mdot
.10861 .24067 Mdot
.10866 .24039 Mdot
.10871 .2401 Mdot
.10875 .23982 Mdot
.1088 .23954 Mdot
.10885 .23925 Mdot
.1089 .23897 Mdot
.10894 .23868 Mdot
.10899 .2384 Mdot
.10904 .23811 Mdot
.10909 .23783 Mdot
.10913 .23755 Mdot
.10918 .23726 Mdot
.10923 .23698 Mdot
.10928 .2367 Mdot
.10932 .23641 Mdot
.10937 .23613 Mdot
.10942 .23585 Mdot
.10947 .23556 Mdot
.10952 .23528 Mdot
.10956 .235 Mdot
.10961 .23471 Mdot
.10966 .23443 Mdot
.10971 .23415 Mdot
.10975 .23386 Mdot
.1098 .23358 Mdot
.10985 .2333 Mdot
.1099 .23302 Mdot
.10994 .23273 Mdot
.10999 .23245 Mdot
.11004 .23217 Mdot
.11009 .23189 Mdot
.11013 .23161 Mdot
.11018 .23132 Mdot
.11023 .23104 Mdot
.11028 .23076 Mdot
.11032 .23048 Mdot
.11037 .2302 Mdot
.11042 .22991 Mdot
.11047 .22963 Mdot
.11052 .22935 Mdot
.11056 .22907 Mdot
.11061 .22879 Mdot
.11066 .22851 Mdot
.11071 .22823 Mdot
.11075 .22794 Mdot
.1108 .22766 Mdot
.11085 .22738 Mdot
.1109 .2271 Mdot
.11094 .22682 Mdot
.11099 .22654 Mdot
.11104 .22626 Mdot
.11109 .22598 Mdot
.11113 .2257 Mdot
.11118 .22542 Mdot
.11123 .22514 Mdot
.11128 .22486 Mdot
.11132 .22458 Mdot
.11137 .2243 Mdot
.11142 .22402 Mdot
.11147 .22374 Mdot
.11152 .22346 Mdot
.11156 .22318 Mdot
.11161 .2229 Mdot
.11166 .22262 Mdot
.11171 .22234 Mdot
.11175 .22206 Mdot
.1118 .22178 Mdot
.11185 .2215 Mdot
.1119 .22123 Mdot
.11194 .22095 Mdot
.11199 .22067 Mdot
.11204 .22039 Mdot
.11209 .22011 Mdot
.11213 .21983 Mdot
.11218 .21955 Mdot
.11223 .21928 Mdot
.11228 .219 Mdot
.11232 .21872 Mdot
.11237 .21844 Mdot
.11242 .21816 Mdot
.11247 .21789 Mdot
.11251 .21761 Mdot
.11256 .21733 Mdot
.11261 .21705 Mdot
.11266 .21678 Mdot
.11271 .2165 Mdot
.11275 .21622 Mdot
.1128 .21594 Mdot
.11285 .21567 Mdot
.1129 .21539 Mdot
.11294 .21511 Mdot
.11299 .21484 Mdot
.11304 .21456 Mdot
.11309 .21428 Mdot
.11313 .21401 Mdot
.11318 .21373 Mdot
.11323 .21345 Mdot
.11328 .21318 Mdot
.11332 .2129 Mdot
.11337 .21263 Mdot
.11342 .21235 Mdot
.11347 .21208 Mdot
.11351 .2118 Mdot
.11356 .21152 Mdot
.11361 .21125 Mdot
.11366 .21097 Mdot
.11371 .2107 Mdot
.11375 .21042 Mdot
.1138 .21015 Mdot
.11385 .20987 Mdot
.1139 .2096 Mdot
.11394 .20932 Mdot
.11399 .20905 Mdot
.11404 .20877 Mdot
.11409 .2085 Mdot
.11413 .20823 Mdot
.11418 .20795 Mdot
.11423 .20768 Mdot
.11428 .2074 Mdot
.11432 .20713 Mdot
.11437 .20686 Mdot
.11442 .20658 Mdot
.11447 .20631 Mdot
.11451 .20604 Mdot
.11456 .20576 Mdot
.11461 .20549 Mdot
.11466 .20522 Mdot
.11471 .20494 Mdot
.11475 .20467 Mdot
.1148 .2044 Mdot
.11485 .20412 Mdot
.1149 .20385 Mdot
.11494 .20358 Mdot
.11499 .20331 Mdot
.11504 .20303 Mdot
.11509 .20276 Mdot
.11513 .20249 Mdot
.11518 .20222 Mdot
.11523 .20195 Mdot
.11528 .20168 Mdot
.11532 .2014 Mdot
.11537 .20113 Mdot
.11542 .20086 Mdot
.11547 .20059 Mdot
.11551 .20032 Mdot
.11556 .20005 Mdot
.11561 .19978 Mdot
.11566 .19951 Mdot
.11571 .19924 Mdot
.11575 .19896 Mdot
.1158 .19869 Mdot
.11585 .19842 Mdot
.1159 .19815 Mdot
.11594 .19788 Mdot
.11599 .19761 Mdot
.11604 .19734 Mdot
.11609 .19707 Mdot
.11613 .1968 Mdot
.11618 .19653 Mdot
.11623 .19627 Mdot
.11628 .196 Mdot
.11632 .19573 Mdot
.11637 .19546 Mdot
.11642 .19519 Mdot
.11647 .19492 Mdot
.11651 .19465 Mdot
.11656 .19438 Mdot
.11661 .19411 Mdot
.11666 .19385 Mdot
.1167 .19358 Mdot
.11675 .19331 Mdot
.1168 .19304 Mdot
.11685 .19277 Mdot
.1169 .19251 Mdot
.11694 .19224 Mdot
.11699 .19197 Mdot
.11704 .1917 Mdot
.11709 .19144 Mdot
.11713 .19117 Mdot
.11718 .1909 Mdot
.11723 .19064 Mdot
.11728 .19037 Mdot
.11732 .1901 Mdot
.11737 .18984 Mdot
.11742 .18957 Mdot
.11747 .1893 Mdot
.11751 .18904 Mdot
.11756 .18877 Mdot
.11761 .1885 Mdot
.11766 .18824 Mdot
.1177 .18797 Mdot
.11775 .18771 Mdot
.1178 .18744 Mdot
.11785 .18718 Mdot
.1179 .18691 Mdot
.11794 .18665 Mdot
.11799 .18638 Mdot
.11804 .18612 Mdot
.11809 .18585 Mdot
.11813 .18559 Mdot
.11818 .18532 Mdot
.11823 .18506 Mdot
.11828 .18479 Mdot
.11832 .18453 Mdot
.11837 .18427 Mdot
.11842 .184 Mdot
.11847 .18374 Mdot
.11851 .18348 Mdot
.11856 .18321 Mdot
.11861 .18295 Mdot
.11866 .18269 Mdot
.1187 .18242 Mdot
.11875 .18216 Mdot
.1188 .1819 Mdot
.11885 .18163 Mdot
.1189 .18137 Mdot
.11894 .18111 Mdot
.11899 .18085 Mdot
.11904 .18059 Mdot
.11909 .18032 Mdot
.11913 .18006 Mdot
.11918 .1798 Mdot
.11923 .17954 Mdot
.11928 .17928 Mdot
.11932 .17902 Mdot
.11937 .17875 Mdot
.11942 .17849 Mdot
.11947 .17823 Mdot
.11951 .17797 Mdot
.11956 .17771 Mdot
.11961 .17745 Mdot
.11966 .17719 Mdot
.1197 .17693 Mdot
.11975 .17667 Mdot
.1198 .17641 Mdot
.11985 .17615 Mdot
.1199 .17589 Mdot
.11994 .17563 Mdot
.11999 .17537 Mdot
.12004 .17511 Mdot
.12009 .17485 Mdot
.12013 .17459 Mdot
.12018 .17434 Mdot
.12023 .17408 Mdot
.12028 .17382 Mdot
.12032 .17356 Mdot
.12037 .1733 Mdot
.12042 .17304 Mdot
.12047 .17279 Mdot
.12051 .17253 Mdot
.12056 .17227 Mdot
.12061 .17201 Mdot
.12066 .17175 Mdot
.1207 .1715 Mdot
.12075 .17124 Mdot
.1208 .17098 Mdot
.12085 .17073 Mdot
.1209 .17047 Mdot
.12094 .17021 Mdot
.12099 .16996 Mdot
.12104 .1697 Mdot
.12109 .16944 Mdot
.12113 .16919 Mdot
.12118 .16893 Mdot
.12123 .16868 Mdot
.12128 .16842 Mdot
.12132 .16816 Mdot
.12137 .16791 Mdot
.12142 .16765 Mdot
.12147 .1674 Mdot
.12151 .16714 Mdot
.12156 .16689 Mdot
.12161 .16663 Mdot
.12166 .16638 Mdot
.1217 .16613 Mdot
.12175 .16587 Mdot
.1218 .16562 Mdot
.12185 .16536 Mdot
.12189 .16511 Mdot
.12194 .16486 Mdot
.12199 .1646 Mdot
.12204 .16435 Mdot
.12209 .1641 Mdot
.12213 .16384 Mdot
.12218 .16359 Mdot
.12223 .16334 Mdot
.12228 .16308 Mdot
.12232 .16283 Mdot
.12237 .16258 Mdot
.12242 .16233 Mdot
.12247 .16208 Mdot
.12251 .16182 Mdot
.12256 .16157 Mdot
.12261 .16132 Mdot
.12266 .16107 Mdot
.1227 .16082 Mdot
.12275 .16057 Mdot
.1228 .16032 Mdot
.12285 .16007 Mdot
.12289 .15981 Mdot
.12294 .15956 Mdot
.12299 .15931 Mdot
.12304 .15906 Mdot
.12309 .15881 Mdot
.12313 .15856 Mdot
.12318 .15831 Mdot
.12323 .15806 Mdot
.12328 .15782 Mdot
.12332 .15757 Mdot
.12337 .15732 Mdot
.12342 .15707 Mdot
.12347 .15682 Mdot
.12351 .15657 Mdot
.12356 .15632 Mdot
.12361 .15607 Mdot
.12366 .15583 Mdot
.1237 .15558 Mdot
.12375 .15533 Mdot
.1238 .15508 Mdot
.12385 .15483 Mdot
.12389 .15459 Mdot
.12394 .15434 Mdot
.12399 .15409 Mdot
.12404 .15385 Mdot
.12409 .1536 Mdot
.12413 .15335 Mdot
.12418 .15311 Mdot
.12423 .15286 Mdot
.12428 .15261 Mdot
.12432 .15237 Mdot
.12437 .15212 Mdot
.12442 .15188 Mdot
.12447 .15163 Mdot
.12451 .15138 Mdot
.12456 .15114 Mdot
.12461 .15089 Mdot
.12466 .15065 Mdot
.1247 .1504 Mdot
.12475 .15016 Mdot
.1248 .14992 Mdot
.12485 .14967 Mdot
.12489 .14943 Mdot
.12494 .14918 Mdot
.12499 .14894 Mdot
.12504 .1487 Mdot
.12509 .14845 Mdot
.12513 .14821 Mdot
.12518 .14797 Mdot
.12523 .14772 Mdot
.12528 .14748 Mdot
.12532 .14724 Mdot
.12537 .14699 Mdot
.12542 .14675 Mdot
.12547 .14651 Mdot
.12551 .14627 Mdot
.12556 .14603 Mdot
.12561 .14578 Mdot
.12566 .14554 Mdot
.1257 .1453 Mdot
.12575 .14506 Mdot
.1258 .14482 Mdot
.12585 .14458 Mdot
.12589 .14434 Mdot
.12594 .1441 Mdot
.12599 .14386 Mdot
.12604 .14362 Mdot
.12609 .14338 Mdot
.12613 .14314 Mdot
.12618 .1429 Mdot
.12623 .14266 Mdot
.12628 .14242 Mdot
.12632 .14218 Mdot
.12637 .14194 Mdot
.12642 .1417 Mdot
.12647 .14146 Mdot
.12651 .14122 Mdot
.12656 .14099 Mdot
.12661 .14075 Mdot
.12666 .14051 Mdot
.1267 .14027 Mdot
.12675 .14003 Mdot
.1268 .1398 Mdot
.12685 .13956 Mdot
.12689 .13932 Mdot
.12694 .13909 Mdot
.12699 .13885 Mdot
.12704 .13861 Mdot
.12708 .13838 Mdot
.12713 .13814 Mdot
.12718 .1379 Mdot
.12723 .13767 Mdot
.12728 .13743 Mdot
.12732 .1372 Mdot
.12737 .13696 Mdot
.12742 .13673 Mdot
.12747 .13649 Mdot
.12751 .13626 Mdot
.12756 .13602 Mdot
.12761 .13579 Mdot
.12766 .13555 Mdot
.1277 .13532 Mdot
.12775 .13508 Mdot
.1278 .13485 Mdot
.12785 .13462 Mdot
.12789 .13438 Mdot
.12794 .13415 Mdot
.12799 .13392 Mdot
.12804 .13368 Mdot
.12808 .13345 Mdot
.12813 .13322 Mdot
.12818 .13299 Mdot
.12823 .13275 Mdot
.12828 .13252 Mdot
.12832 .13229 Mdot
.12837 .13206 Mdot
.12842 .13183 Mdot
.12847 .13159 Mdot
.12851 .13136 Mdot
.12856 .13113 Mdot
.12861 .1309 Mdot
.12866 .13067 Mdot
.1287 .13044 Mdot
.12875 .13021 Mdot
.1288 .12998 Mdot
.12885 .12975 Mdot
.12889 .12952 Mdot
.12894 .12929 Mdot
.12899 .12906 Mdot
.12904 .12883 Mdot
.12908 .1286 Mdot
.12913 .12837 Mdot
.12918 .12814 Mdot
.12923 .12792 Mdot
.12928 .12769 Mdot
.12932 .12746 Mdot
.12937 .12723 Mdot
.12942 .127 Mdot
.12947 .12678 Mdot
.12951 .12655 Mdot
.12956 .12632 Mdot
.12961 .12609 Mdot
.12966 .12587 Mdot
.1297 .12564 Mdot
.12975 .12541 Mdot
.1298 .12519 Mdot
.12985 .12496 Mdot
.12989 .12474 Mdot
.12994 .12451 Mdot
.12999 .12428 Mdot
.13004 .12406 Mdot
.13008 .12383 Mdot
.13013 .12361 Mdot
.13018 .12338 Mdot
.13023 .12316 Mdot
.13028 .12293 Mdot
.13032 .12271 Mdot
.13037 .12249 Mdot
.13042 .12226 Mdot
.13047 .12204 Mdot
.13051 .12181 Mdot
.13056 .12159 Mdot
.13061 .12137 Mdot
.13066 .12114 Mdot
.1307 .12092 Mdot
.13075 .1207 Mdot
.1308 .12048 Mdot
.13085 .12025 Mdot
.13089 .12003 Mdot
.13094 .11981 Mdot
.13099 .11959 Mdot
.13104 .11937 Mdot
.13108 .11915 Mdot
.13113 .11892 Mdot
.13118 .1187 Mdot
.13123 .11848 Mdot
.13127 .11826 Mdot
.13132 .11804 Mdot
.13137 .11782 Mdot
.13142 .1176 Mdot
.13147 .11738 Mdot
.13151 .11716 Mdot
.13156 .11694 Mdot
.13161 .11672 Mdot
.13166 .1165 Mdot
.1317 .11629 Mdot
.13175 .11607 Mdot
.1318 .11585 Mdot
.13185 .11563 Mdot
.13189 .11541 Mdot
.13194 .11519 Mdot
.13199 .11498 Mdot
.13204 .11476 Mdot
.13208 .11454 Mdot
.13213 .11432 Mdot
.13218 .11411 Mdot
.13223 .11389 Mdot
.13227 .11367 Mdot
.13232 .11346 Mdot
.13237 .11324 Mdot
.13242 .11303 Mdot
.13247 .11281 Mdot
.13251 .11259 Mdot
.13256 .11238 Mdot
.13261 .11216 Mdot
.13266 .11195 Mdot
.1327 .11173 Mdot
.13275 .11152 Mdot
.1328 .1113 Mdot
.13285 .11109 Mdot
.13289 .11088 Mdot
.13294 .11066 Mdot
.13299 .11045 Mdot
.13304 .11024 Mdot
.13308 .11002 Mdot
.13313 .10981 Mdot
.13318 .1096 Mdot
.13323 .10938 Mdot
.13327 .10917 Mdot
.13332 .10896 Mdot
.13337 .10875 Mdot
.13342 .10854 Mdot
.13347 .10832 Mdot
.13351 .10811 Mdot
.13356 .1079 Mdot
.13361 .10769 Mdot
.13366 .10748 Mdot
.1337 .10727 Mdot
.13375 .10706 Mdot
.1338 .10685 Mdot
.13385 .10664 Mdot
.13389 .10643 Mdot
.13394 .10622 Mdot
.13399 .10601 Mdot
.13404 .1058 Mdot
.13408 .10559 Mdot
.13413 .10538 Mdot
.13418 .10517 Mdot
.13423 .10496 Mdot
.13427 .10476 Mdot
.13432 .10455 Mdot
.13437 .10434 Mdot
.13442 .10413 Mdot
.13447 .10393 Mdot
.13451 .10372 Mdot
.13456 .10351 Mdot
.13461 .1033 Mdot
.13466 .1031 Mdot
.1347 .10289 Mdot
.13475 .10268 Mdot
.1348 .10248 Mdot
.13485 .10227 Mdot
.13489 .10207 Mdot
.13494 .10186 Mdot
.13499 .10166 Mdot
.13504 .10145 Mdot
.13508 .10125 Mdot
.13513 .10104 Mdot
.13518 .10084 Mdot
.13523 .10063 Mdot
.13527 .10043 Mdot
.13532 .10023 Mdot
.13537 .10002 Mdot
.13542 .09982 Mdot
.13547 .09962 Mdot
.13551 .09941 Mdot
.13556 .09921 Mdot
.13561 .09901 Mdot
.13566 .09881 Mdot
.1357 .0986 Mdot
.13575 .0984 Mdot
.1358 .0982 Mdot
.13585 .098 Mdot
.13589 .0978 Mdot
.13594 .0976 Mdot
.13599 .0974 Mdot
.13604 .09719 Mdot
.13608 .09699 Mdot
.13613 .09679 Mdot
.13618 .09659 Mdot
.13623 .09639 Mdot
.13627 .09619 Mdot
.13632 .096 Mdot
.13637 .0958 Mdot
.13642 .0956 Mdot
.13646 .0954 Mdot
.13651 .0952 Mdot
.13656 .095 Mdot
.13661 .0948 Mdot
.13666 .09461 Mdot
.1367 .09441 Mdot
.13675 .09421 Mdot
.1368 .09401 Mdot
.13685 .09382 Mdot
.13689 .09362 Mdot
.13694 .09342 Mdot
.13699 .09323 Mdot
.13704 .09303 Mdot
.13708 .09283 Mdot
.13713 .09264 Mdot
.13718 .09244 Mdot
.13723 .09225 Mdot
.13727 .09205 Mdot
.13732 .09186 Mdot
.13737 .09166 Mdot
.13742 .09147 Mdot
.13746 .09127 Mdot
.13751 .09108 Mdot
.13756 .09089 Mdot
.13761 .09069 Mdot
.13766 .0905 Mdot
.1377 .09031 Mdot
.13775 .09011 Mdot
.1378 .08992 Mdot
.13785 .08973 Mdot
.13789 .08953 Mdot
.13794 .08934 Mdot
.13799 .08915 Mdot
.13804 .08896 Mdot
.13808 .08877 Mdot
.13813 .08858 Mdot
.13818 .08838 Mdot
.13823 .08819 Mdot
.13827 .088 Mdot
.13832 .08781 Mdot
.13837 .08762 Mdot
.13842 .08743 Mdot
.13846 .08724 Mdot
.13851 .08705 Mdot
.13856 .08686 Mdot
.13861 .08667 Mdot
.13866 .08649 Mdot
.1387 .0863 Mdot
.13875 .08611 Mdot
.1388 .08592 Mdot
.13885 .08573 Mdot
.13889 .08554 Mdot
.13894 .08536 Mdot
.13899 .08517 Mdot
.13904 .08498 Mdot
.13908 .0848 Mdot
.13913 .08461 Mdot
.13918 .08442 Mdot
.13923 .08424 Mdot
.13927 .08405 Mdot
.13932 .08386 Mdot
.13937 .08368 Mdot
.13942 .08349 Mdot
.13946 .08331 Mdot
.13951 .08312 Mdot
.13956 .08294 Mdot
.13961 .08275 Mdot
.13966 .08257 Mdot
.1397 .08239 Mdot
.13975 .0822 Mdot
.1398 .08202 Mdot
.13985 .08183 Mdot
.13989 .08165 Mdot
.13994 .08147 Mdot
.13999 .08129 Mdot
.14004 .0811 Mdot
.14008 .08092 Mdot
.14013 .08074 Mdot
.14018 .08056 Mdot
.14023 .08038 Mdot
.14027 .08019 Mdot
.14032 .08001 Mdot
.14037 .07983 Mdot
.14042 .07965 Mdot
.14046 .07947 Mdot
.14051 .07929 Mdot
.14056 .07911 Mdot
.14061 .07893 Mdot
.14065 .07875 Mdot
.1407 .07857 Mdot
.14075 .07839 Mdot
.1408 .07821 Mdot
.14085 .07804 Mdot
.14089 .07786 Mdot
.14094 .07768 Mdot
.14099 .0775 Mdot
.14104 .07732 Mdot
.14108 .07715 Mdot
.14113 .07697 Mdot
.14118 .07679 Mdot
.14123 .07661 Mdot
.14127 .07644 Mdot
.14132 .07626 Mdot
.14137 .07608 Mdot
.14142 .07591 Mdot
.14146 .07573 Mdot
.14151 .07556 Mdot
.14156 .07538 Mdot
.14161 .07521 Mdot
.14165 .07503 Mdot
.1417 .07486 Mdot
.14175 .07468 Mdot
.1418 .07451 Mdot
.14185 .07434 Mdot
.14189 .07416 Mdot
.14194 .07399 Mdot
.14199 .07381 Mdot
.14204 .07364 Mdot
.14208 .07347 Mdot
.14213 .0733 Mdot
.14218 .07312 Mdot
.14223 .07295 Mdot
.14227 .07278 Mdot
.14232 .07261 Mdot
.14237 .07244 Mdot
.14242 .07227 Mdot
.14246 .0721 Mdot
.14251 .07192 Mdot
.14256 .07175 Mdot
.14261 .07158 Mdot
.14265 .07141 Mdot
.1427 .07124 Mdot
.14275 .07107 Mdot
.1428 .07091 Mdot
.14285 .07074 Mdot
.14289 .07057 Mdot
.14294 .0704 Mdot
.14299 .07023 Mdot
.14304 .07006 Mdot
.14308 .06989 Mdot
.14313 .06973 Mdot
.14318 .06956 Mdot
.14323 .06939 Mdot
.14327 .06923 Mdot
.14332 .06906 Mdot
.14337 .06889 Mdot
.14342 .06873 Mdot
.14346 .06856 Mdot
.14351 .06839 Mdot
.14356 .06823 Mdot
.14361 .06806 Mdot
.14365 .0679 Mdot
.1437 .06773 Mdot
.14375 .06757 Mdot
.1438 .0674 Mdot
.14385 .06724 Mdot
.14389 .06708 Mdot
.14394 .06691 Mdot
.14399 .06675 Mdot
.14404 .06659 Mdot
.14408 .06642 Mdot
.14413 .06626 Mdot
.14418 .0661 Mdot
.14423 .06593 Mdot
.14427 .06577 Mdot
.14432 .06561 Mdot
.14437 .06545 Mdot
.14442 .06529 Mdot
.14446 .06513 Mdot
.14451 .06497 Mdot
.14456 .06481 Mdot
.14461 .06465 Mdot
.14465 .06448 Mdot
.1447 .06433 Mdot
.14475 .06417 Mdot
.1448 .06401 Mdot
.14485 .06385 Mdot
.14489 .06369 Mdot
.14494 .06353 Mdot
.14499 .06337 Mdot
.14504 .06321 Mdot
.14508 .06305 Mdot
.14513 .0629 Mdot
.14518 .06274 Mdot
.14523 .06258 Mdot
.14527 .06242 Mdot
.14532 .06227 Mdot
.14537 .06211 Mdot
.14542 .06195 Mdot
.14546 .0618 Mdot
.14551 .06164 Mdot
.14556 .06149 Mdot
.14561 .06133 Mdot
.14565 .06118 Mdot
.1457 .06102 Mdot
.14575 .06087 Mdot
.1458 .06071 Mdot
.14584 .06056 Mdot
.14589 .0604 Mdot
.14594 .06025 Mdot
.14599 .0601 Mdot
.14604 .05994 Mdot
.14608 .05979 Mdot
.14613 .05964 Mdot
.14618 .05949 Mdot
.14623 .05933 Mdot
.14627 .05918 Mdot
.14632 .05903 Mdot
.14637 .05888 Mdot
.14642 .05873 Mdot
.14646 .05858 Mdot
.14651 .05843 Mdot
.14656 .05828 Mdot
.14661 .05812 Mdot
.14665 .05797 Mdot
.1467 .05783 Mdot
.14675 .05768 Mdot
.1468 .05753 Mdot
.14684 .05738 Mdot
.14689 .05723 Mdot
.14694 .05708 Mdot
.14699 .05693 Mdot
.14704 .05678 Mdot
.14708 .05664 Mdot
.14713 .05649 Mdot
.14718 .05634 Mdot
.14723 .05619 Mdot
.14727 .05605 Mdot
.14732 .0559 Mdot
.14737 .05575 Mdot
.14742 .05561 Mdot
.14746 .05546 Mdot
.14751 .05532 Mdot
.14756 .05517 Mdot
.14761 .05502 Mdot
.14765 .05488 Mdot
.1477 .05474 Mdot
.14775 .05459 Mdot
.1478 .05445 Mdot
.14784 .0543 Mdot
.14789 .05416 Mdot
.14794 .05402 Mdot
.14799 .05387 Mdot
.14804 .05373 Mdot
.14808 .05359 Mdot
.14813 .05344 Mdot
.14818 .0533 Mdot
.14823 .05316 Mdot
.14827 .05302 Mdot
.14832 .05288 Mdot
.14837 .05274 Mdot
.14842 .05259 Mdot
.14846 .05245 Mdot
.14851 .05231 Mdot
.14856 .05217 Mdot
.14861 .05203 Mdot
.14865 .05189 Mdot
.1487 .05175 Mdot
.14875 .05161 Mdot
.1488 .05148 Mdot
.14884 .05134 Mdot
.14889 .0512 Mdot
.14894 .05106 Mdot
.14899 .05092 Mdot
.14904 .05078 Mdot
.14908 .05065 Mdot
.14913 .05051 Mdot
.14918 .05037 Mdot
.14923 .05024 Mdot
.14927 .0501 Mdot
.14932 .04996 Mdot
.14937 .04983 Mdot
.14942 .04969 Mdot
.14946 .04956 Mdot
.14951 .04942 Mdot
.14956 .04929 Mdot
.14961 .04915 Mdot
.14965 .04902 Mdot
.1497 .04888 Mdot
.14975 .04875 Mdot
.1498 .04861 Mdot
.14984 .04848 Mdot
.14989 .04835 Mdot
.14994 .04821 Mdot
.14999 .04808 Mdot
.15003 .04795 Mdot
.15008 .04782 Mdot
.15013 .04769 Mdot
.15018 .04755 Mdot
.15023 .04742 Mdot
.15027 .04729 Mdot
.15032 .04716 Mdot
.15037 .04703 Mdot
.15042 .0469 Mdot
.15046 .04677 Mdot
.15051 .04664 Mdot
.15056 .04651 Mdot
.15061 .04638 Mdot
.15065 .04625 Mdot
.1507 .04612 Mdot
.15075 .04599 Mdot
.1508 .04586 Mdot
.15084 .04574 Mdot
.15089 .04561 Mdot
.15094 .04548 Mdot
.15099 .04535 Mdot
.15103 .04522 Mdot
.15108 .0451 Mdot
.15113 .04497 Mdot
.15118 .04484 Mdot
.15123 .04472 Mdot
.15127 .04459 Mdot
.15132 .04447 Mdot
.15137 .04434 Mdot
.15142 .04422 Mdot
.15146 .04409 Mdot
.15151 .04397 Mdot
.15156 .04384 Mdot
.15161 .04372 Mdot
.15165 .04359 Mdot
.1517 .04347 Mdot
.15175 .04335 Mdot
.1518 .04322 Mdot
.15184 .0431 Mdot
.15189 .04298 Mdot
.15194 .04286 Mdot
.15199 .04273 Mdot
.15203 .04261 Mdot
.15208 .04249 Mdot
.15213 .04237 Mdot
.15218 .04225 Mdot
.15223 .04213 Mdot
.15227 .04201 Mdot
.15232 .04189 Mdot
.15237 .04177 Mdot
.15242 .04165 Mdot
.15246 .04153 Mdot
.15251 .04141 Mdot
.15256 .04129 Mdot
.15261 .04117 Mdot
.15265 .04105 Mdot
.1527 .04093 Mdot
.15275 .04082 Mdot
.1528 .0407 Mdot
.15284 .04058 Mdot
.15289 .04046 Mdot
.15294 .04035 Mdot
.15299 .04023 Mdot
.15303 .04011 Mdot
.15308 .04 Mdot
.15313 .03988 Mdot
.15318 .03976 Mdot
.15323 .03965 Mdot
.15327 .03953 Mdot
.15332 .03942 Mdot
.15337 .0393 Mdot
.15342 .03919 Mdot
.15346 .03908 Mdot
.15351 .03896 Mdot
.15356 .03885 Mdot
.15361 .03874 Mdot
.15365 .03862 Mdot
.1537 .03851 Mdot
.15375 .0384 Mdot
.1538 .03828 Mdot
.15384 .03817 Mdot
.15389 .03806 Mdot
.15394 .03795 Mdot
.15399 .03784 Mdot
.15403 .03773 Mdot
.15408 .03762 Mdot
.15413 .0375 Mdot
.15418 .03739 Mdot
.15423 .03728 Mdot
.15427 .03717 Mdot
.15432 .03707 Mdot
.15437 .03696 Mdot
.15442 .03685 Mdot
.15446 .03674 Mdot
.15451 .03663 Mdot
.15456 .03652 Mdot
.15461 .03641 Mdot
.15465 .03631 Mdot
.1547 .0362 Mdot
.15475 .03609 Mdot
.1548 .03598 Mdot
.15484 .03588 Mdot
.15489 .03577 Mdot
.15494 .03567 Mdot
.15499 .03556 Mdot
.15503 .03545 Mdot
.15508 .03535 Mdot
.15513 .03524 Mdot
.15518 .03514 Mdot
.15522 .03503 Mdot
.15527 .03493 Mdot
.15532 .03483 Mdot
.15537 .03472 Mdot
.15542 .03462 Mdot
.15546 .03452 Mdot
.15551 .03441 Mdot
.15556 .03431 Mdot
.15561 .03421 Mdot
.15565 .03411 Mdot
.1557 .034 Mdot
.15575 .0339 Mdot
.1558 .0338 Mdot
.15584 .0337 Mdot
.15589 .0336 Mdot
.15594 .0335 Mdot
.15599 .0334 Mdot
.15603 .0333 Mdot
.15608 .0332 Mdot
.15613 .0331 Mdot
.15618 .033 Mdot
.15622 .0329 Mdot
.15627 .0328 Mdot
.15632 .0327 Mdot
.15637 .0326 Mdot
.15642 .03251 Mdot
.15646 .03241 Mdot
.15651 .03231 Mdot
.15656 .03221 Mdot
.15661 .03212 Mdot
.15665 .03202 Mdot
.1567 .03192 Mdot
.15675 .03183 Mdot
.1568 .03173 Mdot
.15684 .03164 Mdot
.15689 .03154 Mdot
.15694 .03145 Mdot
.15699 .03135 Mdot
.15703 .03126 Mdot
.15708 .03116 Mdot
.15713 .03107 Mdot
.15718 .03097 Mdot
.15722 .03088 Mdot
.15727 .03079 Mdot
.15732 .0307 Mdot
.15737 .0306 Mdot
.15742 .03051 Mdot
.15746 .03042 Mdot
.15751 .03033 Mdot
.15756 .03023 Mdot
.15761 .03014 Mdot
.15765 .03005 Mdot
.1577 .02996 Mdot
.15775 .02987 Mdot
.1578 .02978 Mdot
.15784 .02969 Mdot
.15789 .0296 Mdot
.15794 .02951 Mdot
.15799 .02942 Mdot
.15803 .02933 Mdot
.15808 .02924 Mdot
.15813 .02916 Mdot
.15818 .02907 Mdot
.15822 .02898 Mdot
.15827 .02889 Mdot
.15832 .0288 Mdot
.15837 .02872 Mdot
.15842 .02863 Mdot
.15846 .02854 Mdot
.15851 .02846 Mdot
.15856 .02837 Mdot
.15861 .02829 Mdot
.15865 .0282 Mdot
.1587 .02811 Mdot
.15875 .02803 Mdot
.1588 .02795 Mdot
.15884 .02786 Mdot
.15889 .02778 Mdot
.15894 .02769 Mdot
.15899 .02761 Mdot
.15903 .02753 Mdot
.15908 .02744 Mdot
.15913 .02736 Mdot
.15918 .02728 Mdot
.15922 .02719 Mdot
.15927 .02711 Mdot
.15932 .02703 Mdot
.15937 .02695 Mdot
.15942 .02687 Mdot
.15946 .02679 Mdot
.15951 .02671 Mdot
.15956 .02663 Mdot
.15961 .02655 Mdot
.15965 .02647 Mdot
.1597 .02639 Mdot
.15975 .02631 Mdot
.1598 .02623 Mdot
.15984 .02615 Mdot
.15989 .02607 Mdot
.15994 .02599 Mdot
.15999 .02591 Mdot
.16003 .02584 Mdot
.16008 .02576 Mdot
.16013 .02568 Mdot
.16018 .0256 Mdot
.16022 .02553 Mdot
.16027 .02545 Mdot
.16032 .02537 Mdot
.16037 .0253 Mdot
.16041 .02522 Mdot
.16046 .02515 Mdot
.16051 .02507 Mdot
.16056 .025 Mdot
.16061 .02492 Mdot
.16065 .02485 Mdot
.1607 .02478 Mdot
.16075 .0247 Mdot
.1608 .02463 Mdot
.16084 .02455 Mdot
.16089 .02448 Mdot
.16094 .02441 Mdot
.16099 .02434 Mdot
.16103 .02426 Mdot
.16108 .02419 Mdot
.16113 .02412 Mdot
.16118 .02405 Mdot
.16122 .02398 Mdot
.16127 .02391 Mdot
.16132 .02384 Mdot
.16137 .02377 Mdot
.16141 .0237 Mdot
.16146 .02363 Mdot
.16151 .02356 Mdot
.16156 .02349 Mdot
.16161 .02342 Mdot
.16165 .02335 Mdot
.1617 .02328 Mdot
.16175 .02322 Mdot
.1618 .02315 Mdot
.16184 .02308 Mdot
.16189 .02301 Mdot
.16194 .02295 Mdot
.16199 .02288 Mdot
.16203 .02281 Mdot
.16208 .02275 Mdot
.16213 .02268 Mdot
.16218 .02261 Mdot
.16222 .02255 Mdot
.16227 .02248 Mdot
.16232 .02242 Mdot
.16237 .02235 Mdot
.16241 .02229 Mdot
.16246 .02223 Mdot
.16251 .02216 Mdot
.16256 .0221 Mdot
.16261 .02204 Mdot
.16265 .02197 Mdot
.1627 .02191 Mdot
.16275 .02185 Mdot
.1628 .02179 Mdot
.16284 .02172 Mdot
.16289 .02166 Mdot
.16294 .0216 Mdot
.16299 .02154 Mdot
.16303 .02148 Mdot
.16308 .02142 Mdot
.16313 .02136 Mdot
.16318 .0213 Mdot
.16322 .02124 Mdot
.16327 .02118 Mdot
.16332 .02112 Mdot
.16337 .02106 Mdot
.16341 .021 Mdot
.16346 .02094 Mdot
.16351 .02089 Mdot
.16356 .02083 Mdot
.16361 .02077 Mdot
.16365 .02071 Mdot
.1637 .02066 Mdot
.16375 .0206 Mdot
.1638 .02054 Mdot
.16384 .02049 Mdot
.16389 .02043 Mdot
.16394 .02037 Mdot
.16399 .02032 Mdot
.16403 .02026 Mdot
.16408 .02021 Mdot
.16413 .02015 Mdot
.16418 .0201 Mdot
.16422 .02005 Mdot
.16427 .01999 Mdot
.16432 .01994 Mdot
.16437 .01989 Mdot
.16441 .01983 Mdot
.16446 .01978 Mdot
.16451 .01973 Mdot
.16456 .01968 Mdot
.1646 .01962 Mdot
.16465 .01957 Mdot
.1647 .01952 Mdot
.16475 .01947 Mdot
.1648 .01942 Mdot
.16484 .01937 Mdot
.16489 .01932 Mdot
.16494 .01927 Mdot
.16499 .01922 Mdot
.16503 .01917 Mdot
.16508 .01912 Mdot
.16513 .01907 Mdot
.16518 .01902 Mdot
.16522 .01897 Mdot
.16527 .01893 Mdot
.16532 .01888 Mdot
.16537 .01883 Mdot
.16541 .01878 Mdot
.16546 .01874 Mdot
.16551 .01869 Mdot
.16556 .01864 Mdot
.1656 .0186 Mdot
.16565 .01855 Mdot
.1657 .01851 Mdot
.16575 .01846 Mdot
.1658 .01842 Mdot
.16584 .01837 Mdot
.16589 .01833 Mdot
.16594 .01828 Mdot
.16599 .01824 Mdot
.16603 .01819 Mdot
.16608 .01815 Mdot
.16613 .01811 Mdot
.16618 .01807 Mdot
.16622 .01802 Mdot
.16627 .01798 Mdot
.16632 .01794 Mdot
.16637 .0179 Mdot
.16641 .01786 Mdot
.16646 .01781 Mdot
.16651 .01777 Mdot
.16656 .01773 Mdot
.1666 .01769 Mdot
.16665 .01765 Mdot
.1667 .01761 Mdot
.16675 .01757 Mdot
.1668 .01753 Mdot
.16684 .01749 Mdot
.16689 .01746 Mdot
.16694 .01742 Mdot
.16699 .01738 Mdot
.16703 .01734 Mdot
.16708 .0173 Mdot
.16713 .01727 Mdot
.16718 .01723 Mdot
.16722 .01719 Mdot
.16727 .01715 Mdot
.16732 .01712 Mdot
.16737 .01708 Mdot
.16741 .01705 Mdot
.16746 .01701 Mdot
.16751 .01698 Mdot
.16756 .01694 Mdot
.1676 .01691 Mdot
.16765 .01687 Mdot
.1677 .01684 Mdot
.16775 .0168 Mdot
.1678 .01677 Mdot
.16784 .01674 Mdot
.16789 .0167 Mdot
.16794 .01667 Mdot
.16799 .01664 Mdot
.16803 .01661 Mdot
.16808 .01657 Mdot
.16813 .01654 Mdot
.16818 .01651 Mdot
.16822 .01648 Mdot
.16827 .01645 Mdot
.16832 .01642 Mdot
.16837 .01639 Mdot
.16841 .01636 Mdot
.16846 .01633 Mdot
.16851 .0163 Mdot
.16856 .01627 Mdot
.1686 .01624 Mdot
.16865 .01621 Mdot
.1687 .01618 Mdot
.16875 .01616 Mdot
.1688 .01613 Mdot
.16884 .0161 Mdot
.16889 .01607 Mdot
.16894 .01605 Mdot
.16899 .01602 Mdot
.16903 .01599 Mdot
.16908 .01597 Mdot
.16913 .01594 Mdot
.16918 .01591 Mdot
.16922 .01589 Mdot
.16927 .01586 Mdot
.16932 .01584 Mdot
.16937 .01581 Mdot
.16941 .01579 Mdot
.16946 .01577 Mdot
.16951 .01574 Mdot
.16956 .01572 Mdot
.1696 .01569 Mdot
.16965 .01567 Mdot
.1697 .01565 Mdot
.16975 .01563 Mdot
.16979 .0156 Mdot
.16984 .01558 Mdot
.16989 .01556 Mdot
.16994 .01554 Mdot
.16999 .01552 Mdot
.17003 .0155 Mdot
.17008 .01548 Mdot
.17013 .01546 Mdot
.17018 .01544 Mdot
.17022 .01542 Mdot
.17027 .0154 Mdot
.17032 .01538 Mdot
.17037 .01536 Mdot
.17041 .01534 Mdot
.17046 .01532 Mdot
.17051 .01531 Mdot
.17056 .01529 Mdot
.1706 .01527 Mdot
.17065 .01525 Mdot
.1707 .01524 Mdot
.17075 .01522 Mdot
.17079 .0152 Mdot
.17084 .01519 Mdot
.17089 .01517 Mdot
.17094 .01515 Mdot
.17099 .01514 Mdot
.17103 .01512 Mdot
.17108 .01511 Mdot
.17113 .0151 Mdot
.17118 .01508 Mdot
.17122 .01507 Mdot
.17127 .01505 Mdot
.17132 .01504 Mdot
.17137 .01503 Mdot
.17141 .01501 Mdot
.17146 .015 Mdot
.17151 .01499 Mdot
.17156 .01498 Mdot
.1716 .01496 Mdot
.17165 .01495 Mdot
.1717 .01494 Mdot
.17175 .01493 Mdot
.17179 .01492 Mdot
.17184 .01491 Mdot
.17189 .0149 Mdot
.17194 .01489 Mdot
.17199 .01488 Mdot
.17203 .01487 Mdot
.17208 .01486 Mdot
.17213 .01485 Mdot
.17218 .01484 Mdot
.17222 .01484 Mdot
.17227 .01483 Mdot
.17232 .01482 Mdot
.17237 .01481 Mdot
.17241 .01481 Mdot
.17246 .0148 Mdot
.17251 .01479 Mdot
.17256 .01479 Mdot
.1726 .01478 Mdot
.17265 .01477 Mdot
.1727 .01477 Mdot
.17275 .01476 Mdot
.17279 .01476 Mdot
.17284 .01475 Mdot
.17289 .01475 Mdot
.17294 .01475 Mdot
.17299 .01474 Mdot
.17303 .01474 Mdot
.17308 .01473 Mdot
.17313 .01473 Mdot
.17318 .01473 Mdot
.17322 .01473 Mdot
.17327 .01472 Mdot
.17332 .01472 Mdot
.17337 .01472 Mdot
.17341 .01472 Mdot
.17346 .01472 Mdot
.17351 .01472 Mdot
.17356 .01472 Mdot
.1736 .01472 Mdot
.17365 .01472 Mdot
.1737 .01472 Mdot
.17375 .01472 Mdot
.17379 .01472 Mdot
.17384 .01472 Mdot
.17389 .01472 Mdot
.17394 .01472 Mdot
.17398 .01472 Mdot
.17403 .01472 Mdot
.17408 .01473 Mdot
.17413 .01473 Mdot
.17418 .01473 Mdot
.17422 .01474 Mdot
.17427 .01474 Mdot
.17432 .01474 Mdot
.17437 .01475 Mdot
.17441 .01475 Mdot
.17446 .01475 Mdot
.17451 .01476 Mdot
.17456 .01476 Mdot
.1746 .01477 Mdot
.17465 .01478 Mdot
.1747 .01478 Mdot
.17475 .01479 Mdot
.17479 .01479 Mdot
.17484 .0148 Mdot
.17489 .01481 Mdot
.17494 .01481 Mdot
.17498 .01482 Mdot
.17503 .01483 Mdot
.17508 .01484 Mdot
.17513 .01485 Mdot
.17518 .01486 Mdot
.17522 .01486 Mdot
.17527 .01487 Mdot
.17532 .01488 Mdot
.17537 .01489 Mdot
.17541 .0149 Mdot
.17546 .01491 Mdot
.17551 .01492 Mdot
.17556 .01493 Mdot
.1756 .01494 Mdot
.17565 .01496 Mdot
.1757 .01497 Mdot
.17575 .01498 Mdot
.17579 .01499 Mdot
.17584 .015 Mdot
.17589 .01502 Mdot
.17594 .01503 Mdot
.17598 .01504 Mdot
.17603 .01506 Mdot
.17608 .01507 Mdot
.17613 .01508 Mdot
.17618 .0151 Mdot
.17622 .01511 Mdot
.17627 .01513 Mdot
.17632 .01514 Mdot
.17637 .01516 Mdot
.17641 .01517 Mdot
.17646 .01519 Mdot
.17651 .0152 Mdot
.17656 .01522 Mdot
.1766 .01524 Mdot
.17665 .01525 Mdot
.1767 .01527 Mdot
.17675 .01529 Mdot
.17679 .01531 Mdot
.17684 .01533 Mdot
.17689 .01534 Mdot
.17694 .01536 Mdot
.17698 .01538 Mdot
.17703 .0154 Mdot
.17708 .01542 Mdot
.17713 .01544 Mdot
.17718 .01546 Mdot
.17722 .01548 Mdot
.17727 .0155 Mdot
.17732 .01552 Mdot
.17737 .01554 Mdot
.17741 .01556 Mdot
.17746 .01558 Mdot
.17751 .01561 Mdot
.17756 .01563 Mdot
.1776 .01565 Mdot
.17765 .01567 Mdot
.1777 .0157 Mdot
.17775 .01572 Mdot
.17779 .01574 Mdot
.17784 .01577 Mdot
.17789 .01579 Mdot
.17794 .01581 Mdot
.17798 .01584 Mdot
.17803 .01586 Mdot
.17808 .01589 Mdot
.17813 .01591 Mdot
.17818 .01594 Mdot
.17822 .01596 Mdot
.17827 .01599 Mdot
.17832 .01602 Mdot
.17837 .01604 Mdot
.17841 .01607 Mdot
.17846 .0161 Mdot
.17851 .01612 Mdot
.17856 .01615 Mdot
.1786 .01618 Mdot
.17865 .01621 Mdot
.1787 .01624 Mdot
.17875 .01627 Mdot
.17879 .01629 Mdot
.17884 .01632 Mdot
.17889 .01635 Mdot
.17894 .01638 Mdot
.17898 .01641 Mdot
.17903 .01644 Mdot
.17908 .01647 Mdot
.17913 .01651 Mdot
.17917 .01654 Mdot
.17922 .01657 Mdot
.17927 .0166 Mdot
.17932 .01663 Mdot
.17937 .01666 Mdot
.17941 .0167 Mdot
.17946 .01673 Mdot
.17951 .01676 Mdot
.17956 .0168 Mdot
.1796 .01683 Mdot
.17965 .01686 Mdot
.1797 .0169 Mdot
.17975 .01693 Mdot
.17979 .01697 Mdot
.17984 .017 Mdot
.17989 .01704 Mdot
.17994 .01707 Mdot
.17998 .01711 Mdot
.18003 .01714 Mdot
.18008 .01718 Mdot
.18013 .01722 Mdot
.18017 .01725 Mdot
.18022 .01729 Mdot
.18027 .01733 Mdot
.18032 .01736 Mdot
.18037 .0174 Mdot
.18041 .01744 Mdot
.18046 .01748 Mdot
.18051 .01752 Mdot
.18056 .01756 Mdot
.1806 .01759 Mdot
.18065 .01763 Mdot
.1807 .01767 Mdot
.18075 .01771 Mdot
.18079 .01775 Mdot
.18084 .01779 Mdot
.18089 .01783 Mdot
.18094 .01788 Mdot
.18098 .01792 Mdot
.18103 .01796 Mdot
.18108 .018 Mdot
.18113 .01804 Mdot
.18117 .01808 Mdot
.18122 .01813 Mdot
.18127 .01817 Mdot
.18132 .01821 Mdot
.18137 .01826 Mdot
.18141 .0183 Mdot
.18146 .01834 Mdot
.18151 .01839 Mdot
.18156 .01843 Mdot
.1816 .01848 Mdot
.18165 .01852 Mdot
.1817 .01857 Mdot
.18175 .01861 Mdot
.18179 .01866 Mdot
.18184 .0187 Mdot
.18189 .01875 Mdot
.18194 .0188 Mdot
.18198 .01884 Mdot
.18203 .01889 Mdot
.18208 .01894 Mdot
.18213 .01899 Mdot
.18217 .01903 Mdot
.18222 .01908 Mdot
.18227 .01913 Mdot
.18232 .01918 Mdot
.18237 .01923 Mdot
.18241 .01928 Mdot
.18246 .01933 Mdot
.18251 .01937 Mdot
.18256 .01942 Mdot
.1826 .01948 Mdot
.18265 .01953 Mdot
.1827 .01958 Mdot
.18275 .01963 Mdot
.18279 .01968 Mdot
.18284 .01973 Mdot
.18289 .01978 Mdot
.18294 .01983 Mdot
.18298 .01989 Mdot
.18303 .01994 Mdot
.18308 .01999 Mdot
.18313 .02004 Mdot
.18317 .0201 Mdot
.18322 .02015 Mdot
.18327 .0202 Mdot
.18332 .02026 Mdot
.18336 .02031 Mdot
.18341 .02037 Mdot
.18346 .02042 Mdot
.18351 .02048 Mdot
.18356 .02053 Mdot
.1836 .02059 Mdot
.18365 .02064 Mdot
.1837 .0207 Mdot
.18375 .02076 Mdot
.18379 .02081 Mdot
.18384 .02087 Mdot
.18389 .02093 Mdot
.18394 .02099 Mdot
.18398 .02104 Mdot
.18403 .0211 Mdot
.18408 .02116 Mdot
.18413 .02122 Mdot
.18417 .02128 Mdot
.18422 .02134 Mdot
.18427 .0214 Mdot
.18432 .02145 Mdot
.18436 .02151 Mdot
.18441 .02157 Mdot
.18446 .02163 Mdot
.18451 .0217 Mdot
.18456 .02176 Mdot
.1846 .02182 Mdot
.18465 .02188 Mdot
.1847 .02194 Mdot
.18475 .022 Mdot
.18479 .02206 Mdot
.18484 .02213 Mdot
.18489 .02219 Mdot
.18494 .02225 Mdot
.18498 .02232 Mdot
.18503 .02238 Mdot
.18508 .02244 Mdot
.18513 .02251 Mdot
.18517 .02257 Mdot
.18522 .02263 Mdot
.18527 .0227 Mdot
.18532 .02276 Mdot
.18536 .02283 Mdot
.18541 .0229 Mdot
.18546 .02296 Mdot
.18551 .02303 Mdot
.18556 .02309 Mdot
.1856 .02316 Mdot
.18565 .02323 Mdot
.1857 .02329 Mdot
.18575 .02336 Mdot
.18579 .02343 Mdot
.18584 .0235 Mdot
.18589 .02356 Mdot
.18594 .02363 Mdot
.18598 .0237 Mdot
.18603 .02377 Mdot
.18608 .02384 Mdot
.18613 .02391 Mdot
.18617 .02398 Mdot
.18622 .02405 Mdot
.18627 .02412 Mdot
.18632 .02419 Mdot
.18636 .02426 Mdot
.18641 .02433 Mdot
.18646 .0244 Mdot
.18651 .02447 Mdot
.18656 .02454 Mdot
.1866 .02462 Mdot
.18665 .02469 Mdot
.1867 .02476 Mdot
.18675 .02483 Mdot
.18679 .02491 Mdot
.18684 .02498 Mdot
.18689 .02505 Mdot
.18694 .02513 Mdot
.18698 .0252 Mdot
.18703 .02527 Mdot
.18708 .02535 Mdot
.18713 .02542 Mdot
.18717 .0255 Mdot
.18722 .02557 Mdot
.18727 .02565 Mdot
.18732 .02572 Mdot
.18736 .0258 Mdot
.18741 .02588 Mdot
.18746 .02595 Mdot
.18751 .02603 Mdot
.18756 .02611 Mdot
.1876 .02618 Mdot
.18765 .02626 Mdot
.1877 .02634 Mdot
.18775 .02642 Mdot
.18779 .02649 Mdot
.18784 .02657 Mdot
.18789 .02665 Mdot
.18794 .02673 Mdot
.18798 .02681 Mdot
.18803 .02689 Mdot
.18808 .02697 Mdot
.18813 .02705 Mdot
.18817 .02713 Mdot
.18822 .02721 Mdot
.18827 .02729 Mdot
.18832 .02737 Mdot
.18836 .02745 Mdot
.18841 .02753 Mdot
.18846 .02762 Mdot
.18851 .0277 Mdot
.18855 .02778 Mdot
.1886 .02786 Mdot
.18865 .02794 Mdot
.1887 .02803 Mdot
.18875 .02811 Mdot
.18879 .02819 Mdot
.18884 .02828 Mdot
.18889 .02836 Mdot
.18894 .02845 Mdot
.18898 .02853 Mdot
.18903 .02862 Mdot
.18908 .0287 Mdot
.18913 .02879 Mdot
.18917 .02887 Mdot
.18922 .02896 Mdot
.18927 .02904 Mdot
.18932 .02913 Mdot
.18936 .02922 Mdot
.18941 .0293 Mdot
.18946 .02939 Mdot
.18951 .02948 Mdot
.18955 .02956 Mdot
.1896 .02965 Mdot
.18965 .02974 Mdot
.1897 .02983 Mdot
.18975 .02992 Mdot
.18979 .03 Mdot
.18984 .03009 Mdot
.18989 .03018 Mdot
.18994 .03027 Mdot
.18998 .03036 Mdot
.19003 .03045 Mdot
.19008 .03054 Mdot
.19013 .03063 Mdot
.19017 .03072 Mdot
.19022 .03081 Mdot
.19027 .0309 Mdot
.19032 .031 Mdot
.19036 .03109 Mdot
.19041 .03118 Mdot
.19046 .03127 Mdot
.19051 .03136 Mdot
.19055 .03146 Mdot
.1906 .03155 Mdot
.19065 .03164 Mdot
.1907 .03174 Mdot
.19075 .03183 Mdot
.19079 .03192 Mdot
.19084 .03202 Mdot
.19089 .03211 Mdot
.19094 .03221 Mdot
.19098 .0323 Mdot
.19103 .0324 Mdot
.19108 .03249 Mdot
.19113 .03259 Mdot
.19117 .03268 Mdot
.19122 .03278 Mdot
.19127 .03288 Mdot
.19132 .03297 Mdot
.19136 .03307 Mdot
.19141 .03317 Mdot
.19146 .03326 Mdot
.19151 .03336 Mdot
.19155 .03346 Mdot
.1916 .03356 Mdot
.19165 .03365 Mdot
.1917 .03375 Mdot
.19175 .03385 Mdot
.19179 .03395 Mdot
.19184 .03405 Mdot
.19189 .03415 Mdot
.19194 .03425 Mdot
.19198 .03435 Mdot
.19203 .03445 Mdot
.19208 .03455 Mdot
.19213 .03465 Mdot
.19217 .03475 Mdot
.19222 .03485 Mdot
.19227 .03495 Mdot
.19232 .03506 Mdot
.19236 .03516 Mdot
.19241 .03526 Mdot
.19246 .03536 Mdot
.19251 .03546 Mdot
.19255 .03557 Mdot
.1926 .03567 Mdot
.19265 .03577 Mdot
.1927 .03588 Mdot
.19275 .03598 Mdot
.19279 .03608 Mdot
.19284 .03619 Mdot
.19289 .03629 Mdot
.19294 .0364 Mdot
.19298 .0365 Mdot
.19303 .03661 Mdot
.19308 .03671 Mdot
.19313 .03682 Mdot
.19317 .03693 Mdot
.19322 .03703 Mdot
.19327 .03714 Mdot
.19332 .03725 Mdot
.19336 .03735 Mdot
.19341 .03746 Mdot
.19346 .03757 Mdot
.19351 .03767 Mdot
.19355 .03778 Mdot
.1936 .03789 Mdot
.19365 .038 Mdot
.1937 .03811 Mdot
.19374 .03822 Mdot
.19379 .03832 Mdot
.19384 .03843 Mdot
.19389 .03854 Mdot
.19394 .03865 Mdot
.19398 .03876 Mdot
.19403 .03887 Mdot
.19408 .03898 Mdot
.19413 .03909 Mdot
.19417 .03921 Mdot
.19422 .03932 Mdot
.19427 .03943 Mdot
.19432 .03954 Mdot
.19436 .03965 Mdot
.19441 .03976 Mdot
.19446 .03988 Mdot
.19451 .03999 Mdot
.19455 .0401 Mdot
.1946 .04021 Mdot
.19465 .04033 Mdot
.1947 .04044 Mdot
.19474 .04056 Mdot
.19479 .04067 Mdot
.19484 .04078 Mdot
.19489 .0409 Mdot
.19494 .04101 Mdot
.19498 .04113 Mdot
.19503 .04124 Mdot
.19508 .04136 Mdot
.19513 .04147 Mdot
.19517 .04159 Mdot
.19522 .04171 Mdot
.19527 .04182 Mdot
.19532 .04194 Mdot
.19536 .04206 Mdot
.19541 .04217 Mdot
.19546 .04229 Mdot
.19551 .04241 Mdot
.19555 .04252 Mdot
.1956 .04264 Mdot
.19565 .04276 Mdot
.1957 .04288 Mdot
.19574 .043 Mdot
.19579 .04312 Mdot
.19584 .04324 Mdot
.19589 .04336 Mdot
.19594 .04347 Mdot
.19598 .04359 Mdot
.19603 .04371 Mdot
.19608 .04383 Mdot
.19613 .04396 Mdot
.19617 .04408 Mdot
.19622 .0442 Mdot
.19627 .04432 Mdot
.19632 .04444 Mdot
.19636 .04456 Mdot
.19641 .04468 Mdot
.19646 .04481 Mdot
.19651 .04493 Mdot
.19655 .04505 Mdot
.1966 .04517 Mdot
.19665 .0453 Mdot
.1967 .04542 Mdot
.19674 .04554 Mdot
.19679 .04567 Mdot
.19684 .04579 Mdot
.19689 .04591 Mdot
.19694 .04604 Mdot
.19698 .04616 Mdot
.19703 .04629 Mdot
.19708 .04641 Mdot
.19713 .04654 Mdot
.19717 .04666 Mdot
.19722 .04679 Mdot
.19727 .04692 Mdot
.19732 .04704 Mdot
.19736 .04717 Mdot
.19741 .0473 Mdot
.19746 .04742 Mdot
.19751 .04755 Mdot
.19755 .04768 Mdot
.1976 .0478 Mdot
.19765 .04793 Mdot
.1977 .04806 Mdot
.19774 .04819 Mdot
.19779 .04832 Mdot
.19784 .04845 Mdot
.19789 .04857 Mdot
.19793 .0487 Mdot
.19798 .04883 Mdot
.19803 .04896 Mdot
.19808 .04909 Mdot
.19813 .04922 Mdot
.19817 .04935 Mdot
.19822 .04948 Mdot
.19827 .04961 Mdot
.19832 .04974 Mdot
.19836 .04988 Mdot
.19841 .05001 Mdot
.19846 .05014 Mdot
.19851 .05027 Mdot
.19855 .0504 Mdot
.1986 .05054 Mdot
.19865 .05067 Mdot
.1987 .0508 Mdot
.19874 .05093 Mdot
.19879 .05107 Mdot
.19884 .0512 Mdot
.19889 .05133 Mdot
.19893 .05147 Mdot
.19898 .0516 Mdot
.19903 .05174 Mdot
.19908 .05187 Mdot
.19913 .052 Mdot
.19917 .05214 Mdot
.19922 .05227 Mdot
.19927 .05241 Mdot
.19932 .05255 Mdot
.19936 .05268 Mdot
.19941 .05282 Mdot
.19946 .05295 Mdot
.19951 .05309 Mdot
.19955 .05323 Mdot
.1996 .05336 Mdot
.19965 .0535 Mdot
.1997 .05364 Mdot
.19974 .05378 Mdot
.19979 .05391 Mdot
.19984 .05405 Mdot
.19989 .05419 Mdot
.19993 .05433 Mdot
.19998 .05447 Mdot
.20003 .05461 Mdot
.20008 .05475 Mdot
.20013 .05488 Mdot
.20017 .05502 Mdot
.20022 .05516 Mdot
.20027 .0553 Mdot
.20032 .05544 Mdot
.20036 .05558 Mdot
.20041 .05572 Mdot
.20046 .05587 Mdot
.20051 .05601 Mdot
.20055 .05615 Mdot
.2006 .05629 Mdot
.20065 .05643 Mdot
.2007 .05657 Mdot
.20074 .05672 Mdot
.20079 .05686 Mdot
.20084 .057 Mdot
.20089 .05714 Mdot
.20093 .05729 Mdot
.20098 .05743 Mdot
.20103 .05757 Mdot
.20108 .05772 Mdot
.20113 .05786 Mdot
.20117 .058 Mdot
.20122 .05815 Mdot
.20127 .05829 Mdot
.20132 .05844 Mdot
.20136 .05858 Mdot
.20141 .05873 Mdot
.20146 .05887 Mdot
.20151 .05902 Mdot
.20155 .05916 Mdot
.2016 .05931 Mdot
.20165 .05946 Mdot
.2017 .0596 Mdot
.20174 .05975 Mdot
.20179 .0599 Mdot
.20184 .06004 Mdot
.20189 .06019 Mdot
.20193 .06034 Mdot
.20198 .06049 Mdot
.20203 .06063 Mdot
.20208 .06078 Mdot
.20213 .06093 Mdot
.20217 .06108 Mdot
.20222 .06123 Mdot
.20227 .06138 Mdot
.20232 .06153 Mdot
.20236 .06167 Mdot
.20241 .06182 Mdot
.20246 .06197 Mdot
.20251 .06212 Mdot
.20255 .06227 Mdot
.2026 .06242 Mdot
.20265 .06258 Mdot
.2027 .06273 Mdot
.20274 .06288 Mdot
.20279 .06303 Mdot
.20284 .06318 Mdot
.20289 .06333 Mdot
.20293 .06348 Mdot
.20298 .06364 Mdot
.20303 .06379 Mdot
.20308 .06394 Mdot
.20312 .06409 Mdot
.20317 .06425 Mdot
.20322 .0644 Mdot
.20327 .06455 Mdot
.20332 .06471 Mdot
.20336 .06486 Mdot
.20341 .06501 Mdot
.20346 .06517 Mdot
.20351 .06532 Mdot
.20355 .06548 Mdot
.2036 .06563 Mdot
.20365 .06579 Mdot
.2037 .06594 Mdot
.20374 .0661 Mdot
.20379 .06625 Mdot
.20384 .06641 Mdot
.20389 .06656 Mdot
.20393 .06672 Mdot
.20398 .06688 Mdot
.20403 .06703 Mdot
.20408 .06719 Mdot
.20412 .06735 Mdot
.20417 .0675 Mdot
.20422 .06766 Mdot
.20427 .06782 Mdot
.20432 .06798 Mdot
.20436 .06814 Mdot
.20441 .06829 Mdot
.20446 .06845 Mdot
.20451 .06861 Mdot
.20455 .06877 Mdot
.2046 .06893 Mdot
.20465 .06909 Mdot
.2047 .06925 Mdot
.20474 .06941 Mdot
.20479 .06957 Mdot
.20484 .06973 Mdot
.20489 .06989 Mdot
.20493 .07005 Mdot
.20498 .07021 Mdot
.20503 .07037 Mdot
.20508 .07053 Mdot
.20512 .07069 Mdot
.20517 .07085 Mdot
.20522 .07101 Mdot
.20527 .07118 Mdot
.20532 .07134 Mdot
.20536 .0715 Mdot
.20541 .07166 Mdot
.20546 .07183 Mdot
.20551 .07199 Mdot
.20555 .07215 Mdot
.2056 .07231 Mdot
.20565 .07248 Mdot
.2057 .07264 Mdot
.20574 .07281 Mdot
.20579 .07297 Mdot
.20584 .07313 Mdot
.20589 .0733 Mdot
.20593 .07346 Mdot
.20598 .07363 Mdot
.20603 .07379 Mdot
.20608 .07396 Mdot
.20612 .07412 Mdot
.20617 .07429 Mdot
.20622 .07445 Mdot
.20627 .07462 Mdot
.20632 .07479 Mdot
.20636 .07495 Mdot
.20641 .07512 Mdot
.20646 .07529 Mdot
.20651 .07545 Mdot
.20655 .07562 Mdot
.2066 .07579 Mdot
.20665 .07595 Mdot
.2067 .07612 Mdot
.20674 .07629 Mdot
.20679 .07646 Mdot
.20684 .07663 Mdot
.20689 .0768 Mdot
.20693 .07696 Mdot
.20698 .07713 Mdot
.20703 .0773 Mdot
.20708 .07747 Mdot
.20712 .07764 Mdot
.20717 .07781 Mdot
.20722 .07798 Mdot
.20727 .07815 Mdot
.20731 .07832 Mdot
.20736 .07849 Mdot
.20741 .07866 Mdot
.20746 .07883 Mdot
.20751 .079 Mdot
.20755 .07917 Mdot
.2076 .07935 Mdot
.20765 .07952 Mdot
.2077 .07969 Mdot
.20774 .07986 Mdot
.20779 .08003 Mdot
.20784 .08021 Mdot
.20789 .08038 Mdot
.20793 .08055 Mdot
.20798 .08072 Mdot
.20803 .0809 Mdot
.20808 .08107 Mdot
.20812 .08124 Mdot
.20817 .08142 Mdot
.20822 .08159 Mdot
.20827 .08176 Mdot
.20831 .08194 Mdot
.20836 .08211 Mdot
.20841 .08229 Mdot
.20846 .08246 Mdot
.20851 .08264 Mdot
.20855 .08281 Mdot
.2086 .08299 Mdot
.20865 .08316 Mdot
.2087 .08334 Mdot
.20874 .08352 Mdot
.20879 .08369 Mdot
.20884 .08387 Mdot
.20889 .08404 Mdot
.20893 .08422 Mdot
.20898 .0844 Mdot
.20903 .08457 Mdot
.20908 .08475 Mdot
.20912 .08493 Mdot
.20917 .08511 Mdot
.20922 .08528 Mdot
.20927 .08546 Mdot
.20931 .08564 Mdot
.20936 .08582 Mdot
.20941 .086 Mdot
.20946 .08618 Mdot
.20951 .08635 Mdot
.20955 .08653 Mdot
.2096 .08671 Mdot
.20965 .08689 Mdot
.2097 .08707 Mdot
.20974 .08725 Mdot
.20979 .08743 Mdot
.20984 .08761 Mdot
.20989 .08779 Mdot
.20993 .08797 Mdot
.20998 .08815 Mdot
.21003 .08833 Mdot
.21008 .08851 Mdot
.21012 .0887 Mdot
.21017 .08888 Mdot
.21022 .08906 Mdot
.21027 .08924 Mdot
.21031 .08942 Mdot
.21036 .0896 Mdot
.21041 .08979 Mdot
.21046 .08997 Mdot
.21051 .09015 Mdot
.21055 .09033 Mdot
.2106 .09052 Mdot
.21065 .0907 Mdot
.2107 .09088 Mdot
.21074 .09107 Mdot
.21079 .09125 Mdot
.21084 .09143 Mdot
.21089 .09162 Mdot
.21093 .0918 Mdot
.21098 .09199 Mdot
.21103 .09217 Mdot
.21108 .09236 Mdot
.21112 .09254 Mdot
.21117 .09273 Mdot
.21122 .09291 Mdot
.21127 .0931 Mdot
.21131 .09328 Mdot
.21136 .09347 Mdot
.21141 .09365 Mdot
.21146 .09384 Mdot
.21151 .09403 Mdot
.21155 .09421 Mdot
.2116 .0944 Mdot
.21165 .09459 Mdot
.2117 .09477 Mdot
.21174 .09496 Mdot
.21179 .09515 Mdot
.21184 .09533 Mdot
.21189 .09552 Mdot
.21193 .09571 Mdot
.21198 .0959 Mdot
.21203 .09609 Mdot
.21208 .09627 Mdot
.21212 .09646 Mdot
.21217 .09665 Mdot
.21222 .09684 Mdot
.21227 .09703 Mdot
.21231 .09722 Mdot
.21236 .09741 Mdot
.21241 .0976 Mdot
.21246 .09779 Mdot
.2125 .09798 Mdot
.21255 .09817 Mdot
.2126 .09836 Mdot
.21265 .09855 Mdot
.2127 .09874 Mdot
.21274 .09893 Mdot
.21279 .09912 Mdot
.21284 .09931 Mdot
.21289 .0995 Mdot
.21293 .09969 Mdot
.21298 .09989 Mdot
.21303 .10008 Mdot
.21308 .10027 Mdot
.21312 .10046 Mdot
.21317 .10065 Mdot
.21322 .10085 Mdot
.21327 .10104 Mdot
.21331 .10123 Mdot
.21336 .10142 Mdot
.21341 .10162 Mdot
.21346 .10181 Mdot
.2135 .102 Mdot
.21355 .1022 Mdot
.2136 .10239 Mdot
.21365 .10259 Mdot
.2137 .10278 Mdot
.21374 .10297 Mdot
.21379 .10317 Mdot
.21384 .10336 Mdot
.21389 .10356 Mdot
.21393 .10375 Mdot
.21398 .10395 Mdot
.21403 .10414 Mdot
.21408 .10434 Mdot
.21412 .10453 Mdot
.21417 .10473 Mdot
.21422 .10492 Mdot
.21427 .10512 Mdot
.21431 .10532 Mdot
.21436 .10551 Mdot
.21441 .10571 Mdot
.21446 .10591 Mdot
.2145 .1061 Mdot
.21455 .1063 Mdot
.2146 .1065 Mdot
.21465 .10669 Mdot
.2147 .10689 Mdot
.21474 .10709 Mdot
.21479 .10729 Mdot
.21484 .10749 Mdot
.21489 .10768 Mdot
.21493 .10788 Mdot
.21498 .10808 Mdot
.21503 .10828 Mdot
.21508 .10848 Mdot
.21512 .10868 Mdot
.21517 .10888 Mdot
.21522 .10907 Mdot
.21527 .10927 Mdot
.21531 .10947 Mdot
.21536 .10967 Mdot
.21541 .10987 Mdot
.21546 .11007 Mdot
.2155 .11027 Mdot
.21555 .11047 Mdot
.2156 .11067 Mdot
.21565 .11087 Mdot
.2157 .11108 Mdot
.21574 .11128 Mdot
.21579 .11148 Mdot
.21584 .11168 Mdot
.21589 .11188 Mdot
.21593 .11208 Mdot
.21598 .11228 Mdot
.21603 .11249 Mdot
.21608 .11269 Mdot
.21612 .11289 Mdot
.21617 .11309 Mdot
.21622 .11329 Mdot
.21627 .1135 Mdot
.21631 .1137 Mdot
.21636 .1139 Mdot
.21641 .11411 Mdot
.21646 .11431 Mdot
.2165 .11451 Mdot
.21655 .11472 Mdot
.2166 .11492 Mdot
.21665 .11512 Mdot
.21669 .11533 Mdot
.21674 .11553 Mdot
.21679 .11574 Mdot
.21684 .11594 Mdot
.21689 .11614 Mdot
.21693 .11635 Mdot
.21698 .11655 Mdot
.21703 .11676 Mdot
.21708 .11696 Mdot
.21712 .11717 Mdot
.21717 .11738 Mdot
.21722 .11758 Mdot
.21727 .11779 Mdot
.21731 .11799 Mdot
.21736 .1182 Mdot
.21741 .11841 Mdot
.21746 .11861 Mdot
.2175 .11882 Mdot
.21755 .11902 Mdot
.2176 .11923 Mdot
.21765 .11944 Mdot
.21769 .11965 Mdot
.21774 .11985 Mdot
.21779 .12006 Mdot
.21784 .12027 Mdot
.21789 .12048 Mdot
.21793 .12068 Mdot
.21798 .12089 Mdot
.21803 .1211 Mdot
.21808 .12131 Mdot
.21812 .12152 Mdot
.21817 .12172 Mdot
.21822 .12193 Mdot
.21827 .12214 Mdot
.21831 .12235 Mdot
.21836 .12256 Mdot
.21841 .12277 Mdot
.21846 .12298 Mdot
.2185 .12319 Mdot
.21855 .1234 Mdot
.2186 .12361 Mdot
.21865 .12382 Mdot
.21869 .12403 Mdot
.21874 .12424 Mdot
.21879 .12445 Mdot
.21884 .12466 Mdot
.21889 .12487 Mdot
.21893 .12508 Mdot
.21898 .12529 Mdot
.21903 .1255 Mdot
.21908 .12571 Mdot
.21912 .12593 Mdot
.21917 .12614 Mdot
.21922 .12635 Mdot
.21927 .12656 Mdot
.21931 .12677 Mdot
.21936 .12698 Mdot
.21941 .1272 Mdot
.21946 .12741 Mdot
.2195 .12762 Mdot
.21955 .12783 Mdot
.2196 .12805 Mdot
.21965 .12826 Mdot
.21969 .12847 Mdot
.21974 .12869 Mdot
.21979 .1289 Mdot
.21984 .12911 Mdot
.21989 .12933 Mdot
.21993 .12954 Mdot
.21998 .12975 Mdot
.22003 .12997 Mdot
.22008 .13018 Mdot
.22012 .1304 Mdot
.22017 .13061 Mdot
.22022 .13083 Mdot
.22027 .13104 Mdot
.22031 .13125 Mdot
.22036 .13147 Mdot
.22041 .13168 Mdot
.22046 .1319 Mdot
.2205 .13212 Mdot
.22055 .13233 Mdot
.2206 .13255 Mdot
.22065 .13276 Mdot
.22069 .13298 Mdot
.22074 .13319 Mdot
.22079 .13341 Mdot
.22084 .13363 Mdot
.22089 .13384 Mdot
.22093 .13406 Mdot
.22098 .13428 Mdot
.22103 .13449 Mdot
.22108 .13471 Mdot
.22112 .13493 Mdot
.22117 .13514 Mdot
.22122 .13536 Mdot
.22127 .13558 Mdot
.22131 .1358 Mdot
.22136 .13601 Mdot
.22141 .13623 Mdot
.22146 .13645 Mdot
.2215 .13667 Mdot
.22155 .13689 Mdot
.2216 .1371 Mdot
.22165 .13732 Mdot
.22169 .13754 Mdot
.22174 .13776 Mdot
.22179 .13798 Mdot
.22184 .1382 Mdot
.22188 .13842 Mdot
.22193 .13864 Mdot
.22198 .13886 Mdot
.22203 .13908 Mdot
.22208 .13929 Mdot
.22212 .13951 Mdot
.22217 .13973 Mdot
.22222 .13995 Mdot
.22227 .14017 Mdot
.22231 .14039 Mdot
.22236 .14061 Mdot
.22241 .14084 Mdot
.22246 .14106 Mdot
.2225 .14128 Mdot
.22255 .1415 Mdot
.2226 .14172 Mdot
.22265 .14194 Mdot
.22269 .14216 Mdot
.22274 .14238 Mdot
.22279 .1426 Mdot
.22284 .14282 Mdot
.22288 .14305 Mdot
.22293 .14327 Mdot
.22298 .14349 Mdot
.22303 .14371 Mdot
.22308 .14393 Mdot
.22312 .14416 Mdot
.22317 .14438 Mdot
.22322 .1446 Mdot
.22327 .14482 Mdot
.22331 .14505 Mdot
.22336 .14527 Mdot
.22341 .14549 Mdot
.22346 .14572 Mdot
.2235 .14594 Mdot
.22355 .14616 Mdot
.2236 .14639 Mdot
.22365 .14661 Mdot
.22369 .14683 Mdot
.22374 .14706 Mdot
.22379 .14728 Mdot
.22384 .14751 Mdot
.22388 .14773 Mdot
.22393 .14795 Mdot
.22398 .14818 Mdot
.22403 .1484 Mdot
.22408 .14863 Mdot
.22412 .14885 Mdot
.22417 .14908 Mdot
.22422 .1493 Mdot
.22427 .14953 Mdot
.22431 .14975 Mdot
.22436 .14998 Mdot
.22441 .1502 Mdot
.22446 .15043 Mdot
.2245 .15065 Mdot
.22455 .15088 Mdot
.2246 .15111 Mdot
.22465 .15133 Mdot
.22469 .15156 Mdot
.22474 .15178 Mdot
.22479 .15201 Mdot
.22484 .15224 Mdot
.22488 .15246 Mdot
.22493 .15269 Mdot
.22498 .15292 Mdot
.22503 .15314 Mdot
.22508 .15337 Mdot
.22512 .1536 Mdot
.22517 .15383 Mdot
.22522 .15405 Mdot
.22527 .15428 Mdot
.22531 .15451 Mdot
.22536 .15474 Mdot
.22541 .15496 Mdot
.22546 .15519 Mdot
.2255 .15542 Mdot
.22555 .15565 Mdot
.2256 .15588 Mdot
.22565 .1561 Mdot
.22569 .15633 Mdot
.22574 .15656 Mdot
.22579 .15679 Mdot
.22584 .15702 Mdot
.22588 .15725 Mdot
.22593 .15748 Mdot
.22598 .15771 Mdot
.22603 .15793 Mdot
.22608 .15816 Mdot
.22612 .15839 Mdot
.22617 .15862 Mdot
.22622 .15885 Mdot
.22627 .15908 Mdot
.22631 .15931 Mdot
.22636 .15954 Mdot
.22641 .15977 Mdot
.22646 .16 Mdot
.2265 .16023 Mdot
.22655 .16046 Mdot
.2266 .16069 Mdot
.22665 .16092 Mdot
.22669 .16115 Mdot
.22674 .16138 Mdot
.22679 .16162 Mdot
.22684 .16185 Mdot
.22688 .16208 Mdot
.22693 .16231 Mdot
.22698 .16254 Mdot
.22703 .16277 Mdot
.22707 .163 Mdot
.22712 .16323 Mdot
.22717 .16347 Mdot
.22722 .1637 Mdot
.22727 .16393 Mdot
.22731 .16416 Mdot
.22736 .16439 Mdot
.22741 .16463 Mdot
.22746 .16486 Mdot
.2275 .16509 Mdot
.22755 .16532 Mdot
.2276 .16556 Mdot
.22765 .16579 Mdot
.22769 .16602 Mdot
.22774 .16625 Mdot
.22779 .16649 Mdot
.22784 .16672 Mdot
.22788 .16695 Mdot
.22793 .16719 Mdot
.22798 .16742 Mdot
.22803 .16765 Mdot
.22807 .16789 Mdot
.22812 .16812 Mdot
.22817 .16835 Mdot
.22822 .16859 Mdot
.22827 .16882 Mdot
.22831 .16905 Mdot
.22836 .16929 Mdot
.22841 .16952 Mdot
.22846 .16976 Mdot
.2285 .16999 Mdot
.22855 .17023 Mdot
.2286 .17046 Mdot
.22865 .1707 Mdot
.22869 .17093 Mdot
.22874 .17116 Mdot
.22879 .1714 Mdot
.22884 .17163 Mdot
.22888 .17187 Mdot
.22893 .17211 Mdot
.22898 .17234 Mdot
.22903 .17258 Mdot
.22907 .17281 Mdot
.22912 .17305 Mdot
.22917 .17328 Mdot
.22922 .17352 Mdot
.22927 .17375 Mdot
.22931 .17399 Mdot
.22936 .17423 Mdot
.22941 .17446 Mdot
.22946 .1747 Mdot
.2295 .17493 Mdot
.22955 .17517 Mdot
.2296 .17541 Mdot
.22965 .17564 Mdot
.22969 .17588 Mdot
.22974 .17612 Mdot
.22979 .17635 Mdot
.22984 .17659 Mdot
.22988 .17683 Mdot
.22993 .17706 Mdot
.22998 .1773 Mdot
.23003 .17754 Mdot
.23007 .17778 Mdot
.23012 .17801 Mdot
.23017 .17825 Mdot
.23022 .17849 Mdot
.23027 .17873 Mdot
.23031 .17896 Mdot
.23036 .1792 Mdot
.23041 .17944 Mdot
.23046 .17968 Mdot
.2305 .17992 Mdot
.23055 .18015 Mdot
.2306 .18039 Mdot
.23065 .18063 Mdot
.23069 .18087 Mdot
.23074 .18111 Mdot
.23079 .18135 Mdot
.23084 .18158 Mdot
.23088 .18182 Mdot
.23093 .18206 Mdot
.23098 .1823 Mdot
.23103 .18254 Mdot
.23107 .18278 Mdot
.23112 .18302 Mdot
.23117 .18326 Mdot
.23122 .1835 Mdot
.23126 .18373 Mdot
.23131 .18397 Mdot
.23136 .18421 Mdot
.23141 .18445 Mdot
.23146 .18469 Mdot
.2315 .18493 Mdot
.23155 .18517 Mdot
.2316 .18541 Mdot
.23165 .18565 Mdot
.23169 .18589 Mdot
.23174 .18613 Mdot
.23179 .18637 Mdot
.23184 .18661 Mdot
.23188 .18685 Mdot
.23193 .18709 Mdot
.23198 .18733 Mdot
.23203 .18757 Mdot
.23207 .18782 Mdot
.23212 .18806 Mdot
.23217 .1883 Mdot
.23222 .18854 Mdot
.23226 .18878 Mdot
.23231 .18902 Mdot
.23236 .18926 Mdot
.23241 .1895 Mdot
.23246 .18974 Mdot
.2325 .18998 Mdot
.23255 .19023 Mdot
.2326 .19047 Mdot
.23265 .19071 Mdot
.23269 .19095 Mdot
.23274 .19119 Mdot
.23279 .19143 Mdot
.23284 .19168 Mdot
.23288 .19192 Mdot
.23293 .19216 Mdot
.23298 .1924 Mdot
.23303 .19264 Mdot
.23307 .19289 Mdot
.23312 .19313 Mdot
.23317 .19337 Mdot
.23322 .19361 Mdot
.23326 .19386 Mdot
.23331 .1941 Mdot
.23336 .19434 Mdot
.23341 .19458 Mdot
.23346 .19483 Mdot
.2335 .19507 Mdot
.23355 .19531 Mdot
.2336 .19555 Mdot
.23365 .1958 Mdot
.23369 .19604 Mdot
.23374 .19628 Mdot
.23379 .19653 Mdot
.23384 .19677 Mdot
.23388 .19701 Mdot
.23393 .19726 Mdot
.23398 .1975 Mdot
.23403 .19774 Mdot
.23407 .19799 Mdot
.23412 .19823 Mdot
.23417 .19847 Mdot
.23422 .19872 Mdot
.23426 .19896 Mdot
.23431 .19921 Mdot
.23436 .19945 Mdot
.23441 .19969 Mdot
.23446 .19994 Mdot
.2345 .20018 Mdot
.23455 .20043 Mdot
.2346 .20067 Mdot
.23465 .20091 Mdot
.23469 .20116 Mdot
.23474 .2014 Mdot
.23479 .20165 Mdot
.23484 .20189 Mdot
.23488 .20214 Mdot
.23493 .20238 Mdot
.23498 .20263 Mdot
.23503 .20287 Mdot
.23507 .20312 Mdot
.23512 .20336 Mdot
.23517 .20361 Mdot
.23522 .20385 Mdot
.23526 .2041 Mdot
.23531 .20434 Mdot
.23536 .20459 Mdot
.23541 .20483 Mdot
.23546 .20508 Mdot
.2355 .20532 Mdot
.23555 .20557 Mdot
.2356 .20581 Mdot
.23565 .20606 Mdot
.23569 .2063 Mdot
.23574 .20655 Mdot
.23579 .2068 Mdot
.23584 .20704 Mdot
.23588 .20729 Mdot
.23593 .20753 Mdot
.23598 .20778 Mdot
.23603 .20802 Mdot
.23607 .20827 Mdot
.23612 .20852 Mdot
.23617 .20876 Mdot
.23622 .20901 Mdot
.23626 .20926 Mdot
.23631 .2095 Mdot
.23636 .20975 Mdot
.23641 .20999 Mdot
.23645 .21024 Mdot
.2365 .21049 Mdot
.23655 .21073 Mdot
.2366 .21098 Mdot
.23665 .21123 Mdot
.23669 .21147 Mdot
.23674 .21172 Mdot
.23679 .21197 Mdot
.23684 .21221 Mdot
.23688 .21246 Mdot
.23693 .21271 Mdot
.23698 .21295 Mdot
.23703 .2132 Mdot
.23707 .21345 Mdot
.23712 .2137 Mdot
.23717 .21394 Mdot
.23722 .21419 Mdot
.23726 .21444 Mdot
.23731 .21469 Mdot
.23736 .21493 Mdot
.23741 .21518 Mdot
.23745 .21543 Mdot
.2375 .21568 Mdot
.23755 .21592 Mdot
.2376 .21617 Mdot
.23765 .21642 Mdot
.23769 .21667 Mdot
.23774 .21691 Mdot
.23779 .21716 Mdot
.23784 .21741 Mdot
.23788 .21766 Mdot
.23793 .2179 Mdot
.23798 .21815 Mdot
.23803 .2184 Mdot
.23807 .21865 Mdot
.23812 .2189 Mdot
.23817 .21915 Mdot
.23822 .21939 Mdot
.23826 .21964 Mdot
.23831 .21989 Mdot
.23836 .22014 Mdot
.23841 .22039 Mdot
.23845 .22063 Mdot
.2385 .22088 Mdot
.23855 .22113 Mdot
.2386 .22138 Mdot
.23865 .22163 Mdot
.23869 .22188 Mdot
.23874 .22213 Mdot
.23879 .22237 Mdot
.23884 .22262 Mdot
.23888 .22287 Mdot
.23893 .22312 Mdot
.23898 .22337 Mdot
.23903 .22362 Mdot
.23907 .22387 Mdot
.23912 .22412 Mdot
.23917 .22437 Mdot
.23922 .22461 Mdot
.23926 .22486 Mdot
.23931 .22511 Mdot
.23936 .22536 Mdot
.23941 .22561 Mdot
.23945 .22586 Mdot
.2395 .22611 Mdot
.23955 .22636 Mdot
.2396 .22661 Mdot
.23965 .22686 Mdot
.23969 .22711 Mdot
.23974 .22736 Mdot
.23979 .22761 Mdot
.23984 .22786 Mdot
.23988 .2281 Mdot
.23993 .22835 Mdot
.23998 .2286 Mdot
.24003 .22885 Mdot
.24007 .2291 Mdot
.24012 .22935 Mdot
.24017 .2296 Mdot
.24022 .22985 Mdot
.24026 .2301 Mdot
.24031 .23035 Mdot
.24036 .2306 Mdot
.24041 .23085 Mdot
.24045 .2311 Mdot
.2405 .23135 Mdot
.24055 .2316 Mdot
.2406 .23185 Mdot
.24064 .2321 Mdot
.24069 .23235 Mdot
.24074 .2326 Mdot
.24079 .23285 Mdot
.24084 .2331 Mdot
.24088 .23335 Mdot
.24093 .2336 Mdot
.24098 .23385 Mdot
.24103 .2341 Mdot
.24107 .23435 Mdot
.24112 .2346 Mdot
.24117 .23485 Mdot
.24122 .2351 Mdot
.24126 .23535 Mdot
.24131 .2356 Mdot
.24136 .23585 Mdot
.24141 .23611 Mdot
.24145 .23636 Mdot
.2415 .23661 Mdot
.24155 .23686 Mdot
.2416 .23711 Mdot
.24164 .23736 Mdot
.24169 .23761 Mdot
.24174 .23786 Mdot
.24179 .23811 Mdot
.24184 .23836 Mdot
.24188 .23861 Mdot
.24193 .23886 Mdot
.24198 .23911 Mdot
.24203 .23936 Mdot
.24207 .23961 Mdot
.24212 .23987 Mdot
.24217 .24012 Mdot
.24222 .24037 Mdot
.24226 .24062 Mdot
.24231 .24087 Mdot
.24236 .24112 Mdot
.24241 .24137 Mdot
.24245 .24162 Mdot
.2425 .24187 Mdot
.24255 .24212 Mdot
.2426 .24237 Mdot
.24264 .24263 Mdot
.24269 .24288 Mdot
.24274 .24313 Mdot
.24279 .24338 Mdot
.24284 .24363 Mdot
.24288 .24388 Mdot
.24293 .24413 Mdot
.24298 .24438 Mdot
.24303 .24463 Mdot
.24307 .24489 Mdot
.24312 .24514 Mdot
.24317 .24539 Mdot
.24322 .24564 Mdot
.24326 .24589 Mdot
.24331 .24614 Mdot
.24336 .24639 Mdot
.24341 .24664 Mdot
.24345 .2469 Mdot
.2435 .24715 Mdot
.24355 .2474 Mdot
.2436 .24765 Mdot
.24364 .2479 Mdot
.24369 .24815 Mdot
.24374 .2484 Mdot
.24379 .24866 Mdot
.24384 .24891 Mdot
.24388 .24916 Mdot
.24393 .24941 Mdot
.24398 .24966 Mdot
.24403 .24991 Mdot
.24407 .25016 Mdot
.24412 .25042 Mdot
.24417 .25067 Mdot
.24422 .25092 Mdot
.24426 .25117 Mdot
.24431 .25142 Mdot
.24436 .25167 Mdot
.24441 .25192 Mdot
.24445 .25218 Mdot
.2445 .25243 Mdot
.24455 .25268 Mdot
.2446 .25293 Mdot
.24464 .25318 Mdot
.24469 .25343 Mdot
.24474 .25369 Mdot
.24479 .25394 Mdot
.24484 .25419 Mdot
.24488 .25444 Mdot
.24493 .25469 Mdot
.24498 .25494 Mdot
.24503 .2552 Mdot
.24507 .25545 Mdot
.24512 .2557 Mdot
.24517 .25595 Mdot
.24522 .2562 Mdot
.24526 .25645 Mdot
.24531 .25671 Mdot
.24536 .25696 Mdot
.24541 .25721 Mdot
.24545 .25746 Mdot
.2455 .25771 Mdot
.24555 .25796 Mdot
.2456 .25822 Mdot
.24564 .25847 Mdot
.24569 .25872 Mdot
.24574 .25897 Mdot
.24579 .25922 Mdot
.24583 .25947 Mdot
.24588 .25973 Mdot
.24593 .25998 Mdot
.24598 .26023 Mdot
.24603 .26048 Mdot
.24607 .26073 Mdot
.24612 .26098 Mdot
.24617 .26124 Mdot
.24622 .26149 Mdot
.24626 .26174 Mdot
.24631 .26199 Mdot
.24636 .26224 Mdot
.24641 .26249 Mdot
.24645 .26275 Mdot
.2465 .263 Mdot
.24655 .26325 Mdot
.2466 .2635 Mdot
.24664 .26375 Mdot
.24669 .26401 Mdot
.24674 .26426 Mdot
.24679 .26451 Mdot
.24683 .26476 Mdot
.24688 .26501 Mdot
.24693 .26526 Mdot
.24698 .26552 Mdot
.24703 .26577 Mdot
.24707 .26602 Mdot
.24712 .26627 Mdot
.24717 .26652 Mdot
.24722 .26677 Mdot
.24726 .26703 Mdot
.24731 .26728 Mdot
.24736 .26753 Mdot
.24741 .26778 Mdot
.24745 .26803 Mdot
.2475 .26828 Mdot
.24755 .26854 Mdot
.2476 .26879 Mdot
.24764 .26904 Mdot
.24769 .26929 Mdot
.24774 .26954 Mdot
.24779 .26979 Mdot
.24783 .27005 Mdot
.24788 .2703 Mdot
.24793 .27055 Mdot
.24798 .2708 Mdot
.24803 .27105 Mdot
.24807 .2713 Mdot
.24812 .27155 Mdot
.24817 .27181 Mdot
.24822 .27206 Mdot
.24826 .27231 Mdot
.24831 .27256 Mdot
.24836 .27281 Mdot
.24841 .27306 Mdot
.24845 .27331 Mdot
.2485 .27357 Mdot
.24855 .27382 Mdot
.2486 .27407 Mdot
.24864 .27432 Mdot
.24869 .27457 Mdot
.24874 .27482 Mdot
.24879 .27507 Mdot
.24883 .27533 Mdot
.24888 .27558 Mdot
.24893 .27583 Mdot
.24898 .27608 Mdot
.24903 .27633 Mdot
.24907 .27658 Mdot
.24912 .27683 Mdot
.24917 .27708 Mdot
.24922 .27734 Mdot
.24926 .27759 Mdot
.24931 .27784 Mdot
.24936 .27809 Mdot
.24941 .27834 Mdot
.24945 .27859 Mdot
.2495 .27884 Mdot
.24955 .27909 Mdot
.2496 .27935 Mdot
.24964 .2796 Mdot
.24969 .27985 Mdot
.24974 .2801 Mdot
.24979 .28035 Mdot
.24983 .2806 Mdot
.24988 .28085 Mdot
.24993 .2811 Mdot
.24998 .28135 Mdot
.25002 .2816 Mdot
.25007 .28186 Mdot
.25012 .28211 Mdot
.25017 .28236 Mdot
.25022 .28261 Mdot
.25026 .28286 Mdot
.25031 .28311 Mdot
.25036 .28336 Mdot
.25041 .28361 Mdot
.25045 .28386 Mdot
.2505 .28411 Mdot
.25055 .28436 Mdot
.2506 .28461 Mdot
.25064 .28486 Mdot
.25069 .28511 Mdot
.25074 .28537 Mdot
.25079 .28562 Mdot
.25083 .28587 Mdot
.25088 .28612 Mdot
.25093 .28637 Mdot
.25098 .28662 Mdot
.25102 .28687 Mdot
.25107 .28712 Mdot
.25112 .28737 Mdot
.25117 .28762 Mdot
.25122 .28787 Mdot
.25126 .28812 Mdot
.25131 .28837 Mdot
.25136 .28862 Mdot
.25141 .28887 Mdot
.25145 .28912 Mdot
.2515 .28937 Mdot
.25155 .28962 Mdot
.2516 .28987 Mdot
.25164 .29012 Mdot
.25169 .29037 Mdot
.25174 .29062 Mdot
.25179 .29087 Mdot
.25183 .29112 Mdot
.25188 .29137 Mdot
.25193 .29162 Mdot
.25198 .29187 Mdot
.25202 .29212 Mdot
.25207 .29237 Mdot
.25212 .29262 Mdot
.25217 .29287 Mdot
.25222 .29312 Mdot
.25226 .29337 Mdot
.25231 .29362 Mdot
.25236 .29387 Mdot
.25241 .29412 Mdot
.25245 .29437 Mdot
.2525 .29462 Mdot
.25255 .29487 Mdot
.2526 .29512 Mdot
.25264 .29537 Mdot
.25269 .29562 Mdot
.25274 .29587 Mdot
.25279 .29611 Mdot
.25283 .29636 Mdot
.25288 .29661 Mdot
.25293 .29686 Mdot
.25298 .29711 Mdot
.25302 .29736 Mdot
.25307 .29761 Mdot
.25312 .29786 Mdot
.25317 .29811 Mdot
.25322 .29836 Mdot
.25326 .29861 Mdot
.25331 .29885 Mdot
.25336 .2991 Mdot
.25341 .29935 Mdot
.25345 .2996 Mdot
.2535 .29985 Mdot
.25355 .3001 Mdot
.2536 .30035 Mdot
.25364 .3006 Mdot
.25369 .30084 Mdot
.25374 .30109 Mdot
.25379 .30134 Mdot
.25383 .30159 Mdot
.25388 .30184 Mdot
.25393 .30209 Mdot
.25398 .30234 Mdot
.25402 .30258 Mdot
.25407 .30283 Mdot
.25412 .30308 Mdot
.25417 .30333 Mdot
.25422 .30358 Mdot
.25426 .30383 Mdot
.25431 .30407 Mdot
.25436 .30432 Mdot
.25441 .30457 Mdot
.25445 .30482 Mdot
.2545 .30507 Mdot
.25455 .30531 Mdot
.2546 .30556 Mdot
.25464 .30581 Mdot
.25469 .30606 Mdot
.25474 .3063 Mdot
.25479 .30655 Mdot
.25483 .3068 Mdot
.25488 .30705 Mdot
.25493 .30729 Mdot
.25498 .30754 Mdot
.25502 .30779 Mdot
.25507 .30804 Mdot
.25512 .30828 Mdot
.25517 .30853 Mdot
.25521 .30878 Mdot
.25526 .30903 Mdot
.25531 .30927 Mdot
.25536 .30952 Mdot
.25541 .30977 Mdot
.25545 .31001 Mdot
.2555 .31026 Mdot
.25555 .31051 Mdot
.2556 .31076 Mdot
.25564 .311 Mdot
.25569 .31125 Mdot
.25574 .3115 Mdot
.25579 .31174 Mdot
.25583 .31199 Mdot
.25588 .31224 Mdot
.25593 .31248 Mdot
.25598 .31273 Mdot
.25602 .31297 Mdot
.25607 .31322 Mdot
.25612 .31347 Mdot
.25617 .31371 Mdot
.25621 .31396 Mdot
.25626 .31421 Mdot
.25631 .31445 Mdot
.25636 .3147 Mdot
.25641 .31494 Mdot
.25645 .31519 Mdot
.2565 .31544 Mdot
.25655 .31568 Mdot
.2566 .31593 Mdot
.25664 .31617 Mdot
.25669 .31642 Mdot
.25674 .31666 Mdot
.25679 .31691 Mdot
.25683 .31716 Mdot
.25688 .3174 Mdot
.25693 .31765 Mdot
.25698 .31789 Mdot
.25702 .31814 Mdot
.25707 .31838 Mdot
.25712 .31863 Mdot
.25717 .31887 Mdot
.25721 .31912 Mdot
.25726 .31936 Mdot
.25731 .31961 Mdot
.25736 .31985 Mdot
.25741 .3201 Mdot
.25745 .32034 Mdot
.2575 .32059 Mdot
.25755 .32083 Mdot
.2576 .32108 Mdot
.25764 .32132 Mdot
.25769 .32157 Mdot
.25774 .32181 Mdot
.25779 .32205 Mdot
.25783 .3223 Mdot
.25788 .32254 Mdot
.25793 .32279 Mdot
.25798 .32303 Mdot
.25802 .32327 Mdot
.25807 .32352 Mdot
.25812 .32376 Mdot
.25817 .32401 Mdot
.25821 .32425 Mdot
.25826 .32449 Mdot
.25831 .32474 Mdot
.25836 .32498 Mdot
.25841 .32523 Mdot
.25845 .32547 Mdot
.2585 .32571 Mdot
.25855 .32596 Mdot
.2586 .3262 Mdot
.25864 .32644 Mdot
.25869 .32669 Mdot
.25874 .32693 Mdot
.25879 .32717 Mdot
.25883 .32741 Mdot
.25888 .32766 Mdot
.25893 .3279 Mdot
.25898 .32814 Mdot
.25902 .32839 Mdot
.25907 .32863 Mdot
.25912 .32887 Mdot
.25917 .32911 Mdot
.25921 .32936 Mdot
.25926 .3296 Mdot
.25931 .32984 Mdot
.25936 .33008 Mdot
.25941 .33032 Mdot
.25945 .33057 Mdot
.2595 .33081 Mdot
.25955 .33105 Mdot
.2596 .33129 Mdot
.25964 .33153 Mdot
.25969 .33178 Mdot
.25974 .33202 Mdot
.25979 .33226 Mdot
.25983 .3325 Mdot
.25988 .33274 Mdot
.25993 .33298 Mdot
.25998 .33323 Mdot
.26002 .33347 Mdot
.26007 .33371 Mdot
.26012 .33395 Mdot
.26017 .33419 Mdot
.26021 .33443 Mdot
.26026 .33467 Mdot
.26031 .33491 Mdot
.26036 .33515 Mdot
.2604 .33539 Mdot
.26045 .33564 Mdot
.2605 .33588 Mdot
.26055 .33612 Mdot
.2606 .33636 Mdot
.26064 .3366 Mdot
.26069 .33684 Mdot
.26074 .33708 Mdot
.26079 .33732 Mdot
.26083 .33756 Mdot
.26088 .3378 Mdot
.26093 .33804 Mdot
.26098 .33828 Mdot
.26102 .33852 Mdot
.26107 .33876 Mdot
.26112 .339 Mdot
.26117 .33924 Mdot
.26121 .33948 Mdot
.26126 .33971 Mdot
.26131 .33995 Mdot
.26136 .34019 Mdot
.2614 .34043 Mdot
.26145 .34067 Mdot
.2615 .34091 Mdot
.26155 .34115 Mdot
.2616 .34139 Mdot
.26164 .34163 Mdot
.26169 .34187 Mdot
.26174 .3421 Mdot
.26179 .34234 Mdot
.26183 .34258 Mdot
.26188 .34282 Mdot
.26193 .34306 Mdot
.26198 .3433 Mdot
.26202 .34353 Mdot
.26207 .34377 Mdot
.26212 .34401 Mdot
.26217 .34425 Mdot
.26221 .34449 Mdot
.26226 .34472 Mdot
.26231 .34496 Mdot
.26236 .3452 Mdot
.2624 .34544 Mdot
.26245 .34567 Mdot
.2625 .34591 Mdot
.26255 .34615 Mdot
.2626 .34638 Mdot
.26264 .34662 Mdot
.26269 .34686 Mdot
.26274 .3471 Mdot
.26279 .34733 Mdot
.26283 .34757 Mdot
.26288 .34781 Mdot
.26293 .34804 Mdot
.26298 .34828 Mdot
.26302 .34851 Mdot
.26307 .34875 Mdot
.26312 .34899 Mdot
.26317 .34922 Mdot
.26321 .34946 Mdot
.26326 .34969 Mdot
.26331 .34993 Mdot
.26336 .35017 Mdot
.2634 .3504 Mdot
.26345 .35064 Mdot
.2635 .35087 Mdot
.26355 .35111 Mdot
.2636 .35134 Mdot
.26364 .35158 Mdot
.26369 .35181 Mdot
.26374 .35205 Mdot
.26379 .35228 Mdot
.26383 .35252 Mdot
.26388 .35275 Mdot
.26393 .35299 Mdot
.26398 .35322 Mdot
.26402 .35346 Mdot
.26407 .35369 Mdot
.26412 .35393 Mdot
.26417 .35416 Mdot
.26421 .35439 Mdot
.26426 .35463 Mdot
.26431 .35486 Mdot
.26436 .3551 Mdot
.2644 .35533 Mdot
.26445 .35556 Mdot
.2645 .3558 Mdot
.26455 .35603 Mdot
.26459 .35626 Mdot
.26464 .3565 Mdot
.26469 .35673 Mdot
.26474 .35696 Mdot
.26479 .3572 Mdot
.26483 .35743 Mdot
.26488 .35766 Mdot
.26493 .3579 Mdot
.26498 .35813 Mdot
.26502 .35836 Mdot
.26507 .35859 Mdot
.26512 .35883 Mdot
.26517 .35906 Mdot
.26521 .35929 Mdot
.26526 .35952 Mdot
.26531 .35975 Mdot
.26536 .35999 Mdot
.2654 .36022 Mdot
.26545 .36045 Mdot
.2655 .36068 Mdot
.26555 .36091 Mdot
.26559 .36114 Mdot
.26564 .36137 Mdot
.26569 .36161 Mdot
.26574 .36184 Mdot
.26579 .36207 Mdot
.26583 .3623 Mdot
.26588 .36253 Mdot
.26593 .36276 Mdot
.26598 .36299 Mdot
.26602 .36322 Mdot
.26607 .36345 Mdot
.26612 .36368 Mdot
.26617 .36391 Mdot
.26621 .36414 Mdot
.26626 .36437 Mdot
.26631 .3646 Mdot
.26636 .36483 Mdot
.2664 .36506 Mdot
.26645 .36529 Mdot
.2665 .36552 Mdot
.26655 .36575 Mdot
.26659 .36598 Mdot
.26664 .36621 Mdot
.26669 .36644 Mdot
.26674 .36667 Mdot
.26679 .3669 Mdot
.26683 .36712 Mdot
.26688 .36735 Mdot
.26693 .36758 Mdot
.26698 .36781 Mdot
.26702 .36804 Mdot
.26707 .36827 Mdot
.26712 .3685 Mdot
.26717 .36872 Mdot
.26721 .36895 Mdot
.26726 .36918 Mdot
.26731 .36941 Mdot
.26736 .36963 Mdot
.2674 .36986 Mdot
.26745 .37009 Mdot
.2675 .37032 Mdot
.26755 .37054 Mdot
.26759 .37077 Mdot
.26764 .371 Mdot
.26769 .37122 Mdot
.26774 .37145 Mdot
.26779 .37168 Mdot
.26783 .3719 Mdot
.26788 .37213 Mdot
.26793 .37236 Mdot
.26798 .37258 Mdot
.26802 .37281 Mdot
.26807 .37304 Mdot
.26812 .37326 Mdot
.26817 .37349 Mdot
.26821 .37371 Mdot
.26826 .37394 Mdot
.26831 .37416 Mdot
.26836 .37439 Mdot
.2684 .37461 Mdot
.26845 .37484 Mdot
.2685 .37506 Mdot
.26855 .37529 Mdot
.26859 .37551 Mdot
.26864 .37574 Mdot
.26869 .37596 Mdot
.26874 .37619 Mdot
.26879 .37641 Mdot
.26883 .37664 Mdot
.26888 .37686 Mdot
.26893 .37708 Mdot
.26898 .37731 Mdot
.26902 .37753 Mdot
.26907 .37776 Mdot
.26912 .37798 Mdot
.26917 .3782 Mdot
.26921 .37843 Mdot
.26926 .37865 Mdot
.26931 .37887 Mdot
.26936 .3791 Mdot
.2694 .37932 Mdot
.26945 .37954 Mdot
.2695 .37976 Mdot
.26955 .37999 Mdot
.26959 .38021 Mdot
.26964 .38043 Mdot
.26969 .38065 Mdot
.26974 .38088 Mdot
.26978 .3811 Mdot
.26983 .38132 Mdot
.26988 .38154 Mdot
.26993 .38176 Mdot
.26998 .38198 Mdot
.27002 .38221 Mdot
.27007 .38243 Mdot
.27012 .38265 Mdot
.27017 .38287 Mdot
.27021 .38309 Mdot
.27026 .38331 Mdot
.27031 .38353 Mdot
.27036 .38375 Mdot
.2704 .38397 Mdot
.27045 .38419 Mdot
.2705 .38441 Mdot
.27055 .38463 Mdot
.27059 .38485 Mdot
.27064 .38507 Mdot
.27069 .38529 Mdot
.27074 .38551 Mdot
.27078 .38573 Mdot
.27083 .38595 Mdot
.27088 .38617 Mdot
.27093 .38639 Mdot
.27098 .38661 Mdot
.27102 .38683 Mdot
.27107 .38704 Mdot
.27112 .38726 Mdot
.27117 .38748 Mdot
.27121 .3877 Mdot
.27126 .38792 Mdot
.27131 .38814 Mdot
.27136 .38835 Mdot
.2714 .38857 Mdot
.27145 .38879 Mdot
.2715 .38901 Mdot
.27155 .38923 Mdot
.27159 .38944 Mdot
.27164 .38966 Mdot
.27169 .38988 Mdot
.27174 .39009 Mdot
.27178 .39031 Mdot
.27183 .39053 Mdot
.27188 .39074 Mdot
.27193 .39096 Mdot
.27198 .39118 Mdot
.27202 .39139 Mdot
.27207 .39161 Mdot
.27212 .39182 Mdot
.27217 .39204 Mdot
.27221 .39226 Mdot
.27226 .39247 Mdot
.27231 .39269 Mdot
.27236 .3929 Mdot
.2724 .39312 Mdot
.27245 .39333 Mdot
.2725 .39355 Mdot
.27255 .39376 Mdot
.27259 .39398 Mdot
.27264 .39419 Mdot
.27269 .39441 Mdot
.27274 .39462 Mdot
.27278 .39484 Mdot
.27283 .39505 Mdot
.27288 .39526 Mdot
.27293 .39548 Mdot
.27298 .39569 Mdot
.27302 .3959 Mdot
.27307 .39612 Mdot
.27312 .39633 Mdot
.27317 .39654 Mdot
.27321 .39676 Mdot
.27326 .39697 Mdot
.27331 .39718 Mdot
.27336 .39739 Mdot
.2734 .39761 Mdot
.27345 .39782 Mdot
.2735 .39803 Mdot
.27355 .39824 Mdot
.27359 .39846 Mdot
.27364 .39867 Mdot
.27369 .39888 Mdot
.27374 .39909 Mdot
.27378 .3993 Mdot
.27383 .39951 Mdot
.27388 .39972 Mdot
.27393 .39994 Mdot
.27397 .40015 Mdot
.27402 .40036 Mdot
.27407 .40057 Mdot
.27412 .40078 Mdot
.27417 .40099 Mdot
.27421 .4012 Mdot
.27426 .40141 Mdot
.27431 .40162 Mdot
.27436 .40183 Mdot
.2744 .40204 Mdot
.27445 .40225 Mdot
.2745 .40246 Mdot
.27455 .40267 Mdot
.27459 .40288 Mdot
.27464 .40308 Mdot
.27469 .40329 Mdot
.27474 .4035 Mdot
.27478 .40371 Mdot
.27483 .40392 Mdot
.27488 .40413 Mdot
.27493 .40434 Mdot
.27497 .40454 Mdot
.27502 .40475 Mdot
.27507 .40496 Mdot
.27512 .40517 Mdot
.27517 .40537 Mdot
.27521 .40558 Mdot
.27526 .40579 Mdot
.27531 .406 Mdot
.27536 .4062 Mdot
.2754 .40641 Mdot
.27545 .40662 Mdot
.2755 .40682 Mdot
.27555 .40703 Mdot
.27559 .40723 Mdot
.27564 .40744 Mdot
.27569 .40765 Mdot
.27574 .40785 Mdot
.27578 .40806 Mdot
.27583 .40826 Mdot
.27588 .40847 Mdot
.27593 .40867 Mdot
.27597 .40888 Mdot
.27602 .40908 Mdot
.27607 .40929 Mdot
.27612 .40949 Mdot
.27617 .4097 Mdot
.27621 .4099 Mdot
.27626 .41011 Mdot
.27631 .41031 Mdot
.27636 .41051 Mdot
.2764 .41072 Mdot
.27645 .41092 Mdot
.2765 .41112 Mdot
.27655 .41133 Mdot
.27659 .41153 Mdot
.27664 .41173 Mdot
.27669 .41194 Mdot
.27674 .41214 Mdot
.27678 .41234 Mdot
.27683 .41254 Mdot
.27688 .41275 Mdot
.27693 .41295 Mdot
.27697 .41315 Mdot
.27702 .41335 Mdot
.27707 .41355 Mdot
.27712 .41376 Mdot
.27717 .41396 Mdot
.27721 .41416 Mdot
.27726 .41436 Mdot
.27731 .41456 Mdot
.27736 .41476 Mdot
.2774 .41496 Mdot
.27745 .41516 Mdot
.2775 .41536 Mdot
.27755 .41556 Mdot
.27759 .41576 Mdot
.27764 .41596 Mdot
.27769 .41616 Mdot
.27774 .41636 Mdot
.27778 .41656 Mdot
.27783 .41676 Mdot
.27788 .41696 Mdot
.27793 .41716 Mdot
.27797 .41736 Mdot
.27802 .41756 Mdot
.27807 .41776 Mdot
.27812 .41795 Mdot
.27817 .41815 Mdot
.27821 .41835 Mdot
.27826 .41855 Mdot
.27831 .41875 Mdot
.27836 .41894 Mdot
.2784 .41914 Mdot
.27845 .41934 Mdot
.2785 .41954 Mdot
.27855 .41973 Mdot
.27859 .41993 Mdot
.27864 .42013 Mdot
.27869 .42032 Mdot
.27874 .42052 Mdot
.27878 .42072 Mdot
.27883 .42091 Mdot
.27888 .42111 Mdot
.27893 .4213 Mdot
.27897 .4215 Mdot
.27902 .42169 Mdot
.27907 .42189 Mdot
.27912 .42208 Mdot
.27916 .42228 Mdot
.27921 .42247 Mdot
.27926 .42267 Mdot
.27931 .42286 Mdot
.27936 .42306 Mdot
.2794 .42325 Mdot
.27945 .42345 Mdot
.2795 .42364 Mdot
.27955 .42383 Mdot
.27959 .42403 Mdot
.27964 .42422 Mdot
.27969 .42441 Mdot
.27974 .42461 Mdot
.27978 .4248 Mdot
.27983 .42499 Mdot
.27988 .42519 Mdot
.27993 .42538 Mdot
.27997 .42557 Mdot
.28002 .42576 Mdot
.28007 .42596 Mdot
.28012 .42615 Mdot
.28016 .42634 Mdot
.28021 .42653 Mdot
.28026 .42672 Mdot
.28031 .42691 Mdot
.28036 .4271 Mdot
.2804 .4273 Mdot
.28045 .42749 Mdot
.2805 .42768 Mdot
.28055 .42787 Mdot
.28059 .42806 Mdot
.28064 .42825 Mdot
.28069 .42844 Mdot
.28074 .42863 Mdot
.28078 .42882 Mdot
.28083 .42901 Mdot
.28088 .4292 Mdot
.28093 .42939 Mdot
.28097 .42957 Mdot
.28102 .42976 Mdot
.28107 .42995 Mdot
.28112 .43014 Mdot
.28116 .43033 Mdot
.28121 .43052 Mdot
.28126 .4307 Mdot
.28131 .43089 Mdot
.28136 .43108 Mdot
.2814 .43127 Mdot
.28145 .43146 Mdot
.2815 .43164 Mdot
.28155 .43183 Mdot
.28159 .43202 Mdot
.28164 .4322 Mdot
.28169 .43239 Mdot
.28174 .43258 Mdot
.28178 .43276 Mdot
.28183 .43295 Mdot
.28188 .43313 Mdot
.28193 .43332 Mdot
.28197 .43351 Mdot
.28202 .43369 Mdot
.28207 .43388 Mdot
.28212 .43406 Mdot
.28216 .43425 Mdot
.28221 .43443 Mdot
.28226 .43462 Mdot
.28231 .4348 Mdot
.28236 .43498 Mdot
.2824 .43517 Mdot
.28245 .43535 Mdot
.2825 .43554 Mdot
.28255 .43572 Mdot
.28259 .4359 Mdot
.28264 .43609 Mdot
.28269 .43627 Mdot
.28274 .43645 Mdot
.28278 .43663 Mdot
.28283 .43682 Mdot
.28288 .437 Mdot
.28293 .43718 Mdot
.28297 .43736 Mdot
.28302 .43755 Mdot
.28307 .43773 Mdot
.28312 .43791 Mdot
.28316 .43809 Mdot
.28321 .43827 Mdot
.28326 .43845 Mdot
.28331 .43863 Mdot
.28335 .43881 Mdot
.2834 .43899 Mdot
.28345 .43917 Mdot
.2835 .43935 Mdot
.28355 .43953 Mdot
.28359 .43971 Mdot
.28364 .43989 Mdot
.28369 .44007 Mdot
.28374 .44025 Mdot
.28378 .44043 Mdot
.28383 .44061 Mdot
.28388 .44079 Mdot
.28393 .44097 Mdot
.28397 .44115 Mdot
.28402 .44133 Mdot
.28407 .4415 Mdot
.28412 .44168 Mdot
.28416 .44186 Mdot
.28421 .44204 Mdot
.28426 .44221 Mdot
.28431 .44239 Mdot
.28435 .44257 Mdot
.2844 .44275 Mdot
.28445 .44292 Mdot
.2845 .4431 Mdot
.28455 .44328 Mdot
.28459 .44345 Mdot
.28464 .44363 Mdot
.28469 .4438 Mdot
.28474 .44398 Mdot
.28478 .44415 Mdot
.28483 .44433 Mdot
.28488 .4445 Mdot
.28493 .44468 Mdot
.28497 .44485 Mdot
.28502 .44503 Mdot
.28507 .4452 Mdot
.28512 .44538 Mdot
.28516 .44555 Mdot
.28521 .44573 Mdot
.28526 .4459 Mdot
.28531 .44607 Mdot
.28535 .44625 Mdot
.2854 .44642 Mdot
.28545 .44659 Mdot
.2855 .44677 Mdot
.28555 .44694 Mdot
.28559 .44711 Mdot
.28564 .44728 Mdot
.28569 .44746 Mdot
.28574 .44763 Mdot
.28578 .4478 Mdot
.28583 .44797 Mdot
.28588 .44814 Mdot
.28593 .44831 Mdot
.28597 .44848 Mdot
.28602 .44866 Mdot
.28607 .44883 Mdot
.28612 .449 Mdot
.28616 .44917 Mdot
.28621 .44934 Mdot
.28626 .44951 Mdot
.28631 .44968 Mdot
.28635 .44985 Mdot
.2864 .45002 Mdot
.28645 .45019 Mdot
.2865 .45035 Mdot
.28655 .45052 Mdot
.28659 .45069 Mdot
.28664 .45086 Mdot
.28669 .45103 Mdot
.28674 .4512 Mdot
.28678 .45136 Mdot
.28683 .45153 Mdot
.28688 .4517 Mdot
.28693 .45187 Mdot
.28697 .45204 Mdot
.28702 .4522 Mdot
.28707 .45237 Mdot
.28712 .45254 Mdot
.28716 .4527 Mdot
.28721 .45287 Mdot
.28726 .45303 Mdot
.28731 .4532 Mdot
.28735 .45337 Mdot
.2874 .45353 Mdot
.28745 .4537 Mdot
.2875 .45386 Mdot
.28755 .45403 Mdot
.28759 .45419 Mdot
.28764 .45436 Mdot
.28769 .45452 Mdot
.28774 .45469 Mdot
.28778 .45485 Mdot
.28783 .45501 Mdot
.28788 .45518 Mdot
.28793 .45534 Mdot
.28797 .45551 Mdot
.28802 .45567 Mdot
.28807 .45583 Mdot
.28812 .45599 Mdot
.28816 .45616 Mdot
.28821 .45632 Mdot
.28826 .45648 Mdot
.28831 .45664 Mdot
.28835 .45681 Mdot
.2884 .45697 Mdot
.28845 .45713 Mdot
.2885 .45729 Mdot
.28854 .45745 Mdot
.28859 .45761 Mdot
.28864 .45777 Mdot
.28869 .45793 Mdot
.28874 .45809 Mdot
.28878 .45825 Mdot
.28883 .45841 Mdot
.28888 .45857 Mdot
.28893 .45873 Mdot
.28897 .45889 Mdot
.28902 .45905 Mdot
.28907 .45921 Mdot
.28912 .45937 Mdot
.28916 .45953 Mdot
.28921 .45969 Mdot
.28926 .45985 Mdot
.28931 .46 Mdot
.28935 .46016 Mdot
.2894 .46032 Mdot
.28945 .46048 Mdot
.2895 .46064 Mdot
.28954 .46079 Mdot
.28959 .46095 Mdot
.28964 .46111 Mdot
.28969 .46126 Mdot
.28974 .46142 Mdot
.28978 .46158 Mdot
.28983 .46173 Mdot
.28988 .46189 Mdot
.28993 .46204 Mdot
.28997 .4622 Mdot
.29002 .46235 Mdot
.29007 .46251 Mdot
.29012 .46266 Mdot
.29016 .46282 Mdot
.29021 .46297 Mdot
.29026 .46313 Mdot
.29031 .46328 Mdot
.29035 .46344 Mdot
.2904 .46359 Mdot
.29045 .46374 Mdot
.2905 .4639 Mdot
.29054 .46405 Mdot
.29059 .4642 Mdot
.29064 .46436 Mdot
.29069 .46451 Mdot
.29074 .46466 Mdot
.29078 .46481 Mdot
.29083 .46497 Mdot
.29088 .46512 Mdot
.29093 .46527 Mdot
.29097 .46542 Mdot
.29102 .46557 Mdot
.29107 .46572 Mdot
.29112 .46587 Mdot
.29116 .46602 Mdot
.29121 .46617 Mdot
.29126 .46632 Mdot
.29131 .46647 Mdot
.29135 .46662 Mdot
.2914 .46677 Mdot
.29145 .46692 Mdot
.2915 .46707 Mdot
.29154 .46722 Mdot
.29159 .46737 Mdot
.29164 .46752 Mdot
.29169 .46767 Mdot
.29174 .46782 Mdot
.29178 .46796 Mdot
.29183 .46811 Mdot
.29188 .46826 Mdot
.29193 .46841 Mdot
.29197 .46856 Mdot
.29202 .4687 Mdot
.29207 .46885 Mdot
.29212 .469 Mdot
.29216 .46914 Mdot
.29221 .46929 Mdot
.29226 .46944 Mdot
.29231 .46958 Mdot
.29235 .46973 Mdot
.2924 .46987 Mdot
.29245 .47002 Mdot
.2925 .47016 Mdot
.29254 .47031 Mdot
.29259 .47045 Mdot
.29264 .4706 Mdot
.29269 .47074 Mdot
.29274 .47089 Mdot
.29278 .47103 Mdot
.29283 .47117 Mdot
.29288 .47132 Mdot
.29293 .47146 Mdot
.29297 .4716 Mdot
.29302 .47175 Mdot
.29307 .47189 Mdot
.29312 .47203 Mdot
.29316 .47217 Mdot
.29321 .47232 Mdot
.29326 .47246 Mdot
.29331 .4726 Mdot
.29335 .47274 Mdot
.2934 .47288 Mdot
.29345 .47302 Mdot
.2935 .47317 Mdot
.29354 .47331 Mdot
.29359 .47345 Mdot
.29364 .47359 Mdot
.29369 .47373 Mdot
.29373 .47387 Mdot
.29378 .47401 Mdot
.29383 .47415 Mdot
.29388 .47429 Mdot
.29393 .47442 Mdot
.29397 .47456 Mdot
.29402 .4747 Mdot
.29407 .47484 Mdot
.29412 .47498 Mdot
.29416 .47512 Mdot
.29421 .47526 Mdot
.29426 .47539 Mdot
.29431 .47553 Mdot
.29435 .47567 Mdot
.2944 .47581 Mdot
.29445 .47594 Mdot
.2945 .47608 Mdot
.29454 .47622 Mdot
.29459 .47635 Mdot
.29464 .47649 Mdot
.29469 .47662 Mdot
.29473 .47676 Mdot
.29478 .4769 Mdot
.29483 .47703 Mdot
.29488 .47717 Mdot
.29493 .4773 Mdot
.29497 .47744 Mdot
.29502 .47757 Mdot
.29507 .4777 Mdot
.29512 .47784 Mdot
.29516 .47797 Mdot
.29521 .47811 Mdot
.29526 .47824 Mdot
.29531 .47837 Mdot
.29535 .47851 Mdot
.2954 .47864 Mdot
.29545 .47877 Mdot
.2955 .4789 Mdot
.29554 .47904 Mdot
.29559 .47917 Mdot
.29564 .4793 Mdot
.29569 .47943 Mdot
.29573 .47956 Mdot
.29578 .47969 Mdot
.29583 .47982 Mdot
.29588 .47996 Mdot
.29593 .48009 Mdot
.29597 .48022 Mdot
.29602 .48035 Mdot
.29607 .48048 Mdot
.29612 .48061 Mdot
.29616 .48074 Mdot
.29621 .48086 Mdot
.29626 .48099 Mdot
.29631 .48112 Mdot
.29635 .48125 Mdot
.2964 .48138 Mdot
.29645 .48151 Mdot
.2965 .48164 Mdot
.29654 .48176 Mdot
.29659 .48189 Mdot
.29664 .48202 Mdot
.29669 .48215 Mdot
.29673 .48227 Mdot
.29678 .4824 Mdot
.29683 .48253 Mdot
.29688 .48265 Mdot
.29693 .48278 Mdot
.29697 .48291 Mdot
.29702 .48303 Mdot
.29707 .48316 Mdot
.29712 .48328 Mdot
.29716 .48341 Mdot
.29721 .48353 Mdot
.29726 .48366 Mdot
.29731 .48378 Mdot
.29735 .48391 Mdot
.2974 .48403 Mdot
.29745 .48415 Mdot
.2975 .48428 Mdot
.29754 .4844 Mdot
.29759 .48452 Mdot
.29764 .48465 Mdot
.29769 .48477 Mdot
.29773 .48489 Mdot
.29778 .48502 Mdot
.29783 .48514 Mdot
.29788 .48526 Mdot
.29792 .48538 Mdot
.29797 .4855 Mdot
.29802 .48562 Mdot
.29807 .48575 Mdot
.29812 .48587 Mdot
.29816 .48599 Mdot
.29821 .48611 Mdot
.29826 .48623 Mdot
.29831 .48635 Mdot
.29835 .48647 Mdot
.2984 .48659 Mdot
.29845 .48671 Mdot
.2985 .48683 Mdot
.29854 .48695 Mdot
.29859 .48706 Mdot
.29864 .48718 Mdot
.29869 .4873 Mdot
.29873 .48742 Mdot
.29878 .48754 Mdot
.29883 .48766 Mdot
.29888 .48777 Mdot
.29892 .48789 Mdot
.29897 .48801 Mdot
.29902 .48812 Mdot
.29907 .48824 Mdot
.29912 .48836 Mdot
.29916 .48847 Mdot
.29921 .48859 Mdot
.29926 .48871 Mdot
.29931 .48882 Mdot
.29935 .48894 Mdot
.2994 .48905 Mdot
.29945 .48917 Mdot
.2995 .48928 Mdot
.29954 .4894 Mdot
.29959 .48951 Mdot
.29964 .48962 Mdot
.29969 .48974 Mdot
.29973 .48985 Mdot
.29978 .48997 Mdot
.29983 .49008 Mdot
.29988 .49019 Mdot
.29992 .4903 Mdot
.29997 .49042 Mdot
.30002 .49053 Mdot
.30007 .49064 Mdot
.30012 .49075 Mdot
.30016 .49087 Mdot
.30021 .49098 Mdot
.30026 .49109 Mdot
.30031 .4912 Mdot
.30035 .49131 Mdot
.3004 .49142 Mdot
.30045 .49153 Mdot
.3005 .49164 Mdot
.30054 .49175 Mdot
.30059 .49186 Mdot
.30064 .49197 Mdot
.30069 .49208 Mdot
.30073 .49219 Mdot
.30078 .4923 Mdot
.30083 .49241 Mdot
.30088 .49252 Mdot
.30092 .49262 Mdot
.30097 .49273 Mdot
.30102 .49284 Mdot
.30107 .49295 Mdot
.30112 .49306 Mdot
.30116 .49316 Mdot
.30121 .49327 Mdot
.30126 .49338 Mdot
.30131 .49348 Mdot
.30135 .49359 Mdot
.3014 .4937 Mdot
.30145 .4938 Mdot
.3015 .49391 Mdot
.30154 .49401 Mdot
.30159 .49412 Mdot
.30164 .49422 Mdot
.30169 .49433 Mdot
.30173 .49443 Mdot
.30178 .49454 Mdot
.30183 .49464 Mdot
.30188 .49474 Mdot
.30192 .49485 Mdot
.30197 .49495 Mdot
.30202 .49505 Mdot
.30207 .49516 Mdot
.30212 .49526 Mdot
.30216 .49536 Mdot
.30221 .49547 Mdot
.30226 .49557 Mdot
.30231 .49567 Mdot
.30235 .49577 Mdot
.3024 .49587 Mdot
.30245 .49597 Mdot
.3025 .49608 Mdot
.30254 .49618 Mdot
.30259 .49628 Mdot
.30264 .49638 Mdot
.30269 .49648 Mdot
.30273 .49658 Mdot
.30278 .49668 Mdot
.30283 .49678 Mdot
.30288 .49688 Mdot
.30292 .49698 Mdot
.30297 .49707 Mdot
.30302 .49717 Mdot
.30307 .49727 Mdot
.30311 .49737 Mdot
.30316 .49747 Mdot
.30321 .49757 Mdot
.30326 .49766 Mdot
.30331 .49776 Mdot
.30335 .49786 Mdot
.3034 .49795 Mdot
.30345 .49805 Mdot
.3035 .49815 Mdot
.30354 .49824 Mdot
.30359 .49834 Mdot
.30364 .49844 Mdot
.30369 .49853 Mdot
.30373 .49863 Mdot
.30378 .49872 Mdot
.30383 .49882 Mdot
.30388 .49891 Mdot
.30392 .49901 Mdot
.30397 .4991 Mdot
.30402 .49919 Mdot
.30407 .49929 Mdot
.30411 .49938 Mdot
.30416 .49947 Mdot
.30421 .49957 Mdot
.30426 .49966 Mdot
.30431 .49975 Mdot
.30435 .49985 Mdot
.3044 .49994 Mdot
.30445 .50003 Mdot
.3045 .50012 Mdot
.30454 .50021 Mdot
.30459 .5003 Mdot
.30464 .5004 Mdot
.30469 .50049 Mdot
.30473 .50058 Mdot
.30478 .50067 Mdot
.30483 .50076 Mdot
.30488 .50085 Mdot
.30492 .50094 Mdot
.30497 .50103 Mdot
.30502 .50112 Mdot
.30507 .50121 Mdot
.30511 .50129 Mdot
.30516 .50138 Mdot
.30521 .50147 Mdot
.30526 .50156 Mdot
.30531 .50165 Mdot
.30535 .50174 Mdot
.3054 .50182 Mdot
.30545 .50191 Mdot
.3055 .502 Mdot
.30554 .50208 Mdot
.30559 .50217 Mdot
.30564 .50226 Mdot
.30569 .50234 Mdot
.30573 .50243 Mdot
.30578 .50251 Mdot
.30583 .5026 Mdot
.30588 .50269 Mdot
.30592 .50277 Mdot
.30597 .50286 Mdot
.30602 .50294 Mdot
.30607 .50302 Mdot
.30611 .50311 Mdot
.30616 .50319 Mdot
.30621 .50328 Mdot
.30626 .50336 Mdot
.30631 .50344 Mdot
.30635 .50353 Mdot
.3064 .50361 Mdot
.30645 .50369 Mdot
.3065 .50377 Mdot
.30654 .50386 Mdot
.30659 .50394 Mdot
.30664 .50402 Mdot
.30669 .5041 Mdot
.30673 .50418 Mdot
.30678 .50426 Mdot
.30683 .50434 Mdot
.30688 .50442 Mdot
.30692 .5045 Mdot
.30697 .50458 Mdot
.30702 .50466 Mdot
.30707 .50474 Mdot
.30711 .50482 Mdot
.30716 .5049 Mdot
.30721 .50498 Mdot
.30726 .50506 Mdot
.3073 .50514 Mdot
.30735 .50522 Mdot
.3074 .5053 Mdot
.30745 .50537 Mdot
.3075 .50545 Mdot
.30754 .50553 Mdot
.30759 .50561 Mdot
.30764 .50568 Mdot
.30769 .50576 Mdot
.30773 .50584 Mdot
.30778 .50591 Mdot
.30783 .50599 Mdot
.30788 .50606 Mdot
.30792 .50614 Mdot
.30797 .50621 Mdot
.30802 .50629 Mdot
.30807 .50636 Mdot
.30811 .50644 Mdot
.30816 .50651 Mdot
.30821 .50659 Mdot
.30826 .50666 Mdot
.3083 .50674 Mdot
.30835 .50681 Mdot
.3084 .50688 Mdot
.30845 .50696 Mdot
.3085 .50703 Mdot
.30854 .5071 Mdot
.30859 .50717 Mdot
.30864 .50725 Mdot
.30869 .50732 Mdot
.30873 .50739 Mdot
.30878 .50746 Mdot
.30883 .50753 Mdot
.30888 .5076 Mdot
.30892 .50767 Mdot
.30897 .50774 Mdot
.30902 .50781 Mdot
.30907 .50788 Mdot
.30911 .50795 Mdot
.30916 .50802 Mdot
.30921 .50809 Mdot
.30926 .50816 Mdot
.3093 .50823 Mdot
.30935 .5083 Mdot
.3094 .50837 Mdot
.30945 .50844 Mdot
.3095 .5085 Mdot
.30954 .50857 Mdot
.30959 .50864 Mdot
.30964 .50871 Mdot
.30969 .50877 Mdot
.30973 .50884 Mdot
.30978 .50891 Mdot
.30983 .50897 Mdot
.30988 .50904 Mdot
.30992 .50911 Mdot
.30997 .50917 Mdot
.31002 .50924 Mdot
.31007 .5093 Mdot
.31011 .50937 Mdot
.31016 .50943 Mdot
.31021 .5095 Mdot
.31026 .50956 Mdot
.3103 .50963 Mdot
.31035 .50969 Mdot
.3104 .50975 Mdot
.31045 .50982 Mdot
.3105 .50988 Mdot
.31054 .50994 Mdot
.31059 .51001 Mdot
.31064 .51007 Mdot
.31069 .51013 Mdot
.31073 .51019 Mdot
.31078 .51025 Mdot
.31083 .51032 Mdot
.31088 .51038 Mdot
.31092 .51044 Mdot
.31097 .5105 Mdot
.31102 .51056 Mdot
.31107 .51062 Mdot
.31111 .51068 Mdot
.31116 .51074 Mdot
.31121 .5108 Mdot
.31126 .51086 Mdot
.3113 .51092 Mdot
.31135 .51098 Mdot
.3114 .51104 Mdot
.31145 .5111 Mdot
.3115 .51115 Mdot
.31154 .51121 Mdot
.31159 .51127 Mdot
.31164 .51133 Mdot
.31169 .51139 Mdot
.31173 .51144 Mdot
.31178 .5115 Mdot
.31183 .51156 Mdot
.31188 .51161 Mdot
.31192 .51167 Mdot
.31197 .51172 Mdot
.31202 .51178 Mdot
.31207 .51184 Mdot
.31211 .51189 Mdot
.31216 .51195 Mdot
.31221 .512 Mdot
.31226 .51206 Mdot
.3123 .51211 Mdot
.31235 .51216 Mdot
.3124 .51222 Mdot
.31245 .51227 Mdot
.31249 .51233 Mdot
.31254 .51238 Mdot
.31259 .51243 Mdot
.31264 .51249 Mdot
.31269 .51254 Mdot
.31273 .51259 Mdot
.31278 .51264 Mdot
.31283 .51269 Mdot
.31288 .51275 Mdot
.31292 .5128 Mdot
.31297 .51285 Mdot
.31302 .5129 Mdot
.31307 .51295 Mdot
.31311 .513 Mdot
.31316 .51305 Mdot
.31321 .5131 Mdot
.31326 .51315 Mdot
.3133 .5132 Mdot
.31335 .51325 Mdot
.3134 .5133 Mdot
.31345 .51335 Mdot
.31349 .5134 Mdot
.31354 .51344 Mdot
.31359 .51349 Mdot
.31364 .51354 Mdot
.31369 .51359 Mdot
.31373 .51364 Mdot
.31378 .51368 Mdot
.31383 .51373 Mdot
.31388 .51378 Mdot
.31392 .51382 Mdot
.31397 .51387 Mdot
.31402 .51392 Mdot
.31407 .51396 Mdot
.31411 .51401 Mdot
.31416 .51405 Mdot
.31421 .5141 Mdot
.31426 .51414 Mdot
.3143 .51419 Mdot
.31435 .51423 Mdot
.3144 .51428 Mdot
.31445 .51432 Mdot
.31449 .51436 Mdot
.31454 .51441 Mdot
.31459 .51445 Mdot
.31464 .51449 Mdot
.31469 .51454 Mdot
.31473 .51458 Mdot
.31478 .51462 Mdot
.31483 .51466 Mdot
.31488 .51471 Mdot
.31492 .51475 Mdot
.31497 .51479 Mdot
.31502 .51483 Mdot
.31507 .51487 Mdot
.31511 .51491 Mdot
.31516 .51495 Mdot
.31521 .51499 Mdot
.31526 .51503 Mdot
.3153 .51507 Mdot
.31535 .51511 Mdot
.3154 .51515 Mdot
.31545 .51519 Mdot
.31549 .51523 Mdot
.31554 .51527 Mdot
.31559 .51531 Mdot
.31564 .51534 Mdot
.31569 .51538 Mdot
.31573 .51542 Mdot
.31578 .51546 Mdot
.31583 .5155 Mdot
.31588 .51553 Mdot
.31592 .51557 Mdot
.31597 .51561 Mdot
.31602 .51564 Mdot
.31607 .51568 Mdot
.31611 .51571 Mdot
.31616 .51575 Mdot
.31621 .51578 Mdot
.31626 .51582 Mdot
.3163 .51585 Mdot
.31635 .51589 Mdot
.3164 .51592 Mdot
.31645 .51596 Mdot
.31649 .51599 Mdot
.31654 .51603 Mdot
.31659 .51606 Mdot
.31664 .51609 Mdot
.31668 .51613 Mdot
.31673 .51616 Mdot
.31678 .51619 Mdot
.31683 .51622 Mdot
.31688 .51626 Mdot
.31692 .51629 Mdot
.31697 .51632 Mdot
.31702 .51635 Mdot
.31707 .51638 Mdot
.31711 .51641 Mdot
.31716 .51644 Mdot
.31721 .51647 Mdot
.31726 .5165 Mdot
.3173 .51653 Mdot
.31735 .51656 Mdot
.3174 .51659 Mdot
.31745 .51662 Mdot
.31749 .51665 Mdot
.31754 .51668 Mdot
.31759 .51671 Mdot
.31764 .51674 Mdot
.31768 .51677 Mdot
.31773 .51679 Mdot
.31778 .51682 Mdot
.31783 .51685 Mdot
.31788 .51688 Mdot
.31792 .5169 Mdot
.31797 .51693 Mdot
.31802 .51696 Mdot
.31807 .51698 Mdot
.31811 .51701 Mdot
.31816 .51703 Mdot
.31821 .51706 Mdot
.31826 .51709 Mdot
.3183 .51711 Mdot
.31835 .51714 Mdot
.3184 .51716 Mdot
.31845 .51718 Mdot
.31849 .51721 Mdot
.31854 .51723 Mdot
.31859 .51726 Mdot
.31864 .51728 Mdot
.31868 .5173 Mdot
.31873 .51733 Mdot
.31878 .51735 Mdot
.31883 .51737 Mdot
.31888 .51739 Mdot
.31892 .51742 Mdot
.31897 .51744 Mdot
.31902 .51746 Mdot
.31907 .51748 Mdot
.31911 .5175 Mdot
.31916 .51752 Mdot
.31921 .51754 Mdot
.31926 .51756 Mdot
.3193 .51758 Mdot
.31935 .5176 Mdot
.3194 .51762 Mdot
.31945 .51764 Mdot
.31949 .51766 Mdot
.31954 .51768 Mdot
.31959 .5177 Mdot
.31964 .51772 Mdot
.31968 .51774 Mdot
.31973 .51776 Mdot
.31978 .51777 Mdot
.31983 .51779 Mdot
.31988 .51781 Mdot
.31992 .51783 Mdot
.31997 .51784 Mdot
.32002 .51786 Mdot
.32007 .51788 Mdot
.32011 .51789 Mdot
.32016 .51791 Mdot
.32021 .51792 Mdot
.32026 .51794 Mdot
.3203 .51795 Mdot
.32035 .51797 Mdot
.3204 .51798 Mdot
.32045 .518 Mdot
.32049 .51801 Mdot
.32054 .51803 Mdot
.32059 .51804 Mdot
.32064 .51806 Mdot
.32068 .51807 Mdot
.32073 .51808 Mdot
.32078 .51809 Mdot
.32083 .51811 Mdot
.32088 .51812 Mdot
.32092 .51813 Mdot
.32097 .51814 Mdot
.32102 .51816 Mdot
.32107 .51817 Mdot
.32111 .51818 Mdot
.32116 .51819 Mdot
.32121 .5182 Mdot
.32126 .51821 Mdot
.3213 .51822 Mdot
.32135 .51823 Mdot
.3214 .51824 Mdot
.32145 .51825 Mdot
.32149 .51826 Mdot
.32154 .51827 Mdot
.32159 .51828 Mdot
.32164 .51829 Mdot
.32168 .5183 Mdot
.32173 .51831 Mdot
.32178 .51831 Mdot
.32183 .51832 Mdot
.32187 .51833 Mdot
.32192 .51834 Mdot
.32197 .51834 Mdot
.32202 .51835 Mdot
.32207 .51836 Mdot
.32211 .51836 Mdot
.32216 .51837 Mdot
.32221 .51838 Mdot
.32226 .51838 Mdot
.3223 .51839 Mdot
.32235 .51839 Mdot
.3224 .5184 Mdot
.32245 .5184 Mdot
.32249 .51841 Mdot
.32254 .51841 Mdot
.32259 .51842 Mdot
.32264 .51842 Mdot
.32268 .51842 Mdot
.32273 .51843 Mdot
.32278 .51843 Mdot
.32283 .51843 Mdot
.32287 .51844 Mdot
.32292 .51844 Mdot
.32297 .51844 Mdot
.32302 .51844 Mdot
.32307 .51844 Mdot
.32311 .51845 Mdot
.32316 .51845 Mdot
.32321 .51845 Mdot
.32326 .51845 Mdot
.3233 .51845 Mdot
.32335 .51845 Mdot
.3234 .51845 Mdot
.32345 .51845 Mdot
.32349 .51845 Mdot
.32354 .51845 Mdot
.32359 .51845 Mdot
.32364 .51845 Mdot
.32368 .51845 Mdot
.32373 .51844 Mdot
.32378 .51844 Mdot
.32383 .51844 Mdot
.32387 .51844 Mdot
.32392 .51844 Mdot
.32397 .51843 Mdot
.32402 .51843 Mdot
.32407 .51843 Mdot
.32411 .51842 Mdot
.32416 .51842 Mdot
.32421 .51842 Mdot
.32426 .51841 Mdot
.3243 .51841 Mdot
.32435 .5184 Mdot
.3244 .5184 Mdot
.32445 .51839 Mdot
.32449 .51839 Mdot
.32454 .51838 Mdot
.32459 .51838 Mdot
.32464 .51837 Mdot
.32468 .51837 Mdot
.32473 .51836 Mdot
.32478 .51835 Mdot
.32483 .51835 Mdot
.32487 .51834 Mdot
.32492 .51833 Mdot
.32497 .51833 Mdot
.32502 .51832 Mdot
.32507 .51831 Mdot
.32511 .5183 Mdot
.32516 .51829 Mdot
.32521 .51828 Mdot
.32526 .51828 Mdot
.3253 .51827 Mdot
.32535 .51826 Mdot
.3254 .51825 Mdot
.32545 .51824 Mdot
.32549 .51823 Mdot
.32554 .51822 Mdot
.32559 .51821 Mdot
.32564 .5182 Mdot
.32568 .51819 Mdot
.32573 .51817 Mdot
.32578 .51816 Mdot
.32583 .51815 Mdot
.32587 .51814 Mdot
.32592 .51813 Mdot
.32597 .51811 Mdot
.32602 .5181 Mdot
.32607 .51809 Mdot
.32611 .51808 Mdot
.32616 .51806 Mdot
.32621 .51805 Mdot
.32626 .51804 Mdot
.3263 .51802 Mdot
.32635 .51801 Mdot
.3264 .51799 Mdot
.32645 .51798 Mdot
.32649 .51796 Mdot
.32654 .51795 Mdot
.32659 .51793 Mdot
.32664 .51792 Mdot
.32668 .5179 Mdot
.32673 .51789 Mdot
.32678 .51787 Mdot
.32683 .51785 Mdot
.32687 .51784 Mdot
.32692 .51782 Mdot
.32697 .5178 Mdot
.32702 .51779 Mdot
.32706 .51777 Mdot
.32711 .51775 Mdot
.32716 .51773 Mdot
.32721 .51771 Mdot
.32726 .51769 Mdot
.3273 .51768 Mdot
.32735 .51766 Mdot
.3274 .51764 Mdot
.32745 .51762 Mdot
.32749 .5176 Mdot
.32754 .51758 Mdot
.32759 .51756 Mdot
.32764 .51754 Mdot
.32768 .51752 Mdot
.32773 .5175 Mdot
.32778 .51748 Mdot
.32783 .51745 Mdot
.32787 .51743 Mdot
.32792 .51741 Mdot
.32797 .51739 Mdot
.32802 .51737 Mdot
.32806 .51734 Mdot
.32811 .51732 Mdot
.32816 .5173 Mdot
.32821 .51728 Mdot
.32826 .51725 Mdot
.3283 .51723 Mdot
.32835 .5172 Mdot
.3284 .51718 Mdot
.32845 .51716 Mdot
.32849 .51713 Mdot
.32854 .51711 Mdot
.32859 .51708 Mdot
.32864 .51706 Mdot
.32868 .51703 Mdot
.32873 .51701 Mdot
.32878 .51698 Mdot
.32883 .51695 Mdot
.32887 .51693 Mdot
.32892 .5169 Mdot
.32897 .51687 Mdot
.32902 .51685 Mdot
.32906 .51682 Mdot
.32911 .51679 Mdot
.32916 .51676 Mdot
.32921 .51674 Mdot
.32926 .51671 Mdot
.3293 .51668 Mdot
.32935 .51665 Mdot
.3294 .51662 Mdot
.32945 .51659 Mdot
.32949 .51656 Mdot
.32954 .51653 Mdot
.32959 .51651 Mdot
.32964 .51648 Mdot
.32968 .51644 Mdot
.32973 .51641 Mdot
.32978 .51638 Mdot
.32983 .51635 Mdot
.32987 .51632 Mdot
.32992 .51629 Mdot
.32997 .51626 Mdot
.33002 .51623 Mdot
.33006 .5162 Mdot
.33011 .51616 Mdot
.33016 .51613 Mdot
.33021 .5161 Mdot
.33026 .51606 Mdot
.3303 .51603 Mdot
.33035 .516 Mdot
.3304 .51596 Mdot
.33045 .51593 Mdot
.33049 .5159 Mdot
.33054 .51586 Mdot
.33059 .51583 Mdot
.33064 .51579 Mdot
.33068 .51576 Mdot
.33073 .51572 Mdot
.33078 .51569 Mdot
.33083 .51565 Mdot
.33087 .51562 Mdot
.33092 .51558 Mdot
.33097 .51554 Mdot
.33102 .51551 Mdot
.33106 .51547 Mdot
.33111 .51543 Mdot
.33116 .5154 Mdot
.33121 .51536 Mdot
.33125 .51532 Mdot
.3313 .51528 Mdot
.33135 .51524 Mdot
.3314 .51521 Mdot
.33145 .51517 Mdot
.33149 .51513 Mdot
.33154 .51509 Mdot
.33159 .51505 Mdot
.33164 .51501 Mdot
.33168 .51497 Mdot
.33173 .51493 Mdot
.33178 .51489 Mdot
.33183 .51485 Mdot
.33187 .51481 Mdot
.33192 .51477 Mdot
.33197 .51473 Mdot
.33202 .51469 Mdot
.33206 .51465 Mdot
.33211 .5146 Mdot
.33216 .51456 Mdot
.33221 .51452 Mdot
.33225 .51448 Mdot
.3323 .51444 Mdot
.33235 .51439 Mdot
.3324 .51435 Mdot
.33245 .51431 Mdot
.33249 .51426 Mdot
.33254 .51422 Mdot
.33259 .51417 Mdot
.33264 .51413 Mdot
.33268 .51409 Mdot
.33273 .51404 Mdot
.33278 .514 Mdot
.33283 .51395 Mdot
.33287 .51391 Mdot
.33292 .51386 Mdot
.33297 .51381 Mdot
.33302 .51377 Mdot
.33306 .51372 Mdot
.33311 .51368 Mdot
.33316 .51363 Mdot
.33321 .51358 Mdot
.33325 .51354 Mdot
.3333 .51349 Mdot
.33335 .51344 Mdot
.3334 .51339 Mdot
.33345 .51334 Mdot
.33349 .5133 Mdot
.33354 .51325 Mdot
.33359 .5132 Mdot
.33364 .51315 Mdot
.33368 .5131 Mdot
.33373 .51305 Mdot
.33378 .513 Mdot
.33383 .51295 Mdot
.33387 .5129 Mdot
.33392 .51285 Mdot
.33397 .5128 Mdot
.33402 .51275 Mdot
.33406 .5127 Mdot
.33411 .51265 Mdot
.33416 .5126 Mdot
.33421 .51255 Mdot
.33425 .5125 Mdot
.3343 .51244 Mdot
.33435 .51239 Mdot
.3344 .51234 Mdot
.33445 .51229 Mdot
.33449 .51223 Mdot
.33454 .51218 Mdot
.33459 .51213 Mdot
.33464 .51207 Mdot
.33468 .51202 Mdot
.33473 .51197 Mdot
.33478 .51191 Mdot
.33483 .51186 Mdot
.33487 .5118 Mdot
.33492 .51175 Mdot
.33497 .51169 Mdot
.33502 .51164 Mdot
.33506 .51158 Mdot
.33511 .51153 Mdot
.33516 .51147 Mdot
.33521 .51141 Mdot
.33525 .51136 Mdot
.3353 .5113 Mdot
.33535 .51124 Mdot
.3354 .51119 Mdot
.33545 .51113 Mdot
.33549 .51107 Mdot
.33554 .51101 Mdot
.33559 .51096 Mdot
.33564 .5109 Mdot
.33568 .51084 Mdot
.33573 .51078 Mdot
.33578 .51072 Mdot
.33583 .51066 Mdot
.33587 .5106 Mdot
.33592 .51054 Mdot
.33597 .51049 Mdot
.33602 .51043 Mdot
.33606 .51037 Mdot
.33611 .5103 Mdot
.33616 .51024 Mdot
.33621 .51018 Mdot
.33625 .51012 Mdot
.3363 .51006 Mdot
.33635 .51 Mdot
.3364 .50994 Mdot
.33644 .50988 Mdot
.33649 .50981 Mdot
.33654 .50975 Mdot
.33659 .50969 Mdot
.33664 .50963 Mdot
.33668 .50956 Mdot
.33673 .5095 Mdot
.33678 .50944 Mdot
.33683 .50937 Mdot
.33687 .50931 Mdot
.33692 .50925 Mdot
.33697 .50918 Mdot
.33702 .50912 Mdot
.33706 .50905 Mdot
.33711 .50899 Mdot
.33716 .50892 Mdot
.33721 .50886 Mdot
.33725 .50879 Mdot
.3373 .50873 Mdot
.33735 .50866 Mdot
.3374 .50859 Mdot
.33744 .50853 Mdot
.33749 .50846 Mdot
.33754 .50839 Mdot
.33759 .50833 Mdot
.33764 .50826 Mdot
.33768 .50819 Mdot
.33773 .50812 Mdot
.33778 .50806 Mdot
.33783 .50799 Mdot
.33787 .50792 Mdot
.33792 .50785 Mdot
.33797 .50778 Mdot
.33802 .50771 Mdot
.33806 .50764 Mdot
.33811 .50758 Mdot
.33816 .50751 Mdot
.33821 .50744 Mdot
.33825 .50737 Mdot
.3383 .5073 Mdot
.33835 .50722 Mdot
.3384 .50715 Mdot
.33844 .50708 Mdot
.33849 .50701 Mdot
.33854 .50694 Mdot
.33859 .50687 Mdot
.33864 .5068 Mdot
.33868 .50673 Mdot
.33873 .50665 Mdot
.33878 .50658 Mdot
.33883 .50651 Mdot
.33887 .50644 Mdot
.33892 .50636 Mdot
.33897 .50629 Mdot
.33902 .50622 Mdot
.33906 .50614 Mdot
.33911 .50607 Mdot
.33916 .50599 Mdot
.33921 .50592 Mdot
.33925 .50584 Mdot
.3393 .50577 Mdot
.33935 .5057 Mdot
.3394 .50562 Mdot
.33944 .50554 Mdot
.33949 .50547 Mdot
.33954 .50539 Mdot
.33959 .50532 Mdot
.33964 .50524 Mdot
.33968 .50516 Mdot
.33973 .50509 Mdot
.33978 .50501 Mdot
.33983 .50493 Mdot
.33987 .50486 Mdot
.33992 .50478 Mdot
.33997 .5047 Mdot
.34002 .50462 Mdot
.34006 .50455 Mdot
.34011 .50447 Mdot
.34016 .50439 Mdot
.34021 .50431 Mdot
.34025 .50423 Mdot
.3403 .50415 Mdot
.34035 .50407 Mdot
.3404 .50399 Mdot
.34044 .50391 Mdot
.34049 .50383 Mdot
.34054 .50375 Mdot
.34059 .50367 Mdot
.34063 .50359 Mdot
.34068 .50351 Mdot
.34073 .50343 Mdot
.34078 .50335 Mdot
.34083 .50327 Mdot
.34087 .50318 Mdot
.34092 .5031 Mdot
.34097 .50302 Mdot
.34102 .50294 Mdot
.34106 .50286 Mdot
.34111 .50277 Mdot
.34116 .50269 Mdot
.34121 .50261 Mdot
.34125 .50252 Mdot
.3413 .50244 Mdot
.34135 .50236 Mdot
.3414 .50227 Mdot
.34144 .50219 Mdot
.34149 .5021 Mdot
.34154 .50202 Mdot
.34159 .50193 Mdot
.34163 .50185 Mdot
.34168 .50176 Mdot
.34173 .50168 Mdot
.34178 .50159 Mdot
.34183 .50151 Mdot
.34187 .50142 Mdot
.34192 .50133 Mdot
.34197 .50125 Mdot
.34202 .50116 Mdot
.34206 .50107 Mdot
.34211 .50099 Mdot
.34216 .5009 Mdot
.34221 .50081 Mdot
.34225 .50072 Mdot
.3423 .50064 Mdot
.34235 .50055 Mdot
.3424 .50046 Mdot
.34244 .50037 Mdot
.34249 .50028 Mdot
.34254 .50019 Mdot
.34259 .50011 Mdot
.34263 .50002 Mdot
.34268 .49993 Mdot
.34273 .49984 Mdot
.34278 .49975 Mdot
.34283 .49966 Mdot
.34287 .49957 Mdot
.34292 .49948 Mdot
.34297 .49938 Mdot
.34302 .49929 Mdot
.34306 .4992 Mdot
.34311 .49911 Mdot
.34316 .49902 Mdot
.34321 .49893 Mdot
.34325 .49884 Mdot
.3433 .49874 Mdot
.34335 .49865 Mdot
.3434 .49856 Mdot
.34344 .49847 Mdot
.34349 .49837 Mdot
.34354 .49828 Mdot
.34359 .49819 Mdot
.34363 .49809 Mdot
.34368 .498 Mdot
.34373 .4979 Mdot
.34378 .49781 Mdot
.34383 .49772 Mdot
.34387 .49762 Mdot
.34392 .49753 Mdot
.34397 .49743 Mdot
.34402 .49734 Mdot
.34406 .49724 Mdot
.34411 .49714 Mdot
.34416 .49705 Mdot
.34421 .49695 Mdot
.34425 .49686 Mdot
.3443 .49676 Mdot
.34435 .49666 Mdot
.3444 .49657 Mdot
.34444 .49647 Mdot
.34449 .49637 Mdot
.34454 .49627 Mdot
.34459 .49618 Mdot
.34463 .49608 Mdot
.34468 .49598 Mdot
.34473 .49588 Mdot
.34478 .49578 Mdot
.34483 .49569 Mdot
.34487 .49559 Mdot
.34492 .49549 Mdot
.34497 .49539 Mdot
.34502 .49529 Mdot
.34506 .49519 Mdot
.34511 .49509 Mdot
.34516 .49499 Mdot
.34521 .49489 Mdot
.34525 .49479 Mdot
.3453 .49469 Mdot
.34535 .49459 Mdot
.3454 .49449 Mdot
.34544 .49438 Mdot
.34549 .49428 Mdot
.34554 .49418 Mdot
.34559 .49408 Mdot
.34563 .49398 Mdot
.34568 .49387 Mdot
.34573 .49377 Mdot
.34578 .49367 Mdot
.34582 .49357 Mdot
.34587 .49346 Mdot
.34592 .49336 Mdot
.34597 .49326 Mdot
.34602 .49315 Mdot
.34606 .49305 Mdot
.34611 .49295 Mdot
.34616 .49284 Mdot
.34621 .49274 Mdot
.34625 .49263 Mdot
.3463 .49253 Mdot
.34635 .49242 Mdot
.3464 .49232 Mdot
.34644 .49221 Mdot
.34649 .49211 Mdot
.34654 .492 Mdot
.34659 .49189 Mdot
.34663 .49179 Mdot
.34668 .49168 Mdot
.34673 .49158 Mdot
.34678 .49147 Mdot
.34682 .49136 Mdot
.34687 .49125 Mdot
.34692 .49115 Mdot
.34697 .49104 Mdot
.34702 .49093 Mdot
.34706 .49082 Mdot
.34711 .49072 Mdot
.34716 .49061 Mdot
.34721 .4905 Mdot
.34725 .49039 Mdot
.3473 .49028 Mdot
.34735 .49017 Mdot
.3474 .49006 Mdot
.34744 .48995 Mdot
.34749 .48984 Mdot
.34754 .48973 Mdot
.34759 .48962 Mdot
.34763 .48951 Mdot
.34768 .4894 Mdot
.34773 .48929 Mdot
.34778 .48918 Mdot
.34782 .48907 Mdot
.34787 .48896 Mdot
.34792 .48885 Mdot
.34797 .48874 Mdot
.34802 .48862 Mdot
.34806 .48851 Mdot
.34811 .4884 Mdot
.34816 .48829 Mdot
.34821 .48818 Mdot
.34825 .48806 Mdot
.3483 .48795 Mdot
.34835 .48784 Mdot
.3484 .48772 Mdot
.34844 .48761 Mdot
.34849 .4875 Mdot
.34854 .48738 Mdot
.34859 .48727 Mdot
.34863 .48715 Mdot
.34868 .48704 Mdot
.34873 .48692 Mdot
.34878 .48681 Mdot
.34882 .48669 Mdot
.34887 .48658 Mdot
.34892 .48646 Mdot
.34897 .48635 Mdot
.34902 .48623 Mdot
.34906 .48612 Mdot
.34911 .486 Mdot
.34916 .48588 Mdot
.34921 .48577 Mdot
.34925 .48565 Mdot
.3493 .48553 Mdot
.34935 .48542 Mdot
.3494 .4853 Mdot
.34944 .48518 Mdot
.34949 .48506 Mdot
.34954 .48495 Mdot
.34959 .48483 Mdot
.34963 .48471 Mdot
.34968 .48459 Mdot
.34973 .48447 Mdot
.34978 .48435 Mdot
.34982 .48424 Mdot
.34987 .48412 Mdot
.34992 .484 Mdot
.34997 .48388 Mdot
.35001 .48376 Mdot
.35006 .48364 Mdot
.35011 .48352 Mdot
.35016 .4834 Mdot
.35021 .48328 Mdot
.35025 .48316 Mdot
.3503 .48304 Mdot
.35035 .48291 Mdot
.3504 .48279 Mdot
.35044 .48267 Mdot
.35049 .48255 Mdot
.35054 .48243 Mdot
.35059 .48231 Mdot
.35063 .48218 Mdot
.35068 .48206 Mdot
.35073 .48194 Mdot
.35078 .48182 Mdot
.35082 .48169 Mdot
.35087 .48157 Mdot
.35092 .48145 Mdot
.35097 .48132 Mdot
.35101 .4812 Mdot
.35106 .48108 Mdot
.35111 .48095 Mdot
.35116 .48083 Mdot
.35121 .48071 Mdot
.35125 .48058 Mdot
.3513 .48046 Mdot
.35135 .48033 Mdot
.3514 .48021 Mdot
.35144 .48008 Mdot
.35149 .47996 Mdot
.35154 .47983 Mdot
.35159 .4797 Mdot
.35163 .47958 Mdot
.35168 .47945 Mdot
.35173 .47933 Mdot
.35178 .4792 Mdot
.35182 .47907 Mdot
.35187 .47895 Mdot
.35192 .47882 Mdot
.35197 .47869 Mdot
.35201 .47856 Mdot
.35206 .47844 Mdot
.35211 .47831 Mdot
.35216 .47818 Mdot
.35221 .47805 Mdot
.35225 .47792 Mdot
.3523 .4778 Mdot
.35235 .47767 Mdot
.3524 .47754 Mdot
.35244 .47741 Mdot
.35249 .47728 Mdot
.35254 .47715 Mdot
.35259 .47702 Mdot
.35263 .47689 Mdot
.35268 .47676 Mdot
.35273 .47663 Mdot
.35278 .4765 Mdot
.35282 .47637 Mdot
.35287 .47624 Mdot
.35292 .47611 Mdot
.35297 .47598 Mdot
.35301 .47585 Mdot
.35306 .47572 Mdot
.35311 .47558 Mdot
.35316 .47545 Mdot
.35321 .47532 Mdot
.35325 .47519 Mdot
.3533 .47506 Mdot
.35335 .47492 Mdot
.3534 .47479 Mdot
.35344 .47466 Mdot
.35349 .47453 Mdot
.35354 .47439 Mdot
.35359 .47426 Mdot
.35363 .47413 Mdot
.35368 .47399 Mdot
.35373 .47386 Mdot
.35378 .47372 Mdot
.35382 .47359 Mdot
.35387 .47346 Mdot
.35392 .47332 Mdot
.35397 .47319 Mdot
.35401 .47305 Mdot
.35406 .47292 Mdot
.35411 .47278 Mdot
.35416 .47265 Mdot
.35421 .47251 Mdot
.35425 .47238 Mdot
.3543 .47224 Mdot
.35435 .4721 Mdot
.3544 .47197 Mdot
.35444 .47183 Mdot
.35449 .47169 Mdot
.35454 .47156 Mdot
.35459 .47142 Mdot
.35463 .47128 Mdot
.35468 .47115 Mdot
.35473 .47101 Mdot
.35478 .47087 Mdot
.35482 .47073 Mdot
.35487 .4706 Mdot
.35492 .47046 Mdot
.35497 .47032 Mdot
.35501 .47018 Mdot
.35506 .47004 Mdot
.35511 .4699 Mdot
.35516 .46977 Mdot
.3552 .46963 Mdot
.35525 .46949 Mdot
.3553 .46935 Mdot
.35535 .46921 Mdot
.3554 .46907 Mdot
.35544 .46893 Mdot
.35549 .46879 Mdot
.35554 .46865 Mdot
.35559 .46851 Mdot
.35563 .46837 Mdot
.35568 .46823 Mdot
.35573 .46808 Mdot
.35578 .46794 Mdot
.35582 .4678 Mdot
.35587 .46766 Mdot
.35592 .46752 Mdot
.35597 .46738 Mdot
.35601 .46724 Mdot
.35606 .46709 Mdot
.35611 .46695 Mdot
.35616 .46681 Mdot
.3562 .46667 Mdot
.35625 .46652 Mdot
.3563 .46638 Mdot
.35635 .46624 Mdot
.3564 .46609 Mdot
.35644 .46595 Mdot
.35649 .46581 Mdot
.35654 .46566 Mdot
.35659 .46552 Mdot
.35663 .46537 Mdot
.35668 .46523 Mdot
.35673 .46509 Mdot
.35678 .46494 Mdot
.35682 .4648 Mdot
.35687 .46465 Mdot
.35692 .46451 Mdot
.35697 .46436 Mdot
.35701 .46422 Mdot
.35706 .46407 Mdot
.35711 .46392 Mdot
.35716 .46378 Mdot
.3572 .46363 Mdot
.35725 .46349 Mdot
.3573 .46334 Mdot
.35735 .46319 Mdot
.3574 .46305 Mdot
.35744 .4629 Mdot
.35749 .46275 Mdot
.35754 .4626 Mdot
.35759 .46246 Mdot
.35763 .46231 Mdot
.35768 .46216 Mdot
.35773 .46201 Mdot
.35778 .46187 Mdot
.35782 .46172 Mdot
.35787 .46157 Mdot
.35792 .46142 Mdot
.35797 .46127 Mdot
.35801 .46112 Mdot
.35806 .46097 Mdot
.35811 .46082 Mdot
.35816 .46068 Mdot
.3582 .46053 Mdot
.35825 .46038 Mdot
.3583 .46023 Mdot
.35835 .46008 Mdot
.3584 .45993 Mdot
.35844 .45978 Mdot
.35849 .45963 Mdot
.35854 .45948 Mdot
.35859 .45932 Mdot
.35863 .45917 Mdot
.35868 .45902 Mdot
.35873 .45887 Mdot
.35878 .45872 Mdot
.35882 .45857 Mdot
.35887 .45842 Mdot
.35892 .45826 Mdot
.35897 .45811 Mdot
.35901 .45796 Mdot
.35906 .45781 Mdot
.35911 .45766 Mdot
.35916 .4575 Mdot
.3592 .45735 Mdot
.35925 .4572 Mdot
.3593 .45704 Mdot
.35935 .45689 Mdot
.3594 .45674 Mdot
.35944 .45658 Mdot
.35949 .45643 Mdot
.35954 .45628 Mdot
.35959 .45612 Mdot
.35963 .45597 Mdot
.35968 .45581 Mdot
.35973 .45566 Mdot
.35978 .4555 Mdot
.35982 .45535 Mdot
.35987 .45519 Mdot
.35992 .45504 Mdot
.35997 .45488 Mdot
.36001 .45473 Mdot
.36006 .45457 Mdot
.36011 .45442 Mdot
.36016 .45426 Mdot
.3602 .45411 Mdot
.36025 .45395 Mdot
.3603 .45379 Mdot
.36035 .45364 Mdot
.36039 .45348 Mdot
.36044 .45332 Mdot
.36049 .45317 Mdot
.36054 .45301 Mdot
.36059 .45285 Mdot
.36063 .45269 Mdot
.36068 .45254 Mdot
.36073 .45238 Mdot
.36078 .45222 Mdot
.36082 .45206 Mdot
.36087 .4519 Mdot
.36092 .45175 Mdot
.36097 .45159 Mdot
.36101 .45143 Mdot
.36106 .45127 Mdot
.36111 .45111 Mdot
.36116 .45095 Mdot
.3612 .45079 Mdot
.36125 .45063 Mdot
.3613 .45047 Mdot
.36135 .45031 Mdot
.36139 .45015 Mdot
.36144 .44999 Mdot
.36149 .44983 Mdot
.36154 .44967 Mdot
.36159 .44951 Mdot
.36163 .44935 Mdot
.36168 .44919 Mdot
.36173 .44903 Mdot
.36178 .44887 Mdot
.36182 .44871 Mdot
.36187 .44855 Mdot
.36192 .44839 Mdot
.36197 .44823 Mdot
.36201 .44806 Mdot
.36206 .4479 Mdot
.36211 .44774 Mdot
.36216 .44758 Mdot
.3622 .44742 Mdot
.36225 .44725 Mdot
.3623 .44709 Mdot
.36235 .44693 Mdot
.36239 .44676 Mdot
.36244 .4466 Mdot
.36249 .44644 Mdot
.36254 .44628 Mdot
.36259 .44611 Mdot
.36263 .44595 Mdot
.36268 .44578 Mdot
.36273 .44562 Mdot
.36278 .44546 Mdot
.36282 .44529 Mdot
.36287 .44513 Mdot
.36292 .44496 Mdot
.36297 .4448 Mdot
.36301 .44463 Mdot
.36306 .44447 Mdot
.36311 .4443 Mdot
.36316 .44414 Mdot
.3632 .44397 Mdot
.36325 .44381 Mdot
.3633 .44364 Mdot
.36335 .44348 Mdot
.36339 .44331 Mdot
.36344 .44314 Mdot
.36349 .44298 Mdot
.36354 .44281 Mdot
.36359 .44265 Mdot
.36363 .44248 Mdot
.36368 .44231 Mdot
.36373 .44215 Mdot
.36378 .44198 Mdot
.36382 .44181 Mdot
.36387 .44164 Mdot
.36392 .44148 Mdot
.36397 .44131 Mdot
.36401 .44114 Mdot
.36406 .44097 Mdot
.36411 .44081 Mdot
.36416 .44064 Mdot
.3642 .44047 Mdot
.36425 .4403 Mdot
.3643 .44013 Mdot
.36435 .43996 Mdot
.36439 .43979 Mdot
.36444 .43963 Mdot
.36449 .43946 Mdot
.36454 .43929 Mdot
.36458 .43912 Mdot
.36463 .43895 Mdot
.36468 .43878 Mdot
.36473 .43861 Mdot
.36478 .43844 Mdot
.36482 .43827 Mdot
.36487 .4381 Mdot
.36492 .43793 Mdot
.36497 .43776 Mdot
.36501 .43759 Mdot
.36506 .43742 Mdot
.36511 .43725 Mdot
.36516 .43708 Mdot
.3652 .4369 Mdot
.36525 .43673 Mdot
.3653 .43656 Mdot
.36535 .43639 Mdot
.36539 .43622 Mdot
.36544 .43605 Mdot
.36549 .43588 Mdot
.36554 .4357 Mdot
.36558 .43553 Mdot
.36563 .43536 Mdot
.36568 .43519 Mdot
.36573 .43501 Mdot
.36578 .43484 Mdot
.36582 .43467 Mdot
.36587 .4345 Mdot
.36592 .43432 Mdot
.36597 .43415 Mdot
.36601 .43398 Mdot
.36606 .4338 Mdot
.36611 .43363 Mdot
.36616 .43345 Mdot
.3662 .43328 Mdot
.36625 .43311 Mdot
.3663 .43293 Mdot
.36635 .43276 Mdot
.36639 .43258 Mdot
.36644 .43241 Mdot
.36649 .43223 Mdot
.36654 .43206 Mdot
.36658 .43188 Mdot
.36663 .43171 Mdot
.36668 .43153 Mdot
.36673 .43136 Mdot
.36678 .43118 Mdot
.36682 .43101 Mdot
.36687 .43083 Mdot
.36692 .43066 Mdot
.36697 .43048 Mdot
.36701 .4303 Mdot
.36706 .43013 Mdot
.36711 .42995 Mdot
.36716 .42978 Mdot
.3672 .4296 Mdot
.36725 .42942 Mdot
.3673 .42925 Mdot
.36735 .42907 Mdot
.36739 .42889 Mdot
.36744 .42871 Mdot
.36749 .42854 Mdot
.36754 .42836 Mdot
.36758 .42818 Mdot
.36763 .428 Mdot
.36768 .42783 Mdot
.36773 .42765 Mdot
.36778 .42747 Mdot
.36782 .42729 Mdot
.36787 .42711 Mdot
.36792 .42694 Mdot
.36797 .42676 Mdot
.36801 .42658 Mdot
.36806 .4264 Mdot
.36811 .42622 Mdot
.36816 .42604 Mdot
.3682 .42586 Mdot
.36825 .42568 Mdot
.3683 .4255 Mdot
.36835 .42532 Mdot
.36839 .42514 Mdot
.36844 .42496 Mdot
.36849 .42479 Mdot
.36854 .42461 Mdot
.36858 .42442 Mdot
.36863 .42424 Mdot
.36868 .42406 Mdot
.36873 .42388 Mdot
.36878 .4237 Mdot
.36882 .42352 Mdot
.36887 .42334 Mdot
.36892 .42316 Mdot
.36897 .42298 Mdot
.36901 .4228 Mdot
.36906 .42262 Mdot
.36911 .42244 Mdot
.36916 .42225 Mdot
.3692 .42207 Mdot
.36925 .42189 Mdot
.3693 .42171 Mdot
.36935 .42153 Mdot
.36939 .42134 Mdot
.36944 .42116 Mdot
.36949 .42098 Mdot
.36954 .4208 Mdot
.36958 .42061 Mdot
.36963 .42043 Mdot
.36968 .42025 Mdot
.36973 .42007 Mdot
.36977 .41988 Mdot
.36982 .4197 Mdot
.36987 .41952 Mdot
.36992 .41933 Mdot
.36997 .41915 Mdot
.37001 .41897 Mdot
.37006 .41878 Mdot
.37011 .4186 Mdot
.37016 .41841 Mdot
.3702 .41823 Mdot
.37025 .41805 Mdot
.3703 .41786 Mdot
.37035 .41768 Mdot
.37039 .41749 Mdot
.37044 .41731 Mdot
.37049 .41712 Mdot
.37054 .41694 Mdot
.37058 .41675 Mdot
.37063 .41657 Mdot
.37068 .41638 Mdot
.37073 .4162 Mdot
.37077 .41601 Mdot
.37082 .41583 Mdot
.37087 .41564 Mdot
.37092 .41545 Mdot
.37097 .41527 Mdot
.37101 .41508 Mdot
.37106 .4149 Mdot
.37111 .41471 Mdot
.37116 .41452 Mdot
.3712 .41434 Mdot
.37125 .41415 Mdot
.3713 .41396 Mdot
.37135 .41378 Mdot
.37139 .41359 Mdot
.37144 .4134 Mdot
.37149 .41322 Mdot
.37154 .41303 Mdot
.37158 .41284 Mdot
.37163 .41265 Mdot
.37168 .41247 Mdot
.37173 .41228 Mdot
.37177 .41209 Mdot
.37182 .4119 Mdot
.37187 .41171 Mdot
.37192 .41153 Mdot
.37197 .41134 Mdot
.37201 .41115 Mdot
.37206 .41096 Mdot
.37211 .41077 Mdot
.37216 .41058 Mdot
.3722 .4104 Mdot
.37225 .41021 Mdot
.3723 .41002 Mdot
.37235 .40983 Mdot
.37239 .40964 Mdot
.37244 .40945 Mdot
.37249 .40926 Mdot
.37254 .40907 Mdot
.37258 .40888 Mdot
.37263 .40869 Mdot
.37268 .4085 Mdot
.37273 .40831 Mdot
.37277 .40812 Mdot
.37282 .40793 Mdot
.37287 .40774 Mdot
.37292 .40755 Mdot
.37297 .40736 Mdot
.37301 .40717 Mdot
.37306 .40698 Mdot
.37311 .40679 Mdot
.37316 .4066 Mdot
.3732 .40641 Mdot
.37325 .40622 Mdot
.3733 .40603 Mdot
.37335 .40583 Mdot
.37339 .40564 Mdot
.37344 .40545 Mdot
.37349 .40526 Mdot
.37354 .40507 Mdot
.37358 .40488 Mdot
.37363 .40469 Mdot
.37368 .40449 Mdot
.37373 .4043 Mdot
.37377 .40411 Mdot
.37382 .40392 Mdot
.37387 .40372 Mdot
.37392 .40353 Mdot
.37396 .40334 Mdot
.37401 .40315 Mdot
.37406 .40295 Mdot
.37411 .40276 Mdot
.37416 .40257 Mdot
.3742 .40238 Mdot
.37425 .40218 Mdot
.3743 .40199 Mdot
.37435 .4018 Mdot
.37439 .4016 Mdot
.37444 .40141 Mdot
.37449 .40122 Mdot
.37454 .40102 Mdot
.37458 .40083 Mdot
.37463 .40063 Mdot
.37468 .40044 Mdot
.37473 .40025 Mdot
.37477 .40005 Mdot
.37482 .39986 Mdot
.37487 .39966 Mdot
.37492 .39947 Mdot
.37496 .39927 Mdot
.37501 .39908 Mdot
.37506 .39889 Mdot
.37511 .39869 Mdot
.37516 .3985 Mdot
.3752 .3983 Mdot
.37525 .39811 Mdot
.3753 .39791 Mdot
.37535 .39772 Mdot
.37539 .39752 Mdot
.37544 .39732 Mdot
.37549 .39713 Mdot
.37554 .39693 Mdot
.37558 .39674 Mdot
.37563 .39654 Mdot
.37568 .39635 Mdot
.37573 .39615 Mdot
.37577 .39595 Mdot
.37582 .39576 Mdot
.37587 .39556 Mdot
.37592 .39536 Mdot
.37596 .39517 Mdot
.37601 .39497 Mdot
.37606 .39477 Mdot
.37611 .39458 Mdot
.37616 .39438 Mdot
.3762 .39418 Mdot
.37625 .39399 Mdot
.3763 .39379 Mdot
.37635 .39359 Mdot
.37639 .3934 Mdot
.37644 .3932 Mdot
.37649 .393 Mdot
.37654 .3928 Mdot
.37658 .39261 Mdot
.37663 .39241 Mdot
.37668 .39221 Mdot
.37673 .39201 Mdot
.37677 .39181 Mdot
.37682 .39162 Mdot
.37687 .39142 Mdot
.37692 .39122 Mdot
.37696 .39102 Mdot
.37701 .39082 Mdot
.37706 .39063 Mdot
.37711 .39043 Mdot
.37716 .39023 Mdot
.3772 .39003 Mdot
.37725 .38983 Mdot
.3773 .38963 Mdot
.37735 .38943 Mdot
.37739 .38923 Mdot
.37744 .38903 Mdot
.37749 .38884 Mdot
.37754 .38864 Mdot
.37758 .38844 Mdot
.37763 .38824 Mdot
.37768 .38804 Mdot
.37773 .38784 Mdot
.37777 .38764 Mdot
.37782 .38744 Mdot
.37787 .38724 Mdot
.37792 .38704 Mdot
.37796 .38684 Mdot
.37801 .38664 Mdot
.37806 .38644 Mdot
.37811 .38624 Mdot
.37816 .38604 Mdot
.3782 .38584 Mdot
.37825 .38564 Mdot
.3783 .38544 Mdot
.37835 .38524 Mdot
.37839 .38503 Mdot
.37844 .38483 Mdot
.37849 .38463 Mdot
.37854 .38443 Mdot
.37858 .38423 Mdot
.37863 .38403 Mdot
.37868 .38383 Mdot
.37873 .38363 Mdot
.37877 .38343 Mdot
.37882 .38322 Mdot
.37887 .38302 Mdot
.37892 .38282 Mdot
.37896 .38262 Mdot
.37901 .38242 Mdot
.37906 .38222 Mdot
.37911 .38201 Mdot
.37915 .38181 Mdot
.3792 .38161 Mdot
.37925 .38141 Mdot
.3793 .38121 Mdot
.37935 .381 Mdot
.37939 .3808 Mdot
.37944 .3806 Mdot
.37949 .3804 Mdot
.37954 .38019 Mdot
.37958 .37999 Mdot
.37963 .37979 Mdot
.37968 .37958 Mdot
.37973 .37938 Mdot
.37977 .37918 Mdot
.37982 .37898 Mdot
.37987 .37877 Mdot
.37992 .37857 Mdot
.37996 .37837 Mdot
.38001 .37816 Mdot
.38006 .37796 Mdot
.38011 .37776 Mdot
.38015 .37755 Mdot
.3802 .37735 Mdot
.38025 .37714 Mdot
.3803 .37694 Mdot
.38035 .37674 Mdot
.38039 .37653 Mdot
.38044 .37633 Mdot
.38049 .37613 Mdot
.38054 .37592 Mdot
.38058 .37572 Mdot
.38063 .37551 Mdot
.38068 .37531 Mdot
.38073 .3751 Mdot
.38077 .3749 Mdot
.38082 .3747 Mdot
.38087 .37449 Mdot
.38092 .37429 Mdot
.38096 .37408 Mdot
.38101 .37388 Mdot
.38106 .37367 Mdot
.38111 .37347 Mdot
.38115 .37326 Mdot
.3812 .37306 Mdot
.38125 .37285 Mdot
.3813 .37265 Mdot
.38135 .37244 Mdot
.38139 .37224 Mdot
.38144 .37203 Mdot
.38149 .37182 Mdot
.38154 .37162 Mdot
.38158 .37141 Mdot
.38163 .37121 Mdot
.38168 .371 Mdot
.38173 .3708 Mdot
.38177 .37059 Mdot
.38182 .37038 Mdot
.38187 .37018 Mdot
.38192 .36997 Mdot
.38196 .36977 Mdot
.38201 .36956 Mdot
.38206 .36935 Mdot
.38211 .36915 Mdot
.38215 .36894 Mdot
.3822 .36874 Mdot
.38225 .36853 Mdot
.3823 .36832 Mdot
.38235 .36812 Mdot
.38239 .36791 Mdot
.38244 .3677 Mdot
.38249 .3675 Mdot
.38254 .36729 Mdot
.38258 .36708 Mdot
.38263 .36687 Mdot
.38268 .36667 Mdot
.38273 .36646 Mdot
.38277 .36625 Mdot
.38282 .36605 Mdot
.38287 .36584 Mdot
.38292 .36563 Mdot
.38296 .36542 Mdot
.38301 .36522 Mdot
.38306 .36501 Mdot
.38311 .3648 Mdot
.38315 .36459 Mdot
.3832 .36439 Mdot
.38325 .36418 Mdot
.3833 .36397 Mdot
.38334 .36376 Mdot
.38339 .36355 Mdot
.38344 .36335 Mdot
.38349 .36314 Mdot
.38354 .36293 Mdot
.38358 .36272 Mdot
.38363 .36251 Mdot
.38368 .36231 Mdot
.38373 .3621 Mdot
.38377 .36189 Mdot
.38382 .36168 Mdot
.38387 .36147 Mdot
.38392 .36126 Mdot
.38396 .36106 Mdot
.38401 .36085 Mdot
.38406 .36064 Mdot
.38411 .36043 Mdot
.38415 .36022 Mdot
.3842 .36001 Mdot
.38425 .3598 Mdot
.3843 .35959 Mdot
.38434 .35938 Mdot
.38439 .35918 Mdot
.38444 .35897 Mdot
.38449 .35876 Mdot
.38454 .35855 Mdot
.38458 .35834 Mdot
.38463 .35813 Mdot
.38468 .35792 Mdot
.38473 .35771 Mdot
.38477 .3575 Mdot
.38482 .35729 Mdot
.38487 .35708 Mdot
.38492 .35687 Mdot
.38496 .35666 Mdot
.38501 .35645 Mdot
.38506 .35624 Mdot
.38511 .35603 Mdot
.38515 .35582 Mdot
.3852 .35561 Mdot
.38525 .3554 Mdot
.3853 .35519 Mdot
.38534 .35498 Mdot
.38539 .35477 Mdot
.38544 .35456 Mdot
.38549 .35435 Mdot
.38554 .35414 Mdot
.38558 .35393 Mdot
.38563 .35372 Mdot
.38568 .35351 Mdot
.38573 .3533 Mdot
.38577 .35309 Mdot
.38582 .35288 Mdot
.38587 .35267 Mdot
.38592 .35246 Mdot
.38596 .35225 Mdot
.38601 .35204 Mdot
.38606 .35183 Mdot
.38611 .35162 Mdot
.38615 .35141 Mdot
.3862 .35119 Mdot
.38625 .35098 Mdot
.3863 .35077 Mdot
.38634 .35056 Mdot
.38639 .35035 Mdot
.38644 .35014 Mdot
.38649 .34993 Mdot
.38654 .34972 Mdot
.38658 .34951 Mdot
.38663 .34929 Mdot
.38668 .34908 Mdot
.38673 .34887 Mdot
.38677 .34866 Mdot
.38682 .34845 Mdot
.38687 .34824 Mdot
.38692 .34803 Mdot
.38696 .34781 Mdot
.38701 .3476 Mdot
.38706 .34739 Mdot
.38711 .34718 Mdot
.38715 .34697 Mdot
.3872 .34676 Mdot
.38725 .34654 Mdot
.3873 .34633 Mdot
.38734 .34612 Mdot
.38739 .34591 Mdot
.38744 .3457 Mdot
.38749 .34548 Mdot
.38754 .34527 Mdot
.38758 .34506 Mdot
.38763 .34485 Mdot
.38768 .34464 Mdot
.38773 .34442 Mdot
.38777 .34421 Mdot
.38782 .344 Mdot
.38787 .34379 Mdot
.38792 .34357 Mdot
.38796 .34336 Mdot
.38801 .34315 Mdot
.38806 .34294 Mdot
.38811 .34272 Mdot
.38815 .34251 Mdot
.3882 .3423 Mdot
.38825 .34209 Mdot
.3883 .34187 Mdot
.38834 .34166 Mdot
.38839 .34145 Mdot
.38844 .34124 Mdot
.38849 .34102 Mdot
.38853 .34081 Mdot
.38858 .3406 Mdot
.38863 .34039 Mdot
.38868 .34017 Mdot
.38873 .33996 Mdot
.38877 .33975 Mdot
.38882 .33953 Mdot
.38887 .33932 Mdot
.38892 .33911 Mdot
.38896 .33889 Mdot
.38901 .33868 Mdot
.38906 .33847 Mdot
.38911 .33825 Mdot
.38915 .33804 Mdot
.3892 .33783 Mdot
.38925 .33761 Mdot
.3893 .3374 Mdot
.38934 .33719 Mdot
.38939 .33697 Mdot
.38944 .33676 Mdot
.38949 .33655 Mdot
.38953 .33633 Mdot
.38958 .33612 Mdot
.38963 .33591 Mdot
.38968 .33569 Mdot
.38973 .33548 Mdot
.38977 .33527 Mdot
.38982 .33505 Mdot
.38987 .33484 Mdot
.38992 .33463 Mdot
.38996 .33441 Mdot
.39001 .3342 Mdot
.39006 .33398 Mdot
.39011 .33377 Mdot
.39015 .33356 Mdot
.3902 .33334 Mdot
.39025 .33313 Mdot
.3903 .33292 Mdot
.39034 .3327 Mdot
.39039 .33249 Mdot
.39044 .33227 Mdot
.39049 .33206 Mdot
.39053 .33185 Mdot
.39058 .33163 Mdot
.39063 .33142 Mdot
.39068 .3312 Mdot
.39073 .33099 Mdot
.39077 .33077 Mdot
.39082 .33056 Mdot
.39087 .33035 Mdot
.39092 .33013 Mdot
.39096 .32992 Mdot
.39101 .3297 Mdot
.39106 .32949 Mdot
.39111 .32927 Mdot
.39115 .32906 Mdot
.3912 .32885 Mdot
.39125 .32863 Mdot
.3913 .32842 Mdot
.39134 .3282 Mdot
.39139 .32799 Mdot
.39144 .32777 Mdot
.39149 .32756 Mdot
.39153 .32735 Mdot
.39158 .32713 Mdot
.39163 .32692 Mdot
.39168 .3267 Mdot
.39173 .32649 Mdot
.39177 .32627 Mdot
.39182 .32606 Mdot
.39187 .32584 Mdot
.39192 .32563 Mdot
.39196 .32541 Mdot
.39201 .3252 Mdot
.39206 .32498 Mdot
.39211 .32477 Mdot
.39215 .32455 Mdot
.3922 .32434 Mdot
.39225 .32413 Mdot
.3923 .32391 Mdot
.39234 .3237 Mdot
.39239 .32348 Mdot
.39244 .32327 Mdot
.39249 .32305 Mdot
.39253 .32284 Mdot
.39258 .32262 Mdot
.39263 .32241 Mdot
.39268 .32219 Mdot
.39273 .32198 Mdot
.39277 .32176 Mdot
.39282 .32155 Mdot
.39287 .32133 Mdot
.39292 .32112 Mdot
.39296 .3209 Mdot
.39301 .32069 Mdot
.39306 .32047 Mdot
.39311 .32026 Mdot
.39315 .32004 Mdot
.3932 .31983 Mdot
.39325 .31961 Mdot
.3933 .3194 Mdot
.39334 .31918 Mdot
.39339 .31897 Mdot
.39344 .31875 Mdot
.39349 .31854 Mdot
.39353 .31832 Mdot
.39358 .31811 Mdot
.39363 .31789 Mdot
.39368 .31768 Mdot
.39372 .31746 Mdot
.39377 .31724 Mdot
.39382 .31703 Mdot
.39387 .31681 Mdot
.39392 .3166 Mdot
.39396 .31638 Mdot
.39401 .31617 Mdot
.39406 .31595 Mdot
.39411 .31574 Mdot
.39415 .31552 Mdot
.3942 .31531 Mdot
.39425 .31509 Mdot
.3943 .31488 Mdot
.39434 .31466 Mdot
.39439 .31445 Mdot
.39444 .31423 Mdot
.39449 .31402 Mdot
.39453 .3138 Mdot
.39458 .31358 Mdot
.39463 .31337 Mdot
.39468 .31315 Mdot
.39472 .31294 Mdot
.39477 .31272 Mdot
.39482 .31251 Mdot
.39487 .31229 Mdot
.39492 .31208 Mdot
.39496 .31186 Mdot
.39501 .31165 Mdot
.39506 .31143 Mdot
.39511 .31122 Mdot
.39515 .311 Mdot
.3952 .31079 Mdot
.39525 .31057 Mdot
.3953 .31035 Mdot
.39534 .31014 Mdot
.39539 .30992 Mdot
.39544 .30971 Mdot
.39549 .30949 Mdot
.39553 .30928 Mdot
.39558 .30906 Mdot
.39563 .30885 Mdot
.39568 .30863 Mdot
.39572 .30842 Mdot
.39577 .3082 Mdot
.39582 .30798 Mdot
.39587 .30777 Mdot
.39592 .30755 Mdot
.39596 .30734 Mdot
.39601 .30712 Mdot
.39606 .30691 Mdot
.39611 .30669 Mdot
.39615 .30648 Mdot
.3962 .30626 Mdot
.39625 .30605 Mdot
.3963 .30583 Mdot
.39634 .30561 Mdot
.39639 .3054 Mdot
.39644 .30518 Mdot
.39649 .30497 Mdot
.39653 .30475 Mdot
.39658 .30454 Mdot
.39663 .30432 Mdot
.39668 .30411 Mdot
.39672 .30389 Mdot
.39677 .30368 Mdot
.39682 .30346 Mdot
.39687 .30325 Mdot
.39692 .30303 Mdot
.39696 .30281 Mdot
.39701 .3026 Mdot
.39706 .30238 Mdot
.39711 .30217 Mdot
.39715 .30195 Mdot
.3972 .30174 Mdot
.39725 .30152 Mdot
.3973 .30131 Mdot
.39734 .30109 Mdot
.39739 .30088 Mdot
.39744 .30066 Mdot
.39749 .30045 Mdot
.39753 .30023 Mdot
.39758 .30002 Mdot
.39763 .2998 Mdot
.39768 .29958 Mdot
.39772 .29937 Mdot
.39777 .29915 Mdot
.39782 .29894 Mdot
.39787 .29872 Mdot
.39791 .29851 Mdot
.39796 .29829 Mdot
.39801 .29808 Mdot
.39806 .29786 Mdot
.39811 .29765 Mdot
.39815 .29743 Mdot
.3982 .29722 Mdot
.39825 .297 Mdot
.3983 .29679 Mdot
.39834 .29657 Mdot
.39839 .29636 Mdot
.39844 .29614 Mdot
.39849 .29593 Mdot
.39853 .29571 Mdot
.39858 .2955 Mdot
.39863 .29528 Mdot
.39868 .29507 Mdot
.39872 .29485 Mdot
.39877 .29464 Mdot
.39882 .29442 Mdot
.39887 .29421 Mdot
.39891 .29399 Mdot
.39896 .29378 Mdot
.39901 .29356 Mdot
.39906 .29335 Mdot
.39911 .29313 Mdot
.39915 .29292 Mdot
.3992 .2927 Mdot
.39925 .29249 Mdot
.3993 .29227 Mdot
.39934 .29206 Mdot
.39939 .29184 Mdot
.39944 .29163 Mdot
.39949 .29141 Mdot
.39953 .2912 Mdot
.39958 .29098 Mdot
.39963 .29077 Mdot
.39968 .29055 Mdot
.39972 .29034 Mdot
.39977 .29012 Mdot
.39982 .28991 Mdot
.39987 .28969 Mdot
.39991 .28948 Mdot
.39996 .28926 Mdot
.40001 .28905 Mdot
.40006 .28883 Mdot
.40011 .28862 Mdot
.40015 .28841 Mdot
.4002 .28819 Mdot
.40025 .28798 Mdot
.4003 .28776 Mdot
.40034 .28755 Mdot
.40039 .28733 Mdot
.40044 .28712 Mdot
.40049 .2869 Mdot
.40053 .28669 Mdot
.40058 .28647 Mdot
.40063 .28626 Mdot
.40068 .28605 Mdot
.40072 .28583 Mdot
.40077 .28562 Mdot
.40082 .2854 Mdot
.40087 .28519 Mdot
.40091 .28497 Mdot
.40096 .28476 Mdot
.40101 .28455 Mdot
.40106 .28433 Mdot
.40111 .28412 Mdot
.40115 .2839 Mdot
.4012 .28369 Mdot
.40125 .28347 Mdot
.4013 .28326 Mdot
.40134 .28305 Mdot
.40139 .28283 Mdot
.40144 .28262 Mdot
.40149 .2824 Mdot
.40153 .28219 Mdot
.40158 .28198 Mdot
.40163 .28176 Mdot
.40168 .28155 Mdot
.40172 .28134 Mdot
.40177 .28112 Mdot
.40182 .28091 Mdot
.40187 .28069 Mdot
.40191 .28048 Mdot
.40196 .28027 Mdot
.40201 .28005 Mdot
.40206 .27984 Mdot
.40211 .27963 Mdot
.40215 .27941 Mdot
.4022 .2792 Mdot
.40225 .27898 Mdot
.4023 .27877 Mdot
.40234 .27856 Mdot
.40239 .27834 Mdot
.40244 .27813 Mdot
.40249 .27792 Mdot
.40253 .2777 Mdot
.40258 .27749 Mdot
.40263 .27728 Mdot
.40268 .27706 Mdot
.40272 .27685 Mdot
.40277 .27664 Mdot
.40282 .27642 Mdot
.40287 .27621 Mdot
.40291 .276 Mdot
.40296 .27578 Mdot
.40301 .27557 Mdot
.40306 .27536 Mdot
.4031 .27515 Mdot
.40315 .27493 Mdot
.4032 .27472 Mdot
.40325 .27451 Mdot
.4033 .27429 Mdot
.40334 .27408 Mdot
.40339 .27387 Mdot
.40344 .27366 Mdot
.40349 .27344 Mdot
.40353 .27323 Mdot
.40358 .27302 Mdot
.40363 .2728 Mdot
.40368 .27259 Mdot
.40372 .27238 Mdot
.40377 .27217 Mdot
.40382 .27195 Mdot
.40387 .27174 Mdot
.40391 .27153 Mdot
.40396 .27132 Mdot
.40401 .2711 Mdot
.40406 .27089 Mdot
.4041 .27068 Mdot
.40415 .27047 Mdot
.4042 .27026 Mdot
.40425 .27004 Mdot
.4043 .26983 Mdot
.40434 .26962 Mdot
.40439 .26941 Mdot
.40444 .26919 Mdot
.40449 .26898 Mdot
.40453 .26877 Mdot
.40458 .26856 Mdot
.40463 .26835 Mdot
.40468 .26814 Mdot
.40472 .26792 Mdot
.40477 .26771 Mdot
.40482 .2675 Mdot
.40487 .26729 Mdot
.40491 .26708 Mdot
.40496 .26686 Mdot
.40501 .26665 Mdot
.40506 .26644 Mdot
.4051 .26623 Mdot
.40515 .26602 Mdot
.4052 .26581 Mdot
.40525 .2656 Mdot
.4053 .26538 Mdot
.40534 .26517 Mdot
.40539 .26496 Mdot
.40544 .26475 Mdot
.40549 .26454 Mdot
.40553 .26433 Mdot
.40558 .26412 Mdot
.40563 .26391 Mdot
.40568 .2637 Mdot
.40572 .26348 Mdot
.40577 .26327 Mdot
.40582 .26306 Mdot
.40587 .26285 Mdot
.40591 .26264 Mdot
.40596 .26243 Mdot
.40601 .26222 Mdot
.40606 .26201 Mdot
.4061 .2618 Mdot
.40615 .26159 Mdot
.4062 .26138 Mdot
.40625 .26117 Mdot
.4063 .26096 Mdot
.40634 .26075 Mdot
.40639 .26054 Mdot
.40644 .26033 Mdot
.40649 .26012 Mdot
.40653 .25991 Mdot
.40658 .2597 Mdot
.40663 .25949 Mdot
.40668 .25928 Mdot
.40672 .25907 Mdot
.40677 .25886 Mdot
.40682 .25865 Mdot
.40687 .25844 Mdot
.40691 .25823 Mdot
.40696 .25802 Mdot
.40701 .25781 Mdot
.40706 .2576 Mdot
.4071 .25739 Mdot
.40715 .25718 Mdot
.4072 .25697 Mdot
.40725 .25676 Mdot
.40729 .25655 Mdot
.40734 .25634 Mdot
.40739 .25613 Mdot
.40744 .25592 Mdot
.40749 .25571 Mdot
.40753 .2555 Mdot
.40758 .25529 Mdot
.40763 .25508 Mdot
.40768 .25488 Mdot
.40772 .25467 Mdot
.40777 .25446 Mdot
.40782 .25425 Mdot
.40787 .25404 Mdot
.40791 .25383 Mdot
.40796 .25362 Mdot
.40801 .25341 Mdot
.40806 .25321 Mdot
.4081 .253 Mdot
.40815 .25279 Mdot
.4082 .25258 Mdot
.40825 .25237 Mdot
.40829 .25216 Mdot
.40834 .25196 Mdot
.40839 .25175 Mdot
.40844 .25154 Mdot
.40849 .25133 Mdot
.40853 .25112 Mdot
.40858 .25091 Mdot
.40863 .25071 Mdot
.40868 .2505 Mdot
.40872 .25029 Mdot
.40877 .25008 Mdot
.40882 .24988 Mdot
.40887 .24967 Mdot
.40891 .24946 Mdot
.40896 .24925 Mdot
.40901 .24905 Mdot
.40906 .24884 Mdot
.4091 .24863 Mdot
.40915 .24842 Mdot
.4092 .24822 Mdot
.40925 .24801 Mdot
.40929 .2478 Mdot
.40934 .2476 Mdot
.40939 .24739 Mdot
.40944 .24718 Mdot
.40949 .24697 Mdot
.40953 .24677 Mdot
.40958 .24656 Mdot
.40963 .24635 Mdot
.40968 .24615 Mdot
.40972 .24594 Mdot
.40977 .24573 Mdot
.40982 .24553 Mdot
.40987 .24532 Mdot
.40991 .24512 Mdot
.40996 .24491 Mdot
.41001 .2447 Mdot
.41006 .2445 Mdot
.4101 .24429 Mdot
.41015 .24408 Mdot
.4102 .24388 Mdot
.41025 .24367 Mdot
.41029 .24347 Mdot
.41034 .24326 Mdot
.41039 .24306 Mdot
.41044 .24285 Mdot
.41049 .24264 Mdot
.41053 .24244 Mdot
.41058 .24223 Mdot
.41063 .24203 Mdot
.41068 .24182 Mdot
.41072 .24162 Mdot
.41077 .24141 Mdot
.41082 .24121 Mdot
.41087 .241 Mdot
.41091 .2408 Mdot
.41096 .24059 Mdot
.41101 .24039 Mdot
.41106 .24018 Mdot
.4111 .23998 Mdot
.41115 .23977 Mdot
.4112 .23957 Mdot
.41125 .23936 Mdot
.41129 .23916 Mdot
.41134 .23895 Mdot
.41139 .23875 Mdot
.41144 .23855 Mdot
.41149 .23834 Mdot
.41153 .23814 Mdot
.41158 .23793 Mdot
.41163 .23773 Mdot
.41168 .23753 Mdot
.41172 .23732 Mdot
.41177 .23712 Mdot
.41182 .23691 Mdot
.41187 .23671 Mdot
.41191 .23651 Mdot
.41196 .2363 Mdot
.41201 .2361 Mdot
.41206 .2359 Mdot
.4121 .23569 Mdot
.41215 .23549 Mdot
.4122 .23529 Mdot
.41225 .23508 Mdot
.41229 .23488 Mdot
.41234 .23468 Mdot
.41239 .23448 Mdot
.41244 .23427 Mdot
.41248 .23407 Mdot
.41253 .23387 Mdot
.41258 .23366 Mdot
.41263 .23346 Mdot
.41268 .23326 Mdot
.41272 .23306 Mdot
.41277 .23285 Mdot
.41282 .23265 Mdot
.41287 .23245 Mdot
.41291 .23225 Mdot
.41296 .23205 Mdot
.41301 .23184 Mdot
.41306 .23164 Mdot
.4131 .23144 Mdot
.41315 .23124 Mdot
.4132 .23104 Mdot
.41325 .23084 Mdot
.41329 .23063 Mdot
.41334 .23043 Mdot
.41339 .23023 Mdot
.41344 .23003 Mdot
.41348 .22983 Mdot
.41353 .22963 Mdot
.41358 .22943 Mdot
.41363 .22923 Mdot
.41368 .22903 Mdot
.41372 .22882 Mdot
.41377 .22862 Mdot
.41382 .22842 Mdot
.41387 .22822 Mdot
.41391 .22802 Mdot
.41396 .22782 Mdot
.41401 .22762 Mdot
.41406 .22742 Mdot
.4141 .22722 Mdot
.41415 .22702 Mdot
.4142 .22682 Mdot
.41425 .22662 Mdot
.41429 .22642 Mdot
.41434 .22622 Mdot
.41439 .22602 Mdot
.41444 .22582 Mdot
.41448 .22562 Mdot
.41453 .22542 Mdot
.41458 .22522 Mdot
.41463 .22502 Mdot
.41468 .22483 Mdot
.41472 .22463 Mdot
.41477 .22443 Mdot
.41482 .22423 Mdot
.41487 .22403 Mdot
.41491 .22383 Mdot
.41496 .22363 Mdot
.41501 .22343 Mdot
.41506 .22323 Mdot
.4151 .22304 Mdot
.41515 .22284 Mdot
.4152 .22264 Mdot
.41525 .22244 Mdot
.41529 .22224 Mdot
.41534 .22205 Mdot
.41539 .22185 Mdot
.41544 .22165 Mdot
.41548 .22145 Mdot
.41553 .22125 Mdot
.41558 .22106 Mdot
.41563 .22086 Mdot
.41568 .22066 Mdot
.41572 .22046 Mdot
.41577 .22027 Mdot
.41582 .22007 Mdot
.41587 .21987 Mdot
.41591 .21968 Mdot
.41596 .21948 Mdot
.41601 .21928 Mdot
.41606 .21908 Mdot
.4161 .21889 Mdot
.41615 .21869 Mdot
.4162 .21849 Mdot
.41625 .2183 Mdot
.41629 .2181 Mdot
.41634 .21791 Mdot
.41639 .21771 Mdot
.41644 .21751 Mdot
.41648 .21732 Mdot
.41653 .21712 Mdot
.41658 .21693 Mdot
.41663 .21673 Mdot
.41667 .21653 Mdot
.41672 .21634 Mdot
.41677 .21614 Mdot
.41682 .21595 Mdot
.41687 .21575 Mdot
.41691 .21556 Mdot
.41696 .21536 Mdot
.41701 .21517 Mdot
.41706 .21497 Mdot
.4171 .21478 Mdot
.41715 .21458 Mdot
.4172 .21439 Mdot
.41725 .21419 Mdot
.41729 .214 Mdot
.41734 .2138 Mdot
.41739 .21361 Mdot
.41744 .21342 Mdot
.41748 .21322 Mdot
.41753 .21303 Mdot
.41758 .21283 Mdot
.41763 .21264 Mdot
.41767 .21245 Mdot
.41772 .21225 Mdot
.41777 .21206 Mdot
.41782 .21187 Mdot
.41787 .21167 Mdot
.41791 .21148 Mdot
.41796 .21129 Mdot
.41801 .21109 Mdot
.41806 .2109 Mdot
.4181 .21071 Mdot
.41815 .21051 Mdot
.4182 .21032 Mdot
.41825 .21013 Mdot
.41829 .20994 Mdot
.41834 .20974 Mdot
.41839 .20955 Mdot
.41844 .20936 Mdot
.41848 .20917 Mdot
.41853 .20898 Mdot
.41858 .20878 Mdot
.41863 .20859 Mdot
.41867 .2084 Mdot
.41872 .20821 Mdot
.41877 .20802 Mdot
.41882 .20783 Mdot
.41887 .20763 Mdot
.41891 .20744 Mdot
.41896 .20725 Mdot
.41901 .20706 Mdot
.41906 .20687 Mdot
.4191 .20668 Mdot
.41915 .20649 Mdot
.4192 .2063 Mdot
.41925 .20611 Mdot
.41929 .20592 Mdot
.41934 .20573 Mdot
.41939 .20554 Mdot
.41944 .20535 Mdot
.41948 .20516 Mdot
.41953 .20497 Mdot
.41958 .20478 Mdot
.41963 .20459 Mdot
.41967 .2044 Mdot
.41972 .20421 Mdot
.41977 .20402 Mdot
.41982 .20383 Mdot
.41987 .20364 Mdot
.41991 .20345 Mdot
.41996 .20326 Mdot
.42001 .20307 Mdot
.42006 .20288 Mdot
.4201 .20269 Mdot
.42015 .20251 Mdot
.4202 .20232 Mdot
.42025 .20213 Mdot
.42029 .20194 Mdot
.42034 .20175 Mdot
.42039 .20156 Mdot
.42044 .20138 Mdot
.42048 .20119 Mdot
.42053 .201 Mdot
.42058 .20081 Mdot
.42063 .20062 Mdot
.42067 .20044 Mdot
.42072 .20025 Mdot
.42077 .20006 Mdot
.42082 .19987 Mdot
.42087 .19969 Mdot
.42091 .1995 Mdot
.42096 .19931 Mdot
.42101 .19913 Mdot
.42106 .19894 Mdot
.4211 .19875 Mdot
.42115 .19857 Mdot
.4212 .19838 Mdot
.42125 .19819 Mdot
.42129 .19801 Mdot
.42134 .19782 Mdot
.42139 .19764 Mdot
.42144 .19745 Mdot
.42148 .19726 Mdot
.42153 .19708 Mdot
.42158 .19689 Mdot
.42163 .19671 Mdot
.42167 .19652 Mdot
.42172 .19634 Mdot
.42177 .19615 Mdot
.42182 .19597 Mdot
.42186 .19578 Mdot
.42191 .1956 Mdot
.42196 .19541 Mdot
.42201 .19523 Mdot
.42206 .19504 Mdot
.4221 .19486 Mdot
.42215 .19468 Mdot
.4222 .19449 Mdot
.42225 .19431 Mdot
.42229 .19412 Mdot
.42234 .19394 Mdot
.42239 .19376 Mdot
.42244 .19357 Mdot
.42248 .19339 Mdot
.42253 .19321 Mdot
.42258 .19302 Mdot
.42263 .19284 Mdot
.42267 .19266 Mdot
.42272 .19247 Mdot
.42277 .19229 Mdot
.42282 .19211 Mdot
.42286 .19193 Mdot
.42291 .19174 Mdot
.42296 .19156 Mdot
.42301 .19138 Mdot
.42306 .1912 Mdot
.4231 .19102 Mdot
.42315 .19083 Mdot
.4232 .19065 Mdot
.42325 .19047 Mdot
.42329 .19029 Mdot
.42334 .19011 Mdot
.42339 .18993 Mdot
.42344 .18974 Mdot
.42348 .18956 Mdot
.42353 .18938 Mdot
.42358 .1892 Mdot
.42363 .18902 Mdot
.42367 .18884 Mdot
.42372 .18866 Mdot
.42377 .18848 Mdot
.42382 .1883 Mdot
.42386 .18812 Mdot
.42391 .18794 Mdot
.42396 .18776 Mdot
.42401 .18758 Mdot
.42406 .1874 Mdot
.4241 .18722 Mdot
.42415 .18704 Mdot
.4242 .18686 Mdot
.42425 .18668 Mdot
.42429 .1865 Mdot
.42434 .18632 Mdot
.42439 .18614 Mdot
.42444 .18597 Mdot
.42448 .18579 Mdot
.42453 .18561 Mdot
.42458 .18543 Mdot
.42463 .18525 Mdot
.42467 .18507 Mdot
.42472 .1849 Mdot
.42477 .18472 Mdot
.42482 .18454 Mdot
.42486 .18436 Mdot
.42491 .18419 Mdot
.42496 .18401 Mdot
.42501 .18383 Mdot
.42506 .18365 Mdot
.4251 .18348 Mdot
.42515 .1833 Mdot
.4252 .18312 Mdot
.42525 .18295 Mdot
.42529 .18277 Mdot
.42534 .18259 Mdot
.42539 .18242 Mdot
.42544 .18224 Mdot
.42548 .18206 Mdot
.42553 .18189 Mdot
.42558 .18171 Mdot
.42563 .18154 Mdot
.42567 .18136 Mdot
.42572 .18118 Mdot
.42577 .18101 Mdot
.42582 .18083 Mdot
.42586 .18066 Mdot
.42591 .18048 Mdot
.42596 .18031 Mdot
.42601 .18013 Mdot
.42606 .17996 Mdot
.4261 .17979 Mdot
.42615 .17961 Mdot
.4262 .17944 Mdot
.42625 .17926 Mdot
.42629 .17909 Mdot
.42634 .17891 Mdot
.42639 .17874 Mdot
.42644 .17857 Mdot
.42648 .17839 Mdot
.42653 .17822 Mdot
.42658 .17805 Mdot
.42663 .17787 Mdot
.42667 .1777 Mdot
.42672 .17753 Mdot
.42677 .17735 Mdot
.42682 .17718 Mdot
.42686 .17701 Mdot
.42691 .17684 Mdot
.42696 .17667 Mdot
.42701 .17649 Mdot
.42705 .17632 Mdot
.4271 .17615 Mdot
.42715 .17598 Mdot
.4272 .17581 Mdot
.42725 .17563 Mdot
.42729 .17546 Mdot
.42734 .17529 Mdot
.42739 .17512 Mdot
.42744 .17495 Mdot
.42748 .17478 Mdot
.42753 .17461 Mdot
.42758 .17444 Mdot
.42763 .17427 Mdot
.42767 .1741 Mdot
.42772 .17393 Mdot
.42777 .17376 Mdot
.42782 .17359 Mdot
.42786 .17342 Mdot
.42791 .17325 Mdot
.42796 .17308 Mdot
.42801 .17291 Mdot
.42805 .17274 Mdot
.4281 .17257 Mdot
.42815 .1724 Mdot
.4282 .17223 Mdot
.42825 .17206 Mdot
.42829 .17189 Mdot
.42834 .17172 Mdot
.42839 .17156 Mdot
.42844 .17139 Mdot
.42848 .17122 Mdot
.42853 .17105 Mdot
.42858 .17088 Mdot
.42863 .17072 Mdot
.42867 .17055 Mdot
.42872 .17038 Mdot
.42877 .17021 Mdot
.42882 .17005 Mdot
.42886 .16988 Mdot
.42891 .16971 Mdot
.42896 .16955 Mdot
.42901 .16938 Mdot
.42905 .16921 Mdot
.4291 .16905 Mdot
.42915 .16888 Mdot
.4292 .16871 Mdot
.42925 .16855 Mdot
.42929 .16838 Mdot
.42934 .16822 Mdot
.42939 .16805 Mdot
.42944 .16788 Mdot
.42948 .16772 Mdot
.42953 .16755 Mdot
.42958 .16739 Mdot
.42963 .16722 Mdot
.42967 .16706 Mdot
.42972 .16689 Mdot
.42977 .16673 Mdot
.42982 .16657 Mdot
.42986 .1664 Mdot
.42991 .16624 Mdot
.42996 .16607 Mdot
.43001 .16591 Mdot
.43005 .16575 Mdot
.4301 .16558 Mdot
.43015 .16542 Mdot
.4302 .16526 Mdot
.43025 .16509 Mdot
.43029 .16493 Mdot
.43034 .16477 Mdot
.43039 .1646 Mdot
.43044 .16444 Mdot
.43048 .16428 Mdot
.43053 .16412 Mdot
.43058 .16395 Mdot
.43063 .16379 Mdot
.43067 .16363 Mdot
.43072 .16347 Mdot
.43077 .16331 Mdot
.43082 .16314 Mdot
.43086 .16298 Mdot
.43091 .16282 Mdot
.43096 .16266 Mdot
.43101 .1625 Mdot
.43105 .16234 Mdot
.4311 .16218 Mdot
.43115 .16202 Mdot
.4312 .16186 Mdot
.43124 .1617 Mdot
.43129 .16154 Mdot
.43134 .16138 Mdot
.43139 .16122 Mdot
.43144 .16106 Mdot
.43148 .1609 Mdot
.43153 .16074 Mdot
.43158 .16058 Mdot
.43163 .16042 Mdot
.43167 .16026 Mdot
.43172 .1601 Mdot
.43177 .15994 Mdot
.43182 .15979 Mdot
.43186 .15963 Mdot
.43191 .15947 Mdot
.43196 .15931 Mdot
.43201 .15915 Mdot
.43205 .15899 Mdot
.4321 .15884 Mdot
.43215 .15868 Mdot
.4322 .15852 Mdot
.43224 .15836 Mdot
.43229 .15821 Mdot
.43234 .15805 Mdot
.43239 .15789 Mdot
.43244 .15774 Mdot
.43248 .15758 Mdot
.43253 .15742 Mdot
.43258 .15727 Mdot
.43263 .15711 Mdot
.43267 .15696 Mdot
.43272 .1568 Mdot
.43277 .15664 Mdot
.43282 .15649 Mdot
.43286 .15633 Mdot
.43291 .15618 Mdot
.43296 .15602 Mdot
.43301 .15587 Mdot
.43305 .15571 Mdot
.4331 .15556 Mdot
.43315 .1554 Mdot
.4332 .15525 Mdot
.43324 .15509 Mdot
.43329 .15494 Mdot
.43334 .15479 Mdot
.43339 .15463 Mdot
.43344 .15448 Mdot
.43348 .15433 Mdot
.43353 .15417 Mdot
.43358 .15402 Mdot
.43363 .15387 Mdot
.43367 .15371 Mdot
.43372 .15356 Mdot
.43377 .15341 Mdot
.43382 .15326 Mdot
.43386 .1531 Mdot
.43391 .15295 Mdot
.43396 .1528 Mdot
.43401 .15265 Mdot
.43405 .1525 Mdot
.4341 .15234 Mdot
.43415 .15219 Mdot
.4342 .15204 Mdot
.43424 .15189 Mdot
.43429 .15174 Mdot
.43434 .15159 Mdot
.43439 .15144 Mdot
.43444 .15129 Mdot
.43448 .15114 Mdot
.43453 .15099 Mdot
.43458 .15084 Mdot
.43463 .15069 Mdot
.43467 .15054 Mdot
.43472 .15039 Mdot
.43477 .15024 Mdot
.43482 .15009 Mdot
.43486 .14994 Mdot
.43491 .14979 Mdot
.43496 .14964 Mdot
.43501 .14949 Mdot
.43505 .14934 Mdot
.4351 .14919 Mdot
.43515 .14905 Mdot
.4352 .1489 Mdot
.43524 .14875 Mdot
.43529 .1486 Mdot
.43534 .14845 Mdot
.43539 .14831 Mdot
.43544 .14816 Mdot
.43548 .14801 Mdot
.43553 .14787 Mdot
.43558 .14772 Mdot
.43563 .14757 Mdot
.43567 .14743 Mdot
.43572 .14728 Mdot
.43577 .14713 Mdot
.43582 .14699 Mdot
.43586 .14684 Mdot
.43591 .14669 Mdot
.43596 .14655 Mdot
.43601 .1464 Mdot
.43605 .14626 Mdot
.4361 .14611 Mdot
.43615 .14597 Mdot
.4362 .14582 Mdot
.43624 .14568 Mdot
.43629 .14553 Mdot
.43634 .14539 Mdot
.43639 .14524 Mdot
.43643 .1451 Mdot
.43648 .14496 Mdot
.43653 .14481 Mdot
.43658 .14467 Mdot
.43663 .14453 Mdot
.43667 .14438 Mdot
.43672 .14424 Mdot
.43677 .1441 Mdot
.43682 .14395 Mdot
.43686 .14381 Mdot
.43691 .14367 Mdot
.43696 .14353 Mdot
.43701 .14338 Mdot
.43705 .14324 Mdot
.4371 .1431 Mdot
.43715 .14296 Mdot
.4372 .14282 Mdot
.43724 .14267 Mdot
.43729 .14253 Mdot
.43734 .14239 Mdot
.43739 .14225 Mdot
.43743 .14211 Mdot
.43748 .14197 Mdot
.43753 .14183 Mdot
.43758 .14169 Mdot
.43763 .14155 Mdot
.43767 .14141 Mdot
.43772 .14127 Mdot
.43777 .14113 Mdot
.43782 .14099 Mdot
.43786 .14085 Mdot
.43791 .14071 Mdot
.43796 .14057 Mdot
.43801 .14043 Mdot
.43805 .14029 Mdot
.4381 .14015 Mdot
.43815 .14002 Mdot
.4382 .13988 Mdot
.43824 .13974 Mdot
.43829 .1396 Mdot
.43834 .13946 Mdot
.43839 .13933 Mdot
.43843 .13919 Mdot
.43848 .13905 Mdot
.43853 .13891 Mdot
.43858 .13878 Mdot
.43863 .13864 Mdot
.43867 .1385 Mdot
.43872 .13837 Mdot
.43877 .13823 Mdot
.43882 .13809 Mdot
.43886 .13796 Mdot
.43891 .13782 Mdot
.43896 .13769 Mdot
.43901 .13755 Mdot
.43905 .13742 Mdot
.4391 .13728 Mdot
.43915 .13714 Mdot
.4392 .13701 Mdot
.43924 .13688 Mdot
.43929 .13674 Mdot
.43934 .13661 Mdot
.43939 .13647 Mdot
.43943 .13634 Mdot
.43948 .1362 Mdot
.43953 .13607 Mdot
.43958 .13594 Mdot
.43963 .1358 Mdot
.43967 .13567 Mdot
.43972 .13554 Mdot
.43977 .1354 Mdot
.43982 .13527 Mdot
.43986 .13514 Mdot
.43991 .13501 Mdot
.43996 .13487 Mdot
.44001 .13474 Mdot
.44005 .13461 Mdot
.4401 .13448 Mdot
.44015 .13435 Mdot
.4402 .13421 Mdot
.44024 .13408 Mdot
.44029 .13395 Mdot
.44034 .13382 Mdot
.44039 .13369 Mdot
.44043 .13356 Mdot
.44048 .13343 Mdot
.44053 .1333 Mdot
.44058 .13317 Mdot
.44062 .13304 Mdot
.44067 .13291 Mdot
.44072 .13278 Mdot
.44077 .13265 Mdot
.44082 .13252 Mdot
.44086 .13239 Mdot
.44091 .13226 Mdot
.44096 .13213 Mdot
.44101 .132 Mdot
.44105 .13188 Mdot
.4411 .13175 Mdot
.44115 .13162 Mdot
.4412 .13149 Mdot
.44124 .13136 Mdot
.44129 .13124 Mdot
.44134 .13111 Mdot
.44139 .13098 Mdot
.44143 .13085 Mdot
.44148 .13073 Mdot
.44153 .1306 Mdot
.44158 .13047 Mdot
.44162 .13035 Mdot
.44167 .13022 Mdot
.44172 .13009 Mdot
.44177 .12997 Mdot
.44182 .12984 Mdot
.44186 .12972 Mdot
.44191 .12959 Mdot
.44196 .12947 Mdot
.44201 .12934 Mdot
.44205 .12922 Mdot
.4421 .12909 Mdot
.44215 .12897 Mdot
.4422 .12884 Mdot
.44224 .12872 Mdot
.44229 .12859 Mdot
.44234 .12847 Mdot
.44239 .12835 Mdot
.44243 .12822 Mdot
.44248 .1281 Mdot
.44253 .12798 Mdot
.44258 .12785 Mdot
.44262 .12773 Mdot
.44267 .12761 Mdot
.44272 .12748 Mdot
.44277 .12736 Mdot
.44282 .12724 Mdot
.44286 .12712 Mdot
.44291 .127 Mdot
.44296 .12687 Mdot
.44301 .12675 Mdot
.44305 .12663 Mdot
.4431 .12651 Mdot
.44315 .12639 Mdot
.4432 .12627 Mdot
.44324 .12615 Mdot
.44329 .12603 Mdot
.44334 .12591 Mdot
.44339 .12579 Mdot
.44343 .12567 Mdot
.44348 .12555 Mdot
.44353 .12543 Mdot
.44358 .12531 Mdot
.44362 .12519 Mdot
.44367 .12507 Mdot
.44372 .12495 Mdot
.44377 .12483 Mdot
.44382 .12471 Mdot
.44386 .12459 Mdot
.44391 .12448 Mdot
.44396 .12436 Mdot
.44401 .12424 Mdot
.44405 .12412 Mdot
.4441 .124 Mdot
.44415 .12389 Mdot
.4442 .12377 Mdot
.44424 .12365 Mdot
.44429 .12354 Mdot
.44434 .12342 Mdot
.44439 .1233 Mdot
.44443 .12319 Mdot
.44448 .12307 Mdot
.44453 .12295 Mdot
.44458 .12284 Mdot
.44462 .12272 Mdot
.44467 .12261 Mdot
.44472 .12249 Mdot
.44477 .12238 Mdot
.44482 .12226 Mdot
.44486 .12215 Mdot
.44491 .12203 Mdot
.44496 .12192 Mdot
.44501 .1218 Mdot
.44505 .12169 Mdot
.4451 .12157 Mdot
.44515 .12146 Mdot
.4452 .12135 Mdot
.44524 .12123 Mdot
.44529 .12112 Mdot
.44534 .12101 Mdot
.44539 .12089 Mdot
.44543 .12078 Mdot
.44548 .12067 Mdot
.44553 .12056 Mdot
.44558 .12044 Mdot
.44562 .12033 Mdot
.44567 .12022 Mdot
.44572 .12011 Mdot
.44577 .12 Mdot
.44581 .11989 Mdot
.44586 .11978 Mdot
.44591 .11966 Mdot
.44596 .11955 Mdot
.44601 .11944 Mdot
.44605 .11933 Mdot
.4461 .11922 Mdot
.44615 .11911 Mdot
.4462 .119 Mdot
.44624 .11889 Mdot
.44629 .11878 Mdot
.44634 .11867 Mdot
.44639 .11857 Mdot
.44643 .11846 Mdot
.44648 .11835 Mdot
.44653 .11824 Mdot
.44658 .11813 Mdot
.44662 .11802 Mdot
.44667 .11791 Mdot
.44672 .11781 Mdot
.44677 .1177 Mdot
.44681 .11759 Mdot
.44686 .11748 Mdot
.44691 .11738 Mdot
.44696 .11727 Mdot
.44701 .11716 Mdot
.44705 .11706 Mdot
.4471 .11695 Mdot
.44715 .11684 Mdot
.4472 .11674 Mdot
.44724 .11663 Mdot
.44729 .11653 Mdot
.44734 .11642 Mdot
.44739 .11631 Mdot
.44743 .11621 Mdot
.44748 .1161 Mdot
.44753 .116 Mdot
.44758 .11589 Mdot
.44762 .11579 Mdot
.44767 .11569 Mdot
.44772 .11558 Mdot
.44777 .11548 Mdot
.44781 .11537 Mdot
.44786 .11527 Mdot
.44791 .11517 Mdot
.44796 .11506 Mdot
.44801 .11496 Mdot
.44805 .11486 Mdot
.4481 .11476 Mdot
.44815 .11465 Mdot
.4482 .11455 Mdot
.44824 .11445 Mdot
.44829 .11435 Mdot
.44834 .11424 Mdot
.44839 .11414 Mdot
.44843 .11404 Mdot
.44848 .11394 Mdot
.44853 .11384 Mdot
.44858 .11374 Mdot
.44862 .11364 Mdot
.44867 .11354 Mdot
.44872 .11344 Mdot
.44877 .11334 Mdot
.44881 .11324 Mdot
.44886 .11314 Mdot
.44891 .11304 Mdot
.44896 .11294 Mdot
.44901 .11284 Mdot
.44905 .11274 Mdot
.4491 .11264 Mdot
.44915 .11254 Mdot
.4492 .11244 Mdot
.44924 .11235 Mdot
.44929 .11225 Mdot
.44934 .11215 Mdot
.44939 .11205 Mdot
.44943 .11195 Mdot
.44948 .11186 Mdot
.44953 .11176 Mdot
.44958 .11166 Mdot
.44962 .11157 Mdot
.44967 .11147 Mdot
.44972 .11137 Mdot
.44977 .11128 Mdot
.44981 .11118 Mdot
.44986 .11109 Mdot
.44991 .11099 Mdot
.44996 .11089 Mdot
.45 .1108 Mdot
.45005 .1107 Mdot
.4501 .11061 Mdot
.45015 .11051 Mdot
.4502 .11042 Mdot
.45024 .11032 Mdot
.45029 .11023 Mdot
.45034 .11014 Mdot
.45039 .11004 Mdot
.45043 .10995 Mdot
.45048 .10986 Mdot
.45053 .10976 Mdot
.45058 .10967 Mdot
.45062 .10958 Mdot
.45067 .10948 Mdot
.45072 .10939 Mdot
.45077 .1093 Mdot
.45081 .10921 Mdot
.45086 .10911 Mdot
.45091 .10902 Mdot
.45096 .10893 Mdot
.451 .10884 Mdot
.45105 .10875 Mdot
.4511 .10866 Mdot
.45115 .10857 Mdot
.4512 .10848 Mdot
.45124 .10838 Mdot
.45129 .10829 Mdot
.45134 .1082 Mdot
.45139 .10811 Mdot
.45143 .10802 Mdot
.45148 .10794 Mdot
.45153 .10785 Mdot
.45158 .10776 Mdot
.45162 .10767 Mdot
.45167 .10758 Mdot
.45172 .10749 Mdot
.45177 .1074 Mdot
.45181 .10731 Mdot
.45186 .10723 Mdot
.45191 .10714 Mdot
.45196 .10705 Mdot
.452 .10696 Mdot
.45205 .10687 Mdot
.4521 .10679 Mdot
.45215 .1067 Mdot
.4522 .10661 Mdot
.45224 .10653 Mdot
.45229 .10644 Mdot
.45234 .10635 Mdot
.45239 .10627 Mdot
.45243 .10618 Mdot
.45248 .1061 Mdot
.45253 .10601 Mdot
.45258 .10593 Mdot
.45262 .10584 Mdot
.45267 .10576 Mdot
.45272 .10567 Mdot
.45277 .10559 Mdot
.45281 .1055 Mdot
.45286 .10542 Mdot
.45291 .10534 Mdot
.45296 .10525 Mdot
.453 .10517 Mdot
.45305 .10508 Mdot
.4531 .105 Mdot
.45315 .10492 Mdot
.4532 .10484 Mdot
.45324 .10475 Mdot
.45329 .10467 Mdot
.45334 .10459 Mdot
.45339 .10451 Mdot
.45343 .10442 Mdot
.45348 .10434 Mdot
.45353 .10426 Mdot
.45358 .10418 Mdot
.45362 .1041 Mdot
.45367 .10402 Mdot
.45372 .10394 Mdot
.45377 .10386 Mdot
.45381 .10378 Mdot
.45386 .1037 Mdot
.45391 .10362 Mdot
.45396 .10354 Mdot
.454 .10346 Mdot
.45405 .10338 Mdot
.4541 .1033 Mdot
.45415 .10322 Mdot
.4542 .10314 Mdot
.45424 .10306 Mdot
.45429 .10298 Mdot
.45434 .10291 Mdot
.45439 .10283 Mdot
.45443 .10275 Mdot
.45448 .10267 Mdot
.45453 .10259 Mdot
.45458 .10252 Mdot
.45462 .10244 Mdot
.45467 .10236 Mdot
.45472 .10229 Mdot
.45477 .10221 Mdot
.45481 .10213 Mdot
.45486 .10206 Mdot
.45491 .10198 Mdot
.45496 .10191 Mdot
.455 .10183 Mdot
.45505 .10175 Mdot
.4551 .10168 Mdot
.45515 .1016 Mdot
.45519 .10153 Mdot
.45524 .10146 Mdot
.45529 .10138 Mdot
.45534 .10131 Mdot
.45539 .10123 Mdot
.45543 .10116 Mdot
.45548 .10109 Mdot
.45553 .10101 Mdot
.45558 .10094 Mdot
.45562 .10087 Mdot
.45567 .10079 Mdot
.45572 .10072 Mdot
.45577 .10065 Mdot
.45581 .10058 Mdot
.45586 .1005 Mdot
.45591 .10043 Mdot
.45596 .10036 Mdot
.456 .10029 Mdot
.45605 .10022 Mdot
.4561 .10015 Mdot
.45615 .10007 Mdot
.45619 .1 Mdot
.45624 .09993 Mdot
.45629 .09986 Mdot
.45634 .09979 Mdot
.45639 .09972 Mdot
.45643 .09965 Mdot
.45648 .09958 Mdot
.45653 .09951 Mdot
.45658 .09944 Mdot
.45662 .09938 Mdot
.45667 .09931 Mdot
.45672 .09924 Mdot
.45677 .09917 Mdot
.45681 .0991 Mdot
.45686 .09903 Mdot
.45691 .09897 Mdot
.45696 .0989 Mdot
.457 .09883 Mdot
.45705 .09876 Mdot
.4571 .0987 Mdot
.45715 .09863 Mdot
.45719 .09856 Mdot
.45724 .0985 Mdot
.45729 .09843 Mdot
.45734 .09836 Mdot
.45739 .0983 Mdot
.45743 .09823 Mdot
.45748 .09817 Mdot
.45753 .0981 Mdot
.45758 .09804 Mdot
.45762 .09797 Mdot
.45767 .09791 Mdot
.45772 .09784 Mdot
.45777 .09778 Mdot
.45781 .09771 Mdot
.45786 .09765 Mdot
.45791 .09759 Mdot
.45796 .09752 Mdot
.458 .09746 Mdot
.45805 .0974 Mdot
.4581 .09733 Mdot
.45815 .09727 Mdot
.45819 .09721 Mdot
.45824 .09715 Mdot
.45829 .09708 Mdot
.45834 .09702 Mdot
.45839 .09696 Mdot
.45843 .0969 Mdot
.45848 .09684 Mdot
.45853 .09677 Mdot
.45858 .09671 Mdot
.45862 .09665 Mdot
.45867 .09659 Mdot
.45872 .09653 Mdot
.45877 .09647 Mdot
.45881 .09641 Mdot
.45886 .09635 Mdot
.45891 .09629 Mdot
.45896 .09623 Mdot
.459 .09617 Mdot
.45905 .09611 Mdot
.4591 .09606 Mdot
.45915 .096 Mdot
.45919 .09594 Mdot
.45924 .09588 Mdot
.45929 .09582 Mdot
.45934 .09576 Mdot
.45939 .09571 Mdot
.45943 .09565 Mdot
.45948 .09559 Mdot
.45953 .09553 Mdot
.45958 .09548 Mdot
.45962 .09542 Mdot
.45967 .09536 Mdot
.45972 .09531 Mdot
.45977 .09525 Mdot
.45981 .0952 Mdot
.45986 .09514 Mdot
.45991 .09508 Mdot
.45996 .09503 Mdot
.46 .09497 Mdot
.46005 .09492 Mdot
.4601 .09486 Mdot
.46015 .09481 Mdot
.46019 .09476 Mdot
.46024 .0947 Mdot
.46029 .09465 Mdot
.46034 .09459 Mdot
.46038 .09454 Mdot
.46043 .09449 Mdot
.46048 .09443 Mdot
.46053 .09438 Mdot
.46058 .09433 Mdot
.46062 .09428 Mdot
.46067 .09422 Mdot
.46072 .09417 Mdot
.46077 .09412 Mdot
.46081 .09407 Mdot
.46086 .09402 Mdot
.46091 .09396 Mdot
.46096 .09391 Mdot
.461 .09386 Mdot
.46105 .09381 Mdot
.4611 .09376 Mdot
.46115 .09371 Mdot
.46119 .09366 Mdot
.46124 .09361 Mdot
.46129 .09356 Mdot
.46134 .09351 Mdot
.46138 .09346 Mdot
.46143 .09341 Mdot
.46148 .09336 Mdot
.46153 .09331 Mdot
.46158 .09326 Mdot
.46162 .09322 Mdot
.46167 .09317 Mdot
.46172 .09312 Mdot
.46177 .09307 Mdot
.46181 .09302 Mdot
.46186 .09298 Mdot
.46191 .09293 Mdot
.46196 .09288 Mdot
.462 .09284 Mdot
.46205 .09279 Mdot
.4621 .09274 Mdot
.46215 .0927 Mdot
.46219 .09265 Mdot
.46224 .0926 Mdot
.46229 .09256 Mdot
.46234 .09251 Mdot
.46238 .09247 Mdot
.46243 .09242 Mdot
.46248 .09238 Mdot
.46253 .09233 Mdot
.46258 .09229 Mdot
.46262 .09225 Mdot
.46267 .0922 Mdot
.46272 .09216 Mdot
.46277 .09211 Mdot
.46281 .09207 Mdot
.46286 .09203 Mdot
.46291 .09198 Mdot
.46296 .09194 Mdot
.463 .0919 Mdot
.46305 .09186 Mdot
.4631 .09181 Mdot
.46315 .09177 Mdot
.46319 .09173 Mdot
.46324 .09169 Mdot
.46329 .09165 Mdot
.46334 .0916 Mdot
.46338 .09156 Mdot
.46343 .09152 Mdot
.46348 .09148 Mdot
.46353 .09144 Mdot
.46358 .0914 Mdot
.46362 .09136 Mdot
.46367 .09132 Mdot
.46372 .09128 Mdot
.46377 .09124 Mdot
.46381 .0912 Mdot
.46386 .09116 Mdot
.46391 .09112 Mdot
.46396 .09109 Mdot
.464 .09105 Mdot
.46405 .09101 Mdot
.4641 .09097 Mdot
.46415 .09093 Mdot
.46419 .0909 Mdot
.46424 .09086 Mdot
.46429 .09082 Mdot
.46434 .09078 Mdot
.46438 .09075 Mdot
.46443 .09071 Mdot
.46448 .09067 Mdot
.46453 .09064 Mdot
.46457 .0906 Mdot
.46462 .09056 Mdot
.46467 .09053 Mdot
.46472 .09049 Mdot
.46477 .09046 Mdot
.46481 .09042 Mdot
.46486 .09039 Mdot
.46491 .09035 Mdot
.46496 .09032 Mdot
.465 .09028 Mdot
.46505 .09025 Mdot
.4651 .09022 Mdot
.46515 .09018 Mdot
.46519 .09015 Mdot
.46524 .09012 Mdot
.46529 .09008 Mdot
.46534 .09005 Mdot
.46538 .09002 Mdot
.46543 .08998 Mdot
.46548 .08995 Mdot
.46553 .08992 Mdot
.46557 .08989 Mdot
.46562 .08986 Mdot
.46567 .08982 Mdot
.46572 .08979 Mdot
.46577 .08976 Mdot
.46581 .08973 Mdot
.46586 .0897 Mdot
.46591 .08967 Mdot
.46596 .08964 Mdot
.466 .08961 Mdot
.46605 .08958 Mdot
.4661 .08955 Mdot
.46615 .08952 Mdot
.46619 .08949 Mdot
.46624 .08946 Mdot
.46629 .08943 Mdot
.46634 .0894 Mdot
.46638 .08938 Mdot
.46643 .08935 Mdot
.46648 .08932 Mdot
.46653 .08929 Mdot
.46657 .08926 Mdot
.46662 .08924 Mdot
.46667 .08921 Mdot
.46672 .08918 Mdot
.46677 .08915 Mdot
.46681 .08913 Mdot
.46686 .0891 Mdot
.46691 .08907 Mdot
.46696 .08905 Mdot
.467 .08902 Mdot
.46705 .089 Mdot
.4671 .08897 Mdot
.46715 .08895 Mdot
.46719 .08892 Mdot
.46724 .0889 Mdot
.46729 .08887 Mdot
.46734 .08885 Mdot
.46738 .08882 Mdot
.46743 .0888 Mdot
.46748 .08877 Mdot
.46753 .08875 Mdot
.46757 .08873 Mdot
.46762 .0887 Mdot
.46767 .08868 Mdot
.46772 .08866 Mdot
.46777 .08863 Mdot
.46781 .08861 Mdot
.46786 .08859 Mdot
.46791 .08857 Mdot
.46796 .08854 Mdot
.468 .08852 Mdot
.46805 .0885 Mdot
.4681 .08848 Mdot
.46815 .08846 Mdot
.46819 .08844 Mdot
.46824 .08842 Mdot
.46829 .0884 Mdot
.46834 .08838 Mdot
.46838 .08836 Mdot
.46843 .08834 Mdot
.46848 .08832 Mdot
.46853 .0883 Mdot
.46857 .08828 Mdot
.46862 .08826 Mdot
.46867 .08824 Mdot
.46872 .08822 Mdot
.46877 .0882 Mdot
.46881 .08818 Mdot
.46886 .08817 Mdot
.46891 .08815 Mdot
.46896 .08813 Mdot
.469 .08811 Mdot
.46905 .08809 Mdot
.4691 .08808 Mdot
.46915 .08806 Mdot
.46919 .08804 Mdot
.46924 .08803 Mdot
.46929 .08801 Mdot
.46934 .08799 Mdot
.46938 .08798 Mdot
.46943 .08796 Mdot
.46948 .08795 Mdot
.46953 .08793 Mdot
.46957 .08792 Mdot
.46962 .0879 Mdot
.46967 .08789 Mdot
.46972 .08787 Mdot
.46976 .08786 Mdot
.46981 .08784 Mdot
.46986 .08783 Mdot
.46991 .08782 Mdot
.46996 .0878 Mdot
.47 .08779 Mdot
.47005 .08778 Mdot
.4701 .08776 Mdot
.47015 .08775 Mdot
.47019 .08774 Mdot
.47024 .08773 Mdot
.47029 .08771 Mdot
.47034 .0877 Mdot
.47038 .08769 Mdot
.47043 .08768 Mdot
.47048 .08767 Mdot
.47053 .08766 Mdot
.47057 .08764 Mdot
.47062 .08763 Mdot
.47067 .08762 Mdot
.47072 .08761 Mdot
.47076 .0876 Mdot
.47081 .08759 Mdot
.47086 .08758 Mdot
.47091 .08757 Mdot
.47096 .08756 Mdot
.471 .08755 Mdot
.47105 .08755 Mdot
.4711 .08754 Mdot
.47115 .08753 Mdot
.47119 .08752 Mdot
.47124 .08751 Mdot
.47129 .0875 Mdot
.47134 .0875 Mdot
.47138 .08749 Mdot
.47143 .08748 Mdot
.47148 .08747 Mdot
.47153 .08747 Mdot
.47157 .08746 Mdot
.47162 .08745 Mdot
.47167 .08745 Mdot
.47172 .08744 Mdot
.47176 .08743 Mdot
.47181 .08743 Mdot
.47186 .08742 Mdot
.47191 .08742 Mdot
.47196 .08741 Mdot
.472 .08741 Mdot
.47205 .0874 Mdot
.4721 .0874 Mdot
.47215 .08739 Mdot
.47219 .08739 Mdot
.47224 .08739 Mdot
.47229 .08738 Mdot
.47234 .08738 Mdot
.47238 .08737 Mdot
.47243 .08737 Mdot
.47248 .08737 Mdot
.47253 .08737 Mdot
.47257 .08736 Mdot
.47262 .08736 Mdot
.47267 .08736 Mdot
.47272 .08736 Mdot
.47276 .08735 Mdot
.47281 .08735 Mdot
.47286 .08735 Mdot
.47291 .08735 Mdot
.47296 .08735 Mdot
.473 .08735 Mdot
.47305 .08735 Mdot
.4731 .08735 Mdot
.47315 .08735 Mdot
.47319 .08735 Mdot
.47324 .08735 Mdot
.47329 .08735 Mdot
.47334 .08735 Mdot
.47338 .08735 Mdot
.47343 .08735 Mdot
.47348 .08735 Mdot
.47353 .08735 Mdot
.47357 .08735 Mdot
.47362 .08736 Mdot
.47367 .08736 Mdot
.47372 .08736 Mdot
.47376 .08736 Mdot
.47381 .08736 Mdot
.47386 .08737 Mdot
.47391 .08737 Mdot
.47395 .08737 Mdot
.474 .08738 Mdot
.47405 .08738 Mdot
.4741 .08738 Mdot
.47415 .08739 Mdot
.47419 .08739 Mdot
.47424 .0874 Mdot
.47429 .0874 Mdot
.47434 .08741 Mdot
.47438 .08741 Mdot
.47443 .08742 Mdot
.47448 .08742 Mdot
.47453 .08743 Mdot
.47457 .08743 Mdot
.47462 .08744 Mdot
.47467 .08744 Mdot
.47472 .08745 Mdot
.47476 .08746 Mdot
.47481 .08746 Mdot
.47486 .08747 Mdot
.47491 .08748 Mdot
.47495 .08749 Mdot
.475 .08749 Mdot
.47505 .0875 Mdot
.4751 .08751 Mdot
.47515 .08752 Mdot
.47519 .08753 Mdot
.47524 .08753 Mdot
.47529 .08754 Mdot
.47534 .08755 Mdot
.47538 .08756 Mdot
.47543 .08757 Mdot
.47548 .08758 Mdot
.47553 .08759 Mdot
.47557 .0876 Mdot
.47562 .08761 Mdot
.47567 .08762 Mdot
.47572 .08763 Mdot
.47576 .08764 Mdot
.47581 .08765 Mdot
.47586 .08766 Mdot
.47591 .08767 Mdot
.47595 .08769 Mdot
.476 .0877 Mdot
.47605 .08771 Mdot
.4761 .08772 Mdot
.47615 .08773 Mdot
.47619 .08775 Mdot
.47624 .08776 Mdot
.47629 .08777 Mdot
.47634 .08778 Mdot
.47638 .0878 Mdot
.47643 .08781 Mdot
.47648 .08782 Mdot
.47653 .08784 Mdot
.47657 .08785 Mdot
.47662 .08787 Mdot
.47667 .08788 Mdot
.47672 .0879 Mdot
.47676 .08791 Mdot
.47681 .08793 Mdot
.47686 .08794 Mdot
.47691 .08796 Mdot
.47695 .08797 Mdot
.477 .08799 Mdot
.47705 .088 Mdot
.4771 .08802 Mdot
.47715 .08804 Mdot
.47719 .08805 Mdot
.47724 .08807 Mdot
.47729 .08809 Mdot
.47734 .0881 Mdot
.47738 .08812 Mdot
.47743 .08814 Mdot
.47748 .08816 Mdot
.47753 .08817 Mdot
.47757 .08819 Mdot
.47762 .08821 Mdot
.47767 .08823 Mdot
.47772 .08825 Mdot
.47776 .08827 Mdot
.47781 .08829 Mdot
.47786 .08831 Mdot
.47791 .08833 Mdot
.47795 .08834 Mdot
.478 .08836 Mdot
.47805 .08838 Mdot
.4781 .08841 Mdot
.47815 .08843 Mdot
.47819 .08845 Mdot
.47824 .08847 Mdot
.47829 .08849 Mdot
.47834 .08851 Mdot
.47838 .08853 Mdot
.47843 .08855 Mdot
.47848 .08857 Mdot
.47853 .0886 Mdot
.47857 .08862 Mdot
.47862 .08864 Mdot
.47867 .08866 Mdot
.47872 .08869 Mdot
.47876 .08871 Mdot
.47881 .08873 Mdot
.47886 .08876 Mdot
.47891 .08878 Mdot
.47895 .0888 Mdot
.479 .08883 Mdot
.47905 .08885 Mdot
.4791 .08888 Mdot
.47914 .0889 Mdot
.47919 .08893 Mdot
.47924 .08895 Mdot
.47929 .08898 Mdot
.47934 .089 Mdot
.47938 .08903 Mdot
.47943 .08905 Mdot
.47948 .08908 Mdot
.47953 .08911 Mdot
.47957 .08913 Mdot
.47962 .08916 Mdot
.47967 .08919 Mdot
.47972 .08921 Mdot
.47976 .08924 Mdot
.47981 .08927 Mdot
.47986 .08929 Mdot
.47991 .08932 Mdot
.47995 .08935 Mdot
.48 .08938 Mdot
.48005 .08941 Mdot
.4801 .08943 Mdot
.48014 .08946 Mdot
.48019 .08949 Mdot
.48024 .08952 Mdot
.48029 .08955 Mdot
.48034 .08958 Mdot
.48038 .08961 Mdot
.48043 .08964 Mdot
.48048 .08967 Mdot
.48053 .0897 Mdot
.48057 .08973 Mdot
.48062 .08976 Mdot
.48067 .08979 Mdot
.48072 .08982 Mdot
.48076 .08985 Mdot
.48081 .08989 Mdot
.48086 .08992 Mdot
.48091 .08995 Mdot
.48095 .08998 Mdot
.481 .09001 Mdot
.48105 .09005 Mdot
.4811 .09008 Mdot
.48114 .09011 Mdot
.48119 .09014 Mdot
.48124 .09018 Mdot
.48129 .09021 Mdot
.48134 .09024 Mdot
.48138 .09028 Mdot
.48143 .09031 Mdot
.48148 .09035 Mdot
.48153 .09038 Mdot
.48157 .09041 Mdot
.48162 .09045 Mdot
.48167 .09048 Mdot
.48172 .09052 Mdot
.48176 .09055 Mdot
.48181 .09059 Mdot
.48186 .09063 Mdot
.48191 .09066 Mdot
.48195 .0907 Mdot
.482 .09073 Mdot
.48205 .09077 Mdot
.4821 .09081 Mdot
.48214 .09084 Mdot
.48219 .09088 Mdot
.48224 .09092 Mdot
.48229 .09095 Mdot
.48234 .09099 Mdot
.48238 .09103 Mdot
.48243 .09107 Mdot
.48248 .09111 Mdot
.48253 .09114 Mdot
.48257 .09118 Mdot
.48262 .09122 Mdot
.48267 .09126 Mdot
.48272 .0913 Mdot
.48276 .09134 Mdot
.48281 .09138 Mdot
.48286 .09142 Mdot
.48291 .09146 Mdot
.48295 .0915 Mdot
.483 .09154 Mdot
.48305 .09158 Mdot
.4831 .09162 Mdot
.48314 .09166 Mdot
.48319 .0917 Mdot
.48324 .09174 Mdot
.48329 .09178 Mdot
.48333 .09182 Mdot
.48338 .09187 Mdot
.48343 .09191 Mdot
.48348 .09195 Mdot
.48353 .09199 Mdot
.48357 .09204 Mdot
.48362 .09208 Mdot
.48367 .09212 Mdot
.48372 .09216 Mdot
.48376 .09221 Mdot
.48381 .09225 Mdot
.48386 .09229 Mdot
.48391 .09234 Mdot
.48395 .09238 Mdot
.484 .09243 Mdot
.48405 .09247 Mdot
.4841 .09252 Mdot
.48414 .09256 Mdot
.48419 .09261 Mdot
.48424 .09265 Mdot
.48429 .0927 Mdot
.48433 .09274 Mdot
.48438 .09279 Mdot
.48443 .09283 Mdot
.48448 .09288 Mdot
.48453 .09293 Mdot
.48457 .09297 Mdot
.48462 .09302 Mdot
.48467 .09307 Mdot
.48472 .09311 Mdot
.48476 .09316 Mdot
.48481 .09321 Mdot
.48486 .09326 Mdot
.48491 .0933 Mdot
.48495 .09335 Mdot
.485 .0934 Mdot
.48505 .09345 Mdot
.4851 .0935 Mdot
.48514 .09354 Mdot
.48519 .09359 Mdot
.48524 .09364 Mdot
.48529 .09369 Mdot
.48533 .09374 Mdot
.48538 .09379 Mdot
.48543 .09384 Mdot
.48548 .09389 Mdot
.48553 .09394 Mdot
.48557 .09399 Mdot
.48562 .09404 Mdot
.48567 .09409 Mdot
.48572 .09414 Mdot
.48576 .0942 Mdot
.48581 .09425 Mdot
.48586 .0943 Mdot
.48591 .09435 Mdot
.48595 .0944 Mdot
.486 .09445 Mdot
.48605 .09451 Mdot
.4861 .09456 Mdot
.48614 .09461 Mdot
.48619 .09466 Mdot
.48624 .09472 Mdot
.48629 .09477 Mdot
.48633 .09482 Mdot
.48638 .09488 Mdot
.48643 .09493 Mdot
.48648 .09499 Mdot
.48653 .09504 Mdot
.48657 .09509 Mdot
.48662 .09515 Mdot
.48667 .0952 Mdot
.48672 .09526 Mdot
.48676 .09531 Mdot
.48681 .09537 Mdot
.48686 .09542 Mdot
.48691 .09548 Mdot
.48695 .09554 Mdot
.487 .09559 Mdot
.48705 .09565 Mdot
.4871 .0957 Mdot
.48714 .09576 Mdot
.48719 .09582 Mdot
.48724 .09587 Mdot
.48729 .09593 Mdot
.48733 .09599 Mdot
.48738 .09605 Mdot
.48743 .0961 Mdot
.48748 .09616 Mdot
.48753 .09622 Mdot
.48757 .09628 Mdot
.48762 .09634 Mdot
.48767 .0964 Mdot
.48772 .09645 Mdot
.48776 .09651 Mdot
.48781 .09657 Mdot
.48786 .09663 Mdot
.48791 .09669 Mdot
.48795 .09675 Mdot
.488 .09681 Mdot
.48805 .09687 Mdot
.4881 .09693 Mdot
.48814 .09699 Mdot
.48819 .09705 Mdot
.48824 .09711 Mdot
.48829 .09717 Mdot
.48833 .09724 Mdot
.48838 .0973 Mdot
.48843 .09736 Mdot
.48848 .09742 Mdot
.48852 .09748 Mdot
.48857 .09754 Mdot
.48862 .09761 Mdot
.48867 .09767 Mdot
.48872 .09773 Mdot
.48876 .09779 Mdot
.48881 .09786 Mdot
.48886 .09792 Mdot
.48891 .09798 Mdot
.48895 .09805 Mdot
.489 .09811 Mdot
.48905 .09817 Mdot
.4891 .09824 Mdot
.48914 .0983 Mdot
.48919 .09837 Mdot
.48924 .09843 Mdot
.48929 .0985 Mdot
.48933 .09856 Mdot
.48938 .09863 Mdot
.48943 .09869 Mdot
.48948 .09876 Mdot
.48952 .09882 Mdot
.48957 .09889 Mdot
.48962 .09896 Mdot
.48967 .09902 Mdot
.48972 .09909 Mdot
.48976 .09916 Mdot
.48981 .09922 Mdot
.48986 .09929 Mdot
.48991 .09936 Mdot
.48995 .09942 Mdot
.49 .09949 Mdot
.49005 .09956 Mdot
.4901 .09963 Mdot
.49014 .09969 Mdot
.49019 .09976 Mdot
.49024 .09983 Mdot
.49029 .0999 Mdot
.49033 .09997 Mdot
.49038 .10004 Mdot
.49043 .10011 Mdot
.49048 .10018 Mdot
.49052 .10025 Mdot
.49057 .10032 Mdot
.49062 .10039 Mdot
.49067 .10046 Mdot
.49072 .10053 Mdot
.49076 .1006 Mdot
.49081 .10067 Mdot
.49086 .10074 Mdot
.49091 .10081 Mdot
.49095 .10088 Mdot
.491 .10095 Mdot
.49105 .10102 Mdot
.4911 .10109 Mdot
.49114 .10117 Mdot
.49119 .10124 Mdot
.49124 .10131 Mdot
.49129 .10138 Mdot
.49133 .10145 Mdot
.49138 .10153 Mdot
.49143 .1016 Mdot
.49148 .10167 Mdot
.49152 .10175 Mdot
.49157 .10182 Mdot
.49162 .10189 Mdot
.49167 .10197 Mdot
.49172 .10204 Mdot
.49176 .10212 Mdot
.49181 .10219 Mdot
.49186 .10226 Mdot
.49191 .10234 Mdot
.49195 .10241 Mdot
.492 .10249 Mdot
.49205 .10256 Mdot
.4921 .10264 Mdot
.49214 .10271 Mdot
.49219 .10279 Mdot
.49224 .10287 Mdot
.49229 .10294 Mdot
.49233 .10302 Mdot
.49238 .10309 Mdot
.49243 .10317 Mdot
.49248 .10325 Mdot
.49252 .10333 Mdot
.49257 .1034 Mdot
.49262 .10348 Mdot
.49267 .10356 Mdot
.49272 .10363 Mdot
.49276 .10371 Mdot
.49281 .10379 Mdot
.49286 .10387 Mdot
.49291 .10395 Mdot
.49295 .10403 Mdot
.493 .1041 Mdot
.49305 .10418 Mdot
.4931 .10426 Mdot
.49314 .10434 Mdot
.49319 .10442 Mdot
.49324 .1045 Mdot
.49329 .10458 Mdot
.49333 .10466 Mdot
.49338 .10474 Mdot
.49343 .10482 Mdot
.49348 .1049 Mdot
.49352 .10498 Mdot
.49357 .10506 Mdot
.49362 .10514 Mdot
.49367 .10522 Mdot
.49371 .10531 Mdot
.49376 .10539 Mdot
.49381 .10547 Mdot
.49386 .10555 Mdot
.49391 .10563 Mdot
.49395 .10571 Mdot
.494 .1058 Mdot
.49405 .10588 Mdot
.4941 .10596 Mdot
.49414 .10604 Mdot
.49419 .10613 Mdot
.49424 .10621 Mdot
.49429 .10629 Mdot
.49433 .10638 Mdot
.49438 .10646 Mdot
.49443 .10655 Mdot
.49448 .10663 Mdot
.49452 .10671 Mdot
.49457 .1068 Mdot
.49462 .10688 Mdot
.49467 .10697 Mdot
.49471 .10705 Mdot
.49476 .10714 Mdot
.49481 .10722 Mdot
.49486 .10731 Mdot
.49491 .10739 Mdot
.49495 .10748 Mdot
.495 .10757 Mdot
.49505 .10765 Mdot
.4951 .10774 Mdot
.49514 .10782 Mdot
.49519 .10791 Mdot
.49524 .108 Mdot
.49529 .10808 Mdot
.49533 .10817 Mdot
.49538 .10826 Mdot
.49543 .10835 Mdot
.49548 .10843 Mdot
.49552 .10852 Mdot
.49557 .10861 Mdot
.49562 .1087 Mdot
.49567 .10879 Mdot
.49571 .10887 Mdot
.49576 .10896 Mdot
.49581 .10905 Mdot
.49586 .10914 Mdot
.49591 .10923 Mdot
.49595 .10932 Mdot
.496 .10941 Mdot
.49605 .1095 Mdot
.4961 .10959 Mdot
.49614 .10968 Mdot
.49619 .10977 Mdot
.49624 .10986 Mdot
.49629 .10995 Mdot
.49633 .11004 Mdot
.49638 .11013 Mdot
.49643 .11022 Mdot
.49648 .11031 Mdot
.49652 .1104 Mdot
.49657 .1105 Mdot
.49662 .11059 Mdot
.49667 .11068 Mdot
.49671 .11077 Mdot
.49676 .11086 Mdot
.49681 .11096 Mdot
.49686 .11105 Mdot
.49691 .11114 Mdot
.49695 .11123 Mdot
.497 .11133 Mdot
.49705 .11142 Mdot
.4971 .11151 Mdot
.49714 .11161 Mdot
.49719 .1117 Mdot
.49724 .11179 Mdot
.49729 .11189 Mdot
.49733 .11198 Mdot
.49738 .11208 Mdot
.49743 .11217 Mdot
.49748 .11227 Mdot
.49752 .11236 Mdot
.49757 .11246 Mdot
.49762 .11255 Mdot
.49767 .11265 Mdot
.49771 .11274 Mdot
.49776 .11284 Mdot
.49781 .11293 Mdot
.49786 .11303 Mdot
.4979 .11312 Mdot
.49795 .11322 Mdot
.498 .11332 Mdot
.49805 .11341 Mdot
.4981 .11351 Mdot
.49814 .11361 Mdot
.49819 .1137 Mdot
.49824 .1138 Mdot
.49829 .1139 Mdot
.49833 .114 Mdot
.49838 .11409 Mdot
.49843 .11419 Mdot
.49848 .11429 Mdot
.49852 .11439 Mdot
.49857 .11449 Mdot
.49862 .11459 Mdot
.49867 .11468 Mdot
.49871 .11478 Mdot
.49876 .11488 Mdot
.49881 .11498 Mdot
.49886 .11508 Mdot
.4989 .11518 Mdot
.49895 .11528 Mdot
.499 .11538 Mdot
.49905 .11548 Mdot
.4991 .11558 Mdot
.49914 .11568 Mdot
.49919 .11578 Mdot
.49924 .11588 Mdot
.49929 .11598 Mdot
.49933 .11608 Mdot
.49938 .11618 Mdot
.49943 .11629 Mdot
.49948 .11639 Mdot
.49952 .11649 Mdot
.49957 .11659 Mdot
.49962 .11669 Mdot
.49967 .11679 Mdot
.49971 .1169 Mdot
.49976 .117 Mdot
.49981 .1171 Mdot
.49986 .1172 Mdot
.4999 .11731 Mdot
.49995 .11741 Mdot
.5 .11751 Mdot
.50005 .11762 Mdot
.5001 .11772 Mdot
.50014 .11782 Mdot
.50019 .11793 Mdot
.50024 .11803 Mdot
.50029 .11814 Mdot
.50033 .11824 Mdot
.50038 .11834 Mdot
.50043 .11845 Mdot
.50048 .11855 Mdot
.50052 .11866 Mdot
.50057 .11876 Mdot
.50062 .11887 Mdot
.50067 .11897 Mdot
.50071 .11908 Mdot
.50076 .11919 Mdot
.50081 .11929 Mdot
.50086 .1194 Mdot
.5009 .1195 Mdot
.50095 .11961 Mdot
.501 .11972 Mdot
.50105 .11982 Mdot
.5011 .11993 Mdot
.50114 .12004 Mdot
.50119 .12014 Mdot
.50124 .12025 Mdot
.50129 .12036 Mdot
.50133 .12047 Mdot
.50138 .12057 Mdot
.50143 .12068 Mdot
.50148 .12079 Mdot
.50152 .1209 Mdot
.50157 .12101 Mdot
.50162 .12112 Mdot
.50167 .12122 Mdot
.50171 .12133 Mdot
.50176 .12144 Mdot
.50181 .12155 Mdot
.50186 .12166 Mdot
.5019 .12177 Mdot
.50195 .12188 Mdot
.502 .12199 Mdot
.50205 .1221 Mdot
.5021 .12221 Mdot
.50214 .12232 Mdot
.50219 .12243 Mdot
.50224 .12254 Mdot
.50229 .12265 Mdot
.50233 .12276 Mdot
.50238 .12287 Mdot
.50243 .12298 Mdot
.50248 .12309 Mdot
.50252 .12321 Mdot
.50257 .12332 Mdot
.50262 .12343 Mdot
.50267 .12354 Mdot
.50271 .12365 Mdot
.50276 .12377 Mdot
.50281 .12388 Mdot
.50286 .12399 Mdot
.5029 .1241 Mdot
.50295 .12422 Mdot
.503 .12433 Mdot
.50305 .12444 Mdot
.50309 .12455 Mdot
.50314 .12467 Mdot
.50319 .12478 Mdot
.50324 .1249 Mdot
.50329 .12501 Mdot
.50333 .12512 Mdot
.50338 .12524 Mdot
.50343 .12535 Mdot
.50348 .12547 Mdot
.50352 .12558 Mdot
.50357 .1257 Mdot
.50362 .12581 Mdot
.50367 .12593 Mdot
.50371 .12604 Mdot
.50376 .12616 Mdot
.50381 .12627 Mdot
.50386 .12639 Mdot
.5039 .1265 Mdot
.50395 .12662 Mdot
.504 .12673 Mdot
.50405 .12685 Mdot
.50409 .12697 Mdot
.50414 .12708 Mdot
.50419 .1272 Mdot
.50424 .12732 Mdot
.50429 .12743 Mdot
.50433 .12755 Mdot
.50438 .12767 Mdot
.50443 .12779 Mdot
.50448 .1279 Mdot
.50452 .12802 Mdot
.50457 .12814 Mdot
.50462 .12826 Mdot
.50467 .12838 Mdot
.50471 .12849 Mdot
.50476 .12861 Mdot
.50481 .12873 Mdot
.50486 .12885 Mdot
.5049 .12897 Mdot
.50495 .12909 Mdot
.505 .12921 Mdot
.50505 .12933 Mdot
.50509 .12945 Mdot
.50514 .12956 Mdot
.50519 .12968 Mdot
.50524 .1298 Mdot
.50529 .12992 Mdot
.50533 .13004 Mdot
.50538 .13016 Mdot
.50543 .13029 Mdot
.50548 .13041 Mdot
.50552 .13053 Mdot
.50557 .13065 Mdot
.50562 .13077 Mdot
.50567 .13089 Mdot
.50571 .13101 Mdot
.50576 .13113 Mdot
.50581 .13125 Mdot
.50586 .13138 Mdot
.5059 .1315 Mdot
.50595 .13162 Mdot
.506 .13174 Mdot
.50605 .13186 Mdot
.50609 .13199 Mdot
.50614 .13211 Mdot
.50619 .13223 Mdot
.50624 .13235 Mdot
.50629 .13248 Mdot
.50633 .1326 Mdot
.50638 .13272 Mdot
.50643 .13285 Mdot
.50648 .13297 Mdot
.50652 .13309 Mdot
.50657 .13322 Mdot
.50662 .13334 Mdot
.50667 .13347 Mdot
.50671 .13359 Mdot
.50676 .13372 Mdot
.50681 .13384 Mdot
.50686 .13396 Mdot
.5069 .13409 Mdot
.50695 .13421 Mdot
.507 .13434 Mdot
.50705 .13447 Mdot
.50709 .13459 Mdot
.50714 .13472 Mdot
.50719 .13484 Mdot
.50724 .13497 Mdot
.50728 .13509 Mdot
.50733 .13522 Mdot
.50738 .13535 Mdot
.50743 .13547 Mdot
.50748 .1356 Mdot
.50752 .13573 Mdot
.50757 .13585 Mdot
.50762 .13598 Mdot
.50767 .13611 Mdot
.50771 .13623 Mdot
.50776 .13636 Mdot
.50781 .13649 Mdot
.50786 .13662 Mdot
.5079 .13674 Mdot
.50795 .13687 Mdot
.508 .137 Mdot
.50805 .13713 Mdot
.50809 .13726 Mdot
.50814 .13738 Mdot
.50819 .13751 Mdot
.50824 .13764 Mdot
.50828 .13777 Mdot
.50833 .1379 Mdot
.50838 .13803 Mdot
.50843 .13816 Mdot
.50848 .13829 Mdot
.50852 .13842 Mdot
.50857 .13855 Mdot
.50862 .13868 Mdot
.50867 .13881 Mdot
.50871 .13894 Mdot
.50876 .13907 Mdot
.50881 .1392 Mdot
.50886 .13933 Mdot
.5089 .13946 Mdot
.50895 .13959 Mdot
.509 .13972 Mdot
.50905 .13985 Mdot
.50909 .13998 Mdot
.50914 .14011 Mdot
.50919 .14024 Mdot
.50924 .14038 Mdot
.50928 .14051 Mdot
.50933 .14064 Mdot
.50938 .14077 Mdot
.50943 .1409 Mdot
.50948 .14104 Mdot
.50952 .14117 Mdot
.50957 .1413 Mdot
.50962 .14143 Mdot
.50967 .14157 Mdot
.50971 .1417 Mdot
.50976 .14183 Mdot
.50981 .14196 Mdot
.50986 .1421 Mdot
.5099 .14223 Mdot
.50995 .14236 Mdot
.51 .1425 Mdot
.51005 .14263 Mdot
.51009 .14277 Mdot
.51014 .1429 Mdot
.51019 .14303 Mdot
.51024 .14317 Mdot
.51028 .1433 Mdot
.51033 .14344 Mdot
.51038 .14357 Mdot
.51043 .14371 Mdot
.51048 .14384 Mdot
.51052 .14398 Mdot
.51057 .14411 Mdot
.51062 .14425 Mdot
.51067 .14438 Mdot
.51071 .14452 Mdot
.51076 .14465 Mdot
.51081 .14479 Mdot
.51086 .14493 Mdot
.5109 .14506 Mdot
.51095 .1452 Mdot
.511 .14533 Mdot
.51105 .14547 Mdot
.51109 .14561 Mdot
.51114 .14574 Mdot
.51119 .14588 Mdot
.51124 .14602 Mdot
.51128 .14616 Mdot
.51133 .14629 Mdot
.51138 .14643 Mdot
.51143 .14657 Mdot
.51148 .1467 Mdot
.51152 .14684 Mdot
.51157 .14698 Mdot
.51162 .14712 Mdot
.51167 .14726 Mdot
.51171 .14739 Mdot
.51176 .14753 Mdot
.51181 .14767 Mdot
.51186 .14781 Mdot
.5119 .14795 Mdot
.51195 .14809 Mdot
.512 .14823 Mdot
.51205 .14837 Mdot
.51209 .14851 Mdot
.51214 .14864 Mdot
.51219 .14878 Mdot
.51224 .14892 Mdot
.51228 .14906 Mdot
.51233 .1492 Mdot
.51238 .14934 Mdot
.51243 .14948 Mdot
.51247 .14962 Mdot
.51252 .14976 Mdot
.51257 .1499 Mdot
.51262 .15004 Mdot
.51267 .15019 Mdot
.51271 .15033 Mdot
.51276 .15047 Mdot
.51281 .15061 Mdot
.51286 .15075 Mdot
.5129 .15089 Mdot
.51295 .15103 Mdot
.513 .15117 Mdot
.51305 .15132 Mdot
.51309 .15146 Mdot
.51314 .1516 Mdot
.51319 .15174 Mdot
.51324 .15188 Mdot
.51328 .15203 Mdot
.51333 .15217 Mdot
.51338 .15231 Mdot
.51343 .15245 Mdot
.51347 .1526 Mdot
.51352 .15274 Mdot
.51357 .15288 Mdot
.51362 .15303 Mdot
.51367 .15317 Mdot
.51371 .15331 Mdot
.51376 .15346 Mdot
.51381 .1536 Mdot
.51386 .15374 Mdot
.5139 .15389 Mdot
.51395 .15403 Mdot
.514 .15417 Mdot
.51405 .15432 Mdot
.51409 .15446 Mdot
.51414 .15461 Mdot
.51419 .15475 Mdot
.51424 .1549 Mdot
.51428 .15504 Mdot
.51433 .15519 Mdot
.51438 .15533 Mdot
.51443 .15548 Mdot
.51447 .15562 Mdot
.51452 .15577 Mdot
.51457 .15591 Mdot
.51462 .15606 Mdot
.51467 .1562 Mdot
.51471 .15635 Mdot
.51476 .1565 Mdot
.51481 .15664 Mdot
.51486 .15679 Mdot
.5149 .15693 Mdot
.51495 .15708 Mdot
.515 .15723 Mdot
.51505 .15737 Mdot
.51509 .15752 Mdot
.51514 .15767 Mdot
.51519 .15781 Mdot
.51524 .15796 Mdot
.51528 .15811 Mdot
.51533 .15826 Mdot
.51538 .1584 Mdot
.51543 .15855 Mdot
.51547 .1587 Mdot
.51552 .15885 Mdot
.51557 .15899 Mdot
.51562 .15914 Mdot
.51567 .15929 Mdot
.51571 .15944 Mdot
.51576 .15959 Mdot
.51581 .15973 Mdot
.51586 .15988 Mdot
.5159 .16003 Mdot
.51595 .16018 Mdot
.516 .16033 Mdot
.51605 .16048 Mdot
.51609 .16063 Mdot
.51614 .16078 Mdot
.51619 .16093 Mdot
.51624 .16108 Mdot
.51628 .16123 Mdot
.51633 .16138 Mdot
.51638 .16152 Mdot
.51643 .16167 Mdot
.51647 .16182 Mdot
.51652 .16197 Mdot
.51657 .16212 Mdot
.51662 .16228 Mdot
.51667 .16243 Mdot
.51671 .16258 Mdot
.51676 .16273 Mdot
.51681 .16288 Mdot
.51686 .16303 Mdot
.5169 .16318 Mdot
.51695 .16333 Mdot
.517 .16348 Mdot
.51705 .16363 Mdot
.51709 .16378 Mdot
.51714 .16394 Mdot
.51719 .16409 Mdot
.51724 .16424 Mdot
.51728 .16439 Mdot
.51733 .16454 Mdot
.51738 .16469 Mdot
.51743 .16485 Mdot
.51747 .165 Mdot
.51752 .16515 Mdot
.51757 .1653 Mdot
.51762 .16546 Mdot
.51766 .16561 Mdot
.51771 .16576 Mdot
.51776 .16591 Mdot
.51781 .16607 Mdot
.51786 .16622 Mdot
.5179 .16637 Mdot
.51795 .16653 Mdot
.518 .16668 Mdot
.51805 .16683 Mdot
.51809 .16699 Mdot
.51814 .16714 Mdot
.51819 .1673 Mdot
.51824 .16745 Mdot
.51828 .1676 Mdot
.51833 .16776 Mdot
.51838 .16791 Mdot
.51843 .16807 Mdot
.51847 .16822 Mdot
.51852 .16838 Mdot
.51857 .16853 Mdot
.51862 .16868 Mdot
.51866 .16884 Mdot
.51871 .16899 Mdot
.51876 .16915 Mdot
.51881 .1693 Mdot
.51886 .16946 Mdot
.5189 .16962 Mdot
.51895 .16977 Mdot
.519 .16993 Mdot
.51905 .17008 Mdot
.51909 .17024 Mdot
.51914 .17039 Mdot
.51919 .17055 Mdot
.51924 .17071 Mdot
.51928 .17086 Mdot
.51933 .17102 Mdot
.51938 .17117 Mdot
.51943 .17133 Mdot
.51947 .17149 Mdot
.51952 .17164 Mdot
.51957 .1718 Mdot
.51962 .17196 Mdot
.51966 .17211 Mdot
.51971 .17227 Mdot
.51976 .17243 Mdot
.51981 .17259 Mdot
.51986 .17274 Mdot
.5199 .1729 Mdot
.51995 .17306 Mdot
.52 .17322 Mdot
.52005 .17337 Mdot
.52009 .17353 Mdot
.52014 .17369 Mdot
.52019 .17385 Mdot
.52024 .17401 Mdot
.52028 .17416 Mdot
.52033 .17432 Mdot
.52038 .17448 Mdot
.52043 .17464 Mdot
.52047 .1748 Mdot
.52052 .17496 Mdot
.52057 .17512 Mdot
.52062 .17527 Mdot
.52066 .17543 Mdot
.52071 .17559 Mdot
.52076 .17575 Mdot
.52081 .17591 Mdot
.52086 .17607 Mdot
.5209 .17623 Mdot
.52095 .17639 Mdot
.521 .17655 Mdot
.52105 .17671 Mdot
.52109 .17687 Mdot
.52114 .17703 Mdot
.52119 .17719 Mdot
.52124 .17735 Mdot
.52128 .17751 Mdot
.52133 .17767 Mdot
.52138 .17783 Mdot
.52143 .17799 Mdot
.52147 .17815 Mdot
.52152 .17831 Mdot
.52157 .17847 Mdot
.52162 .17863 Mdot
.52166 .17879 Mdot
.52171 .17895 Mdot
.52176 .17912 Mdot
.52181 .17928 Mdot
.52185 .17944 Mdot
.5219 .1796 Mdot
.52195 .17976 Mdot
.522 .17992 Mdot
.52205 .18008 Mdot
.52209 .18025 Mdot
.52214 .18041 Mdot
.52219 .18057 Mdot
.52224 .18073 Mdot
.52228 .18089 Mdot
.52233 .18106 Mdot
.52238 .18122 Mdot
.52243 .18138 Mdot
.52247 .18154 Mdot
.52252 .18171 Mdot
.52257 .18187 Mdot
.52262 .18203 Mdot
.52266 .18219 Mdot
.52271 .18236 Mdot
.52276 .18252 Mdot
.52281 .18268 Mdot
.52285 .18285 Mdot
.5229 .18301 Mdot
.52295 .18317 Mdot
.523 .18334 Mdot
.52305 .1835 Mdot
.52309 .18366 Mdot
.52314 .18383 Mdot
.52319 .18399 Mdot
.52324 .18416 Mdot
.52328 .18432 Mdot
.52333 .18448 Mdot
.52338 .18465 Mdot
.52343 .18481 Mdot
.52347 .18498 Mdot
.52352 .18514 Mdot
.52357 .1853 Mdot
.52362 .18547 Mdot
.52366 .18563 Mdot
.52371 .1858 Mdot
.52376 .18596 Mdot
.52381 .18613 Mdot
.52385 .18629 Mdot
.5239 .18646 Mdot
.52395 .18662 Mdot
.524 .18679 Mdot
.52405 .18695 Mdot
.52409 .18712 Mdot
.52414 .18728 Mdot
.52419 .18745 Mdot
.52424 .18762 Mdot
.52428 .18778 Mdot
.52433 .18795 Mdot
.52438 .18811 Mdot
.52443 .18828 Mdot
.52447 .18845 Mdot
.52452 .18861 Mdot
.52457 .18878 Mdot
.52462 .18894 Mdot
.52466 .18911 Mdot
.52471 .18928 Mdot
.52476 .18944 Mdot
.52481 .18961 Mdot
.52485 .18978 Mdot
.5249 .18994 Mdot
.52495 .19011 Mdot
.525 .19028 Mdot
.52505 .19044 Mdot
.52509 .19061 Mdot
.52514 .19078 Mdot
.52519 .19095 Mdot
.52524 .19111 Mdot
.52528 .19128 Mdot
.52533 .19145 Mdot
.52538 .19162 Mdot
.52543 .19178 Mdot
.52547 .19195 Mdot
.52552 .19212 Mdot
.52557 .19229 Mdot
.52562 .19245 Mdot
.52566 .19262 Mdot
.52571 .19279 Mdot
.52576 .19296 Mdot
.52581 .19313 Mdot
.52585 .1933 Mdot
.5259 .19346 Mdot
.52595 .19363 Mdot
.526 .1938 Mdot
.52605 .19397 Mdot
.52609 .19414 Mdot
.52614 .19431 Mdot
.52619 .19448 Mdot
.52624 .19465 Mdot
.52628 .19481 Mdot
.52633 .19498 Mdot
.52638 .19515 Mdot
.52643 .19532 Mdot
.52647 .19549 Mdot
.52652 .19566 Mdot
.52657 .19583 Mdot
.52662 .196 Mdot
.52666 .19617 Mdot
.52671 .19634 Mdot
.52676 .19651 Mdot
.52681 .19668 Mdot
.52685 .19685 Mdot
.5269 .19702 Mdot
.52695 .19719 Mdot
.527 .19736 Mdot
.52704 .19753 Mdot
.52709 .1977 Mdot
.52714 .19787 Mdot
.52719 .19804 Mdot
.52724 .19821 Mdot
.52728 .19838 Mdot
.52733 .19855 Mdot
.52738 .19872 Mdot
.52743 .19889 Mdot
.52747 .19906 Mdot
.52752 .19923 Mdot
.52757 .19941 Mdot
.52762 .19958 Mdot
.52766 .19975 Mdot
.52771 .19992 Mdot
.52776 .20009 Mdot
.52781 .20026 Mdot
.52785 .20043 Mdot
.5279 .2006 Mdot
.52795 .20078 Mdot
.528 .20095 Mdot
.52804 .20112 Mdot
.52809 .20129 Mdot
.52814 .20146 Mdot
.52819 .20163 Mdot
.52824 .20181 Mdot
.52828 .20198 Mdot
.52833 .20215 Mdot
.52838 .20232 Mdot
.52843 .20249 Mdot
.52847 .20267 Mdot
.52852 .20284 Mdot
.52857 .20301 Mdot
.52862 .20318 Mdot
.52866 .20336 Mdot
.52871 .20353 Mdot
.52876 .2037 Mdot
.52881 .20387 Mdot
.52885 .20405 Mdot
.5289 .20422 Mdot
.52895 .20439 Mdot
.529 .20457 Mdot
.52904 .20474 Mdot
.52909 .20491 Mdot
.52914 .20509 Mdot
.52919 .20526 Mdot
.52924 .20543 Mdot
.52928 .20561 Mdot
.52933 .20578 Mdot
.52938 .20595 Mdot
.52943 .20613 Mdot
.52947 .2063 Mdot
.52952 .20647 Mdot
.52957 .20665 Mdot
.52962 .20682 Mdot
.52966 .20699 Mdot
.52971 .20717 Mdot
.52976 .20734 Mdot
.52981 .20752 Mdot
.52985 .20769 Mdot
.5299 .20786 Mdot
.52995 .20804 Mdot
.53 .20821 Mdot
.53004 .20839 Mdot
.53009 .20856 Mdot
.53014 .20874 Mdot
.53019 .20891 Mdot
.53024 .20909 Mdot
.53028 .20926 Mdot
.53033 .20943 Mdot
.53038 .20961 Mdot
.53043 .20978 Mdot
.53047 .20996 Mdot
.53052 .21013 Mdot
.53057 .21031 Mdot
.53062 .21048 Mdot
.53066 .21066 Mdot
.53071 .21083 Mdot
.53076 .21101 Mdot
.53081 .21119 Mdot
.53085 .21136 Mdot
.5309 .21154 Mdot
.53095 .21171 Mdot
.531 .21189 Mdot
.53104 .21206 Mdot
.53109 .21224 Mdot
.53114 .21241 Mdot
.53119 .21259 Mdot
.53123 .21277 Mdot
.53128 .21294 Mdot
.53133 .21312 Mdot
.53138 .21329 Mdot
.53143 .21347 Mdot
.53147 .21365 Mdot
.53152 .21382 Mdot
.53157 .214 Mdot
.53162 .21417 Mdot
.53166 .21435 Mdot
.53171 .21453 Mdot
.53176 .2147 Mdot
.53181 .21488 Mdot
.53185 .21506 Mdot
.5319 .21523 Mdot
.53195 .21541 Mdot
.532 .21559 Mdot
.53204 .21576 Mdot
.53209 .21594 Mdot
.53214 .21612 Mdot
.53219 .21629 Mdot
.53223 .21647 Mdot
.53228 .21665 Mdot
.53233 .21682 Mdot
.53238 .217 Mdot
.53243 .21718 Mdot
.53247 .21736 Mdot
.53252 .21753 Mdot
.53257 .21771 Mdot
.53262 .21789 Mdot
.53266 .21807 Mdot
.53271 .21824 Mdot
.53276 .21842 Mdot
.53281 .2186 Mdot
.53285 .21878 Mdot
.5329 .21895 Mdot
.53295 .21913 Mdot
.533 .21931 Mdot
.53304 .21949 Mdot
.53309 .21966 Mdot
.53314 .21984 Mdot
.53319 .22002 Mdot
.53323 .2202 Mdot
.53328 .22038 Mdot
.53333 .22055 Mdot
.53338 .22073 Mdot
.53343 .22091 Mdot
.53347 .22109 Mdot
.53352 .22127 Mdot
.53357 .22145 Mdot
.53362 .22162 Mdot
.53366 .2218 Mdot
.53371 .22198 Mdot
.53376 .22216 Mdot
.53381 .22234 Mdot
.53385 .22252 Mdot
.5339 .2227 Mdot
.53395 .22287 Mdot
.534 .22305 Mdot
.53404 .22323 Mdot
.53409 .22341 Mdot
.53414 .22359 Mdot
.53419 .22377 Mdot
.53423 .22395 Mdot
.53428 .22413 Mdot
.53433 .22431 Mdot
.53438 .22448 Mdot
.53443 .22466 Mdot
.53447 .22484 Mdot
.53452 .22502 Mdot
.53457 .2252 Mdot
.53462 .22538 Mdot
.53466 .22556 Mdot
.53471 .22574 Mdot
.53476 .22592 Mdot
.53481 .2261 Mdot
.53485 .22628 Mdot
.5349 .22646 Mdot
.53495 .22664 Mdot
.535 .22682 Mdot
.53504 .227 Mdot
.53509 .22718 Mdot
.53514 .22736 Mdot
.53519 .22754 Mdot
.53523 .22772 Mdot
.53528 .2279 Mdot
.53533 .22808 Mdot
.53538 .22826 Mdot
.53543 .22844 Mdot
.53547 .22862 Mdot
.53552 .2288 Mdot
.53557 .22898 Mdot
.53562 .22916 Mdot
.53566 .22934 Mdot
.53571 .22952 Mdot
.53576 .2297 Mdot
.53581 .22988 Mdot
.53585 .23006 Mdot
.5359 .23024 Mdot
.53595 .23042 Mdot
.536 .2306 Mdot
.53604 .23078 Mdot
.53609 .23096 Mdot
.53614 .23114 Mdot
.53619 .23132 Mdot
.53623 .2315 Mdot
.53628 .23168 Mdot
.53633 .23186 Mdot
.53638 .23205 Mdot
.53642 .23223 Mdot
.53647 .23241 Mdot
.53652 .23259 Mdot
.53657 .23277 Mdot
.53662 .23295 Mdot
.53666 .23313 Mdot
.53671 .23331 Mdot
.53676 .23349 Mdot
.53681 .23367 Mdot
.53685 .23386 Mdot
.5369 .23404 Mdot
.53695 .23422 Mdot
.537 .2344 Mdot
.53704 .23458 Mdot
.53709 .23476 Mdot
.53714 .23494 Mdot
.53719 .23512 Mdot
.53723 .23531 Mdot
.53728 .23549 Mdot
.53733 .23567 Mdot
.53738 .23585 Mdot
.53742 .23603 Mdot
.53747 .23621 Mdot
.53752 .2364 Mdot
.53757 .23658 Mdot
.53762 .23676 Mdot
.53766 .23694 Mdot
.53771 .23712 Mdot
.53776 .2373 Mdot
.53781 .23749 Mdot
.53785 .23767 Mdot
.5379 .23785 Mdot
.53795 .23803 Mdot
.538 .23821 Mdot
.53804 .2384 Mdot
.53809 .23858 Mdot
.53814 .23876 Mdot
.53819 .23894 Mdot
.53823 .23912 Mdot
.53828 .23931 Mdot
.53833 .23949 Mdot
.53838 .23967 Mdot
.53842 .23985 Mdot
.53847 .24003 Mdot
.53852 .24022 Mdot
.53857 .2404 Mdot
.53862 .24058 Mdot
.53866 .24076 Mdot
.53871 .24095 Mdot
.53876 .24113 Mdot
.53881 .24131 Mdot
.53885 .24149 Mdot
.5389 .24168 Mdot
.53895 .24186 Mdot
.539 .24204 Mdot
.53904 .24222 Mdot
.53909 .24241 Mdot
.53914 .24259 Mdot
.53919 .24277 Mdot
.53923 .24295 Mdot
.53928 .24314 Mdot
.53933 .24332 Mdot
.53938 .2435 Mdot
.53942 .24368 Mdot
.53947 .24387 Mdot
.53952 .24405 Mdot
.53957 .24423 Mdot
.53962 .24442 Mdot
.53966 .2446 Mdot
.53971 .24478 Mdot
.53976 .24496 Mdot
.53981 .24515 Mdot
.53985 .24533 Mdot
.5399 .24551 Mdot
.53995 .2457 Mdot
.54 .24588 Mdot
.54004 .24606 Mdot
.54009 .24625 Mdot
.54014 .24643 Mdot
.54019 .24661 Mdot
.54023 .24679 Mdot
.54028 .24698 Mdot
.54033 .24716 Mdot
.54038 .24734 Mdot
.54042 .24753 Mdot
.54047 .24771 Mdot
.54052 .24789 Mdot
.54057 .24808 Mdot
.54061 .24826 Mdot
.54066 .24844 Mdot
.54071 .24863 Mdot
.54076 .24881 Mdot
.54081 .24899 Mdot
.54085 .24918 Mdot
.5409 .24936 Mdot
.54095 .24954 Mdot
.541 .24973 Mdot
.54104 .24991 Mdot
.54109 .25009 Mdot
.54114 .25028 Mdot
.54119 .25046 Mdot
.54123 .25065 Mdot
.54128 .25083 Mdot
.54133 .25101 Mdot
.54138 .2512 Mdot
.54142 .25138 Mdot
.54147 .25156 Mdot
.54152 .25175 Mdot
.54157 .25193 Mdot
.54161 .25211 Mdot
.54166 .2523 Mdot
.54171 .25248 Mdot
.54176 .25267 Mdot
.54181 .25285 Mdot
.54185 .25303 Mdot
.5419 .25322 Mdot
.54195 .2534 Mdot
.542 .25358 Mdot
.54204 .25377 Mdot
.54209 .25395 Mdot
.54214 .25414 Mdot
.54219 .25432 Mdot
.54223 .2545 Mdot
.54228 .25469 Mdot
.54233 .25487 Mdot
.54238 .25506 Mdot
.54242 .25524 Mdot
.54247 .25542 Mdot
.54252 .25561 Mdot
.54257 .25579 Mdot
.54261 .25598 Mdot
.54266 .25616 Mdot
.54271 .25634 Mdot
.54276 .25653 Mdot
.54281 .25671 Mdot
.54285 .2569 Mdot
.5429 .25708 Mdot
.54295 .25726 Mdot
.543 .25745 Mdot
.54304 .25763 Mdot
.54309 .25782 Mdot
.54314 .258 Mdot
.54319 .25818 Mdot
.54323 .25837 Mdot
.54328 .25855 Mdot
.54333 .25874 Mdot
.54338 .25892 Mdot
.54342 .2591 Mdot
.54347 .25929 Mdot
.54352 .25947 Mdot
.54357 .25966 Mdot
.54361 .25984 Mdot
.54366 .26003 Mdot
.54371 .26021 Mdot
.54376 .26039 Mdot
.54381 .26058 Mdot
.54385 .26076 Mdot
.5439 .26095 Mdot
.54395 .26113 Mdot
.544 .26131 Mdot
.54404 .2615 Mdot
.54409 .26168 Mdot
.54414 .26187 Mdot
.54419 .26205 Mdot
.54423 .26224 Mdot
.54428 .26242 Mdot
.54433 .2626 Mdot
.54438 .26279 Mdot
.54442 .26297 Mdot
.54447 .26316 Mdot
.54452 .26334 Mdot
.54457 .26353 Mdot
.54461 .26371 Mdot
.54466 .26389 Mdot
.54471 .26408 Mdot
.54476 .26426 Mdot
.54481 .26445 Mdot
.54485 .26463 Mdot
.5449 .26482 Mdot
.54495 .265 Mdot
.545 .26519 Mdot
.54504 .26537 Mdot
.54509 .26555 Mdot
.54514 .26574 Mdot
.54519 .26592 Mdot
.54523 .26611 Mdot
.54528 .26629 Mdot
.54533 .26648 Mdot
.54538 .26666 Mdot
.54542 .26684 Mdot
.54547 .26703 Mdot
.54552 .26721 Mdot
.54557 .2674 Mdot
.54561 .26758 Mdot
.54566 .26777 Mdot
.54571 .26795 Mdot
.54576 .26814 Mdot
.5458 .26832 Mdot
.54585 .2685 Mdot
.5459 .26869 Mdot
.54595 .26887 Mdot
.546 .26906 Mdot
.54604 .26924 Mdot
.54609 .26943 Mdot
.54614 .26961 Mdot
.54619 .26979 Mdot
.54623 .26998 Mdot
.54628 .27016 Mdot
.54633 .27035 Mdot
.54638 .27053 Mdot
.54642 .27072 Mdot
.54647 .2709 Mdot
.54652 .27108 Mdot
.54657 .27127 Mdot
.54661 .27145 Mdot
.54666 .27164 Mdot
.54671 .27182 Mdot
.54676 .27201 Mdot
.5468 .27219 Mdot
.54685 .27238 Mdot
.5469 .27256 Mdot
.54695 .27274 Mdot
.547 .27293 Mdot
.54704 .27311 Mdot
.54709 .2733 Mdot
.54714 .27348 Mdot
.54719 .27367 Mdot
.54723 .27385 Mdot
.54728 .27403 Mdot
.54733 .27422 Mdot
.54738 .2744 Mdot
.54742 .27459 Mdot
.54747 .27477 Mdot
.54752 .27496 Mdot
.54757 .27514 Mdot
.54761 .27532 Mdot
.54766 .27551 Mdot
.54771 .27569 Mdot
.54776 .27588 Mdot
.5478 .27606 Mdot
.54785 .27624 Mdot
.5479 .27643 Mdot
.54795 .27661 Mdot
.548 .2768 Mdot
.54804 .27698 Mdot
.54809 .27717 Mdot
.54814 .27735 Mdot
.54819 .27753 Mdot
.54823 .27772 Mdot
.54828 .2779 Mdot
.54833 .27809 Mdot
.54838 .27827 Mdot
.54842 .27845 Mdot
.54847 .27864 Mdot
.54852 .27882 Mdot
.54857 .27901 Mdot
.54861 .27919 Mdot
.54866 .27937 Mdot
.54871 .27956 Mdot
.54876 .27974 Mdot
.5488 .27993 Mdot
.54885 .28011 Mdot
.5489 .28029 Mdot
.54895 .28048 Mdot
.549 .28066 Mdot
.54904 .28085 Mdot
.54909 .28103 Mdot
.54914 .28121 Mdot
.54919 .2814 Mdot
.54923 .28158 Mdot
.54928 .28177 Mdot
.54933 .28195 Mdot
.54938 .28213 Mdot
.54942 .28232 Mdot
.54947 .2825 Mdot
.54952 .28268 Mdot
.54957 .28287 Mdot
.54961 .28305 Mdot
.54966 .28324 Mdot
.54971 .28342 Mdot
.54976 .2836 Mdot
.5498 .28379 Mdot
.54985 .28397 Mdot
.5499 .28415 Mdot
.54995 .28434 Mdot
.55 .28452 Mdot
.55004 .28471 Mdot
.55009 .28489 Mdot
.55014 .28507 Mdot
.55019 .28526 Mdot
.55023 .28544 Mdot
.55028 .28562 Mdot
.55033 .28581 Mdot
.55038 .28599 Mdot
.55042 .28617 Mdot
.55047 .28636 Mdot
.55052 .28654 Mdot
.55057 .28672 Mdot
.55061 .28691 Mdot
.55066 .28709 Mdot
.55071 .28727 Mdot
.55076 .28746 Mdot
.5508 .28764 Mdot
.55085 .28782 Mdot
.5509 .28801 Mdot
.55095 .28819 Mdot
.55099 .28837 Mdot
.55104 .28856 Mdot
.55109 .28874 Mdot
.55114 .28892 Mdot
.55119 .28911 Mdot
.55123 .28929 Mdot
.55128 .28947 Mdot
.55133 .28966 Mdot
.55138 .28984 Mdot
.55142 .29002 Mdot
.55147 .29021 Mdot
.55152 .29039 Mdot
.55157 .29057 Mdot
.55161 .29075 Mdot
.55166 .29094 Mdot
.55171 .29112 Mdot
.55176 .2913 Mdot
.5518 .29149 Mdot
.55185 .29167 Mdot
.5519 .29185 Mdot
.55195 .29203 Mdot
.55199 .29222 Mdot
.55204 .2924 Mdot
.55209 .29258 Mdot
.55214 .29277 Mdot
.55219 .29295 Mdot
.55223 .29313 Mdot
.55228 .29331 Mdot
.55233 .2935 Mdot
.55238 .29368 Mdot
.55242 .29386 Mdot
.55247 .29404 Mdot
.55252 .29423 Mdot
.55257 .29441 Mdot
.55261 .29459 Mdot
.55266 .29477 Mdot
.55271 .29496 Mdot
.55276 .29514 Mdot
.5528 .29532 Mdot
.55285 .2955 Mdot
.5529 .29568 Mdot
.55295 .29587 Mdot
.55299 .29605 Mdot
.55304 .29623 Mdot
.55309 .29641 Mdot
.55314 .2966 Mdot
.55319 .29678 Mdot
.55323 .29696 Mdot
.55328 .29714 Mdot
.55333 .29732 Mdot
.55338 .29751 Mdot
.55342 .29769 Mdot
.55347 .29787 Mdot
.55352 .29805 Mdot
.55357 .29823 Mdot
.55361 .29842 Mdot
.55366 .2986 Mdot
.55371 .29878 Mdot
.55376 .29896 Mdot
.5538 .29914 Mdot
.55385 .29932 Mdot
.5539 .29951 Mdot
.55395 .29969 Mdot
.55399 .29987 Mdot
.55404 .30005 Mdot
.55409 .30023 Mdot
.55414 .30041 Mdot
.55419 .3006 Mdot
.55423 .30078 Mdot
.55428 .30096 Mdot
.55433 .30114 Mdot
.55438 .30132 Mdot
.55442 .3015 Mdot
.55447 .30168 Mdot
.55452 .30187 Mdot
.55457 .30205 Mdot
.55461 .30223 Mdot
.55466 .30241 Mdot
.55471 .30259 Mdot
.55476 .30277 Mdot
.5548 .30295 Mdot
.55485 .30313 Mdot
.5549 .30331 Mdot
.55495 .30349 Mdot
.55499 .30368 Mdot
.55504 .30386 Mdot
.55509 .30404 Mdot
.55514 .30422 Mdot
.55518 .3044 Mdot
.55523 .30458 Mdot
.55528 .30476 Mdot
.55533 .30494 Mdot
.55538 .30512 Mdot
.55542 .3053 Mdot
.55547 .30548 Mdot
.55552 .30566 Mdot
.55557 .30584 Mdot
.55561 .30602 Mdot
.55566 .3062 Mdot
.55571 .30638 Mdot
.55576 .30657 Mdot
.5558 .30675 Mdot
.55585 .30693 Mdot
.5559 .30711 Mdot
.55595 .30729 Mdot
.55599 .30747 Mdot
.55604 .30765 Mdot
.55609 .30783 Mdot
.55614 .30801 Mdot
.55618 .30819 Mdot
.55623 .30837 Mdot
.55628 .30855 Mdot
.55633 .30873 Mdot
.55638 .30891 Mdot
.55642 .30909 Mdot
.55647 .30927 Mdot
.55652 .30945 Mdot
.55657 .30962 Mdot
.55661 .3098 Mdot
.55666 .30998 Mdot
.55671 .31016 Mdot
.55676 .31034 Mdot
.5568 .31052 Mdot
.55685 .3107 Mdot
.5569 .31088 Mdot
.55695 .31106 Mdot
.55699 .31124 Mdot
.55704 .31142 Mdot
.55709 .3116 Mdot
.55714 .31178 Mdot
.55718 .31196 Mdot
.55723 .31214 Mdot
.55728 .31231 Mdot
.55733 .31249 Mdot
.55738 .31267 Mdot
.55742 .31285 Mdot
.55747 .31303 Mdot
.55752 .31321 Mdot
.55757 .31339 Mdot
.55761 .31357 Mdot
.55766 .31374 Mdot
.55771 .31392 Mdot
.55776 .3141 Mdot
.5578 .31428 Mdot
.55785 .31446 Mdot
.5579 .31464 Mdot
.55795 .31482 Mdot
.55799 .31499 Mdot
.55804 .31517 Mdot
.55809 .31535 Mdot
.55814 .31553 Mdot
.55818 .31571 Mdot
.55823 .31588 Mdot
.55828 .31606 Mdot
.55833 .31624 Mdot
.55838 .31642 Mdot
.55842 .3166 Mdot
.55847 .31677 Mdot
.55852 .31695 Mdot
.55857 .31713 Mdot
.55861 .31731 Mdot
.55866 .31749 Mdot
.55871 .31766 Mdot
.55876 .31784 Mdot
.5588 .31802 Mdot
.55885 .3182 Mdot
.5589 .31837 Mdot
.55895 .31855 Mdot
.55899 .31873 Mdot
.55904 .31891 Mdot
.55909 .31908 Mdot
.55914 .31926 Mdot
.55918 .31944 Mdot
.55923 .31961 Mdot
.55928 .31979 Mdot
.55933 .31997 Mdot
.55938 .32014 Mdot
.55942 .32032 Mdot
.55947 .3205 Mdot
.55952 .32068 Mdot
.55957 .32085 Mdot
.55961 .32103 Mdot
.55966 .32121 Mdot
.55971 .32138 Mdot
.55976 .32156 Mdot
.5598 .32173 Mdot
.55985 .32191 Mdot
.5599 .32209 Mdot
.55995 .32226 Mdot
.55999 .32244 Mdot
.56004 .32262 Mdot
.56009 .32279 Mdot
.56014 .32297 Mdot
.56018 .32314 Mdot
.56023 .32332 Mdot
.56028 .3235 Mdot
.56033 .32367 Mdot
.56037 .32385 Mdot
.56042 .32402 Mdot
.56047 .3242 Mdot
.56052 .32437 Mdot
.56057 .32455 Mdot
.56061 .32473 Mdot
.56066 .3249 Mdot
.56071 .32508 Mdot
.56076 .32525 Mdot
.5608 .32543 Mdot
.56085 .3256 Mdot
.5609 .32578 Mdot
.56095 .32595 Mdot
.56099 .32613 Mdot
.56104 .3263 Mdot
.56109 .32648 Mdot
.56114 .32665 Mdot
.56118 .32683 Mdot
.56123 .327 Mdot
.56128 .32718 Mdot
.56133 .32735 Mdot
.56137 .32753 Mdot
.56142 .3277 Mdot
.56147 .32788 Mdot
.56152 .32805 Mdot
.56157 .32822 Mdot
.56161 .3284 Mdot
.56166 .32857 Mdot
.56171 .32875 Mdot
.56176 .32892 Mdot
.5618 .3291 Mdot
.56185 .32927 Mdot
.5619 .32944 Mdot
.56195 .32962 Mdot
.56199 .32979 Mdot
.56204 .32996 Mdot
.56209 .33014 Mdot
.56214 .33031 Mdot
.56218 .33049 Mdot
.56223 .33066 Mdot
.56228 .33083 Mdot
.56233 .33101 Mdot
.56237 .33118 Mdot
.56242 .33135 Mdot
.56247 .33153 Mdot
.56252 .3317 Mdot
.56257 .33187 Mdot
.56261 .33204 Mdot
.56266 .33222 Mdot
.56271 .33239 Mdot
.56276 .33256 Mdot
.5628 .33274 Mdot
.56285 .33291 Mdot
.5629 .33308 Mdot
.56295 .33325 Mdot
.56299 .33343 Mdot
.56304 .3336 Mdot
.56309 .33377 Mdot
.56314 .33394 Mdot
.56318 .33412 Mdot
.56323 .33429 Mdot
.56328 .33446 Mdot
.56333 .33463 Mdot
.56337 .3348 Mdot
.56342 .33498 Mdot
.56347 .33515 Mdot
.56352 .33532 Mdot
.56357 .33549 Mdot
.56361 .33566 Mdot
.56366 .33584 Mdot
.56371 .33601 Mdot
.56376 .33618 Mdot
.5638 .33635 Mdot
.56385 .33652 Mdot
.5639 .33669 Mdot
.56395 .33686 Mdot
.56399 .33703 Mdot
.56404 .33721 Mdot
.56409 .33738 Mdot
.56414 .33755 Mdot
.56418 .33772 Mdot
.56423 .33789 Mdot
.56428 .33806 Mdot
.56433 .33823 Mdot
.56437 .3384 Mdot
.56442 .33857 Mdot
.56447 .33874 Mdot
.56452 .33891 Mdot
.56456 .33908 Mdot
.56461 .33925 Mdot
.56466 .33942 Mdot
.56471 .33959 Mdot
.56476 .33976 Mdot
.5648 .33993 Mdot
.56485 .3401 Mdot
.5649 .34027 Mdot
.56495 .34044 Mdot
.56499 .34061 Mdot
.56504 .34078 Mdot
.56509 .34095 Mdot
.56514 .34112 Mdot
.56518 .34129 Mdot
.56523 .34146 Mdot
.56528 .34163 Mdot
.56533 .3418 Mdot
.56537 .34197 Mdot
.56542 .34214 Mdot
.56547 .3423 Mdot
.56552 .34247 Mdot
.56556 .34264 Mdot
.56561 .34281 Mdot
.56566 .34298 Mdot
.56571 .34315 Mdot
.56576 .34332 Mdot
.5658 .34349 Mdot
.56585 .34365 Mdot
.5659 .34382 Mdot
.56595 .34399 Mdot
.56599 .34416 Mdot
.56604 .34433 Mdot
.56609 .34449 Mdot
.56614 .34466 Mdot
.56618 .34483 Mdot
.56623 .345 Mdot
.56628 .34517 Mdot
.56633 .34533 Mdot
.56637 .3455 Mdot
.56642 .34567 Mdot
.56647 .34584 Mdot
.56652 .346 Mdot
.56656 .34617 Mdot
.56661 .34634 Mdot
.56666 .3465 Mdot
.56671 .34667 Mdot
.56676 .34684 Mdot
.5668 .34701 Mdot
.56685 .34717 Mdot
.5669 .34734 Mdot
.56695 .34751 Mdot
.56699 .34767 Mdot
.56704 .34784 Mdot
.56709 .348 Mdot
.56714 .34817 Mdot
.56718 .34834 Mdot
.56723 .3485 Mdot
.56728 .34867 Mdot
.56733 .34884 Mdot
.56737 .349 Mdot
.56742 .34917 Mdot
.56747 .34933 Mdot
.56752 .3495 Mdot
.56756 .34966 Mdot
.56761 .34983 Mdot
.56766 .34999 Mdot
.56771 .35016 Mdot
.56776 .35033 Mdot
.5678 .35049 Mdot
.56785 .35066 Mdot
.5679 .35082 Mdot
.56795 .35099 Mdot
.56799 .35115 Mdot
.56804 .35132 Mdot
.56809 .35148 Mdot
.56814 .35164 Mdot
.56818 .35181 Mdot
.56823 .35197 Mdot
.56828 .35214 Mdot
.56833 .3523 Mdot
.56837 .35247 Mdot
.56842 .35263 Mdot
.56847 .35279 Mdot
.56852 .35296 Mdot
.56856 .35312 Mdot
.56861 .35329 Mdot
.56866 .35345 Mdot
.56871 .35361 Mdot
.56876 .35378 Mdot
.5688 .35394 Mdot
.56885 .3541 Mdot
.5689 .35427 Mdot
.56895 .35443 Mdot
.56899 .35459 Mdot
.56904 .35476 Mdot
.56909 .35492 Mdot
.56914 .35508 Mdot
.56918 .35525 Mdot
.56923 .35541 Mdot
.56928 .35557 Mdot
.56933 .35573 Mdot
.56937 .3559 Mdot
.56942 .35606 Mdot
.56947 .35622 Mdot
.56952 .35638 Mdot
.56956 .35654 Mdot
.56961 .35671 Mdot
.56966 .35687 Mdot
.56971 .35703 Mdot
.56975 .35719 Mdot
.5698 .35735 Mdot
.56985 .35752 Mdot
.5699 .35768 Mdot
.56995 .35784 Mdot
.56999 .358 Mdot
.57004 .35816 Mdot
.57009 .35832 Mdot
.57014 .35848 Mdot
.57018 .35864 Mdot
.57023 .3588 Mdot
.57028 .35897 Mdot
.57033 .35913 Mdot
.57037 .35929 Mdot
.57042 .35945 Mdot
.57047 .35961 Mdot
.57052 .35977 Mdot
.57056 .35993 Mdot
.57061 .36009 Mdot
.57066 .36025 Mdot
.57071 .36041 Mdot
.57075 .36057 Mdot
.5708 .36073 Mdot
.57085 .36089 Mdot
.5709 .36105 Mdot
.57095 .36121 Mdot
.57099 .36137 Mdot
.57104 .36153 Mdot
.57109 .36169 Mdot
.57114 .36184 Mdot
.57118 .362 Mdot
.57123 .36216 Mdot
.57128 .36232 Mdot
.57133 .36248 Mdot
.57137 .36264 Mdot
.57142 .3628 Mdot
.57147 .36296 Mdot
.57152 .36311 Mdot
.57156 .36327 Mdot
.57161 .36343 Mdot
.57166 .36359 Mdot
.57171 .36375 Mdot
.57175 .36391 Mdot
.5718 .36406 Mdot
.57185 .36422 Mdot
.5719 .36438 Mdot
.57195 .36454 Mdot
.57199 .36469 Mdot
.57204 .36485 Mdot
.57209 .36501 Mdot
.57214 .36517 Mdot
.57218 .36532 Mdot
.57223 .36548 Mdot
.57228 .36564 Mdot
.57233 .36579 Mdot
.57237 .36595 Mdot
.57242 .36611 Mdot
.57247 .36626 Mdot
.57252 .36642 Mdot
.57256 .36658 Mdot
.57261 .36673 Mdot
.57266 .36689 Mdot
.57271 .36704 Mdot
.57275 .3672 Mdot
.5728 .36736 Mdot
.57285 .36751 Mdot
.5729 .36767 Mdot
.57295 .36782 Mdot
.57299 .36798 Mdot
.57304 .36813 Mdot
.57309 .36829 Mdot
.57314 .36844 Mdot
.57318 .3686 Mdot
.57323 .36876 Mdot
.57328 .36891 Mdot
.57333 .36906 Mdot
.57337 .36922 Mdot
.57342 .36937 Mdot
.57347 .36953 Mdot
.57352 .36968 Mdot
.57356 .36984 Mdot
.57361 .36999 Mdot
.57366 .37015 Mdot
.57371 .3703 Mdot
.57375 .37045 Mdot
.5738 .37061 Mdot
.57385 .37076 Mdot
.5739 .37091 Mdot
.57394 .37107 Mdot
.57399 .37122 Mdot
.57404 .37137 Mdot
.57409 .37153 Mdot
.57414 .37168 Mdot
.57418 .37183 Mdot
.57423 .37199 Mdot
.57428 .37214 Mdot
.57433 .37229 Mdot
.57437 .37245 Mdot
.57442 .3726 Mdot
.57447 .37275 Mdot
.57452 .3729 Mdot
.57456 .37305 Mdot
.57461 .37321 Mdot
.57466 .37336 Mdot
.57471 .37351 Mdot
.57475 .37366 Mdot
.5748 .37381 Mdot
.57485 .37397 Mdot
.5749 .37412 Mdot
.57494 .37427 Mdot
.57499 .37442 Mdot
.57504 .37457 Mdot
.57509 .37472 Mdot
.57514 .37487 Mdot
.57518 .37502 Mdot
.57523 .37517 Mdot
.57528 .37533 Mdot
.57533 .37548 Mdot
.57537 .37563 Mdot
.57542 .37578 Mdot
.57547 .37593 Mdot
.57552 .37608 Mdot
.57556 .37623 Mdot
.57561 .37638 Mdot
.57566 .37653 Mdot
.57571 .37668 Mdot
.57575 .37683 Mdot
.5758 .37698 Mdot
.57585 .37713 Mdot
.5759 .37727 Mdot
.57594 .37742 Mdot
.57599 .37757 Mdot
.57604 .37772 Mdot
.57609 .37787 Mdot
.57614 .37802 Mdot
.57618 .37817 Mdot
.57623 .37832 Mdot
.57628 .37847 Mdot
.57633 .37861 Mdot
.57637 .37876 Mdot
.57642 .37891 Mdot
.57647 .37906 Mdot
.57652 .37921 Mdot
.57656 .37935 Mdot
.57661 .3795 Mdot
.57666 .37965 Mdot
.57671 .3798 Mdot
.57675 .37994 Mdot
.5768 .38009 Mdot
.57685 .38024 Mdot
.5769 .38039 Mdot
.57694 .38053 Mdot
.57699 .38068 Mdot
.57704 .38083 Mdot
.57709 .38097 Mdot
.57714 .38112 Mdot
.57718 .38127 Mdot
.57723 .38141 Mdot
.57728 .38156 Mdot
.57733 .3817 Mdot
.57737 .38185 Mdot
.57742 .382 Mdot
.57747 .38214 Mdot
.57752 .38229 Mdot
.57756 .38243 Mdot
.57761 .38258 Mdot
.57766 .38272 Mdot
.57771 .38287 Mdot
.57775 .38301 Mdot
.5778 .38316 Mdot
.57785 .3833 Mdot
.5779 .38345 Mdot
.57794 .38359 Mdot
.57799 .38374 Mdot
.57804 .38388 Mdot
.57809 .38403 Mdot
.57814 .38417 Mdot
.57818 .38431 Mdot
.57823 .38446 Mdot
.57828 .3846 Mdot
.57833 .38475 Mdot
.57837 .38489 Mdot
.57842 .38503 Mdot
.57847 .38518 Mdot
.57852 .38532 Mdot
.57856 .38546 Mdot
.57861 .38561 Mdot
.57866 .38575 Mdot
.57871 .38589 Mdot
.57875 .38603 Mdot
.5788 .38618 Mdot
.57885 .38632 Mdot
.5789 .38646 Mdot
.57894 .3866 Mdot
.57899 .38675 Mdot
.57904 .38689 Mdot
.57909 .38703 Mdot
.57913 .38717 Mdot
.57918 .38731 Mdot
.57923 .38745 Mdot
.57928 .3876 Mdot
.57933 .38774 Mdot
.57937 .38788 Mdot
.57942 .38802 Mdot
.57947 .38816 Mdot
.57952 .3883 Mdot
.57956 .38844 Mdot
.57961 .38858 Mdot
.57966 .38872 Mdot
.57971 .38886 Mdot
.57975 .389 Mdot
.5798 .38914 Mdot
.57985 .38928 Mdot
.5799 .38942 Mdot
.57994 .38956 Mdot
.57999 .3897 Mdot
.58004 .38984 Mdot
.58009 .38998 Mdot
.58013 .39012 Mdot
.58018 .39026 Mdot
.58023 .3904 Mdot
.58028 .39054 Mdot
.58033 .39068 Mdot
.58037 .39082 Mdot
.58042 .39096 Mdot
.58047 .39109 Mdot
.58052 .39123 Mdot
.58056 .39137 Mdot
.58061 .39151 Mdot
.58066 .39165 Mdot
.58071 .39178 Mdot
.58075 .39192 Mdot
.5808 .39206 Mdot
.58085 .3922 Mdot
.5809 .39234 Mdot
.58094 .39247 Mdot
.58099 .39261 Mdot
.58104 .39275 Mdot
.58109 .39288 Mdot
.58113 .39302 Mdot
.58118 .39316 Mdot
.58123 .39329 Mdot
.58128 .39343 Mdot
.58133 .39357 Mdot
.58137 .3937 Mdot
.58142 .39384 Mdot
.58147 .39397 Mdot
.58152 .39411 Mdot
.58156 .39425 Mdot
.58161 .39438 Mdot
.58166 .39452 Mdot
.58171 .39465 Mdot
.58175 .39479 Mdot
.5818 .39492 Mdot
.58185 .39506 Mdot
.5819 .39519 Mdot
.58194 .39533 Mdot
.58199 .39546 Mdot
.58204 .3956 Mdot
.58209 .39573 Mdot
.58213 .39587 Mdot
.58218 .396 Mdot
.58223 .39613 Mdot
.58228 .39627 Mdot
.58233 .3964 Mdot
.58237 .39654 Mdot
.58242 .39667 Mdot
.58247 .3968 Mdot
.58252 .39694 Mdot
.58256 .39707 Mdot
.58261 .3972 Mdot
.58266 .39734 Mdot
.58271 .39747 Mdot
.58275 .3976 Mdot
.5828 .39773 Mdot
.58285 .39787 Mdot
.5829 .398 Mdot
.58294 .39813 Mdot
.58299 .39826 Mdot
.58304 .39839 Mdot
.58309 .39853 Mdot
.58313 .39866 Mdot
.58318 .39879 Mdot
.58323 .39892 Mdot
.58328 .39905 Mdot
.58333 .39918 Mdot
.58337 .39931 Mdot
.58342 .39944 Mdot
.58347 .39958 Mdot
.58352 .39971 Mdot
.58356 .39984 Mdot
.58361 .39997 Mdot
.58366 .4001 Mdot
.58371 .40023 Mdot
.58375 .40036 Mdot
.5838 .40049 Mdot
.58385 .40062 Mdot
.5839 .40075 Mdot
.58394 .40088 Mdot
.58399 .40101 Mdot
.58404 .40114 Mdot
.58409 .40126 Mdot
.58413 .40139 Mdot
.58418 .40152 Mdot
.58423 .40165 Mdot
.58428 .40178 Mdot
.58432 .40191 Mdot
.58437 .40204 Mdot
.58442 .40216 Mdot
.58447 .40229 Mdot
.58452 .40242 Mdot
.58456 .40255 Mdot
.58461 .40268 Mdot
.58466 .4028 Mdot
.58471 .40293 Mdot
.58475 .40306 Mdot
.5848 .40319 Mdot
.58485 .40331 Mdot
.5849 .40344 Mdot
.58494 .40357 Mdot
.58499 .40369 Mdot
.58504 .40382 Mdot
.58509 .40395 Mdot
.58513 .40407 Mdot
.58518 .4042 Mdot
.58523 .40433 Mdot
.58528 .40445 Mdot
.58532 .40458 Mdot
.58537 .4047 Mdot
.58542 .40483 Mdot
.58547 .40495 Mdot
.58552 .40508 Mdot
.58556 .4052 Mdot
.58561 .40533 Mdot
.58566 .40545 Mdot
.58571 .40558 Mdot
.58575 .4057 Mdot
.5858 .40583 Mdot
.58585 .40595 Mdot
.5859 .40608 Mdot
.58594 .4062 Mdot
.58599 .40632 Mdot
.58604 .40645 Mdot
.58609 .40657 Mdot
.58613 .4067 Mdot
.58618 .40682 Mdot
.58623 .40694 Mdot
.58628 .40707 Mdot
.58632 .40719 Mdot
.58637 .40731 Mdot
.58642 .40743 Mdot
.58647 .40756 Mdot
.58652 .40768 Mdot
.58656 .4078 Mdot
.58661 .40792 Mdot
.58666 .40805 Mdot
.58671 .40817 Mdot
.58675 .40829 Mdot
.5868 .40841 Mdot
.58685 .40853 Mdot
.5869 .40865 Mdot
.58694 .40878 Mdot
.58699 .4089 Mdot
.58704 .40902 Mdot
.58709 .40914 Mdot
.58713 .40926 Mdot
.58718 .40938 Mdot
.58723 .4095 Mdot
.58728 .40962 Mdot
.58732 .40974 Mdot
.58737 .40986 Mdot
.58742 .40998 Mdot
.58747 .4101 Mdot
.58752 .41022 Mdot
.58756 .41034 Mdot
.58761 .41046 Mdot
.58766 .41058 Mdot
.58771 .4107 Mdot
.58775 .41082 Mdot
.5878 .41093 Mdot
.58785 .41105 Mdot
.5879 .41117 Mdot
.58794 .41129 Mdot
.58799 .41141 Mdot
.58804 .41153 Mdot
.58809 .41164 Mdot
.58813 .41176 Mdot
.58818 .41188 Mdot
.58823 .412 Mdot
.58828 .41212 Mdot
.58832 .41223 Mdot
.58837 .41235 Mdot
.58842 .41247 Mdot
.58847 .41258 Mdot
.58851 .4127 Mdot
.58856 .41282 Mdot
.58861 .41293 Mdot
.58866 .41305 Mdot
.58871 .41317 Mdot
.58875 .41328 Mdot
.5888 .4134 Mdot
.58885 .41351 Mdot
.5889 .41363 Mdot
.58894 .41375 Mdot
.58899 .41386 Mdot
.58904 .41398 Mdot
.58909 .41409 Mdot
.58913 .41421 Mdot
.58918 .41432 Mdot
.58923 .41444 Mdot
.58928 .41455 Mdot
.58932 .41466 Mdot
.58937 .41478 Mdot
.58942 .41489 Mdot
.58947 .41501 Mdot
.58951 .41512 Mdot
.58956 .41523 Mdot
.58961 .41535 Mdot
.58966 .41546 Mdot
.58971 .41557 Mdot
.58975 .41569 Mdot
.5898 .4158 Mdot
.58985 .41591 Mdot
.5899 .41603 Mdot
.58994 .41614 Mdot
.58999 .41625 Mdot
.59004 .41636 Mdot
.59009 .41648 Mdot
.59013 .41659 Mdot
.59018 .4167 Mdot
.59023 .41681 Mdot
.59028 .41692 Mdot
.59032 .41703 Mdot
.59037 .41715 Mdot
.59042 .41726 Mdot
.59047 .41737 Mdot
.59051 .41748 Mdot
.59056 .41759 Mdot
.59061 .4177 Mdot
.59066 .41781 Mdot
.59071 .41792 Mdot
.59075 .41803 Mdot
.5908 .41814 Mdot
.59085 .41825 Mdot
.5909 .41836 Mdot
.59094 .41847 Mdot
.59099 .41858 Mdot
.59104 .41869 Mdot
.59109 .4188 Mdot
.59113 .41891 Mdot
.59118 .41902 Mdot
.59123 .41913 Mdot
.59128 .41923 Mdot
.59132 .41934 Mdot
.59137 .41945 Mdot
.59142 .41956 Mdot
.59147 .41967 Mdot
.59151 .41977 Mdot
.59156 .41988 Mdot
.59161 .41999 Mdot
.59166 .4201 Mdot
.59171 .4202 Mdot
.59175 .42031 Mdot
.5918 .42042 Mdot
.59185 .42053 Mdot
.5919 .42063 Mdot
.59194 .42074 Mdot
.59199 .42085 Mdot
.59204 .42095 Mdot
.59209 .42106 Mdot
.59213 .42116 Mdot
.59218 .42127 Mdot
.59223 .42138 Mdot
.59228 .42148 Mdot
.59232 .42159 Mdot
.59237 .42169 Mdot
.59242 .4218 Mdot
.59247 .4219 Mdot
.59251 .42201 Mdot
.59256 .42211 Mdot
.59261 .42222 Mdot
.59266 .42232 Mdot
.59271 .42242 Mdot
.59275 .42253 Mdot
.5928 .42263 Mdot
.59285 .42274 Mdot
.5929 .42284 Mdot
.59294 .42294 Mdot
.59299 .42305 Mdot
.59304 .42315 Mdot
.59309 .42325 Mdot
.59313 .42336 Mdot
.59318 .42346 Mdot
.59323 .42356 Mdot
.59328 .42366 Mdot
.59332 .42377 Mdot
.59337 .42387 Mdot
.59342 .42397 Mdot
.59347 .42407 Mdot
.59351 .42417 Mdot
.59356 .42428 Mdot
.59361 .42438 Mdot
.59366 .42448 Mdot
.5937 .42458 Mdot
.59375 .42468 Mdot
.5938 .42478 Mdot
.59385 .42488 Mdot
.5939 .42498 Mdot
.59394 .42508 Mdot
.59399 .42518 Mdot
.59404 .42528 Mdot
.59409 .42538 Mdot
.59413 .42548 Mdot
.59418 .42558 Mdot
.59423 .42568 Mdot
.59428 .42578 Mdot
.59432 .42588 Mdot
.59437 .42598 Mdot
.59442 .42608 Mdot
.59447 .42618 Mdot
.59451 .42628 Mdot
.59456 .42637 Mdot
.59461 .42647 Mdot
.59466 .42657 Mdot
.5947 .42667 Mdot
.59475 .42677 Mdot
.5948 .42686 Mdot
.59485 .42696 Mdot
.5949 .42706 Mdot
.59494 .42716 Mdot
.59499 .42725 Mdot
.59504 .42735 Mdot
.59509 .42745 Mdot
.59513 .42754 Mdot
.59518 .42764 Mdot
.59523 .42774 Mdot
.59528 .42783 Mdot
.59532 .42793 Mdot
.59537 .42803 Mdot
.59542 .42812 Mdot
.59547 .42822 Mdot
.59551 .42831 Mdot
.59556 .42841 Mdot
.59561 .4285 Mdot
.59566 .4286 Mdot
.5957 .42869 Mdot
.59575 .42879 Mdot
.5958 .42888 Mdot
.59585 .42898 Mdot
.5959 .42907 Mdot
.59594 .42916 Mdot
.59599 .42926 Mdot
.59604 .42935 Mdot
.59609 .42945 Mdot
.59613 .42954 Mdot
.59618 .42963 Mdot
.59623 .42973 Mdot
.59628 .42982 Mdot
.59632 .42991 Mdot
.59637 .43 Mdot
.59642 .4301 Mdot
.59647 .43019 Mdot
.59651 .43028 Mdot
.59656 .43037 Mdot
.59661 .43047 Mdot
.59666 .43056 Mdot
.5967 .43065 Mdot
.59675 .43074 Mdot
.5968 .43083 Mdot
.59685 .43092 Mdot
.5969 .43101 Mdot
.59694 .4311 Mdot
.59699 .4312 Mdot
.59704 .43129 Mdot
.59709 .43138 Mdot
.59713 .43147 Mdot
.59718 .43156 Mdot
.59723 .43165 Mdot
.59728 .43174 Mdot
.59732 .43183 Mdot
.59737 .43192 Mdot
.59742 .432 Mdot
.59747 .43209 Mdot
.59751 .43218 Mdot
.59756 .43227 Mdot
.59761 .43236 Mdot
.59766 .43245 Mdot
.5977 .43254 Mdot
.59775 .43263 Mdot
.5978 .43271 Mdot
.59785 .4328 Mdot
.59789 .43289 Mdot
.59794 .43298 Mdot
.59799 .43306 Mdot
.59804 .43315 Mdot
.59809 .43324 Mdot
.59813 .43333 Mdot
.59818 .43341 Mdot
.59823 .4335 Mdot
.59828 .43359 Mdot
.59832 .43367 Mdot
.59837 .43376 Mdot
.59842 .43384 Mdot
.59847 .43393 Mdot
.59851 .43402 Mdot
.59856 .4341 Mdot
.59861 .43419 Mdot
.59866 .43427 Mdot
.5987 .43436 Mdot
.59875 .43444 Mdot
.5988 .43453 Mdot
.59885 .43461 Mdot
.59889 .4347 Mdot
.59894 .43478 Mdot
.59899 .43486 Mdot
.59904 .43495 Mdot
.59909 .43503 Mdot
.59913 .43512 Mdot
.59918 .4352 Mdot
.59923 .43528 Mdot
.59928 .43537 Mdot
.59932 .43545 Mdot
.59937 .43553 Mdot
.59942 .43562 Mdot
.59947 .4357 Mdot
.59951 .43578 Mdot
.59956 .43586 Mdot
.59961 .43594 Mdot
.59966 .43603 Mdot
.5997 .43611 Mdot
.59975 .43619 Mdot
.5998 .43627 Mdot
.59985 .43635 Mdot
.59989 .43643 Mdot
.59994 .43652 Mdot
.59999 .4366 Mdot
.60004 .43668 Mdot
.60009 .43676 Mdot
.60013 .43684 Mdot
.60018 .43692 Mdot
.60023 .437 Mdot
.60028 .43708 Mdot
.60032 .43716 Mdot
.60037 .43724 Mdot
.60042 .43732 Mdot
.60047 .4374 Mdot
.60051 .43747 Mdot
.60056 .43755 Mdot
.60061 .43763 Mdot
.60066 .43771 Mdot
.6007 .43779 Mdot
.60075 .43787 Mdot
.6008 .43795 Mdot
.60085 .43802 Mdot
.60089 .4381 Mdot
.60094 .43818 Mdot
.60099 .43826 Mdot
.60104 .43833 Mdot
.60109 .43841 Mdot
.60113 .43849 Mdot
.60118 .43857 Mdot
.60123 .43864 Mdot
.60128 .43872 Mdot
.60132 .4388 Mdot
.60137 .43887 Mdot
.60142 .43895 Mdot
.60147 .43902 Mdot
.60151 .4391 Mdot
.60156 .43918 Mdot
.60161 .43925 Mdot
.60166 .43933 Mdot
.6017 .4394 Mdot
.60175 .43948 Mdot
.6018 .43955 Mdot
.60185 .43963 Mdot
.60189 .4397 Mdot
.60194 .43977 Mdot
.60199 .43985 Mdot
.60204 .43992 Mdot
.60209 .44 Mdot
.60213 .44007 Mdot
.60218 .44014 Mdot
.60223 .44022 Mdot
.60228 .44029 Mdot
.60232 .44036 Mdot
.60237 .44044 Mdot
.60242 .44051 Mdot
.60247 .44058 Mdot
.60251 .44065 Mdot
.60256 .44073 Mdot
.60261 .4408 Mdot
.60266 .44087 Mdot
.6027 .44094 Mdot
.60275 .44101 Mdot
.6028 .44108 Mdot
.60285 .44116 Mdot
.60289 .44123 Mdot
.60294 .4413 Mdot
.60299 .44137 Mdot
.60304 .44144 Mdot
.60308 .44151 Mdot
.60313 .44158 Mdot
.60318 .44165 Mdot
.60323 .44172 Mdot
.60328 .44179 Mdot
.60332 .44186 Mdot
.60337 .44193 Mdot
.60342 .442 Mdot
.60347 .44207 Mdot
.60351 .44214 Mdot
.60356 .4422 Mdot
.60361 .44227 Mdot
.60366 .44234 Mdot
.6037 .44241 Mdot
.60375 .44248 Mdot
.6038 .44255 Mdot
.60385 .44261 Mdot
.60389 .44268 Mdot
.60394 .44275 Mdot
.60399 .44282 Mdot
.60404 .44288 Mdot
.60408 .44295 Mdot
.60413 .44302 Mdot
.60418 .44308 Mdot
.60423 .44315 Mdot
.60428 .44322 Mdot
.60432 .44328 Mdot
.60437 .44335 Mdot
.60442 .44342 Mdot
.60447 .44348 Mdot
.60451 .44355 Mdot
.60456 .44361 Mdot
.60461 .44368 Mdot
.60466 .44374 Mdot
.6047 .44381 Mdot
.60475 .44387 Mdot
.6048 .44394 Mdot
.60485 .444 Mdot
.60489 .44406 Mdot
.60494 .44413 Mdot
.60499 .44419 Mdot
.60504 .44426 Mdot
.60508 .44432 Mdot
.60513 .44438 Mdot
.60518 .44445 Mdot
.60523 .44451 Mdot
.60528 .44457 Mdot
.60532 .44464 Mdot
.60537 .4447 Mdot
.60542 .44476 Mdot
.60547 .44482 Mdot
.60551 .44488 Mdot
.60556 .44495 Mdot
.60561 .44501 Mdot
.60566 .44507 Mdot
.6057 .44513 Mdot
.60575 .44519 Mdot
.6058 .44525 Mdot
.60585 .44531 Mdot
.60589 .44538 Mdot
.60594 .44544 Mdot
.60599 .4455 Mdot
.60604 .44556 Mdot
.60608 .44562 Mdot
.60613 .44568 Mdot
.60618 .44574 Mdot
.60623 .4458 Mdot
.60628 .44586 Mdot
.60632 .44592 Mdot
.60637 .44597 Mdot
.60642 .44603 Mdot
.60647 .44609 Mdot
.60651 .44615 Mdot
.60656 .44621 Mdot
.60661 .44627 Mdot
.60666 .44633 Mdot
.6067 .44638 Mdot
.60675 .44644 Mdot
.6068 .4465 Mdot
.60685 .44656 Mdot
.60689 .44661 Mdot
.60694 .44667 Mdot
.60699 .44673 Mdot
.60704 .44678 Mdot
.60708 .44684 Mdot
.60713 .4469 Mdot
.60718 .44695 Mdot
.60723 .44701 Mdot
.60727 .44707 Mdot
.60732 .44712 Mdot
.60737 .44718 Mdot
.60742 .44723 Mdot
.60747 .44729 Mdot
.60751 .44734 Mdot
.60756 .4474 Mdot
.60761 .44745 Mdot
.60766 .44751 Mdot
.6077 .44756 Mdot
.60775 .44762 Mdot
.6078 .44767 Mdot
.60785 .44772 Mdot
.60789 .44778 Mdot
.60794 .44783 Mdot
.60799 .44789 Mdot
.60804 .44794 Mdot
.60808 .44799 Mdot
.60813 .44804 Mdot
.60818 .4481 Mdot
.60823 .44815 Mdot
.60827 .4482 Mdot
.60832 .44825 Mdot
.60837 .44831 Mdot
.60842 .44836 Mdot
.60847 .44841 Mdot
.60851 .44846 Mdot
.60856 .44851 Mdot
.60861 .44857 Mdot
.60866 .44862 Mdot
.6087 .44867 Mdot
.60875 .44872 Mdot
.6088 .44877 Mdot
.60885 .44882 Mdot
.60889 .44887 Mdot
.60894 .44892 Mdot
.60899 .44897 Mdot
.60904 .44902 Mdot
.60908 .44907 Mdot
.60913 .44912 Mdot
.60918 .44917 Mdot
.60923 .44922 Mdot
.60927 .44927 Mdot
.60932 .44931 Mdot
.60937 .44936 Mdot
.60942 .44941 Mdot
.60947 .44946 Mdot
.60951 .44951 Mdot
.60956 .44956 Mdot
.60961 .4496 Mdot
.60966 .44965 Mdot
.6097 .4497 Mdot
.60975 .44975 Mdot
.6098 .44979 Mdot
.60985 .44984 Mdot
.60989 .44989 Mdot
.60994 .44993 Mdot
.60999 .44998 Mdot
.61004 .45003 Mdot
.61008 .45007 Mdot
.61013 .45012 Mdot
.61018 .45016 Mdot
.61023 .45021 Mdot
.61027 .45025 Mdot
.61032 .4503 Mdot
.61037 .45034 Mdot
.61042 .45039 Mdot
.61047 .45043 Mdot
.61051 .45048 Mdot
.61056 .45052 Mdot
.61061 .45057 Mdot
.61066 .45061 Mdot
.6107 .45066 Mdot
.61075 .4507 Mdot
.6108 .45074 Mdot
.61085 .45079 Mdot
.61089 .45083 Mdot
.61094 .45087 Mdot
.61099 .45092 Mdot
.61104 .45096 Mdot
.61108 .451 Mdot
.61113 .45104 Mdot
.61118 .45108 Mdot
.61123 .45113 Mdot
.61127 .45117 Mdot
.61132 .45121 Mdot
.61137 .45125 Mdot
.61142 .45129 Mdot
.61147 .45133 Mdot
.61151 .45138 Mdot
.61156 .45142 Mdot
.61161 .45146 Mdot
.61166 .4515 Mdot
.6117 .45154 Mdot
.61175 .45158 Mdot
.6118 .45162 Mdot
.61185 .45166 Mdot
.61189 .4517 Mdot
.61194 .45174 Mdot
.61199 .45178 Mdot
.61204 .45182 Mdot
.61208 .45185 Mdot
.61213 .45189 Mdot
.61218 .45193 Mdot
.61223 .45197 Mdot
.61227 .45201 Mdot
.61232 .45205 Mdot
.61237 .45208 Mdot
.61242 .45212 Mdot
.61246 .45216 Mdot
.61251 .4522 Mdot
.61256 .45223 Mdot
.61261 .45227 Mdot
.61266 .45231 Mdot
.6127 .45235 Mdot
.61275 .45238 Mdot
.6128 .45242 Mdot
.61285 .45245 Mdot
.61289 .45249 Mdot
.61294 .45253 Mdot
.61299 .45256 Mdot
.61304 .4526 Mdot
.61308 .45263 Mdot
.61313 .45267 Mdot
.61318 .4527 Mdot
.61323 .45274 Mdot
.61327 .45277 Mdot
.61332 .45281 Mdot
.61337 .45284 Mdot
.61342 .45288 Mdot
.61346 .45291 Mdot
.61351 .45294 Mdot
.61356 .45298 Mdot
.61361 .45301 Mdot
.61366 .45305 Mdot
.6137 .45308 Mdot
.61375 .45311 Mdot
.6138 .45314 Mdot
.61385 .45318 Mdot
.61389 .45321 Mdot
.61394 .45324 Mdot
.61399 .45327 Mdot
.61404 .45331 Mdot
.61408 .45334 Mdot
.61413 .45337 Mdot
.61418 .4534 Mdot
.61423 .45343 Mdot
.61427 .45346 Mdot
.61432 .45349 Mdot
.61437 .45353 Mdot
.61442 .45356 Mdot
.61446 .45359 Mdot
.61451 .45362 Mdot
.61456 .45365 Mdot
.61461 .45368 Mdot
.61466 .45371 Mdot
.6147 .45374 Mdot
.61475 .45377 Mdot
.6148 .4538 Mdot
.61485 .45382 Mdot
.61489 .45385 Mdot
.61494 .45388 Mdot
.61499 .45391 Mdot
.61504 .45394 Mdot
.61508 .45397 Mdot
.61513 .454 Mdot
.61518 .45402 Mdot
.61523 .45405 Mdot
.61527 .45408 Mdot
.61532 .45411 Mdot
.61537 .45413 Mdot
.61542 .45416 Mdot
.61546 .45419 Mdot
.61551 .45421 Mdot
.61556 .45424 Mdot
.61561 .45427 Mdot
.61566 .45429 Mdot
.6157 .45432 Mdot
.61575 .45435 Mdot
.6158 .45437 Mdot
.61585 .4544 Mdot
.61589 .45442 Mdot
.61594 .45445 Mdot
.61599 .45447 Mdot
.61604 .4545 Mdot
.61608 .45452 Mdot
.61613 .45455 Mdot
.61618 .45457 Mdot
.61623 .45459 Mdot
.61627 .45462 Mdot
.61632 .45464 Mdot
.61637 .45467 Mdot
.61642 .45469 Mdot
.61646 .45471 Mdot
.61651 .45474 Mdot
.61656 .45476 Mdot
.61661 .45478 Mdot
.61666 .4548 Mdot
.6167 .45483 Mdot
.61675 .45485 Mdot
.6168 .45487 Mdot
.61685 .45489 Mdot
.61689 .45491 Mdot
.61694 .45494 Mdot
.61699 .45496 Mdot
.61704 .45498 Mdot
.61708 .455 Mdot
.61713 .45502 Mdot
.61718 .45504 Mdot
.61723 .45506 Mdot
.61727 .45508 Mdot
.61732 .4551 Mdot
.61737 .45512 Mdot
.61742 .45514 Mdot
.61746 .45516 Mdot
.61751 .45518 Mdot
.61756 .4552 Mdot
.61761 .45522 Mdot
.61765 .45524 Mdot
.6177 .45526 Mdot
.61775 .45528 Mdot
.6178 .4553 Mdot
.61785 .45531 Mdot
.61789 .45533 Mdot
.61794 .45535 Mdot
.61799 .45537 Mdot
.61804 .45539 Mdot
.61808 .4554 Mdot
.61813 .45542 Mdot
.61818 .45544 Mdot
.61823 .45545 Mdot
.61827 .45547 Mdot
.61832 .45549 Mdot
.61837 .4555 Mdot
.61842 .45552 Mdot
.61846 .45554 Mdot
.61851 .45555 Mdot
.61856 .45557 Mdot
.61861 .45558 Mdot
.61865 .4556 Mdot
.6187 .45562 Mdot
.61875 .45563 Mdot
.6188 .45565 Mdot
.61885 .45566 Mdot
.61889 .45567 Mdot
.61894 .45569 Mdot
.61899 .4557 Mdot
.61904 .45572 Mdot
.61908 .45573 Mdot
.61913 .45574 Mdot
.61918 .45576 Mdot
.61923 .45577 Mdot
.61927 .45579 Mdot
.61932 .4558 Mdot
.61937 .45581 Mdot
.61942 .45582 Mdot
.61946 .45584 Mdot
.61951 .45585 Mdot
.61956 .45586 Mdot
.61961 .45587 Mdot
.61965 .45588 Mdot
.6197 .4559 Mdot
.61975 .45591 Mdot
.6198 .45592 Mdot
.61985 .45593 Mdot
.61989 .45594 Mdot
.61994 .45595 Mdot
.61999 .45596 Mdot
.62004 .45597 Mdot
.62008 .45598 Mdot
.62013 .45599 Mdot
.62018 .456 Mdot
.62023 .45601 Mdot
.62027 .45602 Mdot
.62032 .45603 Mdot
.62037 .45604 Mdot
.62042 .45605 Mdot
.62046 .45606 Mdot
.62051 .45607 Mdot
.62056 .45608 Mdot
.62061 .45609 Mdot
.62065 .45609 Mdot
.6207 .4561 Mdot
.62075 .45611 Mdot
.6208 .45612 Mdot
.62085 .45613 Mdot
.62089 .45613 Mdot
.62094 .45614 Mdot
.62099 .45615 Mdot
.62104 .45615 Mdot
.62108 .45616 Mdot
.62113 .45617 Mdot
.62118 .45617 Mdot
.62123 .45618 Mdot
.62127 .45619 Mdot
.62132 .45619 Mdot
.62137 .4562 Mdot
.62142 .4562 Mdot
.62146 .45621 Mdot
.62151 .45621 Mdot
.62156 .45622 Mdot
.62161 .45622 Mdot
.62165 .45623 Mdot
.6217 .45623 Mdot
.62175 .45624 Mdot
.6218 .45624 Mdot
.62184 .45625 Mdot
.62189 .45625 Mdot
.62194 .45625 Mdot
.62199 .45626 Mdot
.62204 .45626 Mdot
.62208 .45626 Mdot
.62213 .45627 Mdot
.62218 .45627 Mdot
.62223 .45627 Mdot
.62227 .45627 Mdot
.62232 .45628 Mdot
.62237 .45628 Mdot
.62242 .45628 Mdot
.62246 .45628 Mdot
.62251 .45628 Mdot
.62256 .45628 Mdot
.62261 .45629 Mdot
.62265 .45629 Mdot
.6227 .45629 Mdot
.62275 .45629 Mdot
.6228 .45629 Mdot
.62284 .45629 Mdot
.62289 .45629 Mdot
.62294 .45629 Mdot
.62299 .45629 Mdot
.62304 .45629 Mdot
.62308 .45629 Mdot
.62313 .45629 Mdot
.62318 .45629 Mdot
.62323 .45629 Mdot
.62327 .45629 Mdot
.62332 .45628 Mdot
.62337 .45628 Mdot
.62342 .45628 Mdot
.62346 .45628 Mdot
.62351 .45628 Mdot
.62356 .45628 Mdot
.62361 .45627 Mdot
.62365 .45627 Mdot
.6237 .45627 Mdot
.62375 .45627 Mdot
.6238 .45626 Mdot
.62384 .45626 Mdot
.62389 .45626 Mdot
.62394 .45625 Mdot
.62399 .45625 Mdot
.62404 .45625 Mdot
.62408 .45624 Mdot
.62413 .45624 Mdot
.62418 .45623 Mdot
.62423 .45623 Mdot
.62427 .45622 Mdot
.62432 .45622 Mdot
.62437 .45621 Mdot
.62442 .45621 Mdot
.62446 .4562 Mdot
.62451 .4562 Mdot
.62456 .45619 Mdot
.62461 .45619 Mdot
.62465 .45618 Mdot
.6247 .45617 Mdot
.62475 .45617 Mdot
.6248 .45616 Mdot
.62484 .45615 Mdot
.62489 .45615 Mdot
.62494 .45614 Mdot
.62499 .45613 Mdot
.62504 .45613 Mdot
.62508 .45612 Mdot
.62513 .45611 Mdot
.62518 .4561 Mdot
.62523 .45609 Mdot
.62527 .45609 Mdot
.62532 .45608 Mdot
.62537 .45607 Mdot
.62542 .45606 Mdot
.62546 .45605 Mdot
.62551 .45604 Mdot
.62556 .45603 Mdot
.62561 .45602 Mdot
.62565 .45601 Mdot
.6257 .456 Mdot
.62575 .45599 Mdot
.6258 .45598 Mdot
.62584 .45597 Mdot
.62589 .45596 Mdot
.62594 .45595 Mdot
.62599 .45594 Mdot
.62604 .45593 Mdot
.62608 .45592 Mdot
.62613 .45591 Mdot
.62618 .4559 Mdot
.62623 .45589 Mdot
.62627 .45587 Mdot
.62632 .45586 Mdot
.62637 .45585 Mdot
.62642 .45584 Mdot
.62646 .45583 Mdot
.62651 .45581 Mdot
.62656 .4558 Mdot
.62661 .45579 Mdot
.62665 .45577 Mdot
.6267 .45576 Mdot
.62675 .45575 Mdot
.6268 .45573 Mdot
.62684 .45572 Mdot
.62689 .45571 Mdot
.62694 .45569 Mdot
.62699 .45568 Mdot
.62703 .45566 Mdot
.62708 .45565 Mdot
.62713 .45563 Mdot
.62718 .45562 Mdot
.62723 .4556 Mdot
.62727 .45559 Mdot
.62732 .45557 Mdot
.62737 .45556 Mdot
.62742 .45554 Mdot
.62746 .45553 Mdot
.62751 .45551 Mdot
.62756 .45549 Mdot
.62761 .45548 Mdot
.62765 .45546 Mdot
.6277 .45544 Mdot
.62775 .45543 Mdot
.6278 .45541 Mdot
.62784 .45539 Mdot
.62789 .45537 Mdot
.62794 .45536 Mdot
.62799 .45534 Mdot
.62803 .45532 Mdot
.62808 .4553 Mdot
.62813 .45528 Mdot
.62818 .45527 Mdot
.62823 .45525 Mdot
.62827 .45523 Mdot
.62832 .45521 Mdot
.62837 .45519 Mdot
.62842 .45517 Mdot
.62846 .45515 Mdot
.62851 .45513 Mdot
.62856 .45511 Mdot
.62861 .45509 Mdot
.62865 .45507 Mdot
.6287 .45505 Mdot
.62875 .45503 Mdot
.6288 .45501 Mdot
.62884 .45499 Mdot
.62889 .45497 Mdot
.62894 .45495 Mdot
.62899 .45493 Mdot
.62903 .4549 Mdot
.62908 .45488 Mdot
.62913 .45486 Mdot
.62918 .45484 Mdot
.62923 .45482 Mdot
.62927 .45479 Mdot
.62932 .45477 Mdot
.62937 .45475 Mdot
.62942 .45473 Mdot
.62946 .4547 Mdot
.62951 .45468 Mdot
.62956 .45466 Mdot
.62961 .45463 Mdot
.62965 .45461 Mdot
.6297 .45459 Mdot
.62975 .45456 Mdot
.6298 .45454 Mdot
.62984 .45451 Mdot
.62989 .45449 Mdot
.62994 .45446 Mdot
.62999 .45444 Mdot
.63003 .45441 Mdot
.63008 .45439 Mdot
.63013 .45436 Mdot
.63018 .45434 Mdot
.63023 .45431 Mdot
.63027 .45429 Mdot
.63032 .45426 Mdot
.63037 .45423 Mdot
.63042 .45421 Mdot
.63046 .45418 Mdot
.63051 .45415 Mdot
.63056 .45413 Mdot
.63061 .4541 Mdot
.63065 .45407 Mdot
.6307 .45405 Mdot
.63075 .45402 Mdot
.6308 .45399 Mdot
.63084 .45396 Mdot
.63089 .45394 Mdot
.63094 .45391 Mdot
.63099 .45388 Mdot
.63103 .45385 Mdot
.63108 .45382 Mdot
.63113 .45379 Mdot
.63118 .45376 Mdot
.63122 .45374 Mdot
.63127 .45371 Mdot
.63132 .45368 Mdot
.63137 .45365 Mdot
.63142 .45362 Mdot
.63146 .45359 Mdot
.63151 .45356 Mdot
.63156 .45353 Mdot
.63161 .4535 Mdot
.63165 .45347 Mdot
.6317 .45344 Mdot
.63175 .4534 Mdot
.6318 .45337 Mdot
.63184 .45334 Mdot
.63189 .45331 Mdot
.63194 .45328 Mdot
.63199 .45325 Mdot
.63203 .45322 Mdot
.63208 .45318 Mdot
.63213 .45315 Mdot
.63218 .45312 Mdot
.63222 .45309 Mdot
.63227 .45305 Mdot
.63232 .45302 Mdot
.63237 .45299 Mdot
.63242 .45295 Mdot
.63246 .45292 Mdot
.63251 .45289 Mdot
.63256 .45285 Mdot
.63261 .45282 Mdot
.63265 .45279 Mdot
.6327 .45275 Mdot
.63275 .45272 Mdot
.6328 .45268 Mdot
.63284 .45265 Mdot
.63289 .45261 Mdot
.63294 .45258 Mdot
.63299 .45254 Mdot
.63303 .45251 Mdot
.63308 .45247 Mdot
.63313 .45244 Mdot
.63318 .4524 Mdot
.63322 .45236 Mdot
.63327 .45233 Mdot
.63332 .45229 Mdot
.63337 .45225 Mdot
.63342 .45222 Mdot
.63346 .45218 Mdot
.63351 .45214 Mdot
.63356 .45211 Mdot
.63361 .45207 Mdot
.63365 .45203 Mdot
.6337 .452 Mdot
.63375 .45196 Mdot
.6338 .45192 Mdot
.63384 .45188 Mdot
.63389 .45184 Mdot
.63394 .4518 Mdot
.63399 .45177 Mdot
.63403 .45173 Mdot
.63408 .45169 Mdot
.63413 .45165 Mdot
.63418 .45161 Mdot
.63422 .45157 Mdot
.63427 .45153 Mdot
.63432 .45149 Mdot
.63437 .45145 Mdot
.63442 .45141 Mdot
.63446 .45137 Mdot
.63451 .45133 Mdot
.63456 .45129 Mdot
.63461 .45125 Mdot
.63465 .45121 Mdot
.6347 .45117 Mdot
.63475 .45113 Mdot
.6348 .45109 Mdot
.63484 .45104 Mdot
.63489 .451 Mdot
.63494 .45096 Mdot
.63499 .45092 Mdot
.63503 .45088 Mdot
.63508 .45083 Mdot
.63513 .45079 Mdot
.63518 .45075 Mdot
.63522 .45071 Mdot
.63527 .45066 Mdot
.63532 .45062 Mdot
.63537 .45058 Mdot
.63542 .45053 Mdot
.63546 .45049 Mdot
.63551 .45045 Mdot
.63556 .4504 Mdot
.63561 .45036 Mdot
.63565 .45031 Mdot
.6357 .45027 Mdot
.63575 .45022 Mdot
.6358 .45018 Mdot
.63584 .45013 Mdot
.63589 .45009 Mdot
.63594 .45004 Mdot
.63599 .45 Mdot
.63603 .44995 Mdot
.63608 .44991 Mdot
.63613 .44986 Mdot
.63618 .44982 Mdot
.63622 .44977 Mdot
.63627 .44972 Mdot
.63632 .44968 Mdot
.63637 .44963 Mdot
.63641 .44958 Mdot
.63646 .44954 Mdot
.63651 .44949 Mdot
.63656 .44944 Mdot
.63661 .4494 Mdot
.63665 .44935 Mdot
.6367 .4493 Mdot
.63675 .44925 Mdot
.6368 .4492 Mdot
.63684 .44916 Mdot
.63689 .44911 Mdot
.63694 .44906 Mdot
.63699 .44901 Mdot
.63703 .44896 Mdot
.63708 .44891 Mdot
.63713 .44886 Mdot
.63718 .44881 Mdot
.63722 .44876 Mdot
.63727 .44872 Mdot
.63732 .44867 Mdot
.63737 .44862 Mdot
.63741 .44857 Mdot
.63746 .44852 Mdot
.63751 .44846 Mdot
.63756 .44841 Mdot
.63761 .44836 Mdot
.63765 .44831 Mdot
.6377 .44826 Mdot
.63775 .44821 Mdot
.6378 .44816 Mdot
.63784 .44811 Mdot
.63789 .44806 Mdot
.63794 .448 Mdot
.63799 .44795 Mdot
.63803 .4479 Mdot
.63808 .44785 Mdot
.63813 .44779 Mdot
.63818 .44774 Mdot
.63822 .44769 Mdot
.63827 .44764 Mdot
.63832 .44758 Mdot
.63837 .44753 Mdot
.63841 .44748 Mdot
.63846 .44742 Mdot
.63851 .44737 Mdot
.63856 .44732 Mdot
.63861 .44726 Mdot
.63865 .44721 Mdot
.6387 .44715 Mdot
.63875 .4471 Mdot
.6388 .44704 Mdot
.63884 .44699 Mdot
.63889 .44693 Mdot
.63894 .44688 Mdot
.63899 .44682 Mdot
.63903 .44677 Mdot
.63908 .44671 Mdot
.63913 .44666 Mdot
.63918 .4466 Mdot
.63922 .44655 Mdot
.63927 .44649 Mdot
.63932 .44643 Mdot
.63937 .44638 Mdot
.63941 .44632 Mdot
.63946 .44626 Mdot
.63951 .44621 Mdot
.63956 .44615 Mdot
.63961 .44609 Mdot
.63965 .44603 Mdot
.6397 .44598 Mdot
.63975 .44592 Mdot
.6398 .44586 Mdot
.63984 .4458 Mdot
.63989 .44574 Mdot
.63994 .44569 Mdot
.63999 .44563 Mdot
.64003 .44557 Mdot
.64008 .44551 Mdot
.64013 .44545 Mdot
.64018 .44539 Mdot
.64022 .44533 Mdot
.64027 .44527 Mdot
.64032 .44521 Mdot
.64037 .44515 Mdot
.64041 .44509 Mdot
.64046 .44503 Mdot
.64051 .44497 Mdot
.64056 .44491 Mdot
.6406 .44485 Mdot
.64065 .44479 Mdot
.6407 .44473 Mdot
.64075 .44467 Mdot
.6408 .44461 Mdot
.64084 .44455 Mdot
.64089 .44449 Mdot
.64094 .44443 Mdot
.64099 .44436 Mdot
.64103 .4443 Mdot
.64108 .44424 Mdot
.64113 .44418 Mdot
.64118 .44412 Mdot
.64122 .44405 Mdot
.64127 .44399 Mdot
.64132 .44393 Mdot
.64137 .44386 Mdot
.64141 .4438 Mdot
.64146 .44374 Mdot
.64151 .44368 Mdot
.64156 .44361 Mdot
.6416 .44355 Mdot
.64165 .44348 Mdot
.6417 .44342 Mdot
.64175 .44336 Mdot
.6418 .44329 Mdot
.64184 .44323 Mdot
.64189 .44316 Mdot
.64194 .4431 Mdot
.64199 .44303 Mdot
.64203 .44297 Mdot
.64208 .4429 Mdot
.64213 .44284 Mdot
.64218 .44277 Mdot
.64222 .44271 Mdot
.64227 .44264 Mdot
.64232 .44257 Mdot
.64237 .44251 Mdot
.64241 .44244 Mdot
.64246 .44238 Mdot
.64251 .44231 Mdot
.64256 .44224 Mdot
.6426 .44218 Mdot
.64265 .44211 Mdot
.6427 .44204 Mdot
.64275 .44197 Mdot
.6428 .44191 Mdot
.64284 .44184 Mdot
.64289 .44177 Mdot
.64294 .4417 Mdot
.64299 .44164 Mdot
.64303 .44157 Mdot
.64308 .4415 Mdot
.64313 .44143 Mdot
.64318 .44136 Mdot
.64322 .44129 Mdot
.64327 .44122 Mdot
.64332 .44116 Mdot
.64337 .44109 Mdot
.64341 .44102 Mdot
.64346 .44095 Mdot
.64351 .44088 Mdot
.64356 .44081 Mdot
.6436 .44074 Mdot
.64365 .44067 Mdot
.6437 .4406 Mdot
.64375 .44053 Mdot
.6438 .44046 Mdot
.64384 .44039 Mdot
.64389 .44031 Mdot
.64394 .44024 Mdot
.64399 .44017 Mdot
.64403 .4401 Mdot
.64408 .44003 Mdot
.64413 .43996 Mdot
.64418 .43989 Mdot
.64422 .43981 Mdot
.64427 .43974 Mdot
.64432 .43967 Mdot
.64437 .4396 Mdot
.64441 .43953 Mdot
.64446 .43945 Mdot
.64451 .43938 Mdot
.64456 .43931 Mdot
.6446 .43923 Mdot
.64465 .43916 Mdot
.6447 .43909 Mdot
.64475 .43901 Mdot
.6448 .43894 Mdot
.64484 .43887 Mdot
.64489 .43879 Mdot
.64494 .43872 Mdot
.64499 .43865 Mdot
.64503 .43857 Mdot
.64508 .4385 Mdot
.64513 .43842 Mdot
.64518 .43835 Mdot
.64522 .43827 Mdot
.64527 .4382 Mdot
.64532 .43812 Mdot
.64537 .43805 Mdot
.64541 .43797 Mdot
.64546 .4379 Mdot
.64551 .43782 Mdot
.64556 .43774 Mdot
.6456 .43767 Mdot
.64565 .43759 Mdot
.6457 .43751 Mdot
.64575 .43744 Mdot
.64579 .43736 Mdot
.64584 .43728 Mdot
.64589 .43721 Mdot
.64594 .43713 Mdot
.64599 .43705 Mdot
.64603 .43698 Mdot
.64608 .4369 Mdot
.64613 .43682 Mdot
.64618 .43674 Mdot
.64622 .43666 Mdot
.64627 .43659 Mdot
.64632 .43651 Mdot
.64637 .43643 Mdot
.64641 .43635 Mdot
.64646 .43627 Mdot
.64651 .43619 Mdot
.64656 .43612 Mdot
.6466 .43604 Mdot
.64665 .43596 Mdot
.6467 .43588 Mdot
.64675 .4358 Mdot
.64679 .43572 Mdot
.64684 .43564 Mdot
.64689 .43556 Mdot
.64694 .43548 Mdot
.64699 .4354 Mdot
.64703 .43532 Mdot
.64708 .43524 Mdot
.64713 .43516 Mdot
.64718 .43508 Mdot
.64722 .435 Mdot
.64727 .43491 Mdot
.64732 .43483 Mdot
.64737 .43475 Mdot
.64741 .43467 Mdot
.64746 .43459 Mdot
.64751 .43451 Mdot
.64756 .43442 Mdot
.6476 .43434 Mdot
.64765 .43426 Mdot
.6477 .43418 Mdot
.64775 .4341 Mdot
.64779 .43401 Mdot
.64784 .43393 Mdot
.64789 .43385 Mdot
.64794 .43376 Mdot
.64799 .43368 Mdot
.64803 .4336 Mdot
.64808 .43351 Mdot
.64813 .43343 Mdot
.64818 .43335 Mdot
.64822 .43326 Mdot
.64827 .43318 Mdot
.64832 .43309 Mdot
.64837 .43301 Mdot
.64841 .43293 Mdot
.64846 .43284 Mdot
.64851 .43276 Mdot
.64856 .43267 Mdot
.6486 .43259 Mdot
.64865 .4325 Mdot
.6487 .43242 Mdot
.64875 .43233 Mdot
.64879 .43225 Mdot
.64884 .43216 Mdot
.64889 .43207 Mdot
.64894 .43199 Mdot
.64899 .4319 Mdot
.64903 .43182 Mdot
.64908 .43173 Mdot
.64913 .43164 Mdot
.64918 .43156 Mdot
.64922 .43147 Mdot
.64927 .43138 Mdot
.64932 .4313 Mdot
.64937 .43121 Mdot
.64941 .43112 Mdot
.64946 .43103 Mdot
.64951 .43095 Mdot
.64956 .43086 Mdot
.6496 .43077 Mdot
.64965 .43068 Mdot
.6497 .43059 Mdot
.64975 .43051 Mdot
.64979 .43042 Mdot
.64984 .43033 Mdot
.64989 .43024 Mdot
.64994 .43015 Mdot
.64999 .43006 Mdot
.65003 .42997 Mdot
.65008 .42988 Mdot
.65013 .4298 Mdot
.65018 .42971 Mdot
.65022 .42962 Mdot
.65027 .42953 Mdot
.65032 .42944 Mdot
.65037 .42935 Mdot
.65041 .42926 Mdot
.65046 .42917 Mdot
.65051 .42908 Mdot
.65056 .42899 Mdot
.6506 .42889 Mdot
.65065 .4288 Mdot
.6507 .42871 Mdot
.65075 .42862 Mdot
.65079 .42853 Mdot
.65084 .42844 Mdot
.65089 .42835 Mdot
.65094 .42826 Mdot
.65098 .42816 Mdot
.65103 .42807 Mdot
.65108 .42798 Mdot
.65113 .42789 Mdot
.65118 .4278 Mdot
.65122 .4277 Mdot
.65127 .42761 Mdot
.65132 .42752 Mdot
.65137 .42743 Mdot
.65141 .42733 Mdot
.65146 .42724 Mdot
.65151 .42715 Mdot
.65156 .42705 Mdot
.6516 .42696 Mdot
.65165 .42687 Mdot
.6517 .42677 Mdot
.65175 .42668 Mdot
.65179 .42658 Mdot
.65184 .42649 Mdot
.65189 .4264 Mdot
.65194 .4263 Mdot
.65198 .42621 Mdot
.65203 .42611 Mdot
.65208 .42602 Mdot
.65213 .42592 Mdot
.65218 .42583 Mdot
.65222 .42573 Mdot
.65227 .42564 Mdot
.65232 .42554 Mdot
.65237 .42545 Mdot
.65241 .42535 Mdot
.65246 .42525 Mdot
.65251 .42516 Mdot
.65256 .42506 Mdot
.6526 .42497 Mdot
.65265 .42487 Mdot
.6527 .42477 Mdot
.65275 .42468 Mdot
.65279 .42458 Mdot
.65284 .42448 Mdot
.65289 .42439 Mdot
.65294 .42429 Mdot
.65298 .42419 Mdot
.65303 .42409 Mdot
.65308 .424 Mdot
.65313 .4239 Mdot
.65318 .4238 Mdot
.65322 .4237 Mdot
.65327 .42361 Mdot
.65332 .42351 Mdot
.65337 .42341 Mdot
.65341 .42331 Mdot
.65346 .42321 Mdot
.65351 .42311 Mdot
.65356 .42302 Mdot
.6536 .42292 Mdot
.65365 .42282 Mdot
.6537 .42272 Mdot
.65375 .42262 Mdot
.65379 .42252 Mdot
.65384 .42242 Mdot
.65389 .42232 Mdot
.65394 .42222 Mdot
.65398 .42212 Mdot
.65403 .42202 Mdot
.65408 .42192 Mdot
.65413 .42182 Mdot
.65418 .42172 Mdot
.65422 .42162 Mdot
.65427 .42152 Mdot
.65432 .42142 Mdot
.65437 .42132 Mdot
.65441 .42122 Mdot
.65446 .42111 Mdot
.65451 .42101 Mdot
.65456 .42091 Mdot
.6546 .42081 Mdot
.65465 .42071 Mdot
.6547 .42061 Mdot
.65475 .4205 Mdot
.65479 .4204 Mdot
.65484 .4203 Mdot
.65489 .4202 Mdot
.65494 .4201 Mdot
.65498 .41999 Mdot
.65503 .41989 Mdot
.65508 .41979 Mdot
.65513 .41968 Mdot
.65517 .41958 Mdot
.65522 .41948 Mdot
.65527 .41938 Mdot
.65532 .41927 Mdot
.65537 .41917 Mdot
.65541 .41906 Mdot
.65546 .41896 Mdot
.65551 .41886 Mdot
.65556 .41875 Mdot
.6556 .41865 Mdot
.65565 .41854 Mdot
.6557 .41844 Mdot
.65575 .41834 Mdot
.65579 .41823 Mdot
.65584 .41813 Mdot
.65589 .41802 Mdot
.65594 .41792 Mdot
.65598 .41781 Mdot
.65603 .41771 Mdot
.65608 .4176 Mdot
.65613 .4175 Mdot
.65617 .41739 Mdot
.65622 .41728 Mdot
.65627 .41718 Mdot
.65632 .41707 Mdot
.65637 .41697 Mdot
.65641 .41686 Mdot
.65646 .41675 Mdot
.65651 .41665 Mdot
.65656 .41654 Mdot
.6566 .41643 Mdot
.65665 .41633 Mdot
.6567 .41622 Mdot
.65675 .41611 Mdot
.65679 .41601 Mdot
.65684 .4159 Mdot
.65689 .41579 Mdot
.65694 .41568 Mdot
.65698 .41558 Mdot
.65703 .41547 Mdot
.65708 .41536 Mdot
.65713 .41525 Mdot
.65717 .41514 Mdot
.65722 .41504 Mdot
.65727 .41493 Mdot
.65732 .41482 Mdot
.65737 .41471 Mdot
.65741 .4146 Mdot
.65746 .41449 Mdot
.65751 .41438 Mdot
.65756 .41428 Mdot
.6576 .41417 Mdot
.65765 .41406 Mdot
.6577 .41395 Mdot
.65775 .41384 Mdot
.65779 .41373 Mdot
.65784 .41362 Mdot
.65789 .41351 Mdot
.65794 .4134 Mdot
.65798 .41329 Mdot
.65803 .41318 Mdot
.65808 .41307 Mdot
.65813 .41296 Mdot
.65817 .41285 Mdot
.65822 .41274 Mdot
.65827 .41263 Mdot
.65832 .41251 Mdot
.65837 .4124 Mdot
.65841 .41229 Mdot
.65846 .41218 Mdot
.65851 .41207 Mdot
.65856 .41196 Mdot
.6586 .41185 Mdot
.65865 .41173 Mdot
.6587 .41162 Mdot
.65875 .41151 Mdot
.65879 .4114 Mdot
.65884 .41129 Mdot
.65889 .41117 Mdot
.65894 .41106 Mdot
.65898 .41095 Mdot
.65903 .41084 Mdot
.65908 .41072 Mdot
.65913 .41061 Mdot
.65917 .4105 Mdot
.65922 .41039 Mdot
.65927 .41027 Mdot
.65932 .41016 Mdot
.65937 .41005 Mdot
.65941 .40993 Mdot
.65946 .40982 Mdot
.65951 .4097 Mdot
.65956 .40959 Mdot
.6596 .40948 Mdot
.65965 .40936 Mdot
.6597 .40925 Mdot
.65975 .40913 Mdot
.65979 .40902 Mdot
.65984 .4089 Mdot
.65989 .40879 Mdot
.65994 .40868 Mdot
.65998 .40856 Mdot
.66003 .40845 Mdot
.66008 .40833 Mdot
.66013 .40822 Mdot
.66017 .4081 Mdot
.66022 .40798 Mdot
.66027 .40787 Mdot
.66032 .40775 Mdot
.66036 .40764 Mdot
.66041 .40752 Mdot
.66046 .40741 Mdot
.66051 .40729 Mdot
.66056 .40717 Mdot
.6606 .40706 Mdot
.66065 .40694 Mdot
.6607 .40682 Mdot
.66075 .40671 Mdot
.66079 .40659 Mdot
.66084 .40647 Mdot
.66089 .40636 Mdot
.66094 .40624 Mdot
.66098 .40612 Mdot
.66103 .40601 Mdot
.66108 .40589 Mdot
.66113 .40577 Mdot
.66117 .40565 Mdot
.66122 .40553 Mdot
.66127 .40542 Mdot
.66132 .4053 Mdot
.66136 .40518 Mdot
.66141 .40506 Mdot
.66146 .40494 Mdot
.66151 .40483 Mdot
.66156 .40471 Mdot
.6616 .40459 Mdot
.66165 .40447 Mdot
.6617 .40435 Mdot
.66175 .40423 Mdot
.66179 .40411 Mdot
.66184 .40399 Mdot
.66189 .40388 Mdot
.66194 .40376 Mdot
.66198 .40364 Mdot
.66203 .40352 Mdot
.66208 .4034 Mdot
.66213 .40328 Mdot
.66217 .40316 Mdot
.66222 .40304 Mdot
.66227 .40292 Mdot
.66232 .4028 Mdot
.66236 .40268 Mdot
.66241 .40256 Mdot
.66246 .40244 Mdot
.66251 .40232 Mdot
.66256 .4022 Mdot
.6626 .40207 Mdot
.66265 .40195 Mdot
.6627 .40183 Mdot
.66275 .40171 Mdot
.66279 .40159 Mdot
.66284 .40147 Mdot
.66289 .40135 Mdot
.66294 .40123 Mdot
.66298 .4011 Mdot
.66303 .40098 Mdot
.66308 .40086 Mdot
.66313 .40074 Mdot
.66317 .40062 Mdot
.66322 .40049 Mdot
.66327 .40037 Mdot
.66332 .40025 Mdot
.66336 .40013 Mdot
.66341 .40001 Mdot
.66346 .39988 Mdot
.66351 .39976 Mdot
.66356 .39964 Mdot
.6636 .39951 Mdot
.66365 .39939 Mdot
.6637 .39927 Mdot
.66375 .39914 Mdot
.66379 .39902 Mdot
.66384 .3989 Mdot
.66389 .39877 Mdot
.66394 .39865 Mdot
.66398 .39853 Mdot
.66403 .3984 Mdot
.66408 .39828 Mdot
.66413 .39815 Mdot
.66417 .39803 Mdot
.66422 .39791 Mdot
.66427 .39778 Mdot
.66432 .39766 Mdot
.66436 .39753 Mdot
.66441 .39741 Mdot
.66446 .39728 Mdot
.66451 .39716 Mdot
.66455 .39703 Mdot
.6646 .39691 Mdot
.66465 .39678 Mdot
.6647 .39666 Mdot
.66475 .39653 Mdot
.66479 .39641 Mdot
.66484 .39628 Mdot
.66489 .39616 Mdot
.66494 .39603 Mdot
.66498 .3959 Mdot
.66503 .39578 Mdot
.66508 .39565 Mdot
.66513 .39553 Mdot
.66517 .3954 Mdot
.66522 .39527 Mdot
.66527 .39515 Mdot
.66532 .39502 Mdot
.66536 .39489 Mdot
.66541 .39477 Mdot
.66546 .39464 Mdot
.66551 .39451 Mdot
.66555 .39439 Mdot
.6656 .39426 Mdot
.66565 .39413 Mdot
.6657 .39401 Mdot
.66575 .39388 Mdot
.66579 .39375 Mdot
.66584 .39362 Mdot
.66589 .3935 Mdot
.66594 .39337 Mdot
.66598 .39324 Mdot
.66603 .39311 Mdot
.66608 .39298 Mdot
.66613 .39286 Mdot
.66617 .39273 Mdot
.66622 .3926 Mdot
.66627 .39247 Mdot
.66632 .39234 Mdot
.66636 .39221 Mdot
.66641 .39208 Mdot
.66646 .39196 Mdot
.66651 .39183 Mdot
.66655 .3917 Mdot
.6666 .39157 Mdot
.66665 .39144 Mdot
.6667 .39131 Mdot
.66675 .39118 Mdot
.66679 .39105 Mdot
.66684 .39092 Mdot
.66689 .39079 Mdot
.66694 .39066 Mdot
.66698 .39053 Mdot
.66703 .3904 Mdot
.66708 .39027 Mdot
.66713 .39014 Mdot
.66717 .39001 Mdot
.66722 .38988 Mdot
.66727 .38975 Mdot
.66732 .38962 Mdot
.66736 .38949 Mdot
.66741 .38936 Mdot
.66746 .38923 Mdot
.66751 .3891 Mdot
.66755 .38897 Mdot
.6676 .38884 Mdot
.66765 .38871 Mdot
.6677 .38858 Mdot
.66775 .38844 Mdot
.66779 .38831 Mdot
.66784 .38818 Mdot
.66789 .38805 Mdot
.66794 .38792 Mdot
.66798 .38779 Mdot
.66803 .38765 Mdot
.66808 .38752 Mdot
.66813 .38739 Mdot
.66817 .38726 Mdot
.66822 .38713 Mdot
.66827 .38699 Mdot
.66832 .38686 Mdot
.66836 .38673 Mdot
.66841 .3866 Mdot
.66846 .38646 Mdot
.66851 .38633 Mdot
.66855 .3862 Mdot
.6686 .38607 Mdot
.66865 .38593 Mdot
.6687 .3858 Mdot
.66875 .38567 Mdot
.66879 .38553 Mdot
.66884 .3854 Mdot
.66889 .38527 Mdot
.66894 .38513 Mdot
.66898 .385 Mdot
.66903 .38487 Mdot
.66908 .38473 Mdot
.66913 .3846 Mdot
.66917 .38447 Mdot
.66922 .38433 Mdot
.66927 .3842 Mdot
.66932 .38406 Mdot
.66936 .38393 Mdot
.66941 .3838 Mdot
.66946 .38366 Mdot
.66951 .38353 Mdot
.66955 .38339 Mdot
.6696 .38326 Mdot
.66965 .38312 Mdot
.6697 .38299 Mdot
.66974 .38285 Mdot
.66979 .38272 Mdot
.66984 .38258 Mdot
.66989 .38245 Mdot
.66994 .38231 Mdot
.66998 .38218 Mdot
.67003 .38204 Mdot
.67008 .38191 Mdot
.67013 .38177 Mdot
.67017 .38164 Mdot
.67022 .3815 Mdot
.67027 .38136 Mdot
.67032 .38123 Mdot
.67036 .38109 Mdot
.67041 .38096 Mdot
.67046 .38082 Mdot
.67051 .38068 Mdot
.67055 .38055 Mdot
.6706 .38041 Mdot
.67065 .38027 Mdot
.6707 .38014 Mdot
.67074 .38 Mdot
.67079 .37986 Mdot
.67084 .37973 Mdot
.67089 .37959 Mdot
.67094 .37945 Mdot
.67098 .37932 Mdot
.67103 .37918 Mdot
.67108 .37904 Mdot
.67113 .37891 Mdot
.67117 .37877 Mdot
.67122 .37863 Mdot
.67127 .37849 Mdot
.67132 .37836 Mdot
.67136 .37822 Mdot
.67141 .37808 Mdot
.67146 .37794 Mdot
.67151 .3778 Mdot
.67155 .37767 Mdot
.6716 .37753 Mdot
.67165 .37739 Mdot
.6717 .37725 Mdot
.67174 .37711 Mdot
.67179 .37698 Mdot
.67184 .37684 Mdot
.67189 .3767 Mdot
.67194 .37656 Mdot
.67198 .37642 Mdot
.67203 .37628 Mdot
.67208 .37614 Mdot
.67213 .37601 Mdot
.67217 .37587 Mdot
.67222 .37573 Mdot
.67227 .37559 Mdot
.67232 .37545 Mdot
.67236 .37531 Mdot
.67241 .37517 Mdot
.67246 .37503 Mdot
.67251 .37489 Mdot
.67255 .37475 Mdot
.6726 .37461 Mdot
.67265 .37447 Mdot
.6727 .37433 Mdot
.67274 .37419 Mdot
.67279 .37405 Mdot
.67284 .37391 Mdot
.67289 .37377 Mdot
.67294 .37363 Mdot
.67298 .37349 Mdot
.67303 .37335 Mdot
.67308 .37321 Mdot
.67313 .37307 Mdot
.67317 .37293 Mdot
.67322 .37279 Mdot
.67327 .37265 Mdot
.67332 .37251 Mdot
.67336 .37237 Mdot
.67341 .37223 Mdot
.67346 .37209 Mdot
.67351 .37195 Mdot
.67355 .3718 Mdot
.6736 .37166 Mdot
.67365 .37152 Mdot
.6737 .37138 Mdot
.67374 .37124 Mdot
.67379 .3711 Mdot
.67384 .37096 Mdot
.67389 .37081 Mdot
.67393 .37067 Mdot
.67398 .37053 Mdot
.67403 .37039 Mdot
.67408 .37025 Mdot
.67413 .37011 Mdot
.67417 .36996 Mdot
.67422 .36982 Mdot
.67427 .36968 Mdot
.67432 .36954 Mdot
.67436 .3694 Mdot
.67441 .36925 Mdot
.67446 .36911 Mdot
.67451 .36897 Mdot
.67455 .36883 Mdot
.6746 .36868 Mdot
.67465 .36854 Mdot
.6747 .3684 Mdot
.67474 .36825 Mdot
.67479 .36811 Mdot
.67484 .36797 Mdot
.67489 .36783 Mdot
.67493 .36768 Mdot
.67498 .36754 Mdot
.67503 .3674 Mdot
.67508 .36725 Mdot
.67513 .36711 Mdot
.67517 .36697 Mdot
.67522 .36682 Mdot
.67527 .36668 Mdot
.67532 .36653 Mdot
.67536 .36639 Mdot
.67541 .36625 Mdot
.67546 .3661 Mdot
.67551 .36596 Mdot
.67555 .36582 Mdot
.6756 .36567 Mdot
.67565 .36553 Mdot
.6757 .36538 Mdot
.67574 .36524 Mdot
.67579 .36509 Mdot
.67584 .36495 Mdot
.67589 .36481 Mdot
.67593 .36466 Mdot
.67598 .36452 Mdot
.67603 .36437 Mdot
.67608 .36423 Mdot
.67613 .36408 Mdot
.67617 .36394 Mdot
.67622 .36379 Mdot
.67627 .36365 Mdot
.67632 .3635 Mdot
.67636 .36336 Mdot
.67641 .36321 Mdot
.67646 .36307 Mdot
.67651 .36292 Mdot
.67655 .36278 Mdot
.6766 .36263 Mdot
.67665 .36249 Mdot
.6767 .36234 Mdot
.67674 .3622 Mdot
.67679 .36205 Mdot
.67684 .3619 Mdot
.67689 .36176 Mdot
.67693 .36161 Mdot
.67698 .36147 Mdot
.67703 .36132 Mdot
.67708 .36117 Mdot
.67713 .36103 Mdot
.67717 .36088 Mdot
.67722 .36074 Mdot
.67727 .36059 Mdot
.67732 .36044 Mdot
.67736 .3603 Mdot
.67741 .36015 Mdot
.67746 .36 Mdot
.67751 .35986 Mdot
.67755 .35971 Mdot
.6776 .35956 Mdot
.67765 .35942 Mdot
.6777 .35927 Mdot
.67774 .35912 Mdot
.67779 .35898 Mdot
.67784 .35883 Mdot
.67789 .35868 Mdot
.67793 .35854 Mdot
.67798 .35839 Mdot
.67803 .35824 Mdot
.67808 .3581 Mdot
.67813 .35795 Mdot
.67817 .3578 Mdot
.67822 .35765 Mdot
.67827 .35751 Mdot
.67832 .35736 Mdot
.67836 .35721 Mdot
.67841 .35706 Mdot
.67846 .35692 Mdot
.67851 .35677 Mdot
.67855 .35662 Mdot
.6786 .35647 Mdot
.67865 .35632 Mdot
.6787 .35618 Mdot
.67874 .35603 Mdot
.67879 .35588 Mdot
.67884 .35573 Mdot
.67889 .35558 Mdot
.67893 .35544 Mdot
.67898 .35529 Mdot
.67903 .35514 Mdot
.67908 .35499 Mdot
.67912 .35484 Mdot
.67917 .35469 Mdot
.67922 .35454 Mdot
.67927 .3544 Mdot
.67932 .35425 Mdot
.67936 .3541 Mdot
.67941 .35395 Mdot
.67946 .3538 Mdot
.67951 .35365 Mdot
.67955 .3535 Mdot
.6796 .35335 Mdot
.67965 .35321 Mdot
.6797 .35306 Mdot
.67974 .35291 Mdot
.67979 .35276 Mdot
.67984 .35261 Mdot
.67989 .35246 Mdot
.67993 .35231 Mdot
.67998 .35216 Mdot
.68003 .35201 Mdot
.68008 .35186 Mdot
.68012 .35171 Mdot
.68017 .35156 Mdot
.68022 .35141 Mdot
.68027 .35126 Mdot
.68032 .35111 Mdot
.68036 .35096 Mdot
.68041 .35081 Mdot
.68046 .35066 Mdot
.68051 .35051 Mdot
.68055 .35036 Mdot
.6806 .35021 Mdot
.68065 .35006 Mdot
.6807 .34991 Mdot
.68074 .34976 Mdot
.68079 .34961 Mdot
.68084 .34946 Mdot
.68089 .34931 Mdot
.68093 .34916 Mdot
.68098 .34901 Mdot
.68103 .34886 Mdot
.68108 .34871 Mdot
.68112 .34856 Mdot
.68117 .34841 Mdot
.68122 .34826 Mdot
.68127 .34811 Mdot
.68132 .34796 Mdot
.68136 .34781 Mdot
.68141 .34766 Mdot
.68146 .3475 Mdot
.68151 .34735 Mdot
.68155 .3472 Mdot
.6816 .34705 Mdot
.68165 .3469 Mdot
.6817 .34675 Mdot
.68174 .3466 Mdot
.68179 .34645 Mdot
.68184 .3463 Mdot
.68189 .34614 Mdot
.68193 .34599 Mdot
.68198 .34584 Mdot
.68203 .34569 Mdot
.68208 .34554 Mdot
.68212 .34539 Mdot
.68217 .34524 Mdot
.68222 .34508 Mdot
.68227 .34493 Mdot
.68232 .34478 Mdot
.68236 .34463 Mdot
.68241 .34448 Mdot
.68246 .34432 Mdot
.68251 .34417 Mdot
.68255 .34402 Mdot
.6826 .34387 Mdot
.68265 .34372 Mdot
.6827 .34356 Mdot
.68274 .34341 Mdot
.68279 .34326 Mdot
.68284 .34311 Mdot
.68289 .34296 Mdot
.68293 .3428 Mdot
.68298 .34265 Mdot
.68303 .3425 Mdot
.68308 .34235 Mdot
.68312 .34219 Mdot
.68317 .34204 Mdot
.68322 .34189 Mdot
.68327 .34174 Mdot
.68332 .34158 Mdot
.68336 .34143 Mdot
.68341 .34128 Mdot
.68346 .34113 Mdot
.68351 .34097 Mdot
.68355 .34082 Mdot
.6836 .34067 Mdot
.68365 .34051 Mdot
.6837 .34036 Mdot
.68374 .34021 Mdot
.68379 .34006 Mdot
.68384 .3399 Mdot
.68389 .33975 Mdot
.68393 .3396 Mdot
.68398 .33944 Mdot
.68403 .33929 Mdot
.68408 .33914 Mdot
.68412 .33898 Mdot
.68417 .33883 Mdot
.68422 .33868 Mdot
.68427 .33852 Mdot
.68431 .33837 Mdot
.68436 .33822 Mdot
.68441 .33806 Mdot
.68446 .33791 Mdot
.68451 .33776 Mdot
.68455 .3376 Mdot
.6846 .33745 Mdot
.68465 .33729 Mdot
.6847 .33714 Mdot
.68474 .33699 Mdot
.68479 .33683 Mdot
.68484 .33668 Mdot
.68489 .33653 Mdot
.68493 .33637 Mdot
.68498 .33622 Mdot
.68503 .33606 Mdot
.68508 .33591 Mdot
.68512 .33576 Mdot
.68517 .3356 Mdot
.68522 .33545 Mdot
.68527 .33529 Mdot
.68531 .33514 Mdot
.68536 .33499 Mdot
.68541 .33483 Mdot
.68546 .33468 Mdot
.68551 .33452 Mdot
.68555 .33437 Mdot
.6856 .33421 Mdot
.68565 .33406 Mdot
.6857 .3339 Mdot
.68574 .33375 Mdot
.68579 .3336 Mdot
.68584 .33344 Mdot
.68589 .33329 Mdot
.68593 .33313 Mdot
.68598 .33298 Mdot
.68603 .33282 Mdot
.68608 .33267 Mdot
.68612 .33251 Mdot
.68617 .33236 Mdot
.68622 .3322 Mdot
.68627 .33205 Mdot
.68631 .33189 Mdot
.68636 .33174 Mdot
.68641 .33158 Mdot
.68646 .33143 Mdot
.68651 .33127 Mdot
.68655 .33112 Mdot
.6866 .33096 Mdot
.68665 .33081 Mdot
.6867 .33065 Mdot
.68674 .3305 Mdot
.68679 .33034 Mdot
.68684 .33019 Mdot
.68689 .33003 Mdot
.68693 .32988 Mdot
.68698 .32972 Mdot
.68703 .32957 Mdot
.68708 .32941 Mdot
.68712 .32926 Mdot
.68717 .3291 Mdot
.68722 .32895 Mdot
.68727 .32879 Mdot
.68731 .32864 Mdot
.68736 .32848 Mdot
.68741 .32832 Mdot
.68746 .32817 Mdot
.68751 .32801 Mdot
.68755 .32786 Mdot
.6876 .3277 Mdot
.68765 .32755 Mdot
.6877 .32739 Mdot
.68774 .32724 Mdot
.68779 .32708 Mdot
.68784 .32692 Mdot
.68789 .32677 Mdot
.68793 .32661 Mdot
.68798 .32646 Mdot
.68803 .3263 Mdot
.68808 .32614 Mdot
.68812 .32599 Mdot
.68817 .32583 Mdot
.68822 .32568 Mdot
.68827 .32552 Mdot
.68831 .32536 Mdot
.68836 .32521 Mdot
.68841 .32505 Mdot
.68846 .3249 Mdot
.6885 .32474 Mdot
.68855 .32458 Mdot
.6886 .32443 Mdot
.68865 .32427 Mdot
.6887 .32412 Mdot
.68874 .32396 Mdot
.68879 .3238 Mdot
.68884 .32365 Mdot
.68889 .32349 Mdot
.68893 .32333 Mdot
.68898 .32318 Mdot
.68903 .32302 Mdot
.68908 .32287 Mdot
.68912 .32271 Mdot
.68917 .32255 Mdot
.68922 .3224 Mdot
.68927 .32224 Mdot
.68931 .32208 Mdot
.68936 .32193 Mdot
.68941 .32177 Mdot
.68946 .32161 Mdot
.6895 .32146 Mdot
.68955 .3213 Mdot
.6896 .32114 Mdot
.68965 .32099 Mdot
.6897 .32083 Mdot
.68974 .32067 Mdot
.68979 .32052 Mdot
.68984 .32036 Mdot
.68989 .3202 Mdot
.68993 .32005 Mdot
.68998 .31989 Mdot
.69003 .31973 Mdot
.69008 .31958 Mdot
.69012 .31942 Mdot
.69017 .31926 Mdot
.69022 .31911 Mdot
.69027 .31895 Mdot
.69031 .31879 Mdot
.69036 .31864 Mdot
.69041 .31848 Mdot
.69046 .31832 Mdot
.6905 .31817 Mdot
.69055 .31801 Mdot
.6906 .31785 Mdot
.69065 .3177 Mdot
.6907 .31754 Mdot
.69074 .31738 Mdot
.69079 .31722 Mdot
.69084 .31707 Mdot
.69089 .31691 Mdot
.69093 .31675 Mdot
.69098 .3166 Mdot
.69103 .31644 Mdot
.69108 .31628 Mdot
.69112 .31612 Mdot
.69117 .31597 Mdot
.69122 .31581 Mdot
.69127 .31565 Mdot
.69131 .3155 Mdot
.69136 .31534 Mdot
.69141 .31518 Mdot
.69146 .31502 Mdot
.6915 .31487 Mdot
.69155 .31471 Mdot
.6916 .31455 Mdot
.69165 .3144 Mdot
.6917 .31424 Mdot
.69174 .31408 Mdot
.69179 .31392 Mdot
.69184 .31377 Mdot
.69189 .31361 Mdot
.69193 .31345 Mdot
.69198 .31329 Mdot
.69203 .31314 Mdot
.69208 .31298 Mdot
.69212 .31282 Mdot
.69217 .31266 Mdot
.69222 .31251 Mdot
.69227 .31235 Mdot
.69231 .31219 Mdot
.69236 .31203 Mdot
.69241 .31188 Mdot
.69246 .31172 Mdot
.6925 .31156 Mdot
.69255 .3114 Mdot
.6926 .31125 Mdot
.69265 .31109 Mdot
.6927 .31093 Mdot
.69274 .31077 Mdot
.69279 .31062 Mdot
.69284 .31046 Mdot
.69289 .3103 Mdot
.69293 .31014 Mdot
.69298 .30999 Mdot
.69303 .30983 Mdot
.69308 .30967 Mdot
.69312 .30951 Mdot
.69317 .30936 Mdot
.69322 .3092 Mdot
.69327 .30904 Mdot
.69331 .30888 Mdot
.69336 .30873 Mdot
.69341 .30857 Mdot
.69346 .30841 Mdot
.6935 .30825 Mdot
.69355 .3081 Mdot
.6936 .30794 Mdot
.69365 .30778 Mdot
.69369 .30762 Mdot
.69374 .30747 Mdot
.69379 .30731 Mdot
.69384 .30715 Mdot
.69389 .30699 Mdot
.69393 .30683 Mdot
.69398 .30668 Mdot
.69403 .30652 Mdot
.69408 .30636 Mdot
.69412 .3062 Mdot
.69417 .30605 Mdot
.69422 .30589 Mdot
.69427 .30573 Mdot
.69431 .30557 Mdot
.69436 .30541 Mdot
.69441 .30526 Mdot
.69446 .3051 Mdot
.6945 .30494 Mdot
.69455 .30478 Mdot
.6946 .30463 Mdot
.69465 .30447 Mdot
.69469 .30431 Mdot
.69474 .30415 Mdot
.69479 .30399 Mdot
.69484 .30384 Mdot
.69489 .30368 Mdot
.69493 .30352 Mdot
.69498 .30336 Mdot
.69503 .30321 Mdot
.69508 .30305 Mdot
.69512 .30289 Mdot
.69517 .30273 Mdot
.69522 .30257 Mdot
.69527 .30242 Mdot
.69531 .30226 Mdot
.69536 .3021 Mdot
.69541 .30194 Mdot
.69546 .30179 Mdot
.6955 .30163 Mdot
.69555 .30147 Mdot
.6956 .30131 Mdot
.69565 .30115 Mdot
.69569 .301 Mdot
.69574 .30084 Mdot
.69579 .30068 Mdot
.69584 .30052 Mdot
.69589 .30037 Mdot
.69593 .30021 Mdot
.69598 .30005 Mdot
.69603 .29989 Mdot
.69608 .29973 Mdot
.69612 .29958 Mdot
.69617 .29942 Mdot
.69622 .29926 Mdot
.69627 .2991 Mdot
.69631 .29895 Mdot
.69636 .29879 Mdot
.69641 .29863 Mdot
.69646 .29847 Mdot
.6965 .29831 Mdot
.69655 .29816 Mdot
.6966 .298 Mdot
.69665 .29784 Mdot
.69669 .29768 Mdot
.69674 .29753 Mdot
.69679 .29737 Mdot
.69684 .29721 Mdot
.69689 .29705 Mdot
.69693 .2969 Mdot
.69698 .29674 Mdot
.69703 .29658 Mdot
.69708 .29642 Mdot
.69712 .29626 Mdot
.69717 .29611 Mdot
.69722 .29595 Mdot
.69727 .29579 Mdot
.69731 .29563 Mdot
.69736 .29548 Mdot
.69741 .29532 Mdot
.69746 .29516 Mdot
.6975 .295 Mdot
.69755 .29485 Mdot
.6976 .29469 Mdot
.69765 .29453 Mdot
.69769 .29437 Mdot
.69774 .29422 Mdot
.69779 .29406 Mdot
.69784 .2939 Mdot
.69788 .29374 Mdot
.69793 .29358 Mdot
.69798 .29343 Mdot
.69803 .29327 Mdot
.69808 .29311 Mdot
.69812 .29295 Mdot
.69817 .2928 Mdot
.69822 .29264 Mdot
.69827 .29248 Mdot
.69831 .29232 Mdot
.69836 .29217 Mdot
.69841 .29201 Mdot
.69846 .29185 Mdot
.6985 .29169 Mdot
.69855 .29154 Mdot
.6986 .29138 Mdot
.69865 .29122 Mdot
.69869 .29106 Mdot
.69874 .29091 Mdot
.69879 .29075 Mdot
.69884 .29059 Mdot
.69888 .29044 Mdot
.69893 .29028 Mdot
.69898 .29012 Mdot
.69903 .28996 Mdot
.69908 .28981 Mdot
.69912 .28965 Mdot
.69917 .28949 Mdot
.69922 .28933 Mdot
.69927 .28918 Mdot
.69931 .28902 Mdot
.69936 .28886 Mdot
.69941 .2887 Mdot
.69946 .28855 Mdot
.6995 .28839 Mdot
.69955 .28823 Mdot
.6996 .28808 Mdot
.69965 .28792 Mdot
.69969 .28776 Mdot
.69974 .2876 Mdot
.69979 .28745 Mdot
.69984 .28729 Mdot
.69988 .28713 Mdot
.69993 .28698 Mdot
.69998 .28682 Mdot
.70003 .28666 Mdot
.70008 .2865 Mdot
.70012 .28635 Mdot
.70017 .28619 Mdot
.70022 .28603 Mdot
.70027 .28588 Mdot
.70031 .28572 Mdot
.70036 .28556 Mdot
.70041 .28541 Mdot
.70046 .28525 Mdot
.7005 .28509 Mdot
.70055 .28493 Mdot
.7006 .28478 Mdot
.70065 .28462 Mdot
.70069 .28446 Mdot
.70074 .28431 Mdot
.70079 .28415 Mdot
.70084 .28399 Mdot
.70088 .28384 Mdot
.70093 .28368 Mdot
.70098 .28352 Mdot
.70103 .28337 Mdot
.70108 .28321 Mdot
.70112 .28305 Mdot
.70117 .2829 Mdot
.70122 .28274 Mdot
.70127 .28258 Mdot
.70131 .28243 Mdot
.70136 .28227 Mdot
.70141 .28211 Mdot
.70146 .28196 Mdot
.7015 .2818 Mdot
.70155 .28164 Mdot
.7016 .28149 Mdot
.70165 .28133 Mdot
.70169 .28117 Mdot
.70174 .28102 Mdot
.70179 .28086 Mdot
.70184 .28071 Mdot
.70188 .28055 Mdot
.70193 .28039 Mdot
.70198 .28024 Mdot
.70203 .28008 Mdot
.70208 .27992 Mdot
.70212 .27977 Mdot
.70217 .27961 Mdot
.70222 .27946 Mdot
.70227 .2793 Mdot
.70231 .27914 Mdot
.70236 .27899 Mdot
.70241 .27883 Mdot
.70246 .27867 Mdot
.7025 .27852 Mdot
.70255 .27836 Mdot
.7026 .27821 Mdot
.70265 .27805 Mdot
.70269 .27789 Mdot
.70274 .27774 Mdot
.70279 .27758 Mdot
.70284 .27743 Mdot
.70288 .27727 Mdot
.70293 .27711 Mdot
.70298 .27696 Mdot
.70303 .2768 Mdot
.70307 .27665 Mdot
.70312 .27649 Mdot
.70317 .27634 Mdot
.70322 .27618 Mdot
.70327 .27602 Mdot
.70331 .27587 Mdot
.70336 .27571 Mdot
.70341 .27556 Mdot
.70346 .2754 Mdot
.7035 .27525 Mdot
.70355 .27509 Mdot
.7036 .27493 Mdot
.70365 .27478 Mdot
.70369 .27462 Mdot
.70374 .27447 Mdot
.70379 .27431 Mdot
.70384 .27416 Mdot
.70388 .274 Mdot
.70393 .27385 Mdot
.70398 .27369 Mdot
.70403 .27354 Mdot
.70407 .27338 Mdot
.70412 .27323 Mdot
.70417 .27307 Mdot
.70422 .27292 Mdot
.70427 .27276 Mdot
.70431 .27261 Mdot
.70436 .27245 Mdot
.70441 .2723 Mdot
.70446 .27214 Mdot
.7045 .27199 Mdot
.70455 .27183 Mdot
.7046 .27168 Mdot
.70465 .27152 Mdot
.70469 .27137 Mdot
.70474 .27121 Mdot
.70479 .27106 Mdot
.70484 .2709 Mdot
.70488 .27075 Mdot
.70493 .27059 Mdot
.70498 .27044 Mdot
.70503 .27028 Mdot
.70507 .27013 Mdot
.70512 .26997 Mdot
.70517 .26982 Mdot
.70522 .26966 Mdot
.70527 .26951 Mdot
.70531 .26936 Mdot
.70536 .2692 Mdot
.70541 .26905 Mdot
.70546 .26889 Mdot
.7055 .26874 Mdot
.70555 .26858 Mdot
.7056 .26843 Mdot
.70565 .26828 Mdot
.70569 .26812 Mdot
.70574 .26797 Mdot
.70579 .26781 Mdot
.70584 .26766 Mdot
.70588 .2675 Mdot
.70593 .26735 Mdot
.70598 .2672 Mdot
.70603 .26704 Mdot
.70607 .26689 Mdot
.70612 .26673 Mdot
.70617 .26658 Mdot
.70622 .26643 Mdot
.70627 .26627 Mdot
.70631 .26612 Mdot
.70636 .26597 Mdot
.70641 .26581 Mdot
.70646 .26566 Mdot
.7065 .2655 Mdot
.70655 .26535 Mdot
.7066 .2652 Mdot
.70665 .26504 Mdot
.70669 .26489 Mdot
.70674 .26474 Mdot
.70679 .26458 Mdot
.70684 .26443 Mdot
.70688 .26428 Mdot
.70693 .26412 Mdot
.70698 .26397 Mdot
.70703 .26382 Mdot
.70707 .26366 Mdot
.70712 .26351 Mdot
.70717 .26336 Mdot
.70722 .2632 Mdot
.70726 .26305 Mdot
.70731 .2629 Mdot
.70736 .26275 Mdot
.70741 .26259 Mdot
.70746 .26244 Mdot
.7075 .26229 Mdot
.70755 .26213 Mdot
.7076 .26198 Mdot
.70765 .26183 Mdot
.70769 .26168 Mdot
.70774 .26152 Mdot
.70779 .26137 Mdot
.70784 .26122 Mdot
.70788 .26107 Mdot
.70793 .26091 Mdot
.70798 .26076 Mdot
.70803 .26061 Mdot
.70807 .26046 Mdot
.70812 .2603 Mdot
.70817 .26015 Mdot
.70822 .26 Mdot
.70826 .25985 Mdot
.70831 .2597 Mdot
.70836 .25954 Mdot
.70841 .25939 Mdot
.70846 .25924 Mdot
.7085 .25909 Mdot
.70855 .25894 Mdot
.7086 .25878 Mdot
.70865 .25863 Mdot
.70869 .25848 Mdot
.70874 .25833 Mdot
.70879 .25818 Mdot
.70884 .25802 Mdot
.70888 .25787 Mdot
.70893 .25772 Mdot
.70898 .25757 Mdot
.70903 .25742 Mdot
.70907 .25727 Mdot
.70912 .25712 Mdot
.70917 .25696 Mdot
.70922 .25681 Mdot
.70926 .25666 Mdot
.70931 .25651 Mdot
.70936 .25636 Mdot
.70941 .25621 Mdot
.70946 .25606 Mdot
.7095 .25591 Mdot
.70955 .25575 Mdot
.7096 .2556 Mdot
.70965 .25545 Mdot
.70969 .2553 Mdot
.70974 .25515 Mdot
.70979 .255 Mdot
.70984 .25485 Mdot
.70988 .2547 Mdot
.70993 .25455 Mdot
.70998 .2544 Mdot
.71003 .25425 Mdot
.71007 .2541 Mdot
.71012 .25395 Mdot
.71017 .2538 Mdot
.71022 .25365 Mdot
.71026 .25349 Mdot
.71031 .25334 Mdot
.71036 .25319 Mdot
.71041 .25304 Mdot
.71046 .25289 Mdot
.7105 .25274 Mdot
.71055 .25259 Mdot
.7106 .25244 Mdot
.71065 .25229 Mdot
.71069 .25214 Mdot
.71074 .25199 Mdot
.71079 .25184 Mdot
.71084 .25169 Mdot
.71088 .25155 Mdot
.71093 .2514 Mdot
.71098 .25125 Mdot
.71103 .2511 Mdot
.71107 .25095 Mdot
.71112 .2508 Mdot
.71117 .25065 Mdot
.71122 .2505 Mdot
.71126 .25035 Mdot
.71131 .2502 Mdot
.71136 .25005 Mdot
.71141 .2499 Mdot
.71146 .24975 Mdot
.7115 .2496 Mdot
.71155 .24945 Mdot
.7116 .24931 Mdot
.71165 .24916 Mdot
.71169 .24901 Mdot
.71174 .24886 Mdot
.71179 .24871 Mdot
.71184 .24856 Mdot
.71188 .24841 Mdot
.71193 .24826 Mdot
.71198 .24812 Mdot
.71203 .24797 Mdot
.71207 .24782 Mdot
.71212 .24767 Mdot
.71217 .24752 Mdot
.71222 .24737 Mdot
.71226 .24723 Mdot
.71231 .24708 Mdot
.71236 .24693 Mdot
.71241 .24678 Mdot
.71245 .24663 Mdot
.7125 .24649 Mdot
.71255 .24634 Mdot
.7126 .24619 Mdot
.71265 .24604 Mdot
.71269 .24589 Mdot
.71274 .24575 Mdot
.71279 .2456 Mdot
.71284 .24545 Mdot
.71288 .2453 Mdot
.71293 .24516 Mdot
.71298 .24501 Mdot
.71303 .24486 Mdot
.71307 .24472 Mdot
.71312 .24457 Mdot
.71317 .24442 Mdot
.71322 .24427 Mdot
.71326 .24413 Mdot
.71331 .24398 Mdot
.71336 .24383 Mdot
.71341 .24369 Mdot
.71345 .24354 Mdot
.7135 .24339 Mdot
.71355 .24325 Mdot
.7136 .2431 Mdot
.71365 .24295 Mdot
.71369 .24281 Mdot
.71374 .24266 Mdot
.71379 .24251 Mdot
.71384 .24237 Mdot
.71388 .24222 Mdot
.71393 .24207 Mdot
.71398 .24193 Mdot
.71403 .24178 Mdot
.71407 .24164 Mdot
.71412 .24149 Mdot
.71417 .24134 Mdot
.71422 .2412 Mdot
.71426 .24105 Mdot
.71431 .24091 Mdot
.71436 .24076 Mdot
.71441 .24061 Mdot
.71445 .24047 Mdot
.7145 .24032 Mdot
.71455 .24018 Mdot
.7146 .24003 Mdot
.71465 .23989 Mdot
.71469 .23974 Mdot
.71474 .2396 Mdot
.71479 .23945 Mdot
.71484 .23931 Mdot
.71488 .23916 Mdot
.71493 .23902 Mdot
.71498 .23887 Mdot
.71503 .23873 Mdot
.71507 .23858 Mdot
.71512 .23844 Mdot
.71517 .23829 Mdot
.71522 .23815 Mdot
.71526 .238 Mdot
.71531 .23786 Mdot
.71536 .23771 Mdot
.71541 .23757 Mdot
.71545 .23743 Mdot
.7155 .23728 Mdot
.71555 .23714 Mdot
.7156 .23699 Mdot
.71565 .23685 Mdot
.71569 .23671 Mdot
.71574 .23656 Mdot
.71579 .23642 Mdot
.71584 .23627 Mdot
.71588 .23613 Mdot
.71593 .23599 Mdot
.71598 .23584 Mdot
.71603 .2357 Mdot
.71607 .23556 Mdot
.71612 .23541 Mdot
.71617 .23527 Mdot
.71622 .23513 Mdot
.71626 .23498 Mdot
.71631 .23484 Mdot
.71636 .2347 Mdot
.71641 .23455 Mdot
.71645 .23441 Mdot
.7165 .23427 Mdot
.71655 .23412 Mdot
.7166 .23398 Mdot
.71665 .23384 Mdot
.71669 .2337 Mdot
.71674 .23355 Mdot
.71679 .23341 Mdot
.71684 .23327 Mdot
.71688 .23313 Mdot
.71693 .23298 Mdot
.71698 .23284 Mdot
.71703 .2327 Mdot
.71707 .23256 Mdot
.71712 .23242 Mdot
.71717 .23227 Mdot
.71722 .23213 Mdot
.71726 .23199 Mdot
.71731 .23185 Mdot
.71736 .23171 Mdot
.71741 .23157 Mdot
.71745 .23142 Mdot
.7175 .23128 Mdot
.71755 .23114 Mdot
.7176 .231 Mdot
.71764 .23086 Mdot
.71769 .23072 Mdot
.71774 .23058 Mdot
.71779 .23044 Mdot
.71784 .23029 Mdot
.71788 .23015 Mdot
.71793 .23001 Mdot
.71798 .22987 Mdot
.71803 .22973 Mdot
.71807 .22959 Mdot
.71812 .22945 Mdot
.71817 .22931 Mdot
.71822 .22917 Mdot
.71826 .22903 Mdot
.71831 .22889 Mdot
.71836 .22875 Mdot
.71841 .22861 Mdot
.71845 .22847 Mdot
.7185 .22833 Mdot
.71855 .22819 Mdot
.7186 .22805 Mdot
.71864 .22791 Mdot
.71869 .22777 Mdot
.71874 .22763 Mdot
.71879 .22749 Mdot
.71884 .22735 Mdot
.71888 .22721 Mdot
.71893 .22707 Mdot
.71898 .22693 Mdot
.71903 .22679 Mdot
.71907 .22665 Mdot
.71912 .22651 Mdot
.71917 .22638 Mdot
.71922 .22624 Mdot
.71926 .2261 Mdot
.71931 .22596 Mdot
.71936 .22582 Mdot
.71941 .22568 Mdot
.71945 .22554 Mdot
.7195 .2254 Mdot
.71955 .22527 Mdot
.7196 .22513 Mdot
.71964 .22499 Mdot
.71969 .22485 Mdot
.71974 .22471 Mdot
.71979 .22458 Mdot
.71984 .22444 Mdot
.71988 .2243 Mdot
.71993 .22416 Mdot
.71998 .22402 Mdot
.72003 .22389 Mdot
.72007 .22375 Mdot
.72012 .22361 Mdot
.72017 .22347 Mdot
.72022 .22334 Mdot
.72026 .2232 Mdot
.72031 .22306 Mdot
.72036 .22293 Mdot
.72041 .22279 Mdot
.72045 .22265 Mdot
.7205 .22251 Mdot
.72055 .22238 Mdot
.7206 .22224 Mdot
.72064 .2221 Mdot
.72069 .22197 Mdot
.72074 .22183 Mdot
.72079 .2217 Mdot
.72084 .22156 Mdot
.72088 .22142 Mdot
.72093 .22129 Mdot
.72098 .22115 Mdot
.72103 .22101 Mdot
.72107 .22088 Mdot
.72112 .22074 Mdot
.72117 .22061 Mdot
.72122 .22047 Mdot
.72126 .22034 Mdot
.72131 .2202 Mdot
.72136 .22006 Mdot
.72141 .21993 Mdot
.72145 .21979 Mdot
.7215 .21966 Mdot
.72155 .21952 Mdot
.7216 .21939 Mdot
.72164 .21925 Mdot
.72169 .21912 Mdot
.72174 .21898 Mdot
.72179 .21885 Mdot
.72183 .21871 Mdot
.72188 .21858 Mdot
.72193 .21845 Mdot
.72198 .21831 Mdot
.72203 .21818 Mdot
.72207 .21804 Mdot
.72212 .21791 Mdot
.72217 .21777 Mdot
.72222 .21764 Mdot
.72226 .21751 Mdot
.72231 .21737 Mdot
.72236 .21724 Mdot
.72241 .2171 Mdot
.72245 .21697 Mdot
.7225 .21684 Mdot
.72255 .2167 Mdot
.7226 .21657 Mdot
.72264 .21644 Mdot
.72269 .2163 Mdot
.72274 .21617 Mdot
.72279 .21604 Mdot
.72283 .21591 Mdot
.72288 .21577 Mdot
.72293 .21564 Mdot
.72298 .21551 Mdot
.72303 .21537 Mdot
.72307 .21524 Mdot
.72312 .21511 Mdot
.72317 .21498 Mdot
.72322 .21484 Mdot
.72326 .21471 Mdot
.72331 .21458 Mdot
.72336 .21445 Mdot
.72341 .21432 Mdot
.72345 .21418 Mdot
.7235 .21405 Mdot
.72355 .21392 Mdot
.7236 .21379 Mdot
.72364 .21366 Mdot
.72369 .21353 Mdot
.72374 .2134 Mdot
.72379 .21326 Mdot
.72383 .21313 Mdot
.72388 .213 Mdot
.72393 .21287 Mdot
.72398 .21274 Mdot
.72403 .21261 Mdot
.72407 .21248 Mdot
.72412 .21235 Mdot
.72417 .21222 Mdot
.72422 .21209 Mdot
.72426 .21196 Mdot
.72431 .21183 Mdot
.72436 .2117 Mdot
.72441 .21157 Mdot
.72445 .21144 Mdot
.7245 .21131 Mdot
.72455 .21118 Mdot
.7246 .21105 Mdot
.72464 .21092 Mdot
.72469 .21079 Mdot
.72474 .21066 Mdot
.72479 .21053 Mdot
.72483 .2104 Mdot
.72488 .21027 Mdot
.72493 .21014 Mdot
.72498 .21001 Mdot
.72503 .20988 Mdot
.72507 .20975 Mdot
.72512 .20962 Mdot
.72517 .2095 Mdot
.72522 .20937 Mdot
.72526 .20924 Mdot
.72531 .20911 Mdot
.72536 .20898 Mdot
.72541 .20885 Mdot
.72545 .20873 Mdot
.7255 .2086 Mdot
.72555 .20847 Mdot
.7256 .20834 Mdot
.72564 .20821 Mdot
.72569 .20809 Mdot
.72574 .20796 Mdot
.72579 .20783 Mdot
.72583 .2077 Mdot
.72588 .20758 Mdot
.72593 .20745 Mdot
.72598 .20732 Mdot
.72603 .20719 Mdot
.72607 .20707 Mdot
.72612 .20694 Mdot
.72617 .20681 Mdot
.72622 .20669 Mdot
.72626 .20656 Mdot
.72631 .20643 Mdot
.72636 .20631 Mdot
.72641 .20618 Mdot
.72645 .20606 Mdot
.7265 .20593 Mdot
.72655 .2058 Mdot
.7266 .20568 Mdot
.72664 .20555 Mdot
.72669 .20543 Mdot
.72674 .2053 Mdot
.72679 .20517 Mdot
.72683 .20505 Mdot
.72688 .20492 Mdot
.72693 .2048 Mdot
.72698 .20467 Mdot
.72702 .20455 Mdot
.72707 .20442 Mdot
.72712 .2043 Mdot
.72717 .20417 Mdot
.72722 .20405 Mdot
.72726 .20392 Mdot
.72731 .2038 Mdot
.72736 .20367 Mdot
.72741 .20355 Mdot
.72745 .20343 Mdot
.7275 .2033 Mdot
.72755 .20318 Mdot
.7276 .20305 Mdot
.72764 .20293 Mdot
.72769 .20281 Mdot
.72774 .20268 Mdot
.72779 .20256 Mdot
.72783 .20244 Mdot
.72788 .20231 Mdot
.72793 .20219 Mdot
.72798 .20207 Mdot
.72802 .20194 Mdot
.72807 .20182 Mdot
.72812 .2017 Mdot
.72817 .20157 Mdot
.72822 .20145 Mdot
.72826 .20133 Mdot
.72831 .20121 Mdot
.72836 .20108 Mdot
.72841 .20096 Mdot
.72845 .20084 Mdot
.7285 .20072 Mdot
.72855 .20059 Mdot
.7286 .20047 Mdot
.72864 .20035 Mdot
.72869 .20023 Mdot
.72874 .20011 Mdot
.72879 .19999 Mdot
.72883 .19986 Mdot
.72888 .19974 Mdot
.72893 .19962 Mdot
.72898 .1995 Mdot
.72902 .19938 Mdot
.72907 .19926 Mdot
.72912 .19914 Mdot
.72917 .19902 Mdot
.72922 .1989 Mdot
.72926 .19877 Mdot
.72931 .19865 Mdot
.72936 .19853 Mdot
.72941 .19841 Mdot
.72945 .19829 Mdot
.7295 .19817 Mdot
.72955 .19805 Mdot
.7296 .19793 Mdot
.72964 .19781 Mdot
.72969 .19769 Mdot
.72974 .19757 Mdot
.72979 .19745 Mdot
.72983 .19734 Mdot
.72988 .19722 Mdot
.72993 .1971 Mdot
.72998 .19698 Mdot
.73002 .19686 Mdot
.73007 .19674 Mdot
.73012 .19662 Mdot
.73017 .1965 Mdot
.73022 .19638 Mdot
.73026 .19627 Mdot
.73031 .19615 Mdot
.73036 .19603 Mdot
.73041 .19591 Mdot
.73045 .19579 Mdot
.7305 .19567 Mdot
.73055 .19556 Mdot
.7306 .19544 Mdot
.73064 .19532 Mdot
.73069 .1952 Mdot
.73074 .19509 Mdot
.73079 .19497 Mdot
.73083 .19485 Mdot
.73088 .19473 Mdot
.73093 .19462 Mdot
.73098 .1945 Mdot
.73102 .19438 Mdot
.73107 .19427 Mdot
.73112 .19415 Mdot
.73117 .19403 Mdot
.73121 .19392 Mdot
.73126 .1938 Mdot
.73131 .19368 Mdot
.73136 .19357 Mdot
.73141 .19345 Mdot
.73145 .19334 Mdot
.7315 .19322 Mdot
.73155 .19311 Mdot
.7316 .19299 Mdot
.73164 .19287 Mdot
.73169 .19276 Mdot
.73174 .19264 Mdot
.73179 .19253 Mdot
.73183 .19241 Mdot
.73188 .1923 Mdot
.73193 .19218 Mdot
.73198 .19207 Mdot
.73202 .19195 Mdot
.73207 .19184 Mdot
.73212 .19173 Mdot
.73217 .19161 Mdot
.73221 .1915 Mdot
.73226 .19138 Mdot
.73231 .19127 Mdot
.73236 .19115 Mdot
.73241 .19104 Mdot
.73245 .19093 Mdot
.7325 .19081 Mdot
.73255 .1907 Mdot
.7326 .19059 Mdot
.73264 .19047 Mdot
.73269 .19036 Mdot
.73274 .19025 Mdot
.73279 .19013 Mdot
.73283 .19002 Mdot
.73288 .18991 Mdot
.73293 .1898 Mdot
.73298 .18968 Mdot
.73302 .18957 Mdot
.73307 .18946 Mdot
.73312 .18935 Mdot
.73317 .18923 Mdot
.73321 .18912 Mdot
.73326 .18901 Mdot
.73331 .1889 Mdot
.73336 .18879 Mdot
.73341 .18868 Mdot
.73345 .18856 Mdot
.7335 .18845 Mdot
.73355 .18834 Mdot
.7336 .18823 Mdot
.73364 .18812 Mdot
.73369 .18801 Mdot
.73374 .1879 Mdot
.73379 .18779 Mdot
.73383 .18768 Mdot
.73388 .18757 Mdot
.73393 .18746 Mdot
.73398 .18735 Mdot
.73402 .18724 Mdot
.73407 .18713 Mdot
.73412 .18702 Mdot
.73417 .18691 Mdot
.73421 .1868 Mdot
.73426 .18669 Mdot
.73431 .18658 Mdot
.73436 .18647 Mdot
.73441 .18636 Mdot
.73445 .18625 Mdot
.7345 .18614 Mdot
.73455 .18603 Mdot
.7346 .18592 Mdot
.73464 .18581 Mdot
.73469 .18571 Mdot
.73474 .1856 Mdot
.73479 .18549 Mdot
.73483 .18538 Mdot
.73488 .18527 Mdot
.73493 .18516 Mdot
.73498 .18506 Mdot
.73502 .18495 Mdot
.73507 .18484 Mdot
.73512 .18473 Mdot
.73517 .18463 Mdot
.73521 .18452 Mdot
.73526 .18441 Mdot
.73531 .1843 Mdot
.73536 .1842 Mdot
.73541 .18409 Mdot
.73545 .18398 Mdot
.7355 .18388 Mdot
.73555 .18377 Mdot
.7356 .18366 Mdot
.73564 .18356 Mdot
.73569 .18345 Mdot
.73574 .18335 Mdot
.73579 .18324 Mdot
.73583 .18313 Mdot
.73588 .18303 Mdot
.73593 .18292 Mdot
.73598 .18282 Mdot
.73602 .18271 Mdot
.73607 .18261 Mdot
.73612 .1825 Mdot
.73617 .1824 Mdot
.73621 .18229 Mdot
.73626 .18219 Mdot
.73631 .18208 Mdot
.73636 .18198 Mdot
.7364 .18187 Mdot
.73645 .18177 Mdot
.7365 .18166 Mdot
.73655 .18156 Mdot
.7366 .18145 Mdot
.73664 .18135 Mdot
.73669 .18125 Mdot
.73674 .18114 Mdot
.73679 .18104 Mdot
.73683 .18094 Mdot
.73688 .18083 Mdot
.73693 .18073 Mdot
.73698 .18063 Mdot
.73702 .18052 Mdot
.73707 .18042 Mdot
.73712 .18032 Mdot
.73717 .18021 Mdot
.73721 .18011 Mdot
.73726 .18001 Mdot
.73731 .17991 Mdot
.73736 .17981 Mdot
.7374 .1797 Mdot
.73745 .1796 Mdot
.7375 .1795 Mdot
.73755 .1794 Mdot
.7376 .1793 Mdot
.73764 .17919 Mdot
.73769 .17909 Mdot
.73774 .17899 Mdot
.73779 .17889 Mdot
.73783 .17879 Mdot
.73788 .17869 Mdot
.73793 .17859 Mdot
.73798 .17849 Mdot
.73802 .17839 Mdot
.73807 .17829 Mdot
.73812 .17819 Mdot
.73817 .17809 Mdot
.73821 .17799 Mdot
.73826 .17789 Mdot
.73831 .17779 Mdot
.73836 .17769 Mdot
.7384 .17759 Mdot
.73845 .17749 Mdot
.7385 .17739 Mdot
.73855 .17729 Mdot
.7386 .17719 Mdot
.73864 .17709 Mdot
.73869 .17699 Mdot
.73874 .17689 Mdot
.73879 .17679 Mdot
.73883 .1767 Mdot
.73888 .1766 Mdot
.73893 .1765 Mdot
.73898 .1764 Mdot
.73902 .1763 Mdot
.73907 .1762 Mdot
.73912 .17611 Mdot
.73917 .17601 Mdot
.73921 .17591 Mdot
.73926 .17581 Mdot
.73931 .17572 Mdot
.73936 .17562 Mdot
.7394 .17552 Mdot
.73945 .17542 Mdot
.7395 .17533 Mdot
.73955 .17523 Mdot
.7396 .17513 Mdot
.73964 .17504 Mdot
.73969 .17494 Mdot
.73974 .17485 Mdot
.73979 .17475 Mdot
.73983 .17465 Mdot
.73988 .17456 Mdot
.73993 .17446 Mdot
.73998 .17437 Mdot
.74002 .17427 Mdot
.74007 .17417 Mdot
.74012 .17408 Mdot
.74017 .17398 Mdot
.74021 .17389 Mdot
.74026 .17379 Mdot
.74031 .1737 Mdot
.74036 .1736 Mdot
.7404 .17351 Mdot
.74045 .17342 Mdot
.7405 .17332 Mdot
.74055 .17323 Mdot
.74059 .17313 Mdot
.74064 .17304 Mdot
.74069 .17295 Mdot
.74074 .17285 Mdot
.74079 .17276 Mdot
.74083 .17266 Mdot
.74088 .17257 Mdot
.74093 .17248 Mdot
.74098 .17238 Mdot
.74102 .17229 Mdot
.74107 .1722 Mdot
.74112 .17211 Mdot
.74117 .17201 Mdot
.74121 .17192 Mdot
.74126 .17183 Mdot
.74131 .17174 Mdot
.74136 .17164 Mdot
.7414 .17155 Mdot
.74145 .17146 Mdot
.7415 .17137 Mdot
.74155 .17128 Mdot
.74159 .17119 Mdot
.74164 .17109 Mdot
.74169 .171 Mdot
.74174 .17091 Mdot
.74179 .17082 Mdot
.74183 .17073 Mdot
.74188 .17064 Mdot
.74193 .17055 Mdot
.74198 .17046 Mdot
.74202 .17037 Mdot
.74207 .17028 Mdot
.74212 .17019 Mdot
.74217 .1701 Mdot
.74221 .17001 Mdot
.74226 .16992 Mdot
.74231 .16983 Mdot
.74236 .16974 Mdot
.7424 .16965 Mdot
.74245 .16956 Mdot
.7425 .16947 Mdot
.74255 .16938 Mdot
.74259 .16929 Mdot
.74264 .1692 Mdot
.74269 .16912 Mdot
.74274 .16903 Mdot
.74279 .16894 Mdot
.74283 .16885 Mdot
.74288 .16876 Mdot
.74293 .16867 Mdot
.74298 .16859 Mdot
.74302 .1685 Mdot
.74307 .16841 Mdot
.74312 .16832 Mdot
.74317 .16824 Mdot
.74321 .16815 Mdot
.74326 .16806 Mdot
.74331 .16798 Mdot
.74336 .16789 Mdot
.7434 .1678 Mdot
.74345 .16771 Mdot
.7435 .16763 Mdot
.74355 .16754 Mdot
.74359 .16746 Mdot
.74364 .16737 Mdot
.74369 .16728 Mdot
.74374 .1672 Mdot
.74379 .16711 Mdot
.74383 .16703 Mdot
.74388 .16694 Mdot
.74393 .16686 Mdot
.74398 .16677 Mdot
.74402 .16669 Mdot
.74407 .1666 Mdot
.74412 .16652 Mdot
.74417 .16643 Mdot
.74421 .16635 Mdot
.74426 .16626 Mdot
.74431 .16618 Mdot
.74436 .16609 Mdot
.7444 .16601 Mdot
.74445 .16593 Mdot
.7445 .16584 Mdot
.74455 .16576 Mdot
.74459 .16567 Mdot
.74464 .16559 Mdot
.74469 .16551 Mdot
.74474 .16542 Mdot
.74479 .16534 Mdot
.74483 .16526 Mdot
.74488 .16518 Mdot
.74493 .16509 Mdot
.74498 .16501 Mdot
.74502 .16493 Mdot
.74507 .16485 Mdot
.74512 .16476 Mdot
.74517 .16468 Mdot
.74521 .1646 Mdot
.74526 .16452 Mdot
.74531 .16444 Mdot
.74536 .16436 Mdot
.7454 .16427 Mdot
.74545 .16419 Mdot
.7455 .16411 Mdot
.74555 .16403 Mdot
.74559 .16395 Mdot
.74564 .16387 Mdot
.74569 .16379 Mdot
.74574 .16371 Mdot
.74578 .16363 Mdot
.74583 .16355 Mdot
.74588 .16347 Mdot
.74593 .16339 Mdot
.74598 .16331 Mdot
.74602 .16323 Mdot
.74607 .16315 Mdot
.74612 .16307 Mdot
.74617 .16299 Mdot
.74621 .16291 Mdot
.74626 .16283 Mdot
.74631 .16275 Mdot
.74636 .16267 Mdot
.7464 .1626 Mdot
.74645 .16252 Mdot
.7465 .16244 Mdot
.74655 .16236 Mdot
.74659 .16228 Mdot
.74664 .16221 Mdot
.74669 .16213 Mdot
.74674 .16205 Mdot
.74678 .16197 Mdot
.74683 .16189 Mdot
.74688 .16182 Mdot
.74693 .16174 Mdot
.74698 .16166 Mdot
.74702 .16159 Mdot
.74707 .16151 Mdot
.74712 .16143 Mdot
.74717 .16136 Mdot
.74721 .16128 Mdot
.74726 .1612 Mdot
.74731 .16113 Mdot
.74736 .16105 Mdot
.7474 .16098 Mdot
.74745 .1609 Mdot
.7475 .16082 Mdot
.74755 .16075 Mdot
.74759 .16067 Mdot
.74764 .1606 Mdot
.74769 .16052 Mdot
.74774 .16045 Mdot
.74778 .16037 Mdot
.74783 .1603 Mdot
.74788 .16023 Mdot
.74793 .16015 Mdot
.74798 .16008 Mdot
.74802 .16 Mdot
.74807 .15993 Mdot
.74812 .15985 Mdot
.74817 .15978 Mdot
.74821 .15971 Mdot
.74826 .15963 Mdot
.74831 .15956 Mdot
.74836 .15949 Mdot
.7484 .15941 Mdot
.74845 .15934 Mdot
.7485 .15927 Mdot
.74855 .1592 Mdot
.74859 .15912 Mdot
.74864 .15905 Mdot
.74869 .15898 Mdot
.74874 .15891 Mdot
.74878 .15884 Mdot
.74883 .15876 Mdot
.74888 .15869 Mdot
.74893 .15862 Mdot
.74898 .15855 Mdot
.74902 .15848 Mdot
.74907 .15841 Mdot
.74912 .15834 Mdot
.74917 .15826 Mdot
.74921 .15819 Mdot
.74926 .15812 Mdot
.74931 .15805 Mdot
.74936 .15798 Mdot
.7494 .15791 Mdot
.74945 .15784 Mdot
.7495 .15777 Mdot
.74955 .1577 Mdot
.74959 .15763 Mdot
.74964 .15756 Mdot
.74969 .15749 Mdot
.74974 .15742 Mdot
.74978 .15736 Mdot
.74983 .15729 Mdot
.74988 .15722 Mdot
.74993 .15715 Mdot
.74998 .15708 Mdot
.75002 .15701 Mdot
.75007 .15694 Mdot
.75012 .15688 Mdot
.75017 .15681 Mdot
.75021 .15674 Mdot
.75026 .15667 Mdot
.75031 .1566 Mdot
.75036 .15654 Mdot
.7504 .15647 Mdot
.75045 .1564 Mdot
.7505 .15633 Mdot
.75055 .15627 Mdot
.75059 .1562 Mdot
.75064 .15613 Mdot
.75069 .15607 Mdot
.75074 .156 Mdot
.75078 .15594 Mdot
.75083 .15587 Mdot
.75088 .1558 Mdot
.75093 .15574 Mdot
.75097 .15567 Mdot
.75102 .15561 Mdot
.75107 .15554 Mdot
.75112 .15548 Mdot
.75117 .15541 Mdot
.75121 .15535 Mdot
.75126 .15528 Mdot
.75131 .15522 Mdot
.75136 .15515 Mdot
.7514 .15509 Mdot
.75145 .15502 Mdot
.7515 .15496 Mdot
.75155 .15489 Mdot
.75159 .15483 Mdot
.75164 .15477 Mdot
.75169 .1547 Mdot
.75174 .15464 Mdot
.75178 .15458 Mdot
.75183 .15451 Mdot
.75188 .15445 Mdot
.75193 .15439 Mdot
.75197 .15432 Mdot
.75202 .15426 Mdot
.75207 .1542 Mdot
.75212 .15414 Mdot
.75217 .15407 Mdot
.75221 .15401 Mdot
.75226 .15395 Mdot
.75231 .15389 Mdot
.75236 .15383 Mdot
.7524 .15376 Mdot
.75245 .1537 Mdot
.7525 .15364 Mdot
.75255 .15358 Mdot
.75259 .15352 Mdot
.75264 .15346 Mdot
.75269 .1534 Mdot
.75274 .15334 Mdot
.75278 .15328 Mdot
.75283 .15322 Mdot
.75288 .15316 Mdot
.75293 .1531 Mdot
.75297 .15304 Mdot
.75302 .15298 Mdot
.75307 .15292 Mdot
.75312 .15286 Mdot
.75317 .1528 Mdot
.75321 .15274 Mdot
.75326 .15268 Mdot
.75331 .15262 Mdot
.75336 .15256 Mdot
.7534 .1525 Mdot
.75345 .15244 Mdot
.7535 .15239 Mdot
.75355 .15233 Mdot
.75359 .15227 Mdot
.75364 .15221 Mdot
.75369 .15215 Mdot
.75374 .1521 Mdot
.75378 .15204 Mdot
.75383 .15198 Mdot
.75388 .15192 Mdot
.75393 .15187 Mdot
.75397 .15181 Mdot
.75402 .15175 Mdot
.75407 .1517 Mdot
.75412 .15164 Mdot
.75417 .15158 Mdot
.75421 .15153 Mdot
.75426 .15147 Mdot
.75431 .15142 Mdot
.75436 .15136 Mdot
.7544 .1513 Mdot
.75445 .15125 Mdot
.7545 .15119 Mdot
.75455 .15114 Mdot
.75459 .15108 Mdot
.75464 .15103 Mdot
.75469 .15097 Mdot
.75474 .15092 Mdot
.75478 .15086 Mdot
.75483 .15081 Mdot
.75488 .15075 Mdot
.75493 .1507 Mdot
.75497 .15065 Mdot
.75502 .15059 Mdot
.75507 .15054 Mdot
.75512 .15048 Mdot
.75516 .15043 Mdot
.75521 .15038 Mdot
.75526 .15032 Mdot
.75531 .15027 Mdot
.75536 .15022 Mdot
.7554 .15017 Mdot
.75545 .15011 Mdot
.7555 .15006 Mdot
.75555 .15001 Mdot
.75559 .14996 Mdot
.75564 .1499 Mdot
.75569 .14985 Mdot
.75574 .1498 Mdot
.75578 .14975 Mdot
.75583 .1497 Mdot
.75588 .14965 Mdot
.75593 .14959 Mdot
.75597 .14954 Mdot
.75602 .14949 Mdot
.75607 .14944 Mdot
.75612 .14939 Mdot
.75616 .14934 Mdot
.75621 .14929 Mdot
.75626 .14924 Mdot
.75631 .14919 Mdot
.75636 .14914 Mdot
.7564 .14909 Mdot
.75645 .14904 Mdot
.7565 .14899 Mdot
.75655 .14894 Mdot
.75659 .14889 Mdot
.75664 .14884 Mdot
.75669 .14879 Mdot
.75674 .14875 Mdot
.75678 .1487 Mdot
.75683 .14865 Mdot
.75688 .1486 Mdot
.75693 .14855 Mdot
.75697 .1485 Mdot
.75702 .14846 Mdot
.75707 .14841 Mdot
.75712 .14836 Mdot
.75716 .14831 Mdot
.75721 .14827 Mdot
.75726 .14822 Mdot
.75731 .14817 Mdot
.75736 .14812 Mdot
.7574 .14808 Mdot
.75745 .14803 Mdot
.7575 .14798 Mdot
.75755 .14794 Mdot
.75759 .14789 Mdot
.75764 .14785 Mdot
.75769 .1478 Mdot
.75774 .14775 Mdot
.75778 .14771 Mdot
.75783 .14766 Mdot
.75788 .14762 Mdot
.75793 .14757 Mdot
.75797 .14753 Mdot
.75802 .14748 Mdot
.75807 .14744 Mdot
.75812 .14739 Mdot
.75816 .14735 Mdot
.75821 .1473 Mdot
.75826 .14726 Mdot
.75831 .14722 Mdot
.75836 .14717 Mdot
.7584 .14713 Mdot
.75845 .14708 Mdot
.7585 .14704 Mdot
.75855 .147 Mdot
.75859 .14695 Mdot
.75864 .14691 Mdot
.75869 .14687 Mdot
.75874 .14683 Mdot
.75878 .14678 Mdot
.75883 .14674 Mdot
.75888 .1467 Mdot
.75893 .14666 Mdot
.75897 .14661 Mdot
.75902 .14657 Mdot
.75907 .14653 Mdot
.75912 .14649 Mdot
.75916 .14645 Mdot
.75921 .14641 Mdot
.75926 .14636 Mdot
.75931 .14632 Mdot
.75936 .14628 Mdot
.7594 .14624 Mdot
.75945 .1462 Mdot
.7595 .14616 Mdot
.75955 .14612 Mdot
.75959 .14608 Mdot
.75964 .14604 Mdot
.75969 .146 Mdot
.75974 .14596 Mdot
.75978 .14592 Mdot
.75983 .14588 Mdot
.75988 .14584 Mdot
.75993 .1458 Mdot
.75997 .14576 Mdot
.76002 .14572 Mdot
.76007 .14569 Mdot
.76012 .14565 Mdot
.76016 .14561 Mdot
.76021 .14557 Mdot
.76026 .14553 Mdot
.76031 .14549 Mdot
.76035 .14546 Mdot
.7604 .14542 Mdot
.76045 .14538 Mdot
.7605 .14534 Mdot
.76055 .14531 Mdot
.76059 .14527 Mdot
.76064 .14523 Mdot
.76069 .14519 Mdot
.76074 .14516 Mdot
.76078 .14512 Mdot
.76083 .14508 Mdot
.76088 .14505 Mdot
.76093 .14501 Mdot
.76097 .14498 Mdot
.76102 .14494 Mdot
.76107 .1449 Mdot
.76112 .14487 Mdot
.76116 .14483 Mdot
.76121 .1448 Mdot
.76126 .14476 Mdot
.76131 .14473 Mdot
.76135 .14469 Mdot
.7614 .14466 Mdot
.76145 .14462 Mdot
.7615 .14459 Mdot
.76155 .14456 Mdot
.76159 .14452 Mdot
.76164 .14449 Mdot
.76169 .14445 Mdot
.76174 .14442 Mdot
.76178 .14439 Mdot
.76183 .14435 Mdot
.76188 .14432 Mdot
.76193 .14429 Mdot
.76197 .14425 Mdot
.76202 .14422 Mdot
.76207 .14419 Mdot
.76212 .14416 Mdot
.76216 .14412 Mdot
.76221 .14409 Mdot
.76226 .14406 Mdot
.76231 .14403 Mdot
.76235 .14399 Mdot
.7624 .14396 Mdot
.76245 .14393 Mdot
.7625 .1439 Mdot
.76255 .14387 Mdot
.76259 .14384 Mdot
.76264 .14381 Mdot
.76269 .14378 Mdot
.76274 .14375 Mdot
.76278 .14372 Mdot
.76283 .14368 Mdot
.76288 .14365 Mdot
.76293 .14362 Mdot
.76297 .14359 Mdot
.76302 .14356 Mdot
.76307 .14354 Mdot
.76312 .14351 Mdot
.76316 .14348 Mdot
.76321 .14345 Mdot
.76326 .14342 Mdot
.76331 .14339 Mdot
.76335 .14336 Mdot
.7634 .14333 Mdot
.76345 .1433 Mdot
.7635 .14327 Mdot
.76355 .14325 Mdot
.76359 .14322 Mdot
.76364 .14319 Mdot
.76369 .14316 Mdot
.76374 .14314 Mdot
.76378 .14311 Mdot
.76383 .14308 Mdot
.76388 .14305 Mdot
.76393 .14303 Mdot
.76397 .143 Mdot
.76402 .14297 Mdot
.76407 .14295 Mdot
.76412 .14292 Mdot
.76416 .14289 Mdot
.76421 .14287 Mdot
.76426 .14284 Mdot
.76431 .14282 Mdot
.76435 .14279 Mdot
.7644 .14276 Mdot
.76445 .14274 Mdot
.7645 .14271 Mdot
.76454 .14269 Mdot
.76459 .14266 Mdot
.76464 .14264 Mdot
.76469 .14261 Mdot
.76474 .14259 Mdot
.76478 .14257 Mdot
.76483 .14254 Mdot
.76488 .14252 Mdot
.76493 .14249 Mdot
.76497 .14247 Mdot
.76502 .14245 Mdot
.76507 .14242 Mdot
.76512 .1424 Mdot
.76516 .14238 Mdot
.76521 .14235 Mdot
.76526 .14233 Mdot
.76531 .14231 Mdot
.76535 .14228 Mdot
.7654 .14226 Mdot
.76545 .14224 Mdot
.7655 .14222 Mdot
.76554 .1422 Mdot
.76559 .14217 Mdot
.76564 .14215 Mdot
.76569 .14213 Mdot
.76574 .14211 Mdot
.76578 .14209 Mdot
.76583 .14207 Mdot
.76588 .14204 Mdot
.76593 .14202 Mdot
.76597 .142 Mdot
.76602 .14198 Mdot
.76607 .14196 Mdot
.76612 .14194 Mdot
.76616 .14192 Mdot
.76621 .1419 Mdot
.76626 .14188 Mdot
.76631 .14186 Mdot
.76635 .14184 Mdot
.7664 .14182 Mdot
.76645 .1418 Mdot
.7665 .14178 Mdot
.76654 .14177 Mdot
.76659 .14175 Mdot
.76664 .14173 Mdot
.76669 .14171 Mdot
.76674 .14169 Mdot
.76678 .14167 Mdot
.76683 .14165 Mdot
.76688 .14164 Mdot
.76693 .14162 Mdot
.76697 .1416 Mdot
.76702 .14158 Mdot
.76707 .14157 Mdot
.76712 .14155 Mdot
.76716 .14153 Mdot
.76721 .14152 Mdot
.76726 .1415 Mdot
.76731 .14148 Mdot
.76735 .14147 Mdot
.7674 .14145 Mdot
.76745 .14143 Mdot
.7675 .14142 Mdot
.76754 .1414 Mdot
.76759 .14139 Mdot
.76764 .14137 Mdot
.76769 .14135 Mdot
.76774 .14134 Mdot
.76778 .14132 Mdot
.76783 .14131 Mdot
.76788 .14129 Mdot
.76793 .14128 Mdot
.76797 .14126 Mdot
.76802 .14125 Mdot
.76807 .14124 Mdot
.76812 .14122 Mdot
.76816 .14121 Mdot
.76821 .14119 Mdot
.76826 .14118 Mdot
.76831 .14117 Mdot
.76835 .14115 Mdot
.7684 .14114 Mdot
.76845 .14113 Mdot
.7685 .14111 Mdot
.76854 .1411 Mdot
.76859 .14109 Mdot
.76864 .14108 Mdot
.76869 .14106 Mdot
.76874 .14105 Mdot
.76878 .14104 Mdot
.76883 .14103 Mdot
.76888 .14102 Mdot
.76893 .141 Mdot
.76897 .14099 Mdot
.76902 .14098 Mdot
.76907 .14097 Mdot
.76912 .14096 Mdot
.76916 .14095 Mdot
.76921 .14094 Mdot
.76926 .14093 Mdot
.76931 .14092 Mdot
.76935 .14091 Mdot
.7694 .14089 Mdot
.76945 .14088 Mdot
.7695 .14087 Mdot
.76954 .14087 Mdot
.76959 .14086 Mdot
.76964 .14085 Mdot
.76969 .14084 Mdot
.76973 .14083 Mdot
.76978 .14082 Mdot
.76983 .14081 Mdot
.76988 .1408 Mdot
.76993 .14079 Mdot
.76997 .14078 Mdot
.77002 .14078 Mdot
.77007 .14077 Mdot
.77012 .14076 Mdot
.77016 .14075 Mdot
.77021 .14074 Mdot
.77026 .14074 Mdot
.77031 .14073 Mdot
.77035 .14072 Mdot
.7704 .14071 Mdot
.77045 .14071 Mdot
.7705 .1407 Mdot
.77054 .14069 Mdot
.77059 .14069 Mdot
.77064 .14068 Mdot
.77069 .14067 Mdot
.77073 .14067 Mdot
.77078 .14066 Mdot
.77083 .14066 Mdot
.77088 .14065 Mdot
.77093 .14065 Mdot
.77097 .14064 Mdot
.77102 .14064 Mdot
.77107 .14063 Mdot
.77112 .14063 Mdot
.77116 .14062 Mdot
.77121 .14062 Mdot
.77126 .14061 Mdot
.77131 .14061 Mdot
.77135 .1406 Mdot
.7714 .1406 Mdot
.77145 .14059 Mdot
.7715 .14059 Mdot
.77154 .14059 Mdot
.77159 .14058 Mdot
.77164 .14058 Mdot
.77169 .14058 Mdot
.77173 .14057 Mdot
.77178 .14057 Mdot
.77183 .14057 Mdot
.77188 .14057 Mdot
.77193 .14056 Mdot
.77197 .14056 Mdot
.77202 .14056 Mdot
.77207 .14056 Mdot
.77212 .14056 Mdot
.77216 .14055 Mdot
.77221 .14055 Mdot
.77226 .14055 Mdot
.77231 .14055 Mdot
.77235 .14055 Mdot
.7724 .14055 Mdot
.77245 .14055 Mdot
.7725 .14055 Mdot
.77254 .14054 Mdot
.77259 .14054 Mdot
.77264 .14054 Mdot
.77269 .14054 Mdot
.77273 .14054 Mdot
.77278 .14054 Mdot
.77283 .14054 Mdot
.77288 .14055 Mdot
.77293 .14055 Mdot
.77297 .14055 Mdot
.77302 .14055 Mdot
.77307 .14055 Mdot
.77312 .14055 Mdot
.77316 .14055 Mdot
.77321 .14055 Mdot
.77326 .14055 Mdot
.77331 .14056 Mdot
.77335 .14056 Mdot
.7734 .14056 Mdot
.77345 .14056 Mdot
.7735 .14056 Mdot
.77354 .14057 Mdot
.77359 .14057 Mdot
.77364 .14057 Mdot
.77369 .14058 Mdot
.77373 .14058 Mdot
.77378 .14058 Mdot
.77383 .14058 Mdot
.77388 .14059 Mdot
.77392 .14059 Mdot
.77397 .1406 Mdot
.77402 .1406 Mdot
.77407 .1406 Mdot
.77412 .14061 Mdot
.77416 .14061 Mdot
.77421 .14062 Mdot
.77426 .14062 Mdot
.77431 .14063 Mdot
.77435 .14063 Mdot
.7744 .14064 Mdot
.77445 .14064 Mdot
.7745 .14065 Mdot
.77454 .14065 Mdot
.77459 .14066 Mdot
.77464 .14066 Mdot
.77469 .14067 Mdot
.77473 .14068 Mdot
.77478 .14068 Mdot
.77483 .14069 Mdot
.77488 .1407 Mdot
.77492 .1407 Mdot
.77497 .14071 Mdot
.77502 .14072 Mdot
.77507 .14072 Mdot
.77512 .14073 Mdot
.77516 .14074 Mdot
.77521 .14075 Mdot
.77526 .14075 Mdot
.77531 .14076 Mdot
.77535 .14077 Mdot
.7754 .14078 Mdot
.77545 .14079 Mdot
.7755 .14079 Mdot
.77554 .1408 Mdot
.77559 .14081 Mdot
.77564 .14082 Mdot
.77569 .14083 Mdot
.77573 .14084 Mdot
.77578 .14085 Mdot
.77583 .14086 Mdot
.77588 .14087 Mdot
.77592 .14088 Mdot
.77597 .14089 Mdot
.77602 .1409 Mdot
.77607 .14091 Mdot
.77612 .14092 Mdot
.77616 .14093 Mdot
.77621 .14094 Mdot
.77626 .14095 Mdot
.77631 .14096 Mdot
.77635 .14097 Mdot
.7764 .14098 Mdot
.77645 .14099 Mdot
.7765 .141 Mdot
.77654 .14102 Mdot
.77659 .14103 Mdot
.77664 .14104 Mdot
.77669 .14105 Mdot
.77673 .14106 Mdot
.77678 .14108 Mdot
.77683 .14109 Mdot
.77688 .1411 Mdot
.77692 .14111 Mdot
.77697 .14113 Mdot
.77702 .14114 Mdot
.77707 .14115 Mdot
.77712 .14117 Mdot
.77716 .14118 Mdot
.77721 .14119 Mdot
.77726 .14121 Mdot
.77731 .14122 Mdot
.77735 .14124 Mdot
.7774 .14125 Mdot
.77745 .14126 Mdot
.7775 .14128 Mdot
.77754 .14129 Mdot
.77759 .14131 Mdot
.77764 .14132 Mdot
.77769 .14134 Mdot
.77773 .14135 Mdot
.77778 .14137 Mdot
.77783 .14138 Mdot
.77788 .1414 Mdot
.77792 .14142 Mdot
.77797 .14143 Mdot
.77802 .14145 Mdot
.77807 .14146 Mdot
.77812 .14148 Mdot
.77816 .1415 Mdot
.77821 .14151 Mdot
.77826 .14153 Mdot
.77831 .14155 Mdot
.77835 .14156 Mdot
.7784 .14158 Mdot
.77845 .1416 Mdot
.7785 .14162 Mdot
.77854 .14163 Mdot
.77859 .14165 Mdot
.77864 .14167 Mdot
.77869 .14169 Mdot
.77873 .14171 Mdot
.77878 .14172 Mdot
.77883 .14174 Mdot
.77888 .14176 Mdot
.77892 .14178 Mdot
.77897 .1418 Mdot
.77902 .14182 Mdot
.77907 .14184 Mdot
.77911 .14186 Mdot
.77916 .14188 Mdot
.77921 .1419 Mdot
.77926 .14192 Mdot
.77931 .14193 Mdot
.77935 .14196 Mdot
.7794 .14198 Mdot
.77945 .142 Mdot
.7795 .14202 Mdot
.77954 .14204 Mdot
.77959 .14206 Mdot
.77964 .14208 Mdot
.77969 .1421 Mdot
.77973 .14212 Mdot
.77978 .14214 Mdot
.77983 .14216 Mdot
.77988 .14219 Mdot
.77992 .14221 Mdot
.77997 .14223 Mdot
.78002 .14225 Mdot
.78007 .14227 Mdot
.78011 .1423 Mdot
.78016 .14232 Mdot
.78021 .14234 Mdot
.78026 .14236 Mdot
.78031 .14239 Mdot
.78035 .14241 Mdot
.7804 .14243 Mdot
.78045 .14246 Mdot
.7805 .14248 Mdot
.78054 .1425 Mdot
.78059 .14253 Mdot
.78064 .14255 Mdot
.78069 .14257 Mdot
.78073 .1426 Mdot
.78078 .14262 Mdot
.78083 .14265 Mdot
.78088 .14267 Mdot
.78092 .1427 Mdot
.78097 .14272 Mdot
.78102 .14275 Mdot
.78107 .14277 Mdot
.78111 .1428 Mdot
.78116 .14282 Mdot
.78121 .14285 Mdot
.78126 .14287 Mdot
.78131 .1429 Mdot
.78135 .14293 Mdot
.7814 .14295 Mdot
.78145 .14298 Mdot
.7815 .143 Mdot
.78154 .14303 Mdot
.78159 .14306 Mdot
.78164 .14308 Mdot
.78169 .14311 Mdot
.78173 .14314 Mdot
.78178 .14317 Mdot
.78183 .14319 Mdot
.78188 .14322 Mdot
.78192 .14325 Mdot
.78197 .14328 Mdot
.78202 .1433 Mdot
.78207 .14333 Mdot
.78211 .14336 Mdot
.78216 .14339 Mdot
.78221 .14342 Mdot
.78226 .14345 Mdot
.78231 .14347 Mdot
.78235 .1435 Mdot
.7824 .14353 Mdot
.78245 .14356 Mdot
.7825 .14359 Mdot
.78254 .14362 Mdot
.78259 .14365 Mdot
.78264 .14368 Mdot
.78269 .14371 Mdot
.78273 .14374 Mdot
.78278 .14377 Mdot
.78283 .1438 Mdot
.78288 .14383 Mdot
.78292 .14386 Mdot
.78297 .14389 Mdot
.78302 .14392 Mdot
.78307 .14395 Mdot
.78311 .14399 Mdot
.78316 .14402 Mdot
.78321 .14405 Mdot
.78326 .14408 Mdot
.78331 .14411 Mdot
.78335 .14414 Mdot
.7834 .14418 Mdot
.78345 .14421 Mdot
.7835 .14424 Mdot
.78354 .14427 Mdot
.78359 .14431 Mdot
.78364 .14434 Mdot
.78369 .14437 Mdot
.78373 .1444 Mdot
.78378 .14444 Mdot
.78383 .14447 Mdot
.78388 .1445 Mdot
.78392 .14454 Mdot
.78397 .14457 Mdot
.78402 .1446 Mdot
.78407 .14464 Mdot
.78411 .14467 Mdot
.78416 .14471 Mdot
.78421 .14474 Mdot
.78426 .14478 Mdot
.7843 .14481 Mdot
.78435 .14485 Mdot
.7844 .14488 Mdot
.78445 .14492 Mdot
.7845 .14495 Mdot
.78454 .14499 Mdot
.78459 .14502 Mdot
.78464 .14506 Mdot
.78469 .14509 Mdot
.78473 .14513 Mdot
.78478 .14516 Mdot
.78483 .1452 Mdot
.78488 .14524 Mdot
.78492 .14527 Mdot
.78497 .14531 Mdot
.78502 .14535 Mdot
.78507 .14538 Mdot
.78511 .14542 Mdot
.78516 .14546 Mdot
.78521 .14549 Mdot
.78526 .14553 Mdot
.7853 .14557 Mdot
.78535 .14561 Mdot
.7854 .14565 Mdot
.78545 .14568 Mdot
.7855 .14572 Mdot
.78554 .14576 Mdot
.78559 .1458 Mdot
.78564 .14584 Mdot
.78569 .14587 Mdot
.78573 .14591 Mdot
.78578 .14595 Mdot
.78583 .14599 Mdot
.78588 .14603 Mdot
.78592 .14607 Mdot
.78597 .14611 Mdot
.78602 .14615 Mdot
.78607 .14619 Mdot
.78611 .14623 Mdot
.78616 .14627 Mdot
.78621 .14631 Mdot
.78626 .14635 Mdot
.7863 .14639 Mdot
.78635 .14643 Mdot
.7864 .14647 Mdot
.78645 .14651 Mdot
.7865 .14655 Mdot
.78654 .14659 Mdot
.78659 .14663 Mdot
.78664 .14668 Mdot
.78669 .14672 Mdot
.78673 .14676 Mdot
.78678 .1468 Mdot
.78683 .14684 Mdot
.78688 .14688 Mdot
.78692 .14693 Mdot
.78697 .14697 Mdot
.78702 .14701 Mdot
.78707 .14705 Mdot
.78711 .1471 Mdot
.78716 .14714 Mdot
.78721 .14718 Mdot
.78726 .14723 Mdot
.7873 .14727 Mdot
.78735 .14731 Mdot
.7874 .14736 Mdot
.78745 .1474 Mdot
.7875 .14744 Mdot
.78754 .14749 Mdot
.78759 .14753 Mdot
.78764 .14757 Mdot
.78769 .14762 Mdot
.78773 .14766 Mdot
.78778 .14771 Mdot
.78783 .14775 Mdot
.78788 .1478 Mdot
.78792 .14784 Mdot
.78797 .14789 Mdot
.78802 .14793 Mdot
.78807 .14798 Mdot
.78811 .14802 Mdot
.78816 .14807 Mdot
.78821 .14812 Mdot
.78826 .14816 Mdot
.7883 .14821 Mdot
.78835 .14825 Mdot
.7884 .1483 Mdot
.78845 .14835 Mdot
.78849 .14839 Mdot
.78854 .14844 Mdot
.78859 .14849 Mdot
.78864 .14853 Mdot
.78869 .14858 Mdot
.78873 .14863 Mdot
.78878 .14868 Mdot
.78883 .14872 Mdot
.78888 .14877 Mdot
.78892 .14882 Mdot
.78897 .14887 Mdot
.78902 .14891 Mdot
.78907 .14896 Mdot
.78911 .14901 Mdot
.78916 .14906 Mdot
.78921 .14911 Mdot
.78926 .14916 Mdot
.7893 .14921 Mdot
.78935 .14925 Mdot
.7894 .1493 Mdot
.78945 .14935 Mdot
.78949 .1494 Mdot
.78954 .14945 Mdot
.78959 .1495 Mdot
.78964 .14955 Mdot
.78969 .1496 Mdot
.78973 .14965 Mdot
.78978 .1497 Mdot
.78983 .14975 Mdot
.78988 .1498 Mdot
.78992 .14985 Mdot
.78997 .1499 Mdot
.79002 .14995 Mdot
.79007 .15 Mdot
.79011 .15006 Mdot
.79016 .15011 Mdot
.79021 .15016 Mdot
.79026 .15021 Mdot
.7903 .15026 Mdot
.79035 .15031 Mdot
.7904 .15036 Mdot
.79045 .15042 Mdot
.79049 .15047 Mdot
.79054 .15052 Mdot
.79059 .15057 Mdot
.79064 .15063 Mdot
.79069 .15068 Mdot
.79073 .15073 Mdot
.79078 .15078 Mdot
.79083 .15084 Mdot
.79088 .15089 Mdot
.79092 .15094 Mdot
.79097 .151 Mdot
.79102 .15105 Mdot
.79107 .1511 Mdot
.79111 .15116 Mdot
.79116 .15121 Mdot
.79121 .15127 Mdot
.79126 .15132 Mdot
.7913 .15137 Mdot
.79135 .15143 Mdot
.7914 .15148 Mdot
.79145 .15154 Mdot
.79149 .15159 Mdot
.79154 .15165 Mdot
.79159 .1517 Mdot
.79164 .15176 Mdot
.79169 .15181 Mdot
.79173 .15187 Mdot
.79178 .15192 Mdot
.79183 .15198 Mdot
.79188 .15204 Mdot
.79192 .15209 Mdot
.79197 .15215 Mdot
.79202 .1522 Mdot
.79207 .15226 Mdot
.79211 .15232 Mdot
.79216 .15237 Mdot
.79221 .15243 Mdot
.79226 .15249 Mdot
.7923 .15255 Mdot
.79235 .1526 Mdot
.7924 .15266 Mdot
.79245 .15272 Mdot
.79249 .15277 Mdot
.79254 .15283 Mdot
.79259 .15289 Mdot
.79264 .15295 Mdot
.79269 .15301 Mdot
.79273 .15306 Mdot
.79278 .15312 Mdot
.79283 .15318 Mdot
.79288 .15324 Mdot
.79292 .1533 Mdot
.79297 .15336 Mdot
.79302 .15342 Mdot
.79307 .15347 Mdot
.79311 .15353 Mdot
.79316 .15359 Mdot
.79321 .15365 Mdot
.79326 .15371 Mdot
.7933 .15377 Mdot
.79335 .15383 Mdot
.7934 .15389 Mdot
.79345 .15395 Mdot
.79349 .15401 Mdot
.79354 .15407 Mdot
.79359 .15413 Mdot
.79364 .15419 Mdot
.79368 .15425 Mdot
.79373 .15432 Mdot
.79378 .15438 Mdot
.79383 .15444 Mdot
.79388 .1545 Mdot
.79392 .15456 Mdot
.79397 .15462 Mdot
.79402 .15468 Mdot
.79407 .15474 Mdot
.79411 .15481 Mdot
.79416 .15487 Mdot
.79421 .15493 Mdot
.79426 .15499 Mdot
.7943 .15505 Mdot
.79435 .15512 Mdot
.7944 .15518 Mdot
.79445 .15524 Mdot
.79449 .15531 Mdot
.79454 .15537 Mdot
.79459 .15543 Mdot
.79464 .15549 Mdot
.79468 .15556 Mdot
.79473 .15562 Mdot
.79478 .15569 Mdot
.79483 .15575 Mdot
.79488 .15581 Mdot
.79492 .15588 Mdot
.79497 .15594 Mdot
.79502 .156 Mdot
.79507 .15607 Mdot
.79511 .15613 Mdot
.79516 .1562 Mdot
.79521 .15626 Mdot
.79526 .15633 Mdot
.7953 .15639 Mdot
.79535 .15646 Mdot
.7954 .15652 Mdot
.79545 .15659 Mdot
.79549 .15665 Mdot
.79554 .15672 Mdot
.79559 .15679 Mdot
.79564 .15685 Mdot
.79568 .15692 Mdot
.79573 .15698 Mdot
.79578 .15705 Mdot
.79583 .15712 Mdot
.79588 .15718 Mdot
.79592 .15725 Mdot
.79597 .15731 Mdot
.79602 .15738 Mdot
.79607 .15745 Mdot
.79611 .15752 Mdot
.79616 .15758 Mdot
.79621 .15765 Mdot
.79626 .15772 Mdot
.7963 .15779 Mdot
.79635 .15785 Mdot
.7964 .15792 Mdot
.79645 .15799 Mdot
.79649 .15806 Mdot
.79654 .15812 Mdot
.79659 .15819 Mdot
.79664 .15826 Mdot
.79668 .15833 Mdot
.79673 .1584 Mdot
.79678 .15847 Mdot
.79683 .15854 Mdot
.79688 .1586 Mdot
.79692 .15867 Mdot
.79697 .15874 Mdot
.79702 .15881 Mdot
.79707 .15888 Mdot
.79711 .15895 Mdot
.79716 .15902 Mdot
.79721 .15909 Mdot
.79726 .15916 Mdot
.7973 .15923 Mdot
.79735 .1593 Mdot
.7974 .15937 Mdot
.79745 .15944 Mdot
.79749 .15951 Mdot
.79754 .15958 Mdot
.79759 .15965 Mdot
.79764 .15972 Mdot
.79768 .1598 Mdot
.79773 .15987 Mdot
.79778 .15994 Mdot
.79783 .16001 Mdot
.79787 .16008 Mdot
.79792 .16015 Mdot
.79797 .16022 Mdot
.79802 .1603 Mdot
.79807 .16037 Mdot
.79811 .16044 Mdot
.79816 .16051 Mdot
.79821 .16058 Mdot
.79826 .16066 Mdot
.7983 .16073 Mdot
.79835 .1608 Mdot
.7984 .16088 Mdot
.79845 .16095 Mdot
.79849 .16102 Mdot
.79854 .16109 Mdot
.79859 .16117 Mdot
.79864 .16124 Mdot
.79868 .16131 Mdot
.79873 .16139 Mdot
.79878 .16146 Mdot
.79883 .16154 Mdot
.79887 .16161 Mdot
.79892 .16168 Mdot
.79897 .16176 Mdot
.79902 .16183 Mdot
.79907 .16191 Mdot
.79911 .16198 Mdot
.79916 .16206 Mdot
.79921 .16213 Mdot
.79926 .16221 Mdot
.7993 .16228 Mdot
.79935 .16236 Mdot
.7994 .16243 Mdot
.79945 .16251 Mdot
.79949 .16258 Mdot
.79954 .16266 Mdot
.79959 .16273 Mdot
.79964 .16281 Mdot
.79968 .16289 Mdot
.79973 .16296 Mdot
.79978 .16304 Mdot
.79983 .16311 Mdot
.79987 .16319 Mdot
.79992 .16327 Mdot
.79997 .16334 Mdot
.80002 .16342 Mdot
.80007 .1635 Mdot
.80011 .16357 Mdot
.80016 .16365 Mdot
.80021 .16373 Mdot
.80026 .16381 Mdot
.8003 .16388 Mdot
.80035 .16396 Mdot
.8004 .16404 Mdot
.80045 .16412 Mdot
.80049 .16419 Mdot
.80054 .16427 Mdot
.80059 .16435 Mdot
.80064 .16443 Mdot
.80068 .16451 Mdot
.80073 .16459 Mdot
.80078 .16466 Mdot
.80083 .16474 Mdot
.80087 .16482 Mdot
.80092 .1649 Mdot
.80097 .16498 Mdot
.80102 .16506 Mdot
.80107 .16514 Mdot
.80111 .16522 Mdot
.80116 .1653 Mdot
.80121 .16538 Mdot
.80126 .16546 Mdot
.8013 .16554 Mdot
.80135 .16562 Mdot
.8014 .1657 Mdot
.80145 .16578 Mdot
.80149 .16586 Mdot
.80154 .16594 Mdot
.80159 .16602 Mdot
.80164 .1661 Mdot
.80168 .16618 Mdot
.80173 .16626 Mdot
.80178 .16634 Mdot
.80183 .16642 Mdot
.80187 .1665 Mdot
.80192 .16658 Mdot
.80197 .16667 Mdot
.80202 .16675 Mdot
.80207 .16683 Mdot
.80211 .16691 Mdot
.80216 .16699 Mdot
.80221 .16707 Mdot
.80226 .16716 Mdot
.8023 .16724 Mdot
.80235 .16732 Mdot
.8024 .1674 Mdot
.80245 .16749 Mdot
.80249 .16757 Mdot
.80254 .16765 Mdot
.80259 .16773 Mdot
.80264 .16782 Mdot
.80268 .1679 Mdot
.80273 .16798 Mdot
.80278 .16807 Mdot
.80283 .16815 Mdot
.80287 .16823 Mdot
.80292 .16832 Mdot
.80297 .1684 Mdot
.80302 .16848 Mdot
.80306 .16857 Mdot
.80311 .16865 Mdot
.80316 .16874 Mdot
.80321 .16882 Mdot
.80326 .16891 Mdot
.8033 .16899 Mdot
.80335 .16907 Mdot
.8034 .16916 Mdot
.80345 .16924 Mdot
.80349 .16933 Mdot
.80354 .16941 Mdot
.80359 .1695 Mdot
.80364 .16958 Mdot
.80368 .16967 Mdot
.80373 .16976 Mdot
.80378 .16984 Mdot
.80383 .16993 Mdot
.80387 .17001 Mdot
.80392 .1701 Mdot
.80397 .17018 Mdot
.80402 .17027 Mdot
.80406 .17036 Mdot
.80411 .17044 Mdot
.80416 .17053 Mdot
.80421 .17062 Mdot
.80426 .1707 Mdot
.8043 .17079 Mdot
.80435 .17088 Mdot
.8044 .17096 Mdot
.80445 .17105 Mdot
.80449 .17114 Mdot
.80454 .17122 Mdot
.80459 .17131 Mdot
.80464 .1714 Mdot
.80468 .17149 Mdot
.80473 .17158 Mdot
.80478 .17166 Mdot
.80483 .17175 Mdot
.80487 .17184 Mdot
.80492 .17193 Mdot
.80497 .17202 Mdot
.80502 .1721 Mdot
.80506 .17219 Mdot
.80511 .17228 Mdot
.80516 .17237 Mdot
.80521 .17246 Mdot
.80526 .17255 Mdot
.8053 .17264 Mdot
.80535 .17273 Mdot
.8054 .17281 Mdot
.80545 .1729 Mdot
.80549 .17299 Mdot
.80554 .17308 Mdot
.80559 .17317 Mdot
.80564 .17326 Mdot
.80568 .17335 Mdot
.80573 .17344 Mdot
.80578 .17353 Mdot
.80583 .17362 Mdot
.80587 .17371 Mdot
.80592 .1738 Mdot
.80597 .17389 Mdot
.80602 .17398 Mdot
.80606 .17407 Mdot
.80611 .17416 Mdot
.80616 .17426 Mdot
.80621 .17435 Mdot
.80626 .17444 Mdot
.8063 .17453 Mdot
.80635 .17462 Mdot
.8064 .17471 Mdot
.80645 .1748 Mdot
.80649 .17489 Mdot
.80654 .17499 Mdot
.80659 .17508 Mdot
.80664 .17517 Mdot
.80668 .17526 Mdot
.80673 .17535 Mdot
.80678 .17545 Mdot
.80683 .17554 Mdot
.80687 .17563 Mdot
.80692 .17572 Mdot
.80697 .17582 Mdot
.80702 .17591 Mdot
.80706 .176 Mdot
.80711 .17609 Mdot
.80716 .17619 Mdot
.80721 .17628 Mdot
.80725 .17637 Mdot
.8073 .17647 Mdot
.80735 .17656 Mdot
.8074 .17665 Mdot
.80745 .17675 Mdot
.80749 .17684 Mdot
.80754 .17693 Mdot
.80759 .17703 Mdot
.80764 .17712 Mdot
.80768 .17722 Mdot
.80773 .17731 Mdot
.80778 .1774 Mdot
.80783 .1775 Mdot
.80787 .17759 Mdot
.80792 .17769 Mdot
.80797 .17778 Mdot
.80802 .17788 Mdot
.80806 .17797 Mdot
.80811 .17807 Mdot
.80816 .17816 Mdot
.80821 .17826 Mdot
.80825 .17835 Mdot
.8083 .17845 Mdot
.80835 .17854 Mdot
.8084 .17864 Mdot
.80845 .17874 Mdot
.80849 .17883 Mdot
.80854 .17893 Mdot
.80859 .17902 Mdot
.80864 .17912 Mdot
.80868 .17922 Mdot
.80873 .17931 Mdot
.80878 .17941 Mdot
.80883 .1795 Mdot
.80887 .1796 Mdot
.80892 .1797 Mdot
.80897 .17979 Mdot
.80902 .17989 Mdot
.80906 .17999 Mdot
.80911 .18009 Mdot
.80916 .18018 Mdot
.80921 .18028 Mdot
.80925 .18038 Mdot
.8093 .18047 Mdot
.80935 .18057 Mdot
.8094 .18067 Mdot
.80945 .18077 Mdot
.80949 .18086 Mdot
.80954 .18096 Mdot
.80959 .18106 Mdot
.80964 .18116 Mdot
.80968 .18126 Mdot
.80973 .18136 Mdot
.80978 .18145 Mdot
.80983 .18155 Mdot
.80987 .18165 Mdot
.80992 .18175 Mdot
.80997 .18185 Mdot
.81002 .18195 Mdot
.81006 .18205 Mdot
.81011 .18215 Mdot
.81016 .18224 Mdot
.81021 .18234 Mdot
.81025 .18244 Mdot
.8103 .18254 Mdot
.81035 .18264 Mdot
.8104 .18274 Mdot
.81045 .18284 Mdot
.81049 .18294 Mdot
.81054 .18304 Mdot
.81059 .18314 Mdot
.81064 .18324 Mdot
.81068 .18334 Mdot
.81073 .18344 Mdot
.81078 .18354 Mdot
.81083 .18364 Mdot
.81087 .18374 Mdot
.81092 .18384 Mdot
.81097 .18394 Mdot
.81102 .18404 Mdot
.81106 .18415 Mdot
.81111 .18425 Mdot
.81116 .18435 Mdot
.81121 .18445 Mdot
.81125 .18455 Mdot
.8113 .18465 Mdot
.81135 .18475 Mdot
.8114 .18485 Mdot
.81145 .18496 Mdot
.81149 .18506 Mdot
.81154 .18516 Mdot
.81159 .18526 Mdot
.81164 .18536 Mdot
.81168 .18547 Mdot
.81173 .18557 Mdot
.81178 .18567 Mdot
.81183 .18577 Mdot
.81187 .18587 Mdot
.81192 .18598 Mdot
.81197 .18608 Mdot
.81202 .18618 Mdot
.81206 .18629 Mdot
.81211 .18639 Mdot
.81216 .18649 Mdot
.81221 .18659 Mdot
.81225 .1867 Mdot
.8123 .1868 Mdot
.81235 .1869 Mdot
.8124 .18701 Mdot
.81244 .18711 Mdot
.81249 .18721 Mdot
.81254 .18732 Mdot
.81259 .18742 Mdot
.81264 .18753 Mdot
.81268 .18763 Mdot
.81273 .18773 Mdot
.81278 .18784 Mdot
.81283 .18794 Mdot
.81287 .18805 Mdot
.81292 .18815 Mdot
.81297 .18826 Mdot
.81302 .18836 Mdot
.81306 .18847 Mdot
.81311 .18857 Mdot
.81316 .18867 Mdot
.81321 .18878 Mdot
.81325 .18888 Mdot
.8133 .18899 Mdot
.81335 .1891 Mdot
.8134 .1892 Mdot
.81344 .18931 Mdot
.81349 .18941 Mdot
.81354 .18952 Mdot
.81359 .18962 Mdot
.81364 .18973 Mdot
.81368 .18983 Mdot
.81373 .18994 Mdot
.81378 .19005 Mdot
.81383 .19015 Mdot
.81387 .19026 Mdot
.81392 .19036 Mdot
.81397 .19047 Mdot
.81402 .19058 Mdot
.81406 .19068 Mdot
.81411 .19079 Mdot
.81416 .1909 Mdot
.81421 .191 Mdot
.81425 .19111 Mdot
.8143 .19122 Mdot
.81435 .19132 Mdot
.8144 .19143 Mdot
.81444 .19154 Mdot
.81449 .19165 Mdot
.81454 .19175 Mdot
.81459 .19186 Mdot
.81464 .19197 Mdot
.81468 .19208 Mdot
.81473 .19218 Mdot
.81478 .19229 Mdot
.81483 .1924 Mdot
.81487 .19251 Mdot
.81492 .19261 Mdot
.81497 .19272 Mdot
.81502 .19283 Mdot
.81506 .19294 Mdot
.81511 .19305 Mdot
.81516 .19316 Mdot
.81521 .19326 Mdot
.81525 .19337 Mdot
.8153 .19348 Mdot
.81535 .19359 Mdot
.8154 .1937 Mdot
.81544 .19381 Mdot
.81549 .19392 Mdot
.81554 .19403 Mdot
.81559 .19413 Mdot
.81564 .19424 Mdot
.81568 .19435 Mdot
.81573 .19446 Mdot
.81578 .19457 Mdot
.81583 .19468 Mdot
.81587 .19479 Mdot
.81592 .1949 Mdot
.81597 .19501 Mdot
.81602 .19512 Mdot
.81606 .19523 Mdot
.81611 .19534 Mdot
.81616 .19545 Mdot
.81621 .19556 Mdot
.81625 .19567 Mdot
.8163 .19578 Mdot
.81635 .19589 Mdot
.8164 .196 Mdot
.81644 .19611 Mdot
.81649 .19622 Mdot
.81654 .19633 Mdot
.81659 .19645 Mdot
.81664 .19656 Mdot
.81668 .19667 Mdot
.81673 .19678 Mdot
.81678 .19689 Mdot
.81683 .197 Mdot
.81687 .19711 Mdot
.81692 .19722 Mdot
.81697 .19733 Mdot
.81702 .19745 Mdot
.81706 .19756 Mdot
.81711 .19767 Mdot
.81716 .19778 Mdot
.81721 .19789 Mdot
.81725 .19801 Mdot
.8173 .19812 Mdot
.81735 .19823 Mdot
.8174 .19834 Mdot
.81744 .19845 Mdot
.81749 .19857 Mdot
.81754 .19868 Mdot
.81759 .19879 Mdot
.81763 .1989 Mdot
.81768 .19902 Mdot
.81773 .19913 Mdot
.81778 .19924 Mdot
.81783 .19935 Mdot
.81787 .19947 Mdot
.81792 .19958 Mdot
.81797 .19969 Mdot
.81802 .19981 Mdot
.81806 .19992 Mdot
.81811 .20003 Mdot
.81816 .20015 Mdot
.81821 .20026 Mdot
.81825 .20037 Mdot
.8183 .20049 Mdot
.81835 .2006 Mdot
.8184 .20071 Mdot
.81844 .20083 Mdot
.81849 .20094 Mdot
.81854 .20106 Mdot
.81859 .20117 Mdot
.81863 .20128 Mdot
.81868 .2014 Mdot
.81873 .20151 Mdot
.81878 .20163 Mdot
.81883 .20174 Mdot
.81887 .20186 Mdot
.81892 .20197 Mdot
.81897 .20208 Mdot
.81902 .2022 Mdot
.81906 .20231 Mdot
.81911 .20243 Mdot
.81916 .20254 Mdot
.81921 .20266 Mdot
.81925 .20277 Mdot
.8193 .20289 Mdot
.81935 .203 Mdot
.8194 .20312 Mdot
.81944 .20323 Mdot
.81949 .20335 Mdot
.81954 .20347 Mdot
.81959 .20358 Mdot
.81963 .2037 Mdot
.81968 .20381 Mdot
.81973 .20393 Mdot
.81978 .20404 Mdot
.81983 .20416 Mdot
.81987 .20428 Mdot
.81992 .20439 Mdot
.81997 .20451 Mdot
.82002 .20462 Mdot
.82006 .20474 Mdot
.82011 .20486 Mdot
.82016 .20497 Mdot
.82021 .20509 Mdot
.82025 .20521 Mdot
.8203 .20532 Mdot
.82035 .20544 Mdot
.8204 .20556 Mdot
.82044 .20567 Mdot
.82049 .20579 Mdot
.82054 .20591 Mdot
.82059 .20602 Mdot
.82063 .20614 Mdot
.82068 .20626 Mdot
.82073 .20638 Mdot
.82078 .20649 Mdot
.82083 .20661 Mdot
.82087 .20673 Mdot
.82092 .20684 Mdot
.82097 .20696 Mdot
.82102 .20708 Mdot
.82106 .2072 Mdot
.82111 .20732 Mdot
.82116 .20743 Mdot
.82121 .20755 Mdot
.82125 .20767 Mdot
.8213 .20779 Mdot
.82135 .20791 Mdot
.8214 .20802 Mdot
.82144 .20814 Mdot
.82149 .20826 Mdot
.82154 .20838 Mdot
.82159 .2085 Mdot
.82163 .20862 Mdot
.82168 .20873 Mdot
.82173 .20885 Mdot
.82178 .20897 Mdot
.82182 .20909 Mdot
.82187 .20921 Mdot
.82192 .20933 Mdot
.82197 .20945 Mdot
.82202 .20957 Mdot
.82206 .20968 Mdot
.82211 .2098 Mdot
.82216 .20992 Mdot
.82221 .21004 Mdot
.82225 .21016 Mdot
.8223 .21028 Mdot
.82235 .2104 Mdot
.8224 .21052 Mdot
.82244 .21064 Mdot
.82249 .21076 Mdot
.82254 .21088 Mdot
.82259 .211 Mdot
.82263 .21112 Mdot
.82268 .21124 Mdot
.82273 .21136 Mdot
.82278 .21148 Mdot
.82282 .2116 Mdot
.82287 .21172 Mdot
.82292 .21184 Mdot
.82297 .21196 Mdot
.82302 .21208 Mdot
.82306 .2122 Mdot
.82311 .21232 Mdot
.82316 .21244 Mdot
.82321 .21256 Mdot
.82325 .21268 Mdot
.8233 .2128 Mdot
.82335 .21292 Mdot
.8234 .21305 Mdot
.82344 .21317 Mdot
.82349 .21329 Mdot
.82354 .21341 Mdot
.82359 .21353 Mdot
.82363 .21365 Mdot
.82368 .21377 Mdot
.82373 .21389 Mdot
.82378 .21401 Mdot
.82382 .21414 Mdot
.82387 .21426 Mdot
.82392 .21438 Mdot
.82397 .2145 Mdot
.82402 .21462 Mdot
.82406 .21474 Mdot
.82411 .21486 Mdot
.82416 .21499 Mdot
.82421 .21511 Mdot
.82425 .21523 Mdot
.8243 .21535 Mdot
.82435 .21547 Mdot
.8244 .2156 Mdot
.82444 .21572 Mdot
.82449 .21584 Mdot
.82454 .21596 Mdot
.82459 .21609 Mdot
.82463 .21621 Mdot
.82468 .21633 Mdot
.82473 .21645 Mdot
.82478 .21658 Mdot
.82482 .2167 Mdot
.82487 .21682 Mdot
.82492 .21694 Mdot
.82497 .21707 Mdot
.82502 .21719 Mdot
.82506 .21731 Mdot
.82511 .21744 Mdot
.82516 .21756 Mdot
.82521 .21768 Mdot
.82525 .2178 Mdot
.8253 .21793 Mdot
.82535 .21805 Mdot
.8254 .21817 Mdot
.82544 .2183 Mdot
.82549 .21842 Mdot
.82554 .21854 Mdot
.82559 .21867 Mdot
.82563 .21879 Mdot
.82568 .21892 Mdot
.82573 .21904 Mdot
.82578 .21916 Mdot
.82582 .21929 Mdot
.82587 .21941 Mdot
.82592 .21953 Mdot
.82597 .21966 Mdot
.82602 .21978 Mdot
.82606 .21991 Mdot
.82611 .22003 Mdot
.82616 .22015 Mdot
.82621 .22028 Mdot
.82625 .2204 Mdot
.8263 .22053 Mdot
.82635 .22065 Mdot
.8264 .22078 Mdot
.82644 .2209 Mdot
.82649 .22103 Mdot
.82654 .22115 Mdot
.82659 .22127 Mdot
.82663 .2214 Mdot
.82668 .22152 Mdot
.82673 .22165 Mdot
.82678 .22177 Mdot
.82682 .2219 Mdot
.82687 .22202 Mdot
.82692 .22215 Mdot
.82697 .22227 Mdot
.82701 .2224 Mdot
.82706 .22252 Mdot
.82711 .22265 Mdot
.82716 .22277 Mdot
.82721 .2229 Mdot
.82725 .22303 Mdot
.8273 .22315 Mdot
.82735 .22328 Mdot
.8274 .2234 Mdot
.82744 .22353 Mdot
.82749 .22365 Mdot
.82754 .22378 Mdot
.82759 .2239 Mdot
.82763 .22403 Mdot
.82768 .22416 Mdot
.82773 .22428 Mdot
.82778 .22441 Mdot
.82782 .22453 Mdot
.82787 .22466 Mdot
.82792 .22479 Mdot
.82797 .22491 Mdot
.82801 .22504 Mdot
.82806 .22516 Mdot
.82811 .22529 Mdot
.82816 .22542 Mdot
.82821 .22554 Mdot
.82825 .22567 Mdot
.8283 .2258 Mdot
.82835 .22592 Mdot
.8284 .22605 Mdot
.82844 .22618 Mdot
.82849 .2263 Mdot
.82854 .22643 Mdot
.82859 .22656 Mdot
.82863 .22668 Mdot
.82868 .22681 Mdot
.82873 .22694 Mdot
.82878 .22706 Mdot
.82882 .22719 Mdot
.82887 .22732 Mdot
.82892 .22744 Mdot
.82897 .22757 Mdot
.82901 .2277 Mdot
.82906 .22783 Mdot
.82911 .22795 Mdot
.82916 .22808 Mdot
.82921 .22821 Mdot
.82925 .22834 Mdot
.8293 .22846 Mdot
.82935 .22859 Mdot
.8294 .22872 Mdot
.82944 .22885 Mdot
.82949 .22897 Mdot
.82954 .2291 Mdot
.82959 .22923 Mdot
.82963 .22936 Mdot
.82968 .22948 Mdot
.82973 .22961 Mdot
.82978 .22974 Mdot
.82982 .22987 Mdot
.82987 .23 Mdot
.82992 .23012 Mdot
.82997 .23025 Mdot
.83001 .23038 Mdot
.83006 .23051 Mdot
.83011 .23064 Mdot
.83016 .23076 Mdot
.83021 .23089 Mdot
.83025 .23102 Mdot
.8303 .23115 Mdot
.83035 .23128 Mdot
.8304 .23141 Mdot
.83044 .23154 Mdot
.83049 .23166 Mdot
.83054 .23179 Mdot
.83059 .23192 Mdot
.83063 .23205 Mdot
.83068 .23218 Mdot
.83073 .23231 Mdot
.83078 .23244 Mdot
.83082 .23256 Mdot
.83087 .23269 Mdot
.83092 .23282 Mdot
.83097 .23295 Mdot
.83101 .23308 Mdot
.83106 .23321 Mdot
.83111 .23334 Mdot
.83116 .23347 Mdot
.8312 .2336 Mdot
.83125 .23373 Mdot
.8313 .23386 Mdot
.83135 .23398 Mdot
.8314 .23411 Mdot
.83144 .23424 Mdot
.83149 .23437 Mdot
.83154 .2345 Mdot
.83159 .23463 Mdot
.83163 .23476 Mdot
.83168 .23489 Mdot
.83173 .23502 Mdot
.83178 .23515 Mdot
.83182 .23528 Mdot
.83187 .23541 Mdot
.83192 .23554 Mdot
.83197 .23567 Mdot
.83201 .2358 Mdot
.83206 .23593 Mdot
.83211 .23606 Mdot
.83216 .23619 Mdot
.8322 .23632 Mdot
.83225 .23645 Mdot
.8323 .23658 Mdot
.83235 .23671 Mdot
.8324 .23684 Mdot
.83244 .23697 Mdot
.83249 .2371 Mdot
.83254 .23723 Mdot
.83259 .23736 Mdot
.83263 .23749 Mdot
.83268 .23762 Mdot
.83273 .23775 Mdot
.83278 .23788 Mdot
.83282 .23801 Mdot
.83287 .23814 Mdot
.83292 .23827 Mdot
.83297 .2384 Mdot
.83301 .23853 Mdot
.83306 .23866 Mdot
.83311 .23879 Mdot
.83316 .23892 Mdot
.8332 .23906 Mdot
.83325 .23919 Mdot
.8333 .23932 Mdot
.83335 .23945 Mdot
.8334 .23958 Mdot
.83344 .23971 Mdot
.83349 .23984 Mdot
.83354 .23997 Mdot
.83359 .2401 Mdot
.83363 .24023 Mdot
.83368 .24036 Mdot
.83373 .2405 Mdot
.83378 .24063 Mdot
.83382 .24076 Mdot
.83387 .24089 Mdot
.83392 .24102 Mdot
.83397 .24115 Mdot
.83401 .24128 Mdot
.83406 .24141 Mdot
.83411 .24154 Mdot
.83416 .24168 Mdot
.8342 .24181 Mdot
.83425 .24194 Mdot
.8343 .24207 Mdot
.83435 .2422 Mdot
.8344 .24233 Mdot
.83444 .24246 Mdot
.83449 .2426 Mdot
.83454 .24273 Mdot
.83459 .24286 Mdot
.83463 .24299 Mdot
.83468 .24312 Mdot
.83473 .24325 Mdot
.83478 .24339 Mdot
.83482 .24352 Mdot
.83487 .24365 Mdot
.83492 .24378 Mdot
.83497 .24391 Mdot
.83501 .24405 Mdot
.83506 .24418 Mdot
.83511 .24431 Mdot
.83516 .24444 Mdot
.8352 .24457 Mdot
.83525 .24471 Mdot
.8353 .24484 Mdot
.83535 .24497 Mdot
.8354 .2451 Mdot
.83544 .24523 Mdot
.83549 .24537 Mdot
.83554 .2455 Mdot
.83559 .24563 Mdot
.83563 .24576 Mdot
.83568 .2459 Mdot
.83573 .24603 Mdot
.83578 .24616 Mdot
.83582 .24629 Mdot
.83587 .24642 Mdot
.83592 .24656 Mdot
.83597 .24669 Mdot
.83601 .24682 Mdot
.83606 .24695 Mdot
.83611 .24709 Mdot
.83616 .24722 Mdot
.8362 .24735 Mdot
.83625 .24749 Mdot
.8363 .24762 Mdot
.83635 .24775 Mdot
.83639 .24788 Mdot
.83644 .24802 Mdot
.83649 .24815 Mdot
.83654 .24828 Mdot
.83659 .24841 Mdot
.83663 .24855 Mdot
.83668 .24868 Mdot
.83673 .24881 Mdot
.83678 .24895 Mdot
.83682 .24908 Mdot
.83687 .24921 Mdot
.83692 .24934 Mdot
.83697 .24948 Mdot
.83701 .24961 Mdot
.83706 .24974 Mdot
.83711 .24988 Mdot
.83716 .25001 Mdot
.8372 .25014 Mdot
.83725 .25028 Mdot
.8373 .25041 Mdot
.83735 .25054 Mdot
.83739 .25068 Mdot
.83744 .25081 Mdot
.83749 .25094 Mdot
.83754 .25108 Mdot
.83759 .25121 Mdot
.83763 .25134 Mdot
.83768 .25147 Mdot
.83773 .25161 Mdot
.83778 .25174 Mdot
.83782 .25188 Mdot
.83787 .25201 Mdot
.83792 .25214 Mdot
.83797 .25228 Mdot
.83801 .25241 Mdot
.83806 .25254 Mdot
.83811 .25268 Mdot
.83816 .25281 Mdot
.8382 .25294 Mdot
.83825 .25308 Mdot
.8383 .25321 Mdot
.83835 .25334 Mdot
.83839 .25348 Mdot
.83844 .25361 Mdot
.83849 .25374 Mdot
.83854 .25388 Mdot
.83859 .25401 Mdot
.83863 .25415 Mdot
.83868 .25428 Mdot
.83873 .25441 Mdot
.83878 .25455 Mdot
.83882 .25468 Mdot
.83887 .25481 Mdot
.83892 .25495 Mdot
.83897 .25508 Mdot
.83901 .25522 Mdot
.83906 .25535 Mdot
.83911 .25548 Mdot
.83916 .25562 Mdot
.8392 .25575 Mdot
.83925 .25589 Mdot
.8393 .25602 Mdot
.83935 .25615 Mdot
.83939 .25629 Mdot
.83944 .25642 Mdot
.83949 .25656 Mdot
.83954 .25669 Mdot
.83959 .25682 Mdot
.83963 .25696 Mdot
.83968 .25709 Mdot
.83973 .25723 Mdot
.83978 .25736 Mdot
.83982 .25749 Mdot
.83987 .25763 Mdot
.83992 .25776 Mdot
.83997 .2579 Mdot
.84001 .25803 Mdot
.84006 .25817 Mdot
.84011 .2583 Mdot
.84016 .25843 Mdot
.8402 .25857 Mdot
.84025 .2587 Mdot
.8403 .25884 Mdot
.84035 .25897 Mdot
.84039 .25911 Mdot
.84044 .25924 Mdot
.84049 .25937 Mdot
.84054 .25951 Mdot
.84058 .25964 Mdot
.84063 .25978 Mdot
.84068 .25991 Mdot
.84073 .26005 Mdot
.84078 .26018 Mdot
.84082 .26032 Mdot
.84087 .26045 Mdot
.84092 .26058 Mdot
.84097 .26072 Mdot
.84101 .26085 Mdot
.84106 .26099 Mdot
.84111 .26112 Mdot
.84116 .26126 Mdot
.8412 .26139 Mdot
.84125 .26153 Mdot
.8413 .26166 Mdot
.84135 .2618 Mdot
.84139 .26193 Mdot
.84144 .26206 Mdot
.84149 .2622 Mdot
.84154 .26233 Mdot
.84158 .26247 Mdot
.84163 .2626 Mdot
.84168 .26274 Mdot
.84173 .26287 Mdot
.84178 .26301 Mdot
.84182 .26314 Mdot
.84187 .26328 Mdot
.84192 .26341 Mdot
.84197 .26355 Mdot
.84201 .26368 Mdot
.84206 .26382 Mdot
.84211 .26395 Mdot
.84216 .26408 Mdot
.8422 .26422 Mdot
.84225 .26435 Mdot
.8423 .26449 Mdot
.84235 .26462 Mdot
.84239 .26476 Mdot
.84244 .26489 Mdot
.84249 .26503 Mdot
.84254 .26516 Mdot
.84258 .2653 Mdot
.84263 .26543 Mdot
.84268 .26557 Mdot
.84273 .2657 Mdot
.84278 .26584 Mdot
.84282 .26597 Mdot
.84287 .26611 Mdot
.84292 .26624 Mdot
.84297 .26638 Mdot
.84301 .26651 Mdot
.84306 .26665 Mdot
.84311 .26678 Mdot
.84316 .26692 Mdot
.8432 .26705 Mdot
.84325 .26719 Mdot
.8433 .26732 Mdot
.84335 .26746 Mdot
.84339 .26759 Mdot
.84344 .26773 Mdot
.84349 .26786 Mdot
.84354 .268 Mdot
.84358 .26813 Mdot
.84363 .26827 Mdot
.84368 .2684 Mdot
.84373 .26854 Mdot
.84378 .26867 Mdot
.84382 .26881 Mdot
.84387 .26894 Mdot
.84392 .26908 Mdot
.84397 .26921 Mdot
.84401 .26935 Mdot
.84406 .26948 Mdot
.84411 .26962 Mdot
.84416 .26975 Mdot
.8442 .26989 Mdot
.84425 .27002 Mdot
.8443 .27016 Mdot
.84435 .27029 Mdot
.84439 .27043 Mdot
.84444 .27056 Mdot
.84449 .2707 Mdot
.84454 .27083 Mdot
.84458 .27097 Mdot
.84463 .2711 Mdot
.84468 .27124 Mdot
.84473 .27137 Mdot
.84478 .27151 Mdot
.84482 .27164 Mdot
.84487 .27178 Mdot
.84492 .27191 Mdot
.84497 .27205 Mdot
.84501 .27218 Mdot
.84506 .27232 Mdot
.84511 .27245 Mdot
.84516 .27259 Mdot
.8452 .27272 Mdot
.84525 .27286 Mdot
.8453 .27299 Mdot
.84535 .27313 Mdot
.84539 .27326 Mdot
.84544 .2734 Mdot
.84549 .27353 Mdot
.84554 .27367 Mdot
.84558 .2738 Mdot
.84563 .27394 Mdot
.84568 .27407 Mdot
.84573 .27421 Mdot
.84577 .27434 Mdot
.84582 .27448 Mdot
.84587 .27461 Mdot
.84592 .27475 Mdot
.84597 .27488 Mdot
.84601 .27502 Mdot
.84606 .27515 Mdot
.84611 .27529 Mdot
.84616 .27542 Mdot
.8462 .27556 Mdot
.84625 .27569 Mdot
.8463 .27583 Mdot
.84635 .27596 Mdot
.84639 .2761 Mdot
.84644 .27623 Mdot
.84649 .27637 Mdot
.84654 .2765 Mdot
.84658 .27664 Mdot
.84663 .27677 Mdot
.84668 .27691 Mdot
.84673 .27704 Mdot
.84677 .27718 Mdot
.84682 .27731 Mdot
.84687 .27745 Mdot
.84692 .27758 Mdot
.84697 .27772 Mdot
.84701 .27785 Mdot
.84706 .27799 Mdot
.84711 .27812 Mdot
.84716 .27826 Mdot
.8472 .27839 Mdot
.84725 .27853 Mdot
.8473 .27866 Mdot
.84735 .2788 Mdot
.84739 .27893 Mdot
.84744 .27907 Mdot
.84749 .2792 Mdot
.84754 .27934 Mdot
.84758 .27947 Mdot
.84763 .2796 Mdot
.84768 .27974 Mdot
.84773 .27987 Mdot
.84777 .28001 Mdot
.84782 .28014 Mdot
.84787 .28028 Mdot
.84792 .28041 Mdot
.84797 .28055 Mdot
.84801 .28068 Mdot
.84806 .28082 Mdot
.84811 .28095 Mdot
.84816 .28109 Mdot
.8482 .28122 Mdot
.84825 .28136 Mdot
.8483 .28149 Mdot
.84835 .28163 Mdot
.84839 .28176 Mdot
.84844 .2819 Mdot
.84849 .28203 Mdot
.84854 .28217 Mdot
.84858 .2823 Mdot
.84863 .28244 Mdot
.84868 .28257 Mdot
.84873 .2827 Mdot
.84877 .28284 Mdot
.84882 .28297 Mdot
.84887 .28311 Mdot
.84892 .28324 Mdot
.84897 .28338 Mdot
.84901 .28351 Mdot
.84906 .28365 Mdot
.84911 .28378 Mdot
.84916 .28392 Mdot
.8492 .28405 Mdot
.84925 .28419 Mdot
.8493 .28432 Mdot
.84935 .28445 Mdot
.84939 .28459 Mdot
.84944 .28472 Mdot
.84949 .28486 Mdot
.84954 .28499 Mdot
.84958 .28513 Mdot
.84963 .28526 Mdot
.84968 .2854 Mdot
.84973 .28553 Mdot
.84977 .28566 Mdot
.84982 .2858 Mdot
.84987 .28593 Mdot
.84992 .28607 Mdot
.84997 .2862 Mdot
.85001 .28634 Mdot
.85006 .28647 Mdot
.85011 .28661 Mdot
.85016 .28674 Mdot
.8502 .28687 Mdot
.85025 .28701 Mdot
.8503 .28714 Mdot
.85035 .28728 Mdot
.85039 .28741 Mdot
.85044 .28755 Mdot
.85049 .28768 Mdot
.85054 .28781 Mdot
.85058 .28795 Mdot
.85063 .28808 Mdot
.85068 .28822 Mdot
.85073 .28835 Mdot
.85077 .28848 Mdot
.85082 .28862 Mdot
.85087 .28875 Mdot
.85092 .28889 Mdot
.85096 .28902 Mdot
.85101 .28915 Mdot
.85106 .28929 Mdot
.85111 .28942 Mdot
.85116 .28956 Mdot
.8512 .28969 Mdot
.85125 .28982 Mdot
.8513 .28996 Mdot
.85135 .29009 Mdot
.85139 .29023 Mdot
.85144 .29036 Mdot
.85149 .29049 Mdot
.85154 .29063 Mdot
.85158 .29076 Mdot
.85163 .2909 Mdot
.85168 .29103 Mdot
.85173 .29116 Mdot
.85177 .2913 Mdot
.85182 .29143 Mdot
.85187 .29156 Mdot
.85192 .2917 Mdot
.85196 .29183 Mdot
.85201 .29197 Mdot
.85206 .2921 Mdot
.85211 .29223 Mdot
.85216 .29237 Mdot
.8522 .2925 Mdot
.85225 .29263 Mdot
.8523 .29277 Mdot
.85235 .2929 Mdot
.85239 .29303 Mdot
.85244 .29317 Mdot
.85249 .2933 Mdot
.85254 .29344 Mdot
.85258 .29357 Mdot
.85263 .2937 Mdot
.85268 .29384 Mdot
.85273 .29397 Mdot
.85277 .2941 Mdot
.85282 .29424 Mdot
.85287 .29437 Mdot
.85292 .2945 Mdot
.85296 .29464 Mdot
.85301 .29477 Mdot
.85306 .2949 Mdot
.85311 .29504 Mdot
.85316 .29517 Mdot
.8532 .2953 Mdot
.85325 .29543 Mdot
.8533 .29557 Mdot
.85335 .2957 Mdot
.85339 .29583 Mdot
.85344 .29597 Mdot
.85349 .2961 Mdot
.85354 .29623 Mdot
.85358 .29637 Mdot
.85363 .2965 Mdot
.85368 .29663 Mdot
.85373 .29676 Mdot
.85377 .2969 Mdot
.85382 .29703 Mdot
.85387 .29716 Mdot
.85392 .2973 Mdot
.85396 .29743 Mdot
.85401 .29756 Mdot
.85406 .29769 Mdot
.85411 .29783 Mdot
.85416 .29796 Mdot
.8542 .29809 Mdot
.85425 .29823 Mdot
.8543 .29836 Mdot
.85435 .29849 Mdot
.85439 .29862 Mdot
.85444 .29876 Mdot
.85449 .29889 Mdot
.85454 .29902 Mdot
.85458 .29915 Mdot
.85463 .29929 Mdot
.85468 .29942 Mdot
.85473 .29955 Mdot
.85477 .29968 Mdot
.85482 .29982 Mdot
.85487 .29995 Mdot
.85492 .30008 Mdot
.85496 .30021 Mdot
.85501 .30034 Mdot
.85506 .30048 Mdot
.85511 .30061 Mdot
.85515 .30074 Mdot
.8552 .30087 Mdot
.85525 .301 Mdot
.8553 .30114 Mdot
.85535 .30127 Mdot
.85539 .3014 Mdot
.85544 .30153 Mdot
.85549 .30166 Mdot
.85554 .3018 Mdot
.85558 .30193 Mdot
.85563 .30206 Mdot
.85568 .30219 Mdot
.85573 .30232 Mdot
.85577 .30246 Mdot
.85582 .30259 Mdot
.85587 .30272 Mdot
.85592 .30285 Mdot
.85596 .30298 Mdot
.85601 .30311 Mdot
.85606 .30325 Mdot
.85611 .30338 Mdot
.85615 .30351 Mdot
.8562 .30364 Mdot
.85625 .30377 Mdot
.8563 .3039 Mdot
.85635 .30403 Mdot
.85639 .30417 Mdot
.85644 .3043 Mdot
.85649 .30443 Mdot
.85654 .30456 Mdot
.85658 .30469 Mdot
.85663 .30482 Mdot
.85668 .30495 Mdot
.85673 .30509 Mdot
.85677 .30522 Mdot
.85682 .30535 Mdot
.85687 .30548 Mdot
.85692 .30561 Mdot
.85696 .30574 Mdot
.85701 .30587 Mdot
.85706 .306 Mdot
.85711 .30613 Mdot
.85715 .30626 Mdot
.8572 .30639 Mdot
.85725 .30653 Mdot
.8573 .30666 Mdot
.85735 .30679 Mdot
.85739 .30692 Mdot
.85744 .30705 Mdot
.85749 .30718 Mdot
.85754 .30731 Mdot
.85758 .30744 Mdot
.85763 .30757 Mdot
.85768 .3077 Mdot
.85773 .30783 Mdot
.85777 .30796 Mdot
.85782 .30809 Mdot
.85787 .30822 Mdot
.85792 .30835 Mdot
.85796 .30848 Mdot
.85801 .30861 Mdot
.85806 .30874 Mdot
.85811 .30887 Mdot
.85815 .309 Mdot
.8582 .30913 Mdot
.85825 .30926 Mdot
.8583 .30939 Mdot
.85835 .30952 Mdot
.85839 .30965 Mdot
.85844 .30978 Mdot
.85849 .30991 Mdot
.85854 .31004 Mdot
.85858 .31017 Mdot
.85863 .3103 Mdot
.85868 .31043 Mdot
.85873 .31056 Mdot
.85877 .31069 Mdot
.85882 .31082 Mdot
.85887 .31095 Mdot
.85892 .31108 Mdot
.85896 .31121 Mdot
.85901 .31134 Mdot
.85906 .31147 Mdot
.85911 .3116 Mdot
.85915 .31173 Mdot
.8592 .31186 Mdot
.85925 .31199 Mdot
.8593 .31212 Mdot
.85935 .31225 Mdot
.85939 .31238 Mdot
.85944 .3125 Mdot
.85949 .31263 Mdot
.85954 .31276 Mdot
.85958 .31289 Mdot
.85963 .31302 Mdot
.85968 .31315 Mdot
.85973 .31328 Mdot
.85977 .31341 Mdot
.85982 .31354 Mdot
.85987 .31367 Mdot
.85992 .31379 Mdot
.85996 .31392 Mdot
.86001 .31405 Mdot
.86006 .31418 Mdot
.86011 .31431 Mdot
.86015 .31444 Mdot
.8602 .31457 Mdot
.86025 .31469 Mdot
.8603 .31482 Mdot
.86034 .31495 Mdot
.86039 .31508 Mdot
.86044 .31521 Mdot
.86049 .31534 Mdot
.86054 .31546 Mdot
.86058 .31559 Mdot
.86063 .31572 Mdot
.86068 .31585 Mdot
.86073 .31598 Mdot
.86077 .3161 Mdot
.86082 .31623 Mdot
.86087 .31636 Mdot
.86092 .31649 Mdot
.86096 .31662 Mdot
.86101 .31674 Mdot
.86106 .31687 Mdot
.86111 .317 Mdot
.86115 .31713 Mdot
.8612 .31725 Mdot
.86125 .31738 Mdot
.8613 .31751 Mdot
.86134 .31764 Mdot
.86139 .31776 Mdot
.86144 .31789 Mdot
.86149 .31802 Mdot
.86154 .31815 Mdot
.86158 .31827 Mdot
.86163 .3184 Mdot
.86168 .31853 Mdot
.86173 .31866 Mdot
.86177 .31878 Mdot
.86182 .31891 Mdot
.86187 .31904 Mdot
.86192 .31916 Mdot
.86196 .31929 Mdot
.86201 .31942 Mdot
.86206 .31954 Mdot
.86211 .31967 Mdot
.86215 .3198 Mdot
.8622 .31992 Mdot
.86225 .32005 Mdot
.8623 .32018 Mdot
.86234 .3203 Mdot
.86239 .32043 Mdot
.86244 .32056 Mdot
.86249 .32068 Mdot
.86254 .32081 Mdot
.86258 .32094 Mdot
.86263 .32106 Mdot
.86268 .32119 Mdot
.86273 .32131 Mdot
.86277 .32144 Mdot
.86282 .32157 Mdot
.86287 .32169 Mdot
.86292 .32182 Mdot
.86296 .32194 Mdot
.86301 .32207 Mdot
.86306 .3222 Mdot
.86311 .32232 Mdot
.86315 .32245 Mdot
.8632 .32257 Mdot
.86325 .3227 Mdot
.8633 .32282 Mdot
.86334 .32295 Mdot
.86339 .32308 Mdot
.86344 .3232 Mdot
.86349 .32333 Mdot
.86354 .32345 Mdot
.86358 .32358 Mdot
.86363 .3237 Mdot
.86368 .32383 Mdot
.86373 .32395 Mdot
.86377 .32408 Mdot
.86382 .3242 Mdot
.86387 .32433 Mdot
.86392 .32445 Mdot
.86396 .32458 Mdot
.86401 .3247 Mdot
.86406 .32483 Mdot
.86411 .32495 Mdot
.86415 .32508 Mdot
.8642 .3252 Mdot
.86425 .32532 Mdot
.8643 .32545 Mdot
.86434 .32557 Mdot
.86439 .3257 Mdot
.86444 .32582 Mdot
.86449 .32595 Mdot
.86453 .32607 Mdot
.86458 .3262 Mdot
.86463 .32632 Mdot
.86468 .32644 Mdot
.86473 .32657 Mdot
.86477 .32669 Mdot
.86482 .32682 Mdot
.86487 .32694 Mdot
.86492 .32706 Mdot
.86496 .32719 Mdot
.86501 .32731 Mdot
.86506 .32743 Mdot
.86511 .32756 Mdot
.86515 .32768 Mdot
.8652 .32781 Mdot
.86525 .32793 Mdot
.8653 .32805 Mdot
.86534 .32818 Mdot
.86539 .3283 Mdot
.86544 .32842 Mdot
.86549 .32855 Mdot
.86553 .32867 Mdot
.86558 .32879 Mdot
.86563 .32891 Mdot
.86568 .32904 Mdot
.86573 .32916 Mdot
.86577 .32928 Mdot
.86582 .32941 Mdot
.86587 .32953 Mdot
.86592 .32965 Mdot
.86596 .32977 Mdot
.86601 .3299 Mdot
.86606 .33002 Mdot
.86611 .33014 Mdot
.86615 .33026 Mdot
.8662 .33039 Mdot
.86625 .33051 Mdot
.8663 .33063 Mdot
.86634 .33075 Mdot
.86639 .33088 Mdot
.86644 .331 Mdot
.86649 .33112 Mdot
.86653 .33124 Mdot
.86658 .33136 Mdot
.86663 .33149 Mdot
.86668 .33161 Mdot
.86673 .33173 Mdot
.86677 .33185 Mdot
.86682 .33197 Mdot
.86687 .33209 Mdot
.86692 .33221 Mdot
.86696 .33234 Mdot
.86701 .33246 Mdot
.86706 .33258 Mdot
.86711 .3327 Mdot
.86715 .33282 Mdot
.8672 .33294 Mdot
.86725 .33306 Mdot
.8673 .33318 Mdot
.86734 .33331 Mdot
.86739 .33343 Mdot
.86744 .33355 Mdot
.86749 .33367 Mdot
.86753 .33379 Mdot
.86758 .33391 Mdot
.86763 .33403 Mdot
.86768 .33415 Mdot
.86773 .33427 Mdot
.86777 .33439 Mdot
.86782 .33451 Mdot
.86787 .33463 Mdot
.86792 .33475 Mdot
.86796 .33487 Mdot
.86801 .33499 Mdot
.86806 .33511 Mdot
.86811 .33523 Mdot
.86815 .33535 Mdot
.8682 .33547 Mdot
.86825 .33559 Mdot
.8683 .33571 Mdot
.86834 .33583 Mdot
.86839 .33595 Mdot
.86844 .33607 Mdot
.86849 .33619 Mdot
.86853 .33631 Mdot
.86858 .33643 Mdot
.86863 .33655 Mdot
.86868 .33667 Mdot
.86873 .33679 Mdot
.86877 .33691 Mdot
.86882 .33703 Mdot
.86887 .33714 Mdot
.86892 .33726 Mdot
.86896 .33738 Mdot
.86901 .3375 Mdot
.86906 .33762 Mdot
.86911 .33774 Mdot
.86915 .33786 Mdot
.8692 .33798 Mdot
.86925 .33809 Mdot
.8693 .33821 Mdot
.86934 .33833 Mdot
.86939 .33845 Mdot
.86944 .33857 Mdot
.86949 .33869 Mdot
.86953 .3388 Mdot
.86958 .33892 Mdot
.86963 .33904 Mdot
.86968 .33916 Mdot
.86972 .33928 Mdot
.86977 .33939 Mdot
.86982 .33951 Mdot
.86987 .33963 Mdot
.86992 .33975 Mdot
.86996 .33986 Mdot
.87001 .33998 Mdot
.87006 .3401 Mdot
.87011 .34022 Mdot
.87015 .34033 Mdot
.8702 .34045 Mdot
.87025 .34057 Mdot
.8703 .34069 Mdot
.87034 .3408 Mdot
.87039 .34092 Mdot
.87044 .34104 Mdot
.87049 .34115 Mdot
.87053 .34127 Mdot
.87058 .34139 Mdot
.87063 .3415 Mdot
.87068 .34162 Mdot
.87072 .34174 Mdot
.87077 .34185 Mdot
.87082 .34197 Mdot
.87087 .34209 Mdot
.87092 .3422 Mdot
.87096 .34232 Mdot
.87101 .34243 Mdot
.87106 .34255 Mdot
.87111 .34267 Mdot
.87115 .34278 Mdot
.8712 .3429 Mdot
.87125 .34301 Mdot
.8713 .34313 Mdot
.87134 .34324 Mdot
.87139 .34336 Mdot
.87144 .34348 Mdot
.87149 .34359 Mdot
.87153 .34371 Mdot
.87158 .34382 Mdot
.87163 .34394 Mdot
.87168 .34405 Mdot
.87172 .34417 Mdot
.87177 .34428 Mdot
.87182 .3444 Mdot
.87187 .34451 Mdot
.87192 .34463 Mdot
.87196 .34474 Mdot
.87201 .34486 Mdot
.87206 .34497 Mdot
.87211 .34509 Mdot
.87215 .3452 Mdot
.8722 .34531 Mdot
.87225 .34543 Mdot
.8723 .34554 Mdot
.87234 .34566 Mdot
.87239 .34577 Mdot
.87244 .34588 Mdot
.87249 .346 Mdot
.87253 .34611 Mdot
.87258 .34623 Mdot
.87263 .34634 Mdot
.87268 .34645 Mdot
.87272 .34657 Mdot
.87277 .34668 Mdot
.87282 .34679 Mdot
.87287 .34691 Mdot
.87292 .34702 Mdot
.87296 .34713 Mdot
.87301 .34725 Mdot
.87306 .34736 Mdot
.87311 .34747 Mdot
.87315 .34759 Mdot
.8732 .3477 Mdot
.87325 .34781 Mdot
.8733 .34792 Mdot
.87334 .34804 Mdot
.87339 .34815 Mdot
.87344 .34826 Mdot
.87349 .34837 Mdot
.87353 .34849 Mdot
.87358 .3486 Mdot
.87363 .34871 Mdot
.87368 .34882 Mdot
.87372 .34894 Mdot
.87377 .34905 Mdot
.87382 .34916 Mdot
.87387 .34927 Mdot
.87391 .34938 Mdot
.87396 .34949 Mdot
.87401 .34961 Mdot
.87406 .34972 Mdot
.87411 .34983 Mdot
.87415 .34994 Mdot
.8742 .35005 Mdot
.87425 .35016 Mdot
.8743 .35027 Mdot
.87434 .35039 Mdot
.87439 .3505 Mdot
.87444 .35061 Mdot
.87449 .35072 Mdot
.87453 .35083 Mdot
.87458 .35094 Mdot
.87463 .35105 Mdot
.87468 .35116 Mdot
.87472 .35127 Mdot
.87477 .35138 Mdot
.87482 .35149 Mdot
.87487 .3516 Mdot
.87491 .35171 Mdot
.87496 .35182 Mdot
.87501 .35193 Mdot
.87506 .35204 Mdot
.87511 .35215 Mdot
.87515 .35226 Mdot
.8752 .35237 Mdot
.87525 .35248 Mdot
.8753 .35259 Mdot
.87534 .3527 Mdot
.87539 .35281 Mdot
.87544 .35292 Mdot
.87549 .35303 Mdot
.87553 .35314 Mdot
.87558 .35325 Mdot
.87563 .35336 Mdot
.87568 .35347 Mdot
.87572 .35357 Mdot
.87577 .35368 Mdot
.87582 .35379 Mdot
.87587 .3539 Mdot
.87591 .35401 Mdot
.87596 .35412 Mdot
.87601 .35423 Mdot
.87606 .35433 Mdot
.87611 .35444 Mdot
.87615 .35455 Mdot
.8762 .35466 Mdot
.87625 .35477 Mdot
.8763 .35487 Mdot
.87634 .35498 Mdot
.87639 .35509 Mdot
.87644 .3552 Mdot
.87649 .35531 Mdot
.87653 .35541 Mdot
.87658 .35552 Mdot
.87663 .35563 Mdot
.87668 .35573 Mdot
.87672 .35584 Mdot
.87677 .35595 Mdot
.87682 .35606 Mdot
.87687 .35616 Mdot
.87691 .35627 Mdot
.87696 .35638 Mdot
.87701 .35648 Mdot
.87706 .35659 Mdot
.87711 .3567 Mdot
.87715 .3568 Mdot
.8772 .35691 Mdot
.87725 .35702 Mdot
.8773 .35712 Mdot
.87734 .35723 Mdot
.87739 .35733 Mdot
.87744 .35744 Mdot
.87749 .35755 Mdot
.87753 .35765 Mdot
.87758 .35776 Mdot
.87763 .35786 Mdot
.87768 .35797 Mdot
.87772 .35807 Mdot
.87777 .35818 Mdot
.87782 .35828 Mdot
.87787 .35839 Mdot
.87791 .3585 Mdot
.87796 .3586 Mdot
.87801 .35871 Mdot
.87806 .35881 Mdot
.87811 .35892 Mdot
.87815 .35902 Mdot
.8782 .35912 Mdot
.87825 .35923 Mdot
.8783 .35933 Mdot
.87834 .35944 Mdot
.87839 .35954 Mdot
.87844 .35965 Mdot
.87849 .35975 Mdot
.87853 .35985 Mdot
.87858 .35996 Mdot
.87863 .36006 Mdot
.87868 .36017 Mdot
.87872 .36027 Mdot
.87877 .36037 Mdot
.87882 .36048 Mdot
.87887 .36058 Mdot
.87891 .36068 Mdot
.87896 .36079 Mdot
.87901 .36089 Mdot
.87906 .36099 Mdot
.8791 .3611 Mdot
.87915 .3612 Mdot
.8792 .3613 Mdot
.87925 .36141 Mdot
.8793 .36151 Mdot
.87934 .36161 Mdot
.87939 .36171 Mdot
.87944 .36182 Mdot
.87949 .36192 Mdot
.87953 .36202 Mdot
.87958 .36212 Mdot
.87963 .36223 Mdot
.87968 .36233 Mdot
.87972 .36243 Mdot
.87977 .36253 Mdot
.87982 .36263 Mdot
.87987 .36273 Mdot
.87991 .36284 Mdot
.87996 .36294 Mdot
.88001 .36304 Mdot
.88006 .36314 Mdot
.8801 .36324 Mdot
.88015 .36334 Mdot
.8802 .36344 Mdot
.88025 .36354 Mdot
.8803 .36365 Mdot
.88034 .36375 Mdot
.88039 .36385 Mdot
.88044 .36395 Mdot
.88049 .36405 Mdot
.88053 .36415 Mdot
.88058 .36425 Mdot
.88063 .36435 Mdot
.88068 .36445 Mdot
.88072 .36455 Mdot
.88077 .36465 Mdot
.88082 .36475 Mdot
.88087 .36485 Mdot
.88091 .36495 Mdot
.88096 .36505 Mdot
.88101 .36515 Mdot
.88106 .36525 Mdot
.8811 .36535 Mdot
.88115 .36545 Mdot
.8812 .36555 Mdot
.88125 .36565 Mdot
.8813 .36574 Mdot
.88134 .36584 Mdot
.88139 .36594 Mdot
.88144 .36604 Mdot
.88149 .36614 Mdot
.88153 .36624 Mdot
.88158 .36634 Mdot
.88163 .36644 Mdot
.88168 .36653 Mdot
.88172 .36663 Mdot
.88177 .36673 Mdot
.88182 .36683 Mdot
.88187 .36693 Mdot
.88191 .36702 Mdot
.88196 .36712 Mdot
.88201 .36722 Mdot
.88206 .36732 Mdot
.8821 .36741 Mdot
.88215 .36751 Mdot
.8822 .36761 Mdot
.88225 .36771 Mdot
.8823 .3678 Mdot
.88234 .3679 Mdot
.88239 .368 Mdot
.88244 .36809 Mdot
.88249 .36819 Mdot
.88253 .36829 Mdot
.88258 .36838 Mdot
.88263 .36848 Mdot
.88268 .36858 Mdot
.88272 .36867 Mdot
.88277 .36877 Mdot
.88282 .36887 Mdot
.88287 .36896 Mdot
.88291 .36906 Mdot
.88296 .36915 Mdot
.88301 .36925 Mdot
.88306 .36935 Mdot
.8831 .36944 Mdot
.88315 .36954 Mdot
.8832 .36963 Mdot
.88325 .36973 Mdot
.8833 .36982 Mdot
.88334 .36992 Mdot
.88339 .37001 Mdot
.88344 .37011 Mdot
.88349 .3702 Mdot
.88353 .3703 Mdot
.88358 .37039 Mdot
.88363 .37049 Mdot
.88368 .37058 Mdot
.88372 .37068 Mdot
.88377 .37077 Mdot
.88382 .37086 Mdot
.88387 .37096 Mdot
.88391 .37105 Mdot
.88396 .37115 Mdot
.88401 .37124 Mdot
.88406 .37133 Mdot
.8841 .37143 Mdot
.88415 .37152 Mdot
.8842 .37161 Mdot
.88425 .37171 Mdot
.88429 .3718 Mdot
.88434 .37189 Mdot
.88439 .37199 Mdot
.88444 .37208 Mdot
.88449 .37217 Mdot
.88453 .37227 Mdot
.88458 .37236 Mdot
.88463 .37245 Mdot
.88468 .37254 Mdot
.88472 .37264 Mdot
.88477 .37273 Mdot
.88482 .37282 Mdot
.88487 .37291 Mdot
.88491 .373 Mdot
.88496 .3731 Mdot
.88501 .37319 Mdot
.88506 .37328 Mdot
.8851 .37337 Mdot
.88515 .37346 Mdot
.8852 .37355 Mdot
.88525 .37365 Mdot
.88529 .37374 Mdot
.88534 .37383 Mdot
.88539 .37392 Mdot
.88544 .37401 Mdot
.88549 .3741 Mdot
.88553 .37419 Mdot
.88558 .37428 Mdot
.88563 .37437 Mdot
.88568 .37446 Mdot
.88572 .37455 Mdot
.88577 .37464 Mdot
.88582 .37473 Mdot
.88587 .37482 Mdot
.88591 .37491 Mdot
.88596 .375 Mdot
.88601 .37509 Mdot
.88606 .37518 Mdot
.8861 .37527 Mdot
.88615 .37536 Mdot
.8862 .37545 Mdot
.88625 .37554 Mdot
.88629 .37563 Mdot
.88634 .37572 Mdot
.88639 .37581 Mdot
.88644 .3759 Mdot
.88649 .37599 Mdot
.88653 .37607 Mdot
.88658 .37616 Mdot
.88663 .37625 Mdot
.88668 .37634 Mdot
.88672 .37643 Mdot
.88677 .37652 Mdot
.88682 .3766 Mdot
.88687 .37669 Mdot
.88691 .37678 Mdot
.88696 .37687 Mdot
.88701 .37696 Mdot
.88706 .37704 Mdot
.8871 .37713 Mdot
.88715 .37722 Mdot
.8872 .37731 Mdot
.88725 .37739 Mdot
.88729 .37748 Mdot
.88734 .37757 Mdot
.88739 .37765 Mdot
.88744 .37774 Mdot
.88749 .37783 Mdot
.88753 .37791 Mdot
.88758 .378 Mdot
.88763 .37809 Mdot
.88768 .37817 Mdot
.88772 .37826 Mdot
.88777 .37835 Mdot
.88782 .37843 Mdot
.88787 .37852 Mdot
.88791 .3786 Mdot
.88796 .37869 Mdot
.88801 .37877 Mdot
.88806 .37886 Mdot
.8881 .37895 Mdot
.88815 .37903 Mdot
.8882 .37912 Mdot
.88825 .3792 Mdot
.88829 .37929 Mdot
.88834 .37937 Mdot
.88839 .37946 Mdot
.88844 .37954 Mdot
.88848 .37963 Mdot
.88853 .37971 Mdot
.88858 .37979 Mdot
.88863 .37988 Mdot
.88868 .37996 Mdot
.88872 .38005 Mdot
.88877 .38013 Mdot
.88882 .38021 Mdot
.88887 .3803 Mdot
.88891 .38038 Mdot
.88896 .38047 Mdot
.88901 .38055 Mdot
.88906 .38063 Mdot
.8891 .38072 Mdot
.88915 .3808 Mdot
.8892 .38088 Mdot
.88925 .38096 Mdot
.88929 .38105 Mdot
.88934 .38113 Mdot
.88939 .38121 Mdot
.88944 .3813 Mdot
.88948 .38138 Mdot
.88953 .38146 Mdot
.88958 .38154 Mdot
.88963 .38162 Mdot
.88968 .38171 Mdot
.88972 .38179 Mdot
.88977 .38187 Mdot
.88982 .38195 Mdot
.88987 .38203 Mdot
.88991 .38211 Mdot
.88996 .3822 Mdot
.89001 .38228 Mdot
.89006 .38236 Mdot
.8901 .38244 Mdot
.89015 .38252 Mdot
.8902 .3826 Mdot
.89025 .38268 Mdot
.89029 .38276 Mdot
.89034 .38284 Mdot
.89039 .38292 Mdot
.89044 .383 Mdot
.89048 .38308 Mdot
.89053 .38316 Mdot
.89058 .38324 Mdot
.89063 .38332 Mdot
.89068 .3834 Mdot
.89072 .38348 Mdot
.89077 .38356 Mdot
.89082 .38364 Mdot
.89087 .38372 Mdot
.89091 .3838 Mdot
.89096 .38388 Mdot
.89101 .38396 Mdot
.89106 .38404 Mdot
.8911 .38412 Mdot
.89115 .3842 Mdot
.8912 .38428 Mdot
.89125 .38435 Mdot
.89129 .38443 Mdot
.89134 .38451 Mdot
.89139 .38459 Mdot
.89144 .38467 Mdot
.89148 .38475 Mdot
.89153 .38482 Mdot
.89158 .3849 Mdot
.89163 .38498 Mdot
.89168 .38506 Mdot
.89172 .38513 Mdot
.89177 .38521 Mdot
.89182 .38529 Mdot
.89187 .38537 Mdot
.89191 .38544 Mdot
.89196 .38552 Mdot
.89201 .3856 Mdot
.89206 .38567 Mdot
.8921 .38575 Mdot
.89215 .38583 Mdot
.8922 .3859 Mdot
.89225 .38598 Mdot
.89229 .38606 Mdot
.89234 .38613 Mdot
.89239 .38621 Mdot
.89244 .38628 Mdot
.89248 .38636 Mdot
.89253 .38644 Mdot
.89258 .38651 Mdot
.89263 .38659 Mdot
.89268 .38666 Mdot
.89272 .38674 Mdot
.89277 .38681 Mdot
.89282 .38689 Mdot
.89287 .38696 Mdot
.89291 .38704 Mdot
.89296 .38711 Mdot
.89301 .38719 Mdot
.89306 .38726 Mdot
.8931 .38733 Mdot
.89315 .38741 Mdot
.8932 .38748 Mdot
.89325 .38756 Mdot
.89329 .38763 Mdot
.89334 .38771 Mdot
.89339 .38778 Mdot
.89344 .38785 Mdot
.89348 .38793 Mdot
.89353 .388 Mdot
.89358 .38807 Mdot
.89363 .38815 Mdot
.89367 .38822 Mdot
.89372 .38829 Mdot
.89377 .38836 Mdot
.89382 .38844 Mdot
.89387 .38851 Mdot
.89391 .38858 Mdot
.89396 .38865 Mdot
.89401 .38873 Mdot
.89406 .3888 Mdot
.8941 .38887 Mdot
.89415 .38894 Mdot
.8942 .38902 Mdot
.89425 .38909 Mdot
.89429 .38916 Mdot
.89434 .38923 Mdot
.89439 .3893 Mdot
.89444 .38937 Mdot
.89448 .38944 Mdot
.89453 .38952 Mdot
.89458 .38959 Mdot
.89463 .38966 Mdot
.89467 .38973 Mdot
.89472 .3898 Mdot
.89477 .38987 Mdot
.89482 .38994 Mdot
.89487 .39001 Mdot
.89491 .39008 Mdot
.89496 .39015 Mdot
.89501 .39022 Mdot
.89506 .39029 Mdot
.8951 .39036 Mdot
.89515 .39043 Mdot
.8952 .3905 Mdot
.89525 .39057 Mdot
.89529 .39064 Mdot
.89534 .39071 Mdot
.89539 .39078 Mdot
.89544 .39084 Mdot
.89548 .39091 Mdot
.89553 .39098 Mdot
.89558 .39105 Mdot
.89563 .39112 Mdot
.89567 .39119 Mdot
.89572 .39126 Mdot
.89577 .39132 Mdot
.89582 .39139 Mdot
.89587 .39146 Mdot
.89591 .39153 Mdot
.89596 .3916 Mdot
.89601 .39166 Mdot
.89606 .39173 Mdot
.8961 .3918 Mdot
.89615 .39187 Mdot
.8962 .39193 Mdot
.89625 .392 Mdot
.89629 .39207 Mdot
.89634 .39213 Mdot
.89639 .3922 Mdot
.89644 .39227 Mdot
.89648 .39233 Mdot
.89653 .3924 Mdot
.89658 .39247 Mdot
.89663 .39253 Mdot
.89667 .3926 Mdot
.89672 .39267 Mdot
.89677 .39273 Mdot
.89682 .3928 Mdot
.89687 .39286 Mdot
.89691 .39293 Mdot
.89696 .39299 Mdot
.89701 .39306 Mdot
.89706 .39312 Mdot
.8971 .39319 Mdot
.89715 .39325 Mdot
.8972 .39332 Mdot
.89725 .39338 Mdot
.89729 .39345 Mdot
.89734 .39351 Mdot
.89739 .39358 Mdot
.89744 .39364 Mdot
.89748 .39371 Mdot
.89753 .39377 Mdot
.89758 .39383 Mdot
.89763 .3939 Mdot
.89767 .39396 Mdot
.89772 .39402 Mdot
.89777 .39409 Mdot
.89782 .39415 Mdot
.89786 .39421 Mdot
.89791 .39428 Mdot
.89796 .39434 Mdot
.89801 .3944 Mdot
.89806 .39447 Mdot
.8981 .39453 Mdot
.89815 .39459 Mdot
.8982 .39465 Mdot
.89825 .39472 Mdot
.89829 .39478 Mdot
.89834 .39484 Mdot
.89839 .3949 Mdot
.89844 .39496 Mdot
.89848 .39503 Mdot
.89853 .39509 Mdot
.89858 .39515 Mdot
.89863 .39521 Mdot
.89867 .39527 Mdot
.89872 .39533 Mdot
.89877 .39539 Mdot
.89882 .39545 Mdot
.89886 .39552 Mdot
.89891 .39558 Mdot
.89896 .39564 Mdot
.89901 .3957 Mdot
.89906 .39576 Mdot
.8991 .39582 Mdot
.89915 .39588 Mdot
.8992 .39594 Mdot
.89925 .396 Mdot
.89929 .39606 Mdot
.89934 .39612 Mdot
.89939 .39618 Mdot
.89944 .39624 Mdot
.89948 .3963 Mdot
.89953 .39635 Mdot
.89958 .39641 Mdot
.89963 .39647 Mdot
.89967 .39653 Mdot
.89972 .39659 Mdot
.89977 .39665 Mdot
.89982 .39671 Mdot
.89986 .39677 Mdot
.89991 .39682 Mdot
.89996 .39688 Mdot
.90001 .39694 Mdot
.90006 .397 Mdot
.9001 .39706 Mdot
.90015 .39711 Mdot
.9002 .39717 Mdot
.90025 .39723 Mdot
.90029 .39729 Mdot
.90034 .39734 Mdot
.90039 .3974 Mdot
.90044 .39746 Mdot
.90048 .39751 Mdot
.90053 .39757 Mdot
.90058 .39763 Mdot
.90063 .39768 Mdot
.90067 .39774 Mdot
.90072 .3978 Mdot
.90077 .39785 Mdot
.90082 .39791 Mdot
.90086 .39796 Mdot
.90091 .39802 Mdot
.90096 .39808 Mdot
.90101 .39813 Mdot
.90106 .39819 Mdot
.9011 .39824 Mdot
.90115 .3983 Mdot
.9012 .39835 Mdot
.90125 .39841 Mdot
.90129 .39846 Mdot
.90134 .39852 Mdot
.90139 .39857 Mdot
.90144 .39863 Mdot
.90148 .39868 Mdot
.90153 .39874 Mdot
.90158 .39879 Mdot
.90163 .39884 Mdot
.90167 .3989 Mdot
.90172 .39895 Mdot
.90177 .399 Mdot
.90182 .39906 Mdot
.90186 .39911 Mdot
.90191 .39917 Mdot
.90196 .39922 Mdot
.90201 .39927 Mdot
.90206 .39932 Mdot
.9021 .39938 Mdot
.90215 .39943 Mdot
.9022 .39948 Mdot
.90225 .39954 Mdot
.90229 .39959 Mdot
.90234 .39964 Mdot
.90239 .39969 Mdot
.90244 .39974 Mdot
.90248 .3998 Mdot
.90253 .39985 Mdot
.90258 .3999 Mdot
.90263 .39995 Mdot
.90267 .4 Mdot
.90272 .40005 Mdot
.90277 .40011 Mdot
.90282 .40016 Mdot
.90286 .40021 Mdot
.90291 .40026 Mdot
.90296 .40031 Mdot
.90301 .40036 Mdot
.90305 .40041 Mdot
.9031 .40046 Mdot
.90315 .40051 Mdot
.9032 .40056 Mdot
.90325 .40061 Mdot
.90329 .40066 Mdot
.90334 .40071 Mdot
.90339 .40076 Mdot
.90344 .40081 Mdot
.90348 .40086 Mdot
.90353 .40091 Mdot
.90358 .40096 Mdot
.90363 .40101 Mdot
.90367 .40106 Mdot
.90372 .4011 Mdot
.90377 .40115 Mdot
.90382 .4012 Mdot
.90386 .40125 Mdot
.90391 .4013 Mdot
.90396 .40135 Mdot
.90401 .40139 Mdot
.90405 .40144 Mdot
.9041 .40149 Mdot
.90415 .40154 Mdot
.9042 .40159 Mdot
.90425 .40163 Mdot
.90429 .40168 Mdot
.90434 .40173 Mdot
.90439 .40177 Mdot
.90444 .40182 Mdot
.90448 .40187 Mdot
.90453 .40192 Mdot
.90458 .40196 Mdot
.90463 .40201 Mdot
.90467 .40206 Mdot
.90472 .4021 Mdot
.90477 .40215 Mdot
.90482 .40219 Mdot
.90486 .40224 Mdot
.90491 .40229 Mdot
.90496 .40233 Mdot
.90501 .40238 Mdot
.90505 .40242 Mdot
.9051 .40247 Mdot
.90515 .40251 Mdot
.9052 .40256 Mdot
.90525 .4026 Mdot
.90529 .40265 Mdot
.90534 .40269 Mdot
.90539 .40274 Mdot
.90544 .40278 Mdot
.90548 .40283 Mdot
.90553 .40287 Mdot
.90558 .40291 Mdot
.90563 .40296 Mdot
.90567 .403 Mdot
.90572 .40305 Mdot
.90577 .40309 Mdot
.90582 .40313 Mdot
.90586 .40318 Mdot
.90591 .40322 Mdot
.90596 .40326 Mdot
.90601 .40331 Mdot
.90605 .40335 Mdot
.9061 .40339 Mdot
.90615 .40343 Mdot
.9062 .40348 Mdot
.90625 .40352 Mdot
.90629 .40356 Mdot
.90634 .4036 Mdot
.90639 .40365 Mdot
.90644 .40369 Mdot
.90648 .40373 Mdot
.90653 .40377 Mdot
.90658 .40381 Mdot
.90663 .40385 Mdot
.90667 .40389 Mdot
.90672 .40394 Mdot
.90677 .40398 Mdot
.90682 .40402 Mdot
.90686 .40406 Mdot
.90691 .4041 Mdot
.90696 .40414 Mdot
.90701 .40418 Mdot
.90705 .40422 Mdot
.9071 .40426 Mdot
.90715 .4043 Mdot
.9072 .40434 Mdot
.90724 .40438 Mdot
.90729 .40442 Mdot
.90734 .40446 Mdot
.90739 .4045 Mdot
.90744 .40454 Mdot
.90748 .40458 Mdot
.90753 .40462 Mdot
.90758 .40466 Mdot
.90763 .4047 Mdot
.90767 .40473 Mdot
.90772 .40477 Mdot
.90777 .40481 Mdot
.90782 .40485 Mdot
.90786 .40489 Mdot
.90791 .40493 Mdot
.90796 .40496 Mdot
.90801 .405 Mdot
.90805 .40504 Mdot
.9081 .40508 Mdot
.90815 .40512 Mdot
.9082 .40515 Mdot
.90824 .40519 Mdot
.90829 .40523 Mdot
.90834 .40526 Mdot
.90839 .4053 Mdot
.90844 .40534 Mdot
.90848 .40537 Mdot
.90853 .40541 Mdot
.90858 .40545 Mdot
.90863 .40548 Mdot
.90867 .40552 Mdot
.90872 .40556 Mdot
.90877 .40559 Mdot
.90882 .40563 Mdot
.90886 .40566 Mdot
.90891 .4057 Mdot
.90896 .40573 Mdot
.90901 .40577 Mdot
.90905 .40581 Mdot
.9091 .40584 Mdot
.90915 .40588 Mdot
.9092 .40591 Mdot
.90924 .40594 Mdot
.90929 .40598 Mdot
.90934 .40601 Mdot
.90939 .40605 Mdot
.90944 .40608 Mdot
.90948 .40612 Mdot
.90953 .40615 Mdot
.90958 .40618 Mdot
.90963 .40622 Mdot
.90967 .40625 Mdot
.90972 .40628 Mdot
.90977 .40632 Mdot
.90982 .40635 Mdot
.90986 .40638 Mdot
.90991 .40642 Mdot
.90996 .40645 Mdot
.91001 .40648 Mdot
.91005 .40652 Mdot
.9101 .40655 Mdot
.91015 .40658 Mdot
.9102 .40661 Mdot
.91024 .40664 Mdot
.91029 .40668 Mdot
.91034 .40671 Mdot
.91039 .40674 Mdot
.91044 .40677 Mdot
.91048 .4068 Mdot
.91053 .40683 Mdot
.91058 .40687 Mdot
.91063 .4069 Mdot
.91067 .40693 Mdot
.91072 .40696 Mdot
.91077 .40699 Mdot
.91082 .40702 Mdot
.91086 .40705 Mdot
.91091 .40708 Mdot
.91096 .40711 Mdot
.91101 .40714 Mdot
.91105 .40717 Mdot
.9111 .4072 Mdot
.91115 .40723 Mdot
.9112 .40726 Mdot
.91124 .40729 Mdot
.91129 .40732 Mdot
.91134 .40735 Mdot
.91139 .40738 Mdot
.91144 .40741 Mdot
.91148 .40744 Mdot
.91153 .40747 Mdot
.91158 .40749 Mdot
.91163 .40752 Mdot
.91167 .40755 Mdot
.91172 .40758 Mdot
.91177 .40761 Mdot
.91182 .40763 Mdot
.91186 .40766 Mdot
.91191 .40769 Mdot
.91196 .40772 Mdot
.91201 .40775 Mdot
.91205 .40777 Mdot
.9121 .4078 Mdot
.91215 .40783 Mdot
.9122 .40785 Mdot
.91224 .40788 Mdot
.91229 .40791 Mdot
.91234 .40793 Mdot
.91239 .40796 Mdot
.91243 .40799 Mdot
.91248 .40801 Mdot
.91253 .40804 Mdot
.91258 .40807 Mdot
.91263 .40809 Mdot
.91267 .40812 Mdot
.91272 .40814 Mdot
.91277 .40817 Mdot
.91282 .40819 Mdot
.91286 .40822 Mdot
.91291 .40825 Mdot
.91296 .40827 Mdot
.91301 .4083 Mdot
.91305 .40832 Mdot
.9131 .40834 Mdot
.91315 .40837 Mdot
.9132 .40839 Mdot
.91324 .40842 Mdot
.91329 .40844 Mdot
.91334 .40847 Mdot
.91339 .40849 Mdot
.91343 .40851 Mdot
.91348 .40854 Mdot
.91353 .40856 Mdot
.91358 .40858 Mdot
.91363 .40861 Mdot
.91367 .40863 Mdot
.91372 .40865 Mdot
.91377 .40868 Mdot
.91382 .4087 Mdot
.91386 .40872 Mdot
.91391 .40874 Mdot
.91396 .40877 Mdot
.91401 .40879 Mdot
.91405 .40881 Mdot
.9141 .40883 Mdot
.91415 .40886 Mdot
.9142 .40888 Mdot
.91424 .4089 Mdot
.91429 .40892 Mdot
.91434 .40894 Mdot
.91439 .40896 Mdot
.91443 .40898 Mdot
.91448 .40901 Mdot
.91453 .40903 Mdot
.91458 .40905 Mdot
.91463 .40907 Mdot
.91467 .40909 Mdot
.91472 .40911 Mdot
.91477 .40913 Mdot
.91482 .40915 Mdot
.91486 .40917 Mdot
.91491 .40919 Mdot
.91496 .40921 Mdot
.91501 .40923 Mdot
.91505 .40925 Mdot
.9151 .40927 Mdot
.91515 .40929 Mdot
.9152 .40931 Mdot
.91524 .40932 Mdot
.91529 .40934 Mdot
.91534 .40936 Mdot
.91539 .40938 Mdot
.91543 .4094 Mdot
.91548 .40942 Mdot
.91553 .40944 Mdot
.91558 .40945 Mdot
.91563 .40947 Mdot
.91567 .40949 Mdot
.91572 .40951 Mdot
.91577 .40953 Mdot
.91582 .40954 Mdot
.91586 .40956 Mdot
.91591 .40958 Mdot
.91596 .4096 Mdot
.91601 .40961 Mdot
.91605 .40963 Mdot
.9161 .40965 Mdot
.91615 .40966 Mdot
.9162 .40968 Mdot
.91624 .4097 Mdot
.91629 .40971 Mdot
.91634 .40973 Mdot
.91639 .40974 Mdot
.91643 .40976 Mdot
.91648 .40978 Mdot
.91653 .40979 Mdot
.91658 .40981 Mdot
.91663 .40982 Mdot
.91667 .40984 Mdot
.91672 .40985 Mdot
.91677 .40987 Mdot
.91682 .40988 Mdot
.91686 .4099 Mdot
.91691 .40991 Mdot
.91696 .40993 Mdot
.91701 .40994 Mdot
.91705 .40996 Mdot
.9171 .40997 Mdot
.91715 .40998 Mdot
.9172 .41 Mdot
.91724 .41001 Mdot
.91729 .41003 Mdot
.91734 .41004 Mdot
.91739 .41005 Mdot
.91743 .41007 Mdot
.91748 .41008 Mdot
.91753 .41009 Mdot
.91758 .4101 Mdot
.91762 .41012 Mdot
.91767 .41013 Mdot
.91772 .41014 Mdot
.91777 .41016 Mdot
.91782 .41017 Mdot
.91786 .41018 Mdot
.91791 .41019 Mdot
.91796 .4102 Mdot
.91801 .41022 Mdot
.91805 .41023 Mdot
.9181 .41024 Mdot
.91815 .41025 Mdot
.9182 .41026 Mdot
.91824 .41027 Mdot
.91829 .41028 Mdot
.91834 .41029 Mdot
.91839 .4103 Mdot
.91843 .41032 Mdot
.91848 .41033 Mdot
.91853 .41034 Mdot
.91858 .41035 Mdot
.91862 .41036 Mdot
.91867 .41037 Mdot
.91872 .41038 Mdot
.91877 .41039 Mdot
.91882 .4104 Mdot
.91886 .41041 Mdot
.91891 .41042 Mdot
.91896 .41042 Mdot
.91901 .41043 Mdot
.91905 .41044 Mdot
.9191 .41045 Mdot
.91915 .41046 Mdot
.9192 .41047 Mdot
.91924 .41048 Mdot
.91929 .41049 Mdot
.91934 .41049 Mdot
.91939 .4105 Mdot
.91943 .41051 Mdot
.91948 .41052 Mdot
.91953 .41053 Mdot
.91958 .41053 Mdot
.91962 .41054 Mdot
.91967 .41055 Mdot
.91972 .41056 Mdot
.91977 .41056 Mdot
.91982 .41057 Mdot
.91986 .41058 Mdot
.91991 .41058 Mdot
.91996 .41059 Mdot
.92001 .4106 Mdot
.92005 .4106 Mdot
.9201 .41061 Mdot
.92015 .41062 Mdot
.9202 .41062 Mdot
.92024 .41063 Mdot
.92029 .41063 Mdot
.92034 .41064 Mdot
.92039 .41064 Mdot
.92043 .41065 Mdot
.92048 .41066 Mdot
.92053 .41066 Mdot
.92058 .41067 Mdot
.92062 .41067 Mdot
.92067 .41068 Mdot
.92072 .41068 Mdot
.92077 .41068 Mdot
.92082 .41069 Mdot
.92086 .41069 Mdot
.92091 .4107 Mdot
.92096 .4107 Mdot
.92101 .4107 Mdot
.92105 .41071 Mdot
.9211 .41071 Mdot
.92115 .41072 Mdot
.9212 .41072 Mdot
.92124 .41072 Mdot
.92129 .41073 Mdot
.92134 .41073 Mdot
.92139 .41073 Mdot
.92143 .41073 Mdot
.92148 .41074 Mdot
.92153 .41074 Mdot
.92158 .41074 Mdot
.92162 .41074 Mdot
.92167 .41075 Mdot
.92172 .41075 Mdot
.92177 .41075 Mdot
.92181 .41075 Mdot
.92186 .41075 Mdot
.92191 .41076 Mdot
.92196 .41076 Mdot
.92201 .41076 Mdot
.92205 .41076 Mdot
.9221 .41076 Mdot
.92215 .41076 Mdot
.9222 .41076 Mdot
.92224 .41076 Mdot
.92229 .41076 Mdot
.92234 .41076 Mdot
.92239 .41076 Mdot
.92243 .41076 Mdot
.92248 .41076 Mdot
.92253 .41076 Mdot
.92258 .41076 Mdot
.92262 .41076 Mdot
.92267 .41076 Mdot
.92272 .41076 Mdot
.92277 .41076 Mdot
.92281 .41076 Mdot
.92286 .41076 Mdot
.92291 .41076 Mdot
.92296 .41076 Mdot
.92301 .41076 Mdot
.92305 .41075 Mdot
.9231 .41075 Mdot
.92315 .41075 Mdot
.9232 .41075 Mdot
.92324 .41075 Mdot
.92329 .41075 Mdot
.92334 .41074 Mdot
.92339 .41074 Mdot
.92343 .41074 Mdot
.92348 .41074 Mdot
.92353 .41073 Mdot
.92358 .41073 Mdot
.92362 .41073 Mdot
.92367 .41072 Mdot
.92372 .41072 Mdot
.92377 .41072 Mdot
.92381 .41071 Mdot
.92386 .41071 Mdot
.92391 .41071 Mdot
.92396 .4107 Mdot
.92401 .4107 Mdot
.92405 .41069 Mdot
.9241 .41069 Mdot
.92415 .41069 Mdot
.9242 .41068 Mdot
.92424 .41068 Mdot
.92429 .41067 Mdot
.92434 .41067 Mdot
.92439 .41066 Mdot
.92443 .41066 Mdot
.92448 .41065 Mdot
.92453 .41065 Mdot
.92458 .41064 Mdot
.92462 .41064 Mdot
.92467 .41063 Mdot
.92472 .41062 Mdot
.92477 .41062 Mdot
.92481 .41061 Mdot
.92486 .41061 Mdot
.92491 .4106 Mdot
.92496 .41059 Mdot
.92501 .41059 Mdot
.92505 .41058 Mdot
.9251 .41057 Mdot
.92515 .41057 Mdot
.9252 .41056 Mdot
.92524 .41055 Mdot
.92529 .41055 Mdot
.92534 .41054 Mdot
.92539 .41053 Mdot
.92543 .41052 Mdot
.92548 .41051 Mdot
.92553 .41051 Mdot
.92558 .4105 Mdot
.92562 .41049 Mdot
.92567 .41048 Mdot
.92572 .41047 Mdot
.92577 .41047 Mdot
.92581 .41046 Mdot
.92586 .41045 Mdot
.92591 .41044 Mdot
.92596 .41043 Mdot
.92601 .41042 Mdot
.92605 .41041 Mdot
.9261 .4104 Mdot
.92615 .41039 Mdot
.9262 .41038 Mdot
.92624 .41037 Mdot
.92629 .41036 Mdot
.92634 .41035 Mdot
.92639 .41034 Mdot
.92643 .41033 Mdot
.92648 .41032 Mdot
.92653 .41031 Mdot
.92658 .4103 Mdot
.92662 .41029 Mdot
.92667 .41028 Mdot
.92672 .41027 Mdot
.92677 .41026 Mdot
.92681 .41025 Mdot
.92686 .41024 Mdot
.92691 .41022 Mdot
.92696 .41021 Mdot
.927 .4102 Mdot
.92705 .41019 Mdot
.9271 .41018 Mdot
.92715 .41016 Mdot
.9272 .41015 Mdot
.92724 .41014 Mdot
.92729 .41013 Mdot
.92734 .41011 Mdot
.92739 .4101 Mdot
.92743 .41009 Mdot
.92748 .41008 Mdot
.92753 .41006 Mdot
.92758 .41005 Mdot
.92762 .41004 Mdot
.92767 .41002 Mdot
.92772 .41001 Mdot
.92777 .41 Mdot
.92781 .40998 Mdot
.92786 .40997 Mdot
.92791 .40995 Mdot
.92796 .40994 Mdot
.928 .40993 Mdot
.92805 .40991 Mdot
.9281 .4099 Mdot
.92815 .40988 Mdot
.9282 .40987 Mdot
.92824 .40985 Mdot
.92829 .40984 Mdot
.92834 .40982 Mdot
.92839 .40981 Mdot
.92843 .40979 Mdot
.92848 .40978 Mdot
.92853 .40976 Mdot
.92858 .40974 Mdot
.92862 .40973 Mdot
.92867 .40971 Mdot
.92872 .4097 Mdot
.92877 .40968 Mdot
.92881 .40966 Mdot
.92886 .40965 Mdot
.92891 .40963 Mdot
.92896 .40961 Mdot
.929 .4096 Mdot
.92905 .40958 Mdot
.9291 .40956 Mdot
.92915 .40955 Mdot
.9292 .40953 Mdot
.92924 .40951 Mdot
.92929 .40949 Mdot
.92934 .40948 Mdot
.92939 .40946 Mdot
.92943 .40944 Mdot
.92948 .40942 Mdot
.92953 .4094 Mdot
.92958 .40938 Mdot
.92962 .40937 Mdot
.92967 .40935 Mdot
.92972 .40933 Mdot
.92977 .40931 Mdot
.92981 .40929 Mdot
.92986 .40927 Mdot
.92991 .40925 Mdot
.92996 .40923 Mdot
.93 .40921 Mdot
.93005 .40919 Mdot
.9301 .40918 Mdot
.93015 .40916 Mdot
.9302 .40914 Mdot
.93024 .40912 Mdot
.93029 .4091 Mdot
.93034 .40907 Mdot
.93039 .40905 Mdot
.93043 .40903 Mdot
.93048 .40901 Mdot
.93053 .40899 Mdot
.93058 .40897 Mdot
.93062 .40895 Mdot
.93067 .40893 Mdot
.93072 .40891 Mdot
.93077 .40889 Mdot
.93081 .40887 Mdot
.93086 .40884 Mdot
.93091 .40882 Mdot
.93096 .4088 Mdot
.931 .40878 Mdot
.93105 .40876 Mdot
.9311 .40873 Mdot
.93115 .40871 Mdot
.93119 .40869 Mdot
.93124 .40867 Mdot
.93129 .40864 Mdot
.93134 .40862 Mdot
.93139 .4086 Mdot
.93143 .40858 Mdot
.93148 .40855 Mdot
.93153 .40853 Mdot
.93158 .40851 Mdot
.93162 .40848 Mdot
.93167 .40846 Mdot
.93172 .40843 Mdot
.93177 .40841 Mdot
.93181 .40839 Mdot
.93186 .40836 Mdot
.93191 .40834 Mdot
.93196 .40831 Mdot
.932 .40829 Mdot
.93205 .40826 Mdot
.9321 .40824 Mdot
.93215 .40822 Mdot
.93219 .40819 Mdot
.93224 .40817 Mdot
.93229 .40814 Mdot
.93234 .40811 Mdot
.93239 .40809 Mdot
.93243 .40806 Mdot
.93248 .40804 Mdot
.93253 .40801 Mdot
.93258 .40799 Mdot
.93262 .40796 Mdot
.93267 .40793 Mdot
.93272 .40791 Mdot
.93277 .40788 Mdot
.93281 .40785 Mdot
.93286 .40783 Mdot
.93291 .4078 Mdot
.93296 .40777 Mdot
.933 .40775 Mdot
.93305 .40772 Mdot
.9331 .40769 Mdot
.93315 .40767 Mdot
.93319 .40764 Mdot
.93324 .40761 Mdot
.93329 .40758 Mdot
.93334 .40756 Mdot
.93339 .40753 Mdot
.93343 .4075 Mdot
.93348 .40747 Mdot
.93353 .40744 Mdot
.93358 .40741 Mdot
.93362 .40739 Mdot
.93367 .40736 Mdot
.93372 .40733 Mdot
.93377 .4073 Mdot
.93381 .40727 Mdot
.93386 .40724 Mdot
.93391 .40721 Mdot
.93396 .40718 Mdot
.934 .40715 Mdot
.93405 .40712 Mdot
.9341 .40709 Mdot
.93415 .40706 Mdot
.93419 .40703 Mdot
.93424 .407 Mdot
.93429 .40697 Mdot
.93434 .40694 Mdot
.93439 .40691 Mdot
.93443 .40688 Mdot
.93448 .40685 Mdot
.93453 .40682 Mdot
.93458 .40679 Mdot
.93462 .40676 Mdot
.93467 .40673 Mdot
.93472 .4067 Mdot
.93477 .40667 Mdot
.93481 .40663 Mdot
.93486 .4066 Mdot
.93491 .40657 Mdot
.93496 .40654 Mdot
.935 .40651 Mdot
.93505 .40647 Mdot
.9351 .40644 Mdot
.93515 .40641 Mdot
.93519 .40638 Mdot
.93524 .40635 Mdot
.93529 .40631 Mdot
.93534 .40628 Mdot
.93539 .40625 Mdot
.93543 .40621 Mdot
.93548 .40618 Mdot
.93553 .40615 Mdot
.93558 .40611 Mdot
.93562 .40608 Mdot
.93567 .40605 Mdot
.93572 .40601 Mdot
.93577 .40598 Mdot
.93581 .40595 Mdot
.93586 .40591 Mdot
.93591 .40588 Mdot
.93596 .40584 Mdot
.936 .40581 Mdot
.93605 .40577 Mdot
.9361 .40574 Mdot
.93615 .4057 Mdot
.93619 .40567 Mdot
.93624 .40564 Mdot
.93629 .4056 Mdot
.93634 .40556 Mdot
.93638 .40553 Mdot
.93643 .40549 Mdot
.93648 .40546 Mdot
.93653 .40542 Mdot
.93658 .40539 Mdot
.93662 .40535 Mdot
.93667 .40531 Mdot
.93672 .40528 Mdot
.93677 .40524 Mdot
.93681 .40521 Mdot
.93686 .40517 Mdot
.93691 .40513 Mdot
.93696 .4051 Mdot
.937 .40506 Mdot
.93705 .40502 Mdot
.9371 .40499 Mdot
.93715 .40495 Mdot
.93719 .40491 Mdot
.93724 .40487 Mdot
.93729 .40484 Mdot
.93734 .4048 Mdot
.93738 .40476 Mdot
.93743 .40472 Mdot
.93748 .40468 Mdot
.93753 .40465 Mdot
.93758 .40461 Mdot
.93762 .40457 Mdot
.93767 .40453 Mdot
.93772 .40449 Mdot
.93777 .40445 Mdot
.93781 .40442 Mdot
.93786 .40438 Mdot
.93791 .40434 Mdot
.93796 .4043 Mdot
.938 .40426 Mdot
.93805 .40422 Mdot
.9381 .40418 Mdot
.93815 .40414 Mdot
.93819 .4041 Mdot
.93824 .40406 Mdot
.93829 .40402 Mdot
.93834 .40398 Mdot
.93838 .40394 Mdot
.93843 .4039 Mdot
.93848 .40386 Mdot
.93853 .40382 Mdot
.93858 .40378 Mdot
.93862 .40374 Mdot
.93867 .4037 Mdot
.93872 .40366 Mdot
.93877 .40362 Mdot
.93881 .40357 Mdot
.93886 .40353 Mdot
.93891 .40349 Mdot
.93896 .40345 Mdot
.939 .40341 Mdot
.93905 .40337 Mdot
.9391 .40333 Mdot
.93915 .40328 Mdot
.93919 .40324 Mdot
.93924 .4032 Mdot
.93929 .40316 Mdot
.93934 .40311 Mdot
.93938 .40307 Mdot
.93943 .40303 Mdot
.93948 .40299 Mdot
.93953 .40294 Mdot
.93958 .4029 Mdot
.93962 .40286 Mdot
.93967 .40281 Mdot
.93972 .40277 Mdot
.93977 .40273 Mdot
.93981 .40268 Mdot
.93986 .40264 Mdot
.93991 .4026 Mdot
.93996 .40255 Mdot
.94 .40251 Mdot
.94005 .40246 Mdot
.9401 .40242 Mdot
.94015 .40238 Mdot
.94019 .40233 Mdot
.94024 .40229 Mdot
.94029 .40224 Mdot
.94034 .4022 Mdot
.94038 .40215 Mdot
.94043 .40211 Mdot
.94048 .40206 Mdot
.94053 .40202 Mdot
.94057 .40197 Mdot
.94062 .40193 Mdot
.94067 .40188 Mdot
.94072 .40184 Mdot
.94077 .40179 Mdot
.94081 .40174 Mdot
.94086 .4017 Mdot
.94091 .40165 Mdot
.94096 .40161 Mdot
.941 .40156 Mdot
.94105 .40151 Mdot
.9411 .40147 Mdot
.94115 .40142 Mdot
.94119 .40137 Mdot
.94124 .40133 Mdot
.94129 .40128 Mdot
.94134 .40123 Mdot
.94138 .40118 Mdot
.94143 .40114 Mdot
.94148 .40109 Mdot
.94153 .40104 Mdot
.94157 .40099 Mdot
.94162 .40095 Mdot
.94167 .4009 Mdot
.94172 .40085 Mdot
.94177 .4008 Mdot
.94181 .40075 Mdot
.94186 .40071 Mdot
.94191 .40066 Mdot
.94196 .40061 Mdot
.942 .40056 Mdot
.94205 .40051 Mdot
.9421 .40046 Mdot
.94215 .40041 Mdot
.94219 .40036 Mdot
.94224 .40032 Mdot
.94229 .40027 Mdot
.94234 .40022 Mdot
.94238 .40017 Mdot
.94243 .40012 Mdot
.94248 .40007 Mdot
.94253 .40002 Mdot
.94257 .39997 Mdot
.94262 .39992 Mdot
.94267 .39987 Mdot
.94272 .39982 Mdot
.94277 .39977 Mdot
.94281 .39972 Mdot
.94286 .39967 Mdot
.94291 .39961 Mdot
.94296 .39956 Mdot
.943 .39951 Mdot
.94305 .39946 Mdot
.9431 .39941 Mdot
.94315 .39936 Mdot
.94319 .39931 Mdot
.94324 .39926 Mdot
.94329 .39921 Mdot
.94334 .39915 Mdot
.94338 .3991 Mdot
.94343 .39905 Mdot
.94348 .399 Mdot
.94353 .39895 Mdot
.94357 .39889 Mdot
.94362 .39884 Mdot
.94367 .39879 Mdot
.94372 .39874 Mdot
.94377 .39868 Mdot
.94381 .39863 Mdot
.94386 .39858 Mdot
.94391 .39852 Mdot
.94396 .39847 Mdot
.944 .39842 Mdot
.94405 .39837 Mdot
.9441 .39831 Mdot
.94415 .39826 Mdot
.94419 .3982 Mdot
.94424 .39815 Mdot
.94429 .3981 Mdot
.94434 .39804 Mdot
.94438 .39799 Mdot
.94443 .39793 Mdot
.94448 .39788 Mdot
.94453 .39783 Mdot
.94457 .39777 Mdot
.94462 .39772 Mdot
.94467 .39766 Mdot
.94472 .39761 Mdot
.94477 .39755 Mdot
.94481 .3975 Mdot
.94486 .39744 Mdot
.94491 .39739 Mdot
.94496 .39733 Mdot
.945 .39728 Mdot
.94505 .39722 Mdot
.9451 .39717 Mdot
.94515 .39711 Mdot
.94519 .39705 Mdot
.94524 .397 Mdot
.94529 .39694 Mdot
.94534 .39689 Mdot
.94538 .39683 Mdot
.94543 .39677 Mdot
.94548 .39672 Mdot
.94553 .39666 Mdot
.94557 .3966 Mdot
.94562 .39655 Mdot
.94567 .39649 Mdot
.94572 .39643 Mdot
.94576 .39638 Mdot
.94581 .39632 Mdot
.94586 .39626 Mdot
.94591 .3962 Mdot
.94596 .39615 Mdot
.946 .39609 Mdot
.94605 .39603 Mdot
.9461 .39597 Mdot
.94615 .39591 Mdot
.94619 .39586 Mdot
.94624 .3958 Mdot
.94629 .39574 Mdot
.94634 .39568 Mdot
.94638 .39562 Mdot
.94643 .39556 Mdot
.94648 .39551 Mdot
.94653 .39545 Mdot
.94657 .39539 Mdot
.94662 .39533 Mdot
.94667 .39527 Mdot
.94672 .39521 Mdot
.94676 .39515 Mdot
.94681 .39509 Mdot
.94686 .39503 Mdot
.94691 .39497 Mdot
.94696 .39491 Mdot
.947 .39485 Mdot
.94705 .39479 Mdot
.9471 .39473 Mdot
.94715 .39467 Mdot
.94719 .39461 Mdot
.94724 .39455 Mdot
.94729 .39449 Mdot
.94734 .39443 Mdot
.94738 .39437 Mdot
.94743 .39431 Mdot
.94748 .39425 Mdot
.94753 .39419 Mdot
.94757 .39413 Mdot
.94762 .39407 Mdot
.94767 .39401 Mdot
.94772 .39394 Mdot
.94776 .39388 Mdot
.94781 .39382 Mdot
.94786 .39376 Mdot
.94791 .3937 Mdot
.94796 .39364 Mdot
.948 .39357 Mdot
.94805 .39351 Mdot
.9481 .39345 Mdot
.94815 .39339 Mdot
.94819 .39332 Mdot
.94824 .39326 Mdot
.94829 .3932 Mdot
.94834 .39314 Mdot
.94838 .39307 Mdot
.94843 .39301 Mdot
.94848 .39295 Mdot
.94853 .39289 Mdot
.94857 .39282 Mdot
.94862 .39276 Mdot
.94867 .3927 Mdot
.94872 .39263 Mdot
.94876 .39257 Mdot
.94881 .3925 Mdot
.94886 .39244 Mdot
.94891 .39238 Mdot
.94896 .39231 Mdot
.949 .39225 Mdot
.94905 .39218 Mdot
.9491 .39212 Mdot
.94915 .39206 Mdot
.94919 .39199 Mdot
.94924 .39193 Mdot
.94929 .39186 Mdot
.94934 .3918 Mdot
.94938 .39173 Mdot
.94943 .39167 Mdot
.94948 .3916 Mdot
.94953 .39154 Mdot
.94957 .39147 Mdot
.94962 .39141 Mdot
.94967 .39134 Mdot
.94972 .39128 Mdot
.94976 .39121 Mdot
.94981 .39114 Mdot
.94986 .39108 Mdot
.94991 .39101 Mdot
.94996 .39095 Mdot
.95 .39088 Mdot
.95005 .39081 Mdot
.9501 .39075 Mdot
.95015 .39068 Mdot
.95019 .39062 Mdot
.95024 .39055 Mdot
.95029 .39048 Mdot
.95034 .39041 Mdot
.95038 .39035 Mdot
.95043 .39028 Mdot
.95048 .39021 Mdot
.95053 .39015 Mdot
.95057 .39008 Mdot
.95062 .39001 Mdot
.95067 .38994 Mdot
.95072 .38988 Mdot
.95076 .38981 Mdot
.95081 .38974 Mdot
.95086 .38967 Mdot
.95091 .38961 Mdot
.95095 .38954 Mdot
.951 .38947 Mdot
.95105 .3894 Mdot
.9511 .38933 Mdot
.95115 .38926 Mdot
.95119 .3892 Mdot
.95124 .38913 Mdot
.95129 .38906 Mdot
.95134 .38899 Mdot
.95138 .38892 Mdot
.95143 .38885 Mdot
.95148 .38878 Mdot
.95153 .38871 Mdot
.95157 .38864 Mdot
.95162 .38857 Mdot
.95167 .3885 Mdot
.95172 .38843 Mdot
.95176 .38836 Mdot
.95181 .38829 Mdot
.95186 .38822 Mdot
.95191 .38815 Mdot
.95195 .38808 Mdot
.952 .38801 Mdot
.95205 .38794 Mdot
.9521 .38787 Mdot
.95215 .3878 Mdot
.95219 .38773 Mdot
.95224 .38766 Mdot
.95229 .38759 Mdot
.95234 .38752 Mdot
.95238 .38745 Mdot
.95243 .38738 Mdot
.95248 .38731 Mdot
.95253 .38724 Mdot
.95257 .38716 Mdot
.95262 .38709 Mdot
.95267 .38702 Mdot
.95272 .38695 Mdot
.95276 .38688 Mdot
.95281 .38681 Mdot
.95286 .38673 Mdot
.95291 .38666 Mdot
.95295 .38659 Mdot
.953 .38652 Mdot
.95305 .38645 Mdot
.9531 .38637 Mdot
.95315 .3863 Mdot
.95319 .38623 Mdot
.95324 .38616 Mdot
.95329 .38608 Mdot
.95334 .38601 Mdot
.95338 .38594 Mdot
.95343 .38586 Mdot
.95348 .38579 Mdot
.95353 .38572 Mdot
.95357 .38564 Mdot
.95362 .38557 Mdot
.95367 .3855 Mdot
.95372 .38542 Mdot
.95376 .38535 Mdot
.95381 .38528 Mdot
.95386 .3852 Mdot
.95391 .38513 Mdot
.95395 .38506 Mdot
.954 .38498 Mdot
.95405 .38491 Mdot
.9541 .38483 Mdot
.95415 .38476 Mdot
.95419 .38468 Mdot
.95424 .38461 Mdot
.95429 .38453 Mdot
.95434 .38446 Mdot
.95438 .38438 Mdot
.95443 .38431 Mdot
.95448 .38423 Mdot
.95453 .38416 Mdot
.95457 .38408 Mdot
.95462 .38401 Mdot
.95467 .38393 Mdot
.95472 .38386 Mdot
.95476 .38378 Mdot
.95481 .38371 Mdot
.95486 .38363 Mdot
.95491 .38356 Mdot
.95495 .38348 Mdot
.955 .3834 Mdot
.95505 .38333 Mdot
.9551 .38325 Mdot
.95514 .38317 Mdot
.95519 .3831 Mdot
.95524 .38302 Mdot
.95529 .38295 Mdot
.95534 .38287 Mdot
.95538 .38279 Mdot
.95543 .38272 Mdot
.95548 .38264 Mdot
.95553 .38256 Mdot
.95557 .38248 Mdot
.95562 .38241 Mdot
.95567 .38233 Mdot
.95572 .38225 Mdot
.95576 .38217 Mdot
.95581 .3821 Mdot
.95586 .38202 Mdot
.95591 .38194 Mdot
.95595 .38186 Mdot
.956 .38179 Mdot
.95605 .38171 Mdot
.9561 .38163 Mdot
.95614 .38155 Mdot
.95619 .38147 Mdot
.95624 .3814 Mdot
.95629 .38132 Mdot
.95634 .38124 Mdot
.95638 .38116 Mdot
.95643 .38108 Mdot
.95648 .381 Mdot
.95653 .38092 Mdot
.95657 .38084 Mdot
.95662 .38077 Mdot
.95667 .38069 Mdot
.95672 .38061 Mdot
.95676 .38053 Mdot
.95681 .38045 Mdot
.95686 .38037 Mdot
.95691 .38029 Mdot
.95695 .38021 Mdot
.957 .38013 Mdot
.95705 .38005 Mdot
.9571 .37997 Mdot
.95714 .37989 Mdot
.95719 .37981 Mdot
.95724 .37973 Mdot
.95729 .37965 Mdot
.95734 .37957 Mdot
.95738 .37949 Mdot
.95743 .37941 Mdot
.95748 .37933 Mdot
.95753 .37925 Mdot
.95757 .37917 Mdot
.95762 .37909 Mdot
.95767 .37901 Mdot
.95772 .37892 Mdot
.95776 .37884 Mdot
.95781 .37876 Mdot
.95786 .37868 Mdot
.95791 .3786 Mdot
.95795 .37852 Mdot
.958 .37844 Mdot
.95805 .37835 Mdot
.9581 .37827 Mdot
.95814 .37819 Mdot
.95819 .37811 Mdot
.95824 .37803 Mdot
.95829 .37795 Mdot
.95834 .37786 Mdot
.95838 .37778 Mdot
.95843 .3777 Mdot
.95848 .37762 Mdot
.95853 .37753 Mdot
.95857 .37745 Mdot
.95862 .37737 Mdot
.95867 .37729 Mdot
.95872 .3772 Mdot
.95876 .37712 Mdot
.95881 .37704 Mdot
.95886 .37695 Mdot
.95891 .37687 Mdot
.95895 .37679 Mdot
.959 .37671 Mdot
.95905 .37662 Mdot
.9591 .37654 Mdot
.95914 .37645 Mdot
.95919 .37637 Mdot
.95924 .37629 Mdot
.95929 .3762 Mdot
.95934 .37612 Mdot
.95938 .37604 Mdot
.95943 .37595 Mdot
.95948 .37587 Mdot
.95953 .37578 Mdot
.95957 .3757 Mdot
.95962 .37562 Mdot
.95967 .37553 Mdot
.95972 .37545 Mdot
.95976 .37536 Mdot
.95981 .37528 Mdot
.95986 .37519 Mdot
.95991 .37511 Mdot
.95995 .37502 Mdot
.96 .37494 Mdot
.96005 .37485 Mdot
.9601 .37477 Mdot
.96014 .37468 Mdot
.96019 .3746 Mdot
.96024 .37451 Mdot
.96029 .37443 Mdot
.96033 .37434 Mdot
.96038 .37426 Mdot
.96043 .37417 Mdot
.96048 .37408 Mdot
.96053 .374 Mdot
.96057 .37391 Mdot
.96062 .37383 Mdot
.96067 .37374 Mdot
.96072 .37365 Mdot
.96076 .37357 Mdot
.96081 .37348 Mdot
.96086 .37339 Mdot
.96091 .37331 Mdot
.96095 .37322 Mdot
.961 .37314 Mdot
.96105 .37305 Mdot
.9611 .37296 Mdot
.96114 .37287 Mdot
.96119 .37279 Mdot
.96124 .3727 Mdot
.96129 .37261 Mdot
.96133 .37253 Mdot
.96138 .37244 Mdot
.96143 .37235 Mdot
.96148 .37226 Mdot
.96153 .37218 Mdot
.96157 .37209 Mdot
.96162 .372 Mdot
.96167 .37191 Mdot
.96172 .37183 Mdot
.96176 .37174 Mdot
.96181 .37165 Mdot
.96186 .37156 Mdot
.96191 .37147 Mdot
.96195 .37139 Mdot
.962 .3713 Mdot
.96205 .37121 Mdot
.9621 .37112 Mdot
.96214 .37103 Mdot
.96219 .37094 Mdot
.96224 .37086 Mdot
.96229 .37077 Mdot
.96233 .37068 Mdot
.96238 .37059 Mdot
.96243 .3705 Mdot
.96248 .37041 Mdot
.96253 .37032 Mdot
.96257 .37023 Mdot
.96262 .37014 Mdot
.96267 .37005 Mdot
.96272 .36996 Mdot
.96276 .36988 Mdot
.96281 .36979 Mdot
.96286 .3697 Mdot
.96291 .36961 Mdot
.96295 .36952 Mdot
.963 .36943 Mdot
.96305 .36934 Mdot
.9631 .36925 Mdot
.96314 .36916 Mdot
.96319 .36907 Mdot
.96324 .36898 Mdot
.96329 .36889 Mdot
.96333 .3688 Mdot
.96338 .36871 Mdot
.96343 .36861 Mdot
.96348 .36852 Mdot
.96353 .36843 Mdot
.96357 .36834 Mdot
.96362 .36825 Mdot
.96367 .36816 Mdot
.96372 .36807 Mdot
.96376 .36798 Mdot
.96381 .36789 Mdot
.96386 .3678 Mdot
.96391 .36771 Mdot
.96395 .36761 Mdot
.964 .36752 Mdot
.96405 .36743 Mdot
.9641 .36734 Mdot
.96414 .36725 Mdot
.96419 .36716 Mdot
.96424 .36706 Mdot
.96429 .36697 Mdot
.96433 .36688 Mdot
.96438 .36679 Mdot
.96443 .3667 Mdot
.96448 .3666 Mdot
.96452 .36651 Mdot
.96457 .36642 Mdot
.96462 .36633 Mdot
.96467 .36624 Mdot
.96472 .36614 Mdot
.96476 .36605 Mdot
.96481 .36596 Mdot
.96486 .36587 Mdot
.96491 .36577 Mdot
.96495 .36568 Mdot
.965 .36559 Mdot
.96505 .36549 Mdot
.9651 .3654 Mdot
.96514 .36531 Mdot
.96519 .36521 Mdot
.96524 .36512 Mdot
.96529 .36503 Mdot
.96533 .36493 Mdot
.96538 .36484 Mdot
.96543 .36475 Mdot
.96548 .36465 Mdot
.96552 .36456 Mdot
.96557 .36447 Mdot
.96562 .36437 Mdot
.96567 .36428 Mdot
.96572 .36419 Mdot
.96576 .36409 Mdot
.96581 .364 Mdot
.96586 .3639 Mdot
.96591 .36381 Mdot
.96595 .36371 Mdot
.966 .36362 Mdot
.96605 .36353 Mdot
.9661 .36343 Mdot
.96614 .36334 Mdot
.96619 .36324 Mdot
.96624 .36315 Mdot
.96629 .36305 Mdot
.96633 .36296 Mdot
.96638 .36286 Mdot
.96643 .36277 Mdot
.96648 .36267 Mdot
.96652 .36258 Mdot
.96657 .36248 Mdot
.96662 .36239 Mdot
.96667 .36229 Mdot
.96672 .3622 Mdot
.96676 .3621 Mdot
.96681 .36201 Mdot
.96686 .36191 Mdot
.96691 .36181 Mdot
.96695 .36172 Mdot
.967 .36162 Mdot
.96705 .36153 Mdot
.9671 .36143 Mdot
.96714 .36134 Mdot
.96719 .36124 Mdot
.96724 .36114 Mdot
.96729 .36105 Mdot
.96733 .36095 Mdot
.96738 .36085 Mdot
.96743 .36076 Mdot
.96748 .36066 Mdot
.96752 .36057 Mdot
.96757 .36047 Mdot
.96762 .36037 Mdot
.96767 .36028 Mdot
.96772 .36018 Mdot
.96776 .36008 Mdot
.96781 .35999 Mdot
.96786 .35989 Mdot
.96791 .35979 Mdot
.96795 .35969 Mdot
.968 .3596 Mdot
.96805 .3595 Mdot
.9681 .3594 Mdot
.96814 .35931 Mdot
.96819 .35921 Mdot
.96824 .35911 Mdot
.96829 .35901 Mdot
.96833 .35892 Mdot
.96838 .35882 Mdot
.96843 .35872 Mdot
.96848 .35862 Mdot
.96852 .35852 Mdot
.96857 .35843 Mdot
.96862 .35833 Mdot
.96867 .35823 Mdot
.96872 .35813 Mdot
.96876 .35803 Mdot
.96881 .35794 Mdot
.96886 .35784 Mdot
.96891 .35774 Mdot
.96895 .35764 Mdot
.969 .35754 Mdot
.96905 .35744 Mdot
.9691 .35735 Mdot
.96914 .35725 Mdot
.96919 .35715 Mdot
.96924 .35705 Mdot
.96929 .35695 Mdot
.96933 .35685 Mdot
.96938 .35675 Mdot
.96943 .35665 Mdot
.96948 .35656 Mdot
.96952 .35646 Mdot
.96957 .35636 Mdot
.96962 .35626 Mdot
.96967 .35616 Mdot
.96971 .35606 Mdot
.96976 .35596 Mdot
.96981 .35586 Mdot
.96986 .35576 Mdot
.96991 .35566 Mdot
.96995 .35556 Mdot
.97 .35546 Mdot
.97005 .35536 Mdot
.9701 .35526 Mdot
.97014 .35516 Mdot
.97019 .35506 Mdot
.97024 .35496 Mdot
.97029 .35486 Mdot
.97033 .35476 Mdot
.97038 .35466 Mdot
.97043 .35456 Mdot
.97048 .35446 Mdot
.97052 .35436 Mdot
.97057 .35426 Mdot
.97062 .35416 Mdot
.97067 .35406 Mdot
.97071 .35396 Mdot
.97076 .35386 Mdot
.97081 .35376 Mdot
.97086 .35366 Mdot
.97091 .35356 Mdot
.97095 .35346 Mdot
.971 .35335 Mdot
.97105 .35325 Mdot
.9711 .35315 Mdot
.97114 .35305 Mdot
.97119 .35295 Mdot
.97124 .35285 Mdot
.97129 .35275 Mdot
.97133 .35265 Mdot
.97138 .35255 Mdot
.97143 .35244 Mdot
.97148 .35234 Mdot
.97152 .35224 Mdot
.97157 .35214 Mdot
.97162 .35204 Mdot
.97167 .35194 Mdot
.97171 .35183 Mdot
.97176 .35173 Mdot
.97181 .35163 Mdot
.97186 .35153 Mdot
.97191 .35143 Mdot
.97195 .35132 Mdot
.972 .35122 Mdot
.97205 .35112 Mdot
.9721 .35102 Mdot
.97214 .35092 Mdot
.97219 .35081 Mdot
.97224 .35071 Mdot
.97229 .35061 Mdot
.97233 .35051 Mdot
.97238 .3504 Mdot
.97243 .3503 Mdot
.97248 .3502 Mdot
.97252 .35009 Mdot
.97257 .34999 Mdot
.97262 .34989 Mdot
.97267 .34979 Mdot
.97271 .34968 Mdot
.97276 .34958 Mdot
.97281 .34948 Mdot
.97286 .34937 Mdot
.97291 .34927 Mdot
.97295 .34917 Mdot
.973 .34906 Mdot
.97305 .34896 Mdot
.9731 .34886 Mdot
.97314 .34875 Mdot
.97319 .34865 Mdot
.97324 .34855 Mdot
.97329 .34844 Mdot
.97333 .34834 Mdot
.97338 .34824 Mdot
.97343 .34813 Mdot
.97348 .34803 Mdot
.97352 .34793 Mdot
.97357 .34782 Mdot
.97362 .34772 Mdot
.97367 .34761 Mdot
.97371 .34751 Mdot
.97376 .34741 Mdot
.97381 .3473 Mdot
.97386 .3472 Mdot
.9739 .34709 Mdot
.97395 .34699 Mdot
.974 .34688 Mdot
.97405 .34678 Mdot
.9741 .34668 Mdot
.97414 .34657 Mdot
.97419 .34647 Mdot
.97424 .34636 Mdot
.97429 .34626 Mdot
.97433 .34615 Mdot
.97438 .34605 Mdot
.97443 .34594 Mdot
.97448 .34584 Mdot
.97452 .34573 Mdot
.97457 .34563 Mdot
.97462 .34552 Mdot
.97467 .34542 Mdot
.97471 .34531 Mdot
.97476 .34521 Mdot
.97481 .3451 Mdot
.97486 .345 Mdot
.9749 .34489 Mdot
.97495 .34479 Mdot
.975 .34468 Mdot
.97505 .34458 Mdot
.9751 .34447 Mdot
.97514 .34437 Mdot
.97519 .34426 Mdot
.97524 .34415 Mdot
.97529 .34405 Mdot
.97533 .34394 Mdot
.97538 .34384 Mdot
.97543 .34373 Mdot
.97548 .34363 Mdot
.97552 .34352 Mdot
.97557 .34341 Mdot
.97562 .34331 Mdot
.97567 .3432 Mdot
.97571 .3431 Mdot
.97576 .34299 Mdot
.97581 .34288 Mdot
.97586 .34278 Mdot
.9759 .34267 Mdot
.97595 .34257 Mdot
.976 .34246 Mdot
.97605 .34235 Mdot
.9761 .34225 Mdot
.97614 .34214 Mdot
.97619 .34203 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oo
oo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX0
0?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]Zoooo
nfY2oookJP00oooonf[ooookJT;ooo]Z000hoookJPGo0000oooonf[ooookJPGooo]Z000hoookJPGo
0000oooonf[ooookJPGooo]Z000hoookJPGo0000oooonf[ooookJPGooo]Z000hoookJPGo0000oooo
nf[ooookJPGooo]Z000hoookJPGo0000oooonf[ooookJPGooo]Z000hoookJPGo0000oooonf[ooook
JPGooo]Z000hoookJPGo0000oooonf[ooookJPGooo]Z000hoookJPGo0000oooonf[ooookJPGooo]Z
000hoookJPGo0000B?oonfX5o`000?oooo]Z]ooonfX003Sooo]Z1Ol00016oookJPWo0000oooonfZe
oookJP00>?oonfX5o`0004Gooo]Z2ol0003ooookJ[Cooo]Z000hoookJPGo0000A?oonfX=o`000?oo
oo]Z/ooonfX003Sooo]Z1Ol00013oookJPOo000000?ooo]Zo`000?l000001Ol0003ooookJ[;ooo]Z
000hoookJPGo0000@_oonfX6o`0000Gooo]Z1_l0003ooookJ[7ooo]Z000hoookJPGo0000@_oonfX5
o`0000Oooo]Z1Ol0003ooookJ[7ooo]Z000hoookJPGo0000@OoonfX5o`0000Wooo]Z1Ol0003ooook
J[3ooo]Z000hoookJPGo0000@OoonfX5o`0000Wooo]Z1Ol0003ooookJ[3ooo]Z000hoookJPGo0000
@?oonfX5o`0000_ooo]Z1Ol0003ooookJZoooo]Z000hoookJPGo0000@?oonfX4o`0000cooo]Z1Ol0
003ooookJZoooo]Z000hoookJPGo0000?ooonfX5o`0000gooo]Z1Ol0003ooookJZkooo]Z000hoook
JPGo0000?ooonfX4o`0000kooo]Z1Ol0003ooookJZkooo]Z000hoookJPGo0000?_oonfX5o`0000oo
oo]Z1Ol0003ooookJZgooo]Z000hoookJPGo0000?_oonfX5o`0000oooo]Z1Ol0003ooookJZgooo]Z
000AoookJPGo001o1?oonfX3o`00O`?ooo]Z0ol007l7oookJPGo001o2OoonfX5o`0003gooo]Z1Ol0
000AoookJPGo0000oooonfZ/oookJP004?oonfX7o`00O`?ooo]Z0ol007l3oookJP?o001o1_oonfX7
o`00O`Sooo]Z1Ol0000moookJPGo00004OoonfX5o`000?oooo]Z[?oonfX0013ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o0ooonfX3o`00O`Gooo]Z1?l007l01?oonf[o001oo`00Ool0
07l8oookJPGo0000?OoonfX4o`0001?ooo]Z1?l0003ooookJZcooo]Z0003oookJP[o001o0_oonfX3
o`00O`?ooo]Z0ol007l9oookJP;o001o1OoonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000??oonfX5
o`0001?ooo]Z1Ol0003ooookJZ_ooo]Z0003oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l9oook
JP?o001o2_oonfX3o`00O`Oooo]Z1_l0000koookJPGo00004ooonfX5o`000?oooo]ZZooonfX000oo
oo]Z0ol007l3oookJP?o001o2OoonfX3o`00O`[ooo]Z0ol007l7oookJPGo0000??oonfX4o`0001Go
oo]Z1Ol0003ooookJZ[ooo]Z000?oookJP?o001o0ooonfX3o`00O`[ooo]Z0_l007l5oookJP;o001o
0_oonfX4o`00O`Oooo]Z1Ol0000koookJPGo00005OoonfX5o`000?oooo]ZZ_oonfX000oooo]Z0ol0
07l3oookJP?o001o2_oonfX3o`00O`Cooo]Z1ol007l8oookJPGo0000>ooonfX4o`0001Oooo]Z1?l0
003ooookJZ[ooo]Z000?oookJP?o001o0ooonfX3o`00O`_ooo]Z0_l007l4oookJPKo001o2OoonfX5
o`0003_ooo]Z1?l0000GoookJPGo0000oooonfZYoookJP003ooonfX3o`00O`?ooo]Z0ol007l<oook
JP;o001o0ooonfX2o`00O`gooo]Z1Ol0000joookJPGo00005ooonfX5o`000?oooo]ZZOoonfX0013o
oo]Z0ol007l01?oonf[o001oo`00Ool007l=oookJP;o001o0ooonfX2o`00O`gooo]Z1Ol0000joook
JPGo00006?oonfX4o`000?oooo]ZZOoonfX0013ooo]Z1ol007l7oookJPWo001o0ooonfX7o`00O`Oo
oo]Z1Ol0000joookJPCo00006OoonfX5o`000?oooo]ZZ?oonfX0017ooo]Z1Ol007l8oookJPWo001o
0ooonfX7o`00O`Oooo]Z1Ol0000ioookJPGo00006OoonfX5o`000?oooo]ZZ?oonfX003Sooo]Z1Ol0
000ioookJPGo00006_oonfX4o`000?oooo]ZZ?oonfX003Sooo]Z1Ol0000ioookJPCo00006ooonfX4
o`000?oooo]ZZ?oonfX003Sooo]Z1Ol0000hoookJPGo00006ooonfX5o`000?oooo]ZYooonfX003So
oo]Z1Ol0000hoookJPGo00006ooonfX5o`000?oooo]ZYooonfX003Sooo]Z1Ol0000hoookJPCo0000
7OoonfX4o`000?oooo]ZYooonfX003Sooo]Z1Ol0000hoookJPCo00007OoonfX5o`000?oooo]ZY_oo
nfX003Sooo]Z1Ol0000goookJPGo00007OoonfX5o`000?oooo]ZY_oonfX003Sooo]Z1Ol0000goook
JPGo00007_oonfX4o`000?oooo]ZY_oonfX003Sooo]Z1Ol0000goookJPCo00007ooonfX4o`000?oo
oo]ZY_oonfX003Sooo]Z1Ol0000goookJPCo00007ooonfX5o`000?oooo]ZYOoonfX003Sooo]Z1Ol0
000foookJPGo00007ooonfX5o`00087ooo]Z2Ol0003ooookJQ_ooo]Z000hoookJPGo0000=_oonfX5
o`00023ooo]Z1?l00020oookJP_o0000oooonfXJoookJP00>?oonfX5o`0003Kooo]Z1?l0000Qoook
JPCo0000OooonfX=o`000?oooo]Z6OoonfX003Sooo]Z1Ol0000foookJPCo00008OoonfX5o`0007go
oo]Z3ol0003ooookJQSooo]Z000hoookJPGo0000=OoonfX5o`0002;ooo]Z1?l0001loookJPKo0000
1OoonfX6o`000?oooo]Z5ooonfX003Sooo]Z1Ol0000eoookJPGo00008_oonfX4o`0007_ooo]Z1_l0
0007oookJPKo0000oooonfXFoookJP00>?oonfX5o`0003Gooo]Z1?l0000SoookJPCo0000N_oonfX6
o`0000Wooo]Z1_l0003ooookJQGooo]Z000hoookJPGo0000=OoonfX4o`0002?ooo]Z1Ol0001hoook
JPKo00002ooonfX6o`000?oooo]Z5?oonfX003Sooo]Z1Ol0000doookJPGo00009?oonfX4o`0007So
oo]Z1Ol0000=oookJPGo0000oooonfXDoookJP00>?oonfX5o`0003Cooo]Z1Ol0000ToookJPCo0000
MooonfX5o`0000oooo]Z1Ol0003ooookJQ?ooo]Z000hoookJPGo0000=?oonfX4o`0002Gooo]Z1?l0
001goookJPGo00003ooonfX5o`000?oooo]Z4ooonfX003Sooo]Z1Ol0000doookJPCo00009OoonfX5
o`0007Gooo]Z1Ol0000AoookJPGo0000oooonfXBoookJP00>?oonfX5o`0003Cooo]Z1?l0000Uoook
JPGo0000MOoonfX5o`00017ooo]Z1Ol0003ooookJQ;ooo]Z000hoookJPGo0000<ooonfX5o`0002Ko
oo]Z1?l0001doookJPGo00004ooonfX5o`000?oooo]Z4OoonfX003Sooo]Z1Ol0000coookJPCo0000
9ooonfX4o`0007Cooo]Z1Ol0000CoookJPGo0000oooonfXAoookJP00>?oonfX5o`0003?ooo]Z1?l0
000WoookJPGo0000L_oonfX5o`0001Gooo]Z1Ol0003ooookJQ3ooo]Z000hoookJPGo0000<ooonfX4
o`0002Oooo]Z1Ol0001boookJPGo00005OoonfX5o`000?oooo]Z4?oonfX003Sooo]Z1Ol0000boook
JPGo0000:?oonfX4o`00077ooo]Z1Ol0000GoookJPGo0000oooonfX?oookJP006ooonfX5o`00O`Co
oo]Z0ol007l3oookJPGo001o2OoonfX5o`0003;ooo]Z1Ol0000XoookJPCo0000LOoonfX5o`0001Oo
oo]Z1Ol0003ooookJPoooo]Z000JoookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l8oookJPGo0000
<_oonfX4o`0002Wooo]Z1Ol0001_oookJPGo00006OoonfX5o`000?oooo]Z3_oonfX001[ooo]Z0ol0
07l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001o
o`00Ool007l8oookJPGo0000<_oonfX4o`0002Wooo]Z1Ol0001_oookJPGo00006OoonfX5o`000?oo
oo]Z3_oonfX000gooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0003;ooo]Z1?l0000ZoookJPCo0000KooonfX4o`0001_ooo]Z1Ol0003ooookJPgooo]Z
000=oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX6o`00033ooo]Z1Ol0
000ZoookJPCo0000K_oonfX5o`0001_ooo]Z1Ol0003ooookJPgooo]Z000IoookJP?o001o0ooonfX3
o`00O`cooo]Z0ol007l7oookJPGo0000<OoonfX5o`0002[ooo]Z1?l0001^oookJPGo00007?oonfX4
o`000?oooo]Z3OoonfX001Wooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007l7oook
JPGo0000<OoonfX4o`0002_ooo]Z1Ol0001]oookJPCo00007OoonfX5o`000?oooo]Z3?oonfX001Wo
oo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`Sooo]Z1Ol0000aoookJPCo0000:ooonfX5o`0006co
oo]Z1Ol0000MoookJPGo0000oooonfX<oookJP006OoonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o
2OoonfX5o`00037ooo]Z1?l0000/oookJPCo0000K?oonfX5o`0001kooo]Z1?l0003ooookJPcooo]Z
000IoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l=oookJPGo0000<?oonfX5o`0002cooo]Z1?l0
001[oookJPGo00007ooonfX5o`00087ooo]Z2?l00021oookJP006_oonfX3o`00O`04oookJ_l007oo
001oo`00O`Sooo]Z0_l007l=oookJPGo0000<?oonfX5o`0002cooo]Z1Ol0001ZoookJPGo00007ooo
nfX5o`0007oooo]Z3?l0001ooookJP006_oonfX7o`00O`Wooo]Z1ol007l7oookJPGo0000<?oonfX4
o`0002gooo]Z1Ol0001ZoookJPCo00008OoonfX5o`0007gooo]Z3ol0001moookJP006ooonfX5o`00
O`[ooo]Z1ol007l7oookJPGo0000<?oonfX4o`0002kooo]Z1?l0001YoookJPGo00008OoonfX5o`00
07cooo]Z4Ol0001loookJP00>?oonfX5o`00033ooo]Z1?l0000^oookJPCo0000JOoonfX5o`0002;o
oo]Z1?l0001koookJPOo00001OoonfX7o`0007_ooo]Z000hoookJPGo0000;ooonfX5o`0002kooo]Z
1?l0001YoookJPCo00008ooonfX5o`0007Wooo]Z1_l00009oookJPKo0000N_oonfX003Sooo]Z1Ol0
000_oookJPGo0000;_oonfX5o`0006Oooo]Z1Ol0000SoookJPGo0000N?oonfX6o`0000_ooo]Z1_l0
001ioookJP00>?oonfX5o`0002oooo]Z1?l0000_oookJPGo0000IooonfX5o`0002Cooo]Z1?l0001g
oookJPKo00003OoonfX6o`0007Sooo]Z000hoookJPGo0000;ooonfX4o`00033ooo]Z1?l0001Woook
JPCo00009OoonfX5o`0007Gooo]Z1_l0000?oookJPKo0000MooonfX003Sooo]Z1Ol0000_oookJPCo
0000<?oonfX4o`0006Oooo]Z1?l0000UoookJPGo0000MOoonfX5o`00017ooo]Z1Ol0001goookJP00
>?oonfX5o`0002kooo]Z1Ol0000`oookJPCo0000I_oonfX5o`0002Kooo]Z1?l0001doookJPGo0000
4ooonfX5o`0007Kooo]Z000hoookJPGo0000;_oonfX5o`00033ooo]Z1Ol0001UoookJPGo00009_oo
nfX5o`0007;ooo]Z1_l0000CoookJPKo0000MOoonfX003Sooo]Z1Ol0000^oookJPCo0000<OoonfX5
o`0006Gooo]Z1?l0000WoookJPGo0000L_oonfX5o`0001Gooo]Z1Ol0001eoookJP00>?oonfX5o`00
02kooo]Z1?l0000boookJPCo0000I?oonfX5o`0002Sooo]Z1?l0001aoookJPGo00005ooonfX5o`00
07Cooo]Z000hoookJPGo0000;_oonfX4o`0003;ooo]Z1?l0001ToookJPGo0000:?oonfX4o`00077o
oo]Z1Ol0000GoookJPKo0000LooonfX003Sooo]Z1Ol0000]oookJPGo0000<_oonfX4o`0006Cooo]Z
1?l0000YoookJPGo0000KooonfX5o`0001Wooo]Z1Ol0001coookJP00>?oonfX5o`0002gooo]Z1Ol0
000boookJPGo0000HooonfX4o`0002[ooo]Z1?l0001_oookJPGo00006_oonfX5o`0007;ooo]Z000h
oookJPGo0000;OoonfX4o`0003Cooo]Z1?l0001RoookJPGo0000:_oonfX4o`0006kooo]Z1Ol0000K
oookJPGo0000L_oonfX003Sooo]Z1Ol0000]oookJPCo0000=?oonfX4o`0006;ooo]Z1?l0000[oook
JPGo0000K?oonfX6o`0001cooo]Z1Ol0001aoookJP00>?oonfX5o`0002gooo]Z1?l0000doookJPCo
0000H_oonfX4o`0002_ooo]Z1Ol0001/oookJPGo00007OoonfX5o`00077ooo]Z000hoookJPGo0000
;OoonfX4o`0003Cooo]Z1?l0001QoookJPGo0000;?oonfX4o`0006cooo]Z1?l0000OoookJPGo0000
L?oonfX003Sooo]Z1Ol0000/oookJPGo0000=?oonfX5o`00063ooo]Z1Ol0000/oookJPGo0000J_oo
nfX5o`0001oooo]Z1Ol0001`oookJP00>?oonfX5o`0002cooo]Z1Ol0000eoookJPCo0000H?oonfX4
o`0002gooo]Z1Ol0001ZoookJPGo00008?oonfX5o`0006oooo]Z000hoookJPGo0000;?oonfX4o`00
03Kooo]Z1?l0001PoookJPCo0000;_oonfX4o`0006Wooo]Z1Ol0000QoookJPGo0000KooonfX003So
oo]Z1Ol0000/oookJPCo0000=_oonfX4o`0005oooo]Z1Ol0000^oookJPCo0000JOoonfX5o`0002;o
oo]Z1Ol0001^oookJP00>?oonfX5o`0002cooo]Z1?l0000foookJPCo0000GooonfX5o`0002kooo]Z
1Ol0001WoookJPGo00008ooonfX5o`0006kooo]Z000hoookJPGo0000:ooonfX5o`0003Kooo]Z1Ol0
001NoookJPCo0000;ooonfX5o`0006Oooo]Z1Ol0000ToookJPGo0000KOoonfX003Sooo]Z1Ol0000[
oookJPGo0000=ooonfX4o`0005kooo]Z1?l0000`oookJPCo0000I_oonfX5o`0002Gooo]Z1Ol0001]
oookJP00>?oonfX5o`0002_ooo]Z1?l0000hoookJPCo0000GOoonfX5o`00033ooo]Z1Ol0001Uoook
JPGo00009_oonfX4o`0006gooo]Z000hoookJPGo0000:ooonfX4o`0003Sooo]Z1?l0001MoookJPCo
0000<OoonfX5o`0006Gooo]Z1?l0000WoookJPGo0000K?oonfX003Sooo]Z1Ol0000[oookJPCo0000
>?oonfX4o`0005gooo]Z1?l0000boookJPCo0000I?oonfX5o`0002Oooo]Z1Ol0001/oookJP00>?oo
nfX5o`0002_ooo]Z1?l0000hoookJPGo0000FooonfX5o`0003;ooo]Z1?l0001ToookJPGo0000:?oo
nfX5o`0006_ooo]Z000AoookJPGo001o1?oonfX3o`00O`03oookJ_l007oo001o00Oo001o0ooonfX5
o`00O`Wooo]Z1Ol0000ZoookJPGo0000>OoonfX4o`0005_ooo]Z1Ol0000boookJPGo0000H_oonfX5
o`0002Wooo]Z1Ol0001[oookJP004?oonfX7o`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`07o`00
O`;ooo]Z1ol007l8oookJPGo0000:_oonfX5o`0003Wooo]Z1?l0001KoookJPCo0000<ooonfX5o`00
06;ooo]Z1Ol0000ZoookJPGo0000J_oonfX0013ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l6oookJPCo001o00Cooo]Zo`00Ool007oo001o2?oonfX5
o`0002[ooo]Z1?l0000joookJPCo0000FooonfX4o`0003Cooo]Z1?l0001RoookJPCo0000:ooonfX5
o`0006[ooo]Z0003oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l7oookJPCo001o1OoonfX3o`00
O`?ooo]Z0ol007l7oookJPGo0000:_oonfX4o`0003[ooo]Z1?l0001JoookJPGo0000=?oonfX5o`00
063ooo]Z1Ol0000/oookJPCo0000J_oonfX000?ooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`So
oo]Z1Ol007l9oookJP?o001o1ooonfX6o`0002Wooo]Z1?l0000joookJPGo0000FOoonfX5o`0003Co
oo]Z1Ol0001PoookJPGo0000;?oonfX5o`0006Wooo]Z000?oookJP?o001o0ooonfX3o`00O`[ooo]Z
1?l007l8oookJP?o001o1ooonfX5o`0002[ooo]Z1?l0000joookJPGo0000FOoonfX4o`0003Kooo]Z
1?l0001PoookJPCo0000;OoonfX5o`0006Wooo]Z000?oookJP?o001o0ooonfX3o`00O`_ooo]Z0ol0
07l3oookJP;o001o0_oonfX4o`00O`Oooo]Z1Ol0000YoookJPGo0000>ooonfX4o`0005Wooo]Z1?l0
000foookJPCo0000GooonfX5o`0002kooo]Z1Ol0001XoookJP003ooonfX3o`00O`?ooo]Z0ol007l<
oookJP?o001o0_oonfX7o`00O`Sooo]Z1Ol0000YoookJPCo0000??oonfX4o`0005Sooo]Z1Ol0000f
oookJPGo0000G_oonfX5o`0002kooo]Z1Ol0001XoookJP003ooonfX3o`00O`?ooo]Z0ol007l6oook
JP?o001o0ooonfX3o`00O`;ooo]Z1_l007l9oookJPGo0000:OoonfX4o`0003cooo]Z1?l0001Hoook
JPGo0000=_oonfX5o`0005gooo]Z1Ol0000`oookJPCo0000J?oonfX000oooo]Z0ol007l3oookJP?o
001o1_oonfX3o`00O`?ooo]Z0ol007l2oookJP;o001o3OoonfX5o`0002Wooo]Z1?l0000loookJPGo
0000EooonfX4o`0003Sooo]Z1?l0001MoookJPGo0000<?oonfX5o`0006Oooo]Z000@oookJP?o001o
00Cooo]Zo`00Ool007oo001o1ooonfX4o`00O`;ooo]Z0ol007l2oookJP;o001o3OoonfX5o`0002Wo
oo]Z1?l0000loookJPGo0000EooonfX4o`0003Sooo]Z1?l0001MoookJPCo0000<OoonfX5o`0006Oo
oo]Z000@oookJPOo001o2?oonfX7o`00O`Cooo]Z1ol007l7oookJPGo0000:?oonfX5o`0003gooo]Z
1?l0001GoookJPCo0000>?oonfX5o`0005_ooo]Z1Ol0000boookJPGo0000I_oonfX0017ooo]Z1Ol0
07l:oookJPGo001o1OoonfX7o`00O`Oooo]Z1Ol0000XoookJPGo0000?OoonfX4o`0005Kooo]Z1Ol0
000hoookJPGo0000FooonfX5o`0003;ooo]Z1Ol0001VoookJP00>?oonfX5o`0002Sooo]Z1?l0000n
oookJPCo0000E_oonfX5o`0003Wooo]Z1?l0001KoookJPCo0000=?oonfX4o`0006Kooo]Z000hoook
JPGo0000:?oonfX4o`0003kooo]Z1Ol0001EoookJPCo0000>_oonfX5o`0005Wooo]Z1Ol0000doook
JPGo0000IOoonfX003Sooo]Z1Ol0000XoookJPCo0000?_oonfX5o`0005Gooo]Z1?l0000joookJPGo
0000FOoonfX5o`0003Cooo]Z1Ol0001UoookJP00>?oonfX5o`0002Sooo]Z1?l0000ooookJPCo0000
E?oonfX5o`0003_ooo]Z1?l0001IoookJPCo0000=_oonfX4o`0006Gooo]Z000hoookJPGo00009ooo
nfX5o`0003oooo]Z1?l0001DoookJPGo0000>ooonfX4o`0005Sooo]Z1Ol0000foookJPGo0000I?oo
nfX003Sooo]Z1Ol0000WoookJPGo0000?ooonfX4o`0005Cooo]Z1?l0000loookJPGo0000EooonfX5
o`0003Kooo]Z1Ol0001ToookJP00>?oonfX5o`0002Oooo]Z1?l00010oookJPGo0000DooonfX4o`00
03cooo]Z1Ol0001GoookJPCo0000>?oonfX5o`0006?ooo]Z000hoookJPGo00009ooonfX4o`00043o
oo]Z1Ol0001BoookJPGo0000?OoonfX4o`0005Kooo]Z1Ol0000hoookJPGo0000HooonfX003Sooo]Z
1Ol0000WoookJPCo0000@OoonfX4o`0005;ooo]Z1Ol0000moookJPCo0000E_oonfX5o`0003Wooo]Z
1?l0001SoookJP00>?oonfX5o`0002Oooo]Z1?l00011oookJPCo0000D_oonfX4o`0003kooo]Z1Ol0
001EoookJPCo0000>_oonfX5o`0006;ooo]Z000hoookJPGo00009_oonfX5o`00047ooo]Z1?l0001B
oookJPCo0000?_oonfX5o`0005Cooo]Z1Ol0000joookJPGo0000H_oonfX003Sooo]Z1Ol0000Voook
JPGo0000>_oonfX5o`00O`;ooo]Z1?l00004o`00O`Gooo]Z1Ol007l5oookJPGo001o>OoonfX5o`00
01Oooo]Z0ol007l5oookJPGo001o1OoonfX5o`00O`Gooo]Z1Ol007l5oookJP;o001o1?l0001>oook
JP?o001o0ooonfX5o`0000;o001o1OoonfX5o`00O`Gooo]Z1Ol007l5oookJPGo001o6ooonfX4o`00
02cooo]Z2Ol007l3oookJPGo001o1OoonfX5o`00O`Gooo]Z1Ol007l5oookJPGo001o1ooonfX003So
oo]Z1Ol0000VoookJPCo0000>_oonfX7o`00O`03oookJ_l0003o000000?o00001?l007l3oookJPOo
001o0ooonfX7o`00OcSooo]Z1Ol0000GoookJP?o001o1?oonfX7o`00O`?ooo]Z1ol007l3oookJPOo
001o0ooonfX3o`00O`Co0000C_oonfX3o`00O`?ooo]Z1?l00004o`00O`?ooo]Z1ol007l3oookJPOo
001o0ooonfX7o`00Oa[ooo]Z1Ol0000[oookJPWo001o0_oonfX7o`00O`?ooo]Z1ol007l3oookJPOo
001o0ooonfX7o`00O`Kooo]Z000hoookJPGo00009_oonfX4o`0003Wooo]Z1?l007l01Ooonf[o001o
o`00Ool007oooo]Z00Go000000Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001o
o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007lhoookJPCo00006?oonfX3o`00O`Cooo]Z0ol0
07l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04
oookJ_l007oo001oo`00O`?ooo]Z0ol007l5o`0004gooo]Z0ol007l2oookJPGo000000Cooo]Zo`00
Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00
Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o6_oonfX5o`0002_ooo]Z1?l007l7oookJP?o
001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l0
1?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o1_oonfX003Sooo]Z1Ol0
000VoookJPCo0000>OoonfX3o`00O`?ooo]Z0ol007l00ooonf[o0000o`000002o`0000;ooo]Z0ol0
07l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00OcOo
oo]Z1?l0000HoookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`05oookJ_l007oo001oo`00OooonfX01Ol0
001=oookJP?o001o0_oonfX5o`0000;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o
00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007lJoook
JPCo0000;?oonfX4o`00O`Gooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3
o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o
1OoonfX003Sooo]Z1Ol0000VoookJPCo0000?ooonfX3o`00O`03oookJ_l0003o000000;o00000_oo
nfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o
001o=ooonfX4o`0001Sooo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00
O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0_oo
nfX4o`0004gooo]Z0ol007l2oookJPCo00000ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z
0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00
Oa[ooo]Z1Ol0000/oookJPGo001o0ooonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3
oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z
0ol007l5oookJP00>?oonfX5o`0002Gooo]Z1Ol0000ooookJP?o001o00?ooo]Zo`000?l000000_l0
0002oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?o
oo]Z0ol007lfoookJPGo00006?oonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool0
07oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool0
07l2oookJPCo0000COoonfX3o`00O`;ooo]Z1?l00003oookJP?o001o00Cooo]Zo`00Ool007oo001o
0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o6_oonfX5o`0002kooo]Z1?l007l2oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001o
o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o
0ooonfX3o`00O`Gooo]Z000hoookJPGo00009OoonfX5o`0003[ooo]Z0_l007l2oookJPCo001o00?o
oo]Zo`000?l000000ol000001Ooonf[o001oo`00Ool007oooo]Z00?o001o0ooonfX3o`00O`04oook
J_l007oo001oo`00O`?ooo]Z0ol007lfoookJPGo00006?oonfX3o`00O`?ooo]Z0ol007l3oookJP?o
001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l0
1?oonf[o001oo`00Ool007l2oookJPGo0000C?oonfX3o`00O`03oookJ_l0003o000000?o00000_oo
nfX4o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o
001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00Oa_ooo]Z1?l0000_oookJP?o001o0_oonfX3o`00
O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l5oookJP00>?oonfX5o`0002Gooo]Z1?l0
000koookJPOo001o0_oonfX5o`000005oookJ_l007oo001oo`00OooonfX00ol007l3oookJP?o001o
00Cooo]Zo`00Ool007oo001o0ooonfX3o`00OcKooo]Z1?l0000IoookJP?o001o0ooonfX3o`00O`?o
oo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3
o`00O`04oookJ_l007oo001oo`00O`;ooo]Z1Ol0001<oookJP?o001o00?ooo]Zo`000?l000000ol0
0005o`00O`;ooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oook
J_l007oo001oo`00O`?ooo]Z0ol007lKoookJPGo0000;ooonfX3o`00O`04oookJ_l007oo001oo`00
O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l5oookJP00>?oonfX5o`0002Gooo]Z1?l0
000koookJPKo001o0ooonfX00ol007oo0000o`000002o`000005oookJ_l007oo001oo`00OooonfX0
0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00OcKooo]Z1?l0000IoookJP?o
001o0ooonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00
Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z1?l0001<oookJP?o001o00?o
oo]Zo`000?l000000_l00005o`00O`?ooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o
0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007lKoookJPGo0000:OoonfX3o`00O`?o
oo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3
o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o
1OoonfX003Sooo]Z1Ol0000UoookJPCo0000>ooonfX2o`00O`Oooo]Z00?o001oo`000?l000000_l0
00001Ooonf[o001oo`00Ool007oooo]Z00?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?o
oo]Z0ol007leoookJPGo00005_oonfX6o`00O`?ooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool0
07oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool0
07l3oookJPCo0000BOoonfX6o`00O`Go000000?o001ooookJ_oonfX01OoonfX3o`00O`?ooo]Z0ol0
07l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00Oaco
oo]Z1?l0000YoookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l0
07oo001oo`00O`?ooo]Z0ol007l5oookJP00>?oonfX5o`0002Gooo]Z1?l0000koookJP;o001o2?oo
nfX4o`0000?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001o
o`00Ool007lfoookJPGo00005_oonfX6o`00O`Cooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol0
07l00ooonf[o001oo`000004o`0004Sooo]Z1_l007l5o`000003o`00Oooonf[ooo]Z00Kooo]Z0ol0
07l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04
oookJ_l007oo001oo`00Oagooo]Z1Ol0000XoookJPCo001o0_oonfX3o`00O`;ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l0
07oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l6oookJP00>?oonfX5o`0002Cooo]Z
1Ol0000loookJPOo001o0_oonfX5o`0000;o001o0ooonfX7o`00O`?ooo]Z1ol007lfoookJPCo0000
6OoonfX4o`00O`Cooo]Z1ol007l3oookJPOo001o0ooonfX7o`00O`?ooo]Z1Ol007l5o`0004[ooo]Z
1?l007l4o`000003oookJ_l007oo001o00Go001o0_oonfX7o`00O`?ooo]Z1ol007l3oookJPOo001o
7_oonfX4o`0002Wooo]Z1ol007l3oookJPOo001o0ooonfX7o`00O`?ooo]Z1ol007l3oookJPOo001o
1_oonfX003Sooo]Z1Ol0000ToookJPGo0000??oonfX7o`00O`;ooo]Z1Ol000000ol007oooo]Zoook
JP03oookJPGo001o1OoonfX5o`00OcOooo]Z1?l0000JoookJP?o001o1OoonfX5o`00O`Gooo]Z1Ol0
07l5oookJPGo001o1OoonfX5o`00O`Co0000BooonfX2o`00O`Go000000?ooo]Zo`00Ool007l01Ol0
07l3oookJPGo001o1OoonfX5o`00O`Gooo]Z1Ol007lOoookJPGo0000:OoonfX5o`00O`Gooo]Z1Ol0
07l5oookJPGo001o1OoonfX5o`00O`Gooo]Z1Ol007l7oookJP00>?oonfX5o`0002Cooo]Z1?l00017
oookJPCo0000C?oonfX4o`0004Gooo]Z1?l0001=oookJPGo0000@ooonfX5o`0005gooo]Z000hoook
JPGo00009?oonfX4o`0004Oooo]Z1?l0001;oookJPGo0000AOoonfX5o`0004cooo]Z1?l00015oook
JPCo0000GOoonfX003Sooo]Z1Ol0000ToookJPCo0000AooonfX4o`0004_ooo]Z1Ol00016oookJPCo
0000BooonfX5o`0004Gooo]Z1Ol0001LoookJP00>?oonfX5o`0002Cooo]Z1?l00017oookJPCo0000
BooonfX4o`0004Oooo]Z1?l0001;oookJPGo0000AOoonfX5o`0005cooo]Z000hoookJPGo00008ooo
nfX5o`0004Oooo]Z1Ol0001:oookJPCo0000AooonfX5o`0004[ooo]Z1?l00017oookJPCo0000G?oo
nfX002cooo]Zool0003oo`0000Wo00003OoonfX002cooo]Zool0003oo`0000Wo00003OoonfX002co
oo]Zool0003oo`0000Wo00003OoonfX002cooo]Zool0003oo`0000Wo00003OoonfX002cooo]Zool0
003oo`0000Wo00003OoonfX003Sooo]Z1Ol0000SoookJPCo0000BOoonfX5o`0000;ooo]Z00?o0000
oookJ_oonfX0@_oonfX5o`00037ooo]Z00?o0000oookJ_oonfX05_oonfX4o`0004Oooo]Z1Ol0000A
oookJP03o`000?oonf[ooo]Z03Kooo]Z1?l0000moookJP03o`000?oonf[ooo]Z01[ooo]Z000hoook
JPGo00008_oonfX5o`0004[ooo]Z1?l00017oookJPGo0000B_oonfX4o`0004Oooo]Z1?l0001;oook
JPGo0000FOoonfX003Sooo]Z1Ol0000RoookJPGo0000B_oonfX4o`0004Oooo]Z1?l0001;oookJPGo
0000AOoonfX5o`0004_ooo]Z1Ol0001IoookJP00>?oonfX5o`0002;ooo]Z1?l0001;oookJPCo0000
AooonfX4o`0004_ooo]Z1Ol00015oookJPGo0000C?oonfX5o`0005Sooo]Z000hoookJPGo00008_oo
nfX4o`0004_ooo]Z1Ol00015oookJPGo0000C?oonfX4o`0004Gooo]Z1?l0001=oookJPGo0000F?oo
nfX003Sooo]Z1Ol0000RoookJPCo0000BooonfX5o`0004Gooo]Z1Ol0001<oookJPCo0000AOoonfX4
o`0004kooo]Z1?l0001HoookJP00>?oonfX5o`0002;ooo]Z1?l0001<oookJPCo0000AOoonfX4o`00
04gooo]Z1Ol00013oookJPGo0000C_oonfX5o`0005Oooo]Z000hoookJPGo00008OoonfX5o`0004co
oo]Z1?l00015oookJPCo0000COoonfX5o`0004?ooo]Z1?l0001?oookJPGo0000EooonfX003Sooo]Z
1Ol0000QoookJPGo0000C?oonfX4o`0004Gooo]Z1?l0001>oookJPCo0000@ooonfX4o`00053ooo]Z
1?l0001GoookJP00>?oonfX5o`00027ooo]Z1?l0001=oookJPGo0000@ooonfX5o`0004kooo]Z1?l0
0012oookJPGo0000D?oonfX5o`0005Kooo]Z000hoookJPGo00008OoonfX4o`0004gooo]Z1Ol00013
oookJPGo0000C_oonfX5o`00047ooo]Z1Ol0001@oookJPGo0000E_oonfX003Sooo]Z1Ol0000Qoook
JPCo0000C_oonfX4o`0004?ooo]Z1?l0001?oookJPGo0000@OoonfX4o`0005;ooo]Z1?l0001Foook
JP00>?oonfX5o`00027ooo]Z1?l0001>oookJPCo0000@ooonfX4o`00053ooo]Z1?l00010oookJPGo
0000D_oonfX5o`0005Gooo]Z000hoookJPGo00008?oonfX5o`0004kooo]Z1?l00012oookJPGo0000
D?oonfX5o`0003oooo]Z1Ol0001BoookJPGo0000EOoonfX003Sooo]Z1Ol0000PoookJPGo0000C_oo
nfX5o`00047ooo]Z1Ol0001@oookJPGo0000?ooonfX4o`0005Cooo]Z1Ol0001DoookJP00>?oonfX5
o`00023ooo]Z1?l0001?oookJPGo0000@OoonfX4o`0005;ooo]Z1?l0000noookJPGo0000E?oonfX5
o`0005Cooo]Z000hoookJPGo00008?oonfX4o`00053ooo]Z1?l00011oookJPCo0000D_oonfX4o`00
03kooo]Z1Ol0001EoookJPCo0000E?oonfX003Sooo]Z1Ol0000PoookJPCo0000D?oonfX4o`00047o
oo]Z1?l0001BoookJPGo0000?OoonfX4o`0005Kooo]Z1Ol0001CoookJP00>?oonfX5o`00023ooo]Z
1?l0001@oookJPCo0000@?oonfX5o`0005;ooo]Z1Ol0000moookJPCo0000E_oonfX5o`0005?ooo]Z
000hoookJPGo00007ooonfX5o`00053ooo]Z1Ol0000ooookJPGo0000DooonfX4o`0003cooo]Z1Ol0
001GoookJPCo0000DooonfX003Sooo]Z1Ol0000OoookJPGo0000D?oonfX5o`0003oooo]Z1?l0001D
oookJPCo0000??oonfX5o`0005Oooo]Z1Ol0001BoookJP00>?oonfX5o`0001oooo]Z1?l0001Boook
JPCo0000?ooonfX4o`0005Cooo]Z1Ol0000koookJPCo0000F?oonfX5o`0005;ooo]Z000hoookJPGo
00007ooonfX4o`0005;ooo]Z1?l0000noookJPGo0000E?oonfX5o`0003[ooo]Z1Ol0001IoookJPGo
0000DOoonfX003Sooo]Z1Ol0000OoookJPCo0000D_oonfX4o`0003kooo]Z1Ol0001EoookJPCo0000
>_oonfX5o`0005Wooo]Z1Ol0001AoookJP00>?oonfX5o`0001oooo]Z1?l0001BoookJPCo0000?_oo
nfX4o`0005Kooo]Z1Ol0000ioookJPCo0000FooonfX4o`00057ooo]Z000hoookJPGo00007_oonfX5
o`0005;ooo]Z1Ol0000moookJPCo0000E_oonfX5o`0003Sooo]Z1Ol0001KoookJPGo0000<ooonfX2
o`0001_ooo]Z000hoookJPGo00007_oonfX5o`0005?ooo]Z1?l0000moookJPCo0000EooonfX4o`00
03Sooo]Z1Ol0001KoookJPGo0000<_oonfX4o`0001[ooo]Z000hoookJPGo00007_oonfX4o`0005Co
oo]Z1?l0000loookJPGo0000EooonfX4o`0003Sooo]Z1?l0001MoookJPGo0000<?oonfX5o`0001[o
oo]Z000hoookJPGo00007_oonfX4o`0005Cooo]Z1?l0000loookJPGo0000EooonfX5o`0003Kooo]Z
1Ol0001MoookJPGo0000<?oonfX5o`0001[ooo]Z000hoookJPGo00007_oonfX4o`0005Cooo]Z1?l0
000loookJPCo0000F?oonfX5o`0003Kooo]Z1Ol0001NoookJPGo0000;_oonfX5o`0001_ooo]Z000h
oookJPGo00007_oonfX4o`0005Cooo]Z1Ol0000koookJPCo0000FOoonfX4o`0003Kooo]Z1?l0001O
oookJPGo0000;_oonfX5o`0001_ooo]Z000hoookJPGo00007OoonfX5o`0005Gooo]Z1?l0000joook
JPGo0000FOoonfX5o`0003Gooo]Z1?l0001PoookJPCo0000;OoonfX5o`0001cooo]Z000hoookJPGo
00007OoonfX5o`0005Gooo]Z1?l0000joookJPGo0000FOoonfX5o`0003Cooo]Z1Ol0001PoookJPGo
0000;?oonfX5o`0001cooo]Z000hoookJPGo00007OoonfX4o`0005Kooo]Z1?l0000joookJPCo0000
FooonfX4o`0003Cooo]Z1?l0001QoookJPGo0000:ooonfX5o`0001gooo]Z000AoookJPGo001o1?oo
nfX3o`00O`03oookJ_l007oo001o00Oo001o0ooonfX5o`00O`Wooo]Z1Ol0000MoookJPCo0000E_oo
nfX5o`0003Wooo]Z1?l0001KoookJPCo0000=?oonfX4o`0006;ooo]Z1Ol0000ZoookJPGo00007Ooo
nfX0013ooo]Z1ol007l3oookJP?o001o00?ooo]Zo`00Ool007l01ol007l2oookJPOo001o2?oonfX5
o`0001gooo]Z1?l0001FoookJPGo0000>?oonfX5o`0005_ooo]Z1Ol0000boookJPGo0000H_oonfX5
o`0002Wooo]Z1Ol0000NoookJP004?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l0
0ooonf[o001oo`00O`02o`00O`Kooo]Z1?l007l01?oonf[o001oo`00Ool007l8oookJPGo00007Ooo
nfX4o`0005Oooo]Z1?l0000hoookJPGo0000FooonfX5o`0003;ooo]Z1Ol0001SoookJPGo0000:?oo
nfX5o`0001kooo]Z000?oookJP?o001o0ooonfX3o`00O`Oooo]Z1?l007l5oookJP?o001o0ooonfX3
o`00O`Oooo]Z1Ol0000MoookJPCo0000EooonfX4o`0003Sooo]Z1?l0001MoookJPCo0000<_oonfX4
o`0006Cooo]Z1Ol0000WoookJPGo00007ooonfX000oooo]Z0ol007l3oookJP?o001o2?oonfX5o`00
O`Wooo]Z0ol007l7oookJPKo00006ooonfX5o`0005Oooo]Z1?l0000hoookJPCo0000GOoonfX5o`00
033ooo]Z1Ol0001UoookJPGo00009_oonfX5o`0001oooo]Z000?oookJP?o001o0ooonfX3o`00O`[o
oo]Z1?l007l8oookJP?o001o1ooonfX5o`0001cooo]Z1?l0001HoookJPGo0000=ooonfX4o`0005go
oo]Z1Ol0000`oookJPGo0000IOoonfX5o`0002Gooo]Z1Ol0000PoookJP003ooonfX3o`00O`?ooo]Z
0ol007l;oookJP?o001o0ooonfX2o`00O`;ooo]Z1?l007l7oookJPGo00007?oonfX4o`0005Sooo]Z
1Ol0000foookJPGo0000G_oonfX4o`00033ooo]Z1?l0001WoookJPGo00009?oonfX5o`00023ooo]Z
000?oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l2oookJPOo001o2?oonfX5o`0001cooo]Z1?l0
001IoookJPCo0000=_oonfX5o`0005kooo]Z1Ol0000^oookJPGo0000IooonfX5o`0002?ooo]Z1Ol0
000QoookJP003ooonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`;ooo]Z1_l007l9
oookJPGo00007?oonfX4o`0005Wooo]Z1?l0000foookJPCo0000GooonfX5o`0002kooo]Z1Ol0001X
oookJPGo00008_oonfX5o`00027ooo]Z000?oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oook
JP?o001o0_oonfX2o`00O`gooo]Z1Ol0000LoookJPCo0000FOoonfX4o`0003Kooo]Z1?l0001Poook
JPCo0000;_oonfX4o`0006Wooo]Z1Ol0000QoookJPGo00008_oonfX0013ooo]Z0ol007l01?oonf[o
001oo`00Ool007l7oookJPCo001o0_oonfX3o`00O`;ooo]Z0_l007l=oookJPGo00006ooonfX5o`00
05Wooo]Z1Ol0000doookJPGo0000H?oonfX4o`0002gooo]Z1Ol0001ZoookJPGo00008?oonfX5o`00
02;ooo]Z000@oookJPOo001o2?oonfX7o`00O`Cooo]Z1ol007l7oookJPGo00006ooonfX5o`0005Wo
oo]Z1Ol0000doookJPGo0000H?oonfX5o`0002cooo]Z1Ol0001ZoookJPGo00007ooonfX5o`0002?o
oo]Z000AoookJPGo001o2_oonfX5o`00O`Gooo]Z1ol007l7oookJPGo00006ooonfX4o`0005_ooo]Z
1?l0000doookJPCo0000H_oonfX4o`0002_ooo]Z1Ol0001/oookJPGo00007OoonfX6o`0002?ooo]Z
000hoookJPGo00006ooonfX4o`0005_ooo]Z1?l0000doookJPCo0000H_oonfX4o`0002_ooo]Z1Ol0
001/oookJPGo00007OoonfX5o`0002Cooo]Z000hoookJPGo00006ooonfX4o`0005_ooo]Z1?l0000c
oookJPGo0000H_oonfX5o`0002[ooo]Z1?l0001^oookJPGo00006ooonfX5o`0002Gooo]Z000hoook
JPGo00006ooonfX4o`0005_ooo]Z1Ol0000boookJPGo0000HooonfX4o`0002Wooo]Z1Ol0001_oook
JPGo00006OoonfX6o`0002Gooo]Z000hoookJPGo00006_oonfX5o`0005_ooo]Z1Ol0000boookJPCo
0000I?oonfX4o`0002Wooo]Z1Ol0001_oookJPGo00006OoonfX5o`0002Kooo]Z000hoookJPGo0000
6_oonfX5o`0005cooo]Z1?l0000boookJPCo0000I?oonfX5o`0002Sooo]Z1?l0001aoookJPGo0000
5ooonfX5o`0002Oooo]Z000hoookJPGo00006_oonfX4o`0005gooo]Z1?l0000boookJPCo0000IOoo
nfX4o`0002Oooo]Z1Ol0001aoookJPKo00005OoonfX6o`0002Oooo]Z000hoookJPGo00006_oonfX4
o`0005gooo]Z1Ol0000`oookJPGo0000IOoonfX5o`0002Kooo]Z1Ol0001boookJPKo00004ooonfX6
o`0002Sooo]Z000hoookJPGo00006_oonfX4o`0005gooo]Z1Ol0000`oookJPGo0000IOoonfX5o`00
02Kooo]Z1?l0001doookJPKo00004OoonfX6o`0002Wooo]Z000hoookJPGo00006_oonfX4o`0005ko
oo]Z1?l0000`oookJPCo0000IooonfX4o`0002Gooo]Z1Ol0001eoookJPGo00004OoonfX5o`0002[o
oo]Z000hoookJPGo00006OoonfX5o`0005kooo]Z1?l0000`oookJPCo0000IooonfX5o`0002Cooo]Z
1Ol0001foookJPGo00003_oonfX6o`0002_ooo]Z000hoookJPGo00006OoonfX5o`0005kooo]Z1?l0
000_oookJPGo0000IooonfX5o`0002?ooo]Z1Ol0001goookJPOo00002ooonfX7o`0002_ooo]Z000h
oookJPGo00006OoonfX4o`0005oooo]Z1Ol0000^oookJPGo0000J?oonfX4o`0002?ooo]Z1Ol0001h
oookJPOo00002?oonfX8o`0002cooo]Z000hoookJPGo00006OoonfX4o`0005oooo]Z1Ol0000^oook
JPCo0000JOoonfX5o`0002;ooo]Z1?l0001joookJPWo00000ooonfX9o`0002gooo]Z000hoookJPGo
00006OoonfX4o`00063ooo]Z1?l0000^oookJPCo0000JOoonfX5o`00027ooo]Z1Ol0001loookJQ7o
0000;ooonfX003Sooo]Z1Ol0000IoookJPCo0000H?oonfX4o`0002gooo]Z1Ol0001ZoookJPGo0000
8?oonfX5o`0007gooo]Z3ol0000`oookJP00>?oonfX5o`0001Sooo]Z1Ol0001PoookJPGo0000;?oo
nfX5o`0006[ooo]Z1Ol0000OoookJPGo0000OooonfX<o`0003;ooo]Z000hoookJPGo00006?oonfX4
o`00067ooo]Z1Ol0000/oookJPCo0000K?oonfX4o`0001oooo]Z1Ol00022oookJPOo0000=?oonfX0
03Sooo]Z1Ol0000HoookJPCo0000H_oonfX4o`0002cooo]Z1?l0001/oookJPGo00007OoonfX5o`00
0;kooo]Z000hoookJPGo00006?oonfX4o`0006;ooo]Z1?l0000[oookJPGo0000K?oonfX5o`0001go
oo]Z1Ol0002noookJP00>?oonfX5o`0001Sooo]Z1?l0001RoookJPGo0000:_oonfX4o`0006kooo]Z
1Ol0000KoookJPGo0000_ooonfX003Sooo]Z1Ol0000GoookJPGo0000H_oonfX5o`0002[ooo]Z1?l0
001^oookJPGo00006ooonfX5o`000;oooo]Z000hoookJPGo00005ooonfX5o`0006?ooo]Z1?l0000Y
oookJPGo0000KooonfX5o`0001Wooo]Z1Ol00030oookJP00>?oonfX5o`0001Oooo]Z1?l0001Toook
JPCo0000:OoonfX5o`0006oooo]Z1Ol0000IoookJPGo0000`?oonfX003Sooo]Z1Ol0000GoookJPCo
0000I?oonfX5o`0002Sooo]Z1?l0001aoookJPGo00005ooonfX5o`000<7ooo]Z000hoookJPGo0000
5ooonfX4o`0006Cooo]Z1Ol0000XoookJPCo0000LOoonfX5o`0001Oooo]Z1Ol00031oookJP00>?oo
nfX5o`0001Oooo]Z1?l0001UoookJPCo00009ooonfX5o`0007;ooo]Z1Ol0000EoookJPGo0000`_oo
nfX003Sooo]Z1Ol0000FoookJPGo0000IOoonfX4o`0002Oooo]Z1Ol0001boookJPGo00005OoonfX5
o`000<;ooo]Z000hoookJPGo00005_oonfX5o`0006Gooo]Z1Ol0000VoookJPCo0000M?oonfX5o`00
01?ooo]Z1Ol00033oookJP006ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o2OoonfX5o`0001Ko
oo]Z1?l0001VoookJPGo00009_oonfX4o`0007Cooo]Z1Ol0000CoookJPGo0000`ooonfX001[ooo]Z
1ol007l3oookJP?o001o0_oonfX7o`00O`Sooo]Z1Ol0000FoookJPCo0000IooonfX4o`0002Gooo]Z
1Ol0001eoookJPGo00004OoonfX5o`000<Cooo]Z000JoookJP?o001o00Cooo]Zo`00Ool007oo001o
0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0001Ko
oo]Z1?l0001WoookJPCo00009OoonfX5o`0007Gooo]Z1_l0000?oookJPKo0000a?oonfX001Wooo]Z
0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7oookJPGo00005_oonfX4o`0006Oooo]Z
1Ol0000ToookJPCo0000MooonfX6o`0000gooo]Z1_l00035oookJP006OoonfX3o`00O`?ooo]Z0ol0
07l<oookJP?o001o1ooonfX6o`0001Cooo]Z1Ol0001WoookJPGo00008ooonfX5o`0007Sooo]Z1Ol0
000=oookJPGo0000a_oonfX001Wooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1Ol0000E
oookJPCo0000JOoonfX4o`0002?ooo]Z1Ol0001ioookJPGo00002ooonfX5o`000<Oooo]Z000Ioook
JP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o1ooonfX5o`0001Gooo]Z1?l0001Yoook
JPGo00008_oonfX4o`0007[ooo]Z1ol00007oookJPOo0000aooonfX001Wooo]Z0ol007l3oookJP?o
001o1ooonfX7o`00O`Sooo]Z1Ol0000EoookJPCo0000JOoonfX5o`0002;ooo]Z1?l0001koookJPOo
00001OoonfX7o`000<Sooo]Z000IoookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l9oookJPGo0000
5OoonfX4o`0006[ooo]Z1?l0000QoookJPGo0000O?oonfXAo`000<Wooo]Z000IoookJP?o001o0ooo
nfX3o`00O`Oooo]Z0_l007l=oookJPGo00005?oonfX5o`0006[ooo]Z1?l0000QoookJPGo0000OOoo
nfX?o`000<[ooo]Z000JoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`gooo]Z1Ol0
000DoookJPGo0000J_oonfX5o`00023ooo]Z1?l00020oookJP_o0000c?oonfX001[ooo]Z1ol007l9
oookJPOo001o1ooonfX5o`0001Cooo]Z1?l0001[oookJPGo00007ooonfX5o`00087ooo]Z2Ol0003=
oookJP006ooonfX5o`00O`[ooo]Z1ol007l7oookJPGo00005?oonfX4o`0006cooo]Z1?l0000Ooook
JPGo0000oooonfYHoookJP00>?oonfX5o`0001Cooo]Z1?l0001/oookJPGo00007_oonfX4o`000?oo
oo]ZFOoonfX003Sooo]Z1Ol0000CoookJPGo0000K?oonfX5o`0001gooo]Z1Ol0003ooookJUWooo]Z
000hoookJPGo00004ooonfX5o`0006gooo]Z1?l0000MoookJPGo0000oooonfYIoookJP00>?oonfX5
o`0001?ooo]Z1?l0001^oookJPGo00007?oonfX4o`000?oooo]ZF_oonfX003Sooo]Z1Ol0000Coook
JPCo0000K_oonfX5o`0001_ooo]Z1Ol0003ooookJU[ooo]Z000hoookJPGo00004ooonfX4o`0006oo
oo]Z1?l0000KoookJPGo0000oooonfYJoookJP00>?oonfX5o`0001?ooo]Z1?l0001_oookJPGo0000
6_oonfX4o`000?oooo]ZFooonfX003Sooo]Z1Ol0000BoookJPGo0000KooonfX5o`0001Wooo]Z1Ol0
003ooookJU_ooo]Z000hoookJPGo00004_oonfX5o`00073ooo]Z1?l0000IoookJPGo0000oooonfYK
oookJP00>?oonfX5o`0001;ooo]Z1?l0001aoookJPGo00005ooonfX5o`000?oooo]ZG?oonfX003So
oo]Z1Ol0000BoookJPCo0000LOoonfX5o`0001Oooo]Z1Ol0003ooookJUcooo]Z000hoookJPGo0000
4_oonfX4o`0007;ooo]Z1?l0000GoookJPCo0000oooonfYMoookJP00>?oonfX5o`00017ooo]Z1Ol0
001boookJPGo00005OoonfX5o`000?oooo]ZGOoonfX003Sooo]Z1Ol0000AoookJPCo0000LooonfX5
o`0001Gooo]Z1Ol0003ooookJUgooo]Z000hoookJPGo00004OoonfX4o`0007Cooo]Z1Ol0000Coook
JPGo0000oooonfYNoookJP00>?oonfX5o`00017ooo]Z1?l0001doookJPGo00004ooonfX5o`000?oo
oo]ZG_oonfX003Sooo]Z1Ol0000AoookJPCo0000MOoonfX5o`00017ooo]Z1Ol0003ooookJUoooo]Z
000hoookJPGo00004?oonfX5o`0007Gooo]Z1Ol0000AoookJPGo0000oooonfYOoookJP00>?oonfX5
o`00013ooo]Z1?l0001goookJPGo00003ooonfX5o`000?oooo]ZH?oonfX003Sooo]Z1Ol0000@oook
JPCo0000MooonfX5o`0000oooo]Z1Ol0003ooookJV3ooo]Z000hoookJPGo00004?oonfX4o`0007So
oo]Z1Ol0000=oookJPGo0000oooonfYQoookJP00>?oonfX5o`0000oooo]Z1Ol0001hoookJPGo0000
3OoonfX5o`000?oooo]ZHOoonfX003Sooo]Z1Ol0000?oookJPGo0000NOoonfX5o`0000_ooo]Z1Ol0
003ooookJV;ooo]Z000hoookJPGo00003ooonfX4o`0007[ooo]Z1_l00009oookJPKo0000oooonfYR
oookJP00>?oonfX5o`0000oooo]Z1?l0001koookJPGo00002OoonfX5o`000?oooo]ZHooonfX003So
oo]Z1Ol0000?oookJPCo0000O?oonfX5o`0000Oooo]Z1Ol0003ooookJVCooo]Z000hoookJPGo0000
3_oonfX5o`0007cooo]Z1ol00003oookJPOo0000oooonfYToookJP00>?oonfX5o`0000kooo]Z1Ol0
001moookJPoo0000oooonfYUoookJP004OoonfX5o`00O`Cooo]Z0ol007l3oookJP?o001o1ooonfX5
o`00O`Wooo]Z1Ol0000>oookJPCo0000OooonfX=o`000?oooo]ZI_oonfX0013ooo]Z1ol007l3oook
JP?o001o0ooonfX3o`00O`Kooo]Z1ol007l8oookJPGo00003_oonfX4o`00083ooo]Z2ol0003ooook
JVOooo]Z000@oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`?ooo]Z0ol007l5oook
JPCo001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0000gooo]Z1Ol00022oookJPOo0000oooonfYY
oookJP003ooonfX3o`00O`?ooo]Z0ol007l9oookJP;o001o1OoonfX3o`00O`?ooo]Z0ol007l7oook
JPGo00003OoonfX5o`000?oooo]Zl_oonfX000oooo]Z0ol007l3oookJP?o001o2OoonfX3o`00O`[o
oo]Z0ol007l7oookJPKo00003?oonfX4o`000?oooo]ZlooonfX000oooo]Z0ol007l3oookJP?o001o
2OoonfX3o`00O`[ooo]Z0ol007l7oookJPGo00003OoonfX4o`000?oooo]ZlooonfX000oooo]Z0ol0
07l3oookJP?o001o2_oonfX2o`00O`Gooo]Z0_l007l2oookJPCo001o1ooonfX5o`0000gooo]Z1?l0
003ooookJ_?ooo]Z000?oookJP?o001o0ooonfX3o`00O`[ooo]Z0ol007l4oookJPOo001o2?oonfX5
o`0000cooo]Z1Ol0003ooookJ_?ooo]Z000?oookJP?o001o0ooonfX3o`00O`_ooo]Z0_l007l4oook
JPKo001o2OoonfX5o`0000cooo]Z1Ol0003ooookJ_?ooo]Z000?oookJP?o001o0ooonfX3o`00O`co
oo]Z0_l007l3oookJP;o001o3OoonfX5o`0000cooo]Z1?l0003ooookJ_Cooo]Z000@oookJP?o001o
00Cooo]Zo`00Ool007oo001o3OoonfX2o`00O`?ooo]Z0_l007l=oookJPGo00003?oonfX4o`000?oo
oo]Zm?oonfX0013ooo]Z1ol007l7oookJPWo001o0ooonfX7o`00O`Oooo]Z1Ol0000;oookJPGo0000
oooonf[doookJP004OoonfX5o`00O`Sooo]Z2Ol007l3oookJPOo001o1ooonfX5o`0000_ooo]Z1Ol0
003ooookJ_Cooo]Z000hoookJPGo00002ooonfX4o`000?oooo]ZmOoonfX003Sooo]Z1Ol0000;oook
JPCo0000oooonf[eoookJP00>?oonfX5o`0000[ooo]Z1Ol0003ooookJ_Gooo]Z000hoookJPGo0000
2_oonfX4o`000?oooo]Zm_oonfX003Sooo]Z1Ol0000:oookJPCo0000oooonf[foookJP00>?oonfX5
o`0000Wooo]Z1Ol0003ooookJ_Kooo]Z000hoookJPGo00002OoonfX5o`000?oooo]Zm_oonfX003So
oo]Z1Ol00009oookJPCo0000oooonf[goookJP00>?oonfX5o`0000Sooo]Z1Ol0003ooookJ_Oooo]Z
000hoookJPGo00002?oonfX5o`000?oooo]ZmooonfX003Sooo]Z1Ol00008oookJPCo0000oooonf[h
oookJP00>?oonfX5o`0000Sooo]Z1?l0003ooookJ_Sooo]Z000hoookJPGo00001ooonfX5o`000?oo
oo]Zn?oonfX003Sooo]Z1Ol00007oookJPGo0000oooonf[hoookJP00>?oonfX5o`0000Oooo]Z1?l0
003ooookJ_Wooo]Z000hoookJPGo00001_oonfX5o`000?oooo]ZnOoonfX003Sooo]Z1Ol00006oook
JPGo0000oooonf[ioookJP00>?oonfX5o`0000Gooo]Z1Ol0003ooookJ_[ooo]Z000hoookJPGo0000
1OoonfX5o`000?oooo]Zn_oonfX003Sooo]Z1Ol00005oookJPCo0000oooonf[koookJP00>?oonfX5
o`0000Cooo]Z1Ol0003ooookJ__ooo]Z000hoookJPGo00001?oonfX5o`000?oooo]ZnooonfX003So
oo]Z1Ol00003oookJPGo0000oooonf[loookJP00>?oonfX5o`0000?ooo]Z1Ol0003ooookJ_cooo]Z
000hoookJPGo00000_oonfX5o`000?oooo]ZoOoonfX003Sooo]Z1Ol00002oookJPGo0000oooonf[m
oookJP00>?oonfX5o`000003oookJ_l0003o000000?o0000oooonf[noookJP00;?oonfX3o`00O`Wo
oo]Z2ol0003ooookJ_kooo]Z000/oookJP?o001o2OoonfX:o`000?oooo]ZoooonfX002cooo]Z0ol0
07l9oookJPWo0000oooonf[ooookJP7ooo]Z000/oookJP?o001o2OoonfX9o`000?oooo]ZoooonfX1
oookJP00;?oonfX3o`00O`Wooo]Z2?l0003ooookJ_oooo]Z0_oonfX002cooo]Z0ol007l9oookJPOo
0000oooonf[ooookJP?ooo]Z000/oookJP?o001o2OoonfX5o`000?oooo]ZoooonfX5oookJP00;?oo
nfX3o`00O`Wooo]Z1Ol0003ooookJ_oooo]Z1OoonfX002cooo]Z0ol007l9oookJPGo0000oooonf[o
oookJPGooo]Z000YoookJPKo001o2OoonfX5o`000?oooo]ZoooonfX5oookJP00:OoonfX6o`00O`Wo
oo]Z1Ol0003ooookJ_oooo]Z1OoonfX002_ooo]Z1?l007l9oookJPGo0000oooonf[ooookJPGooo]Z
000/oookJP?o001o2OoonfX5o`000?oooo]ZoooonfX5oookJP00>?oonfX5o`000?oooo]ZoooonfX5
oookJP00>?oonfX5o`000?oooo]ZoooonfX5oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z
@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oo
oo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2
oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooo
nf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;o
oo]Z0000\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-2384.12, -1.01617, 40.8473, \
0.00613213}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["Change parameters for Growth Function:", "Text"],

Cell[BoxData[
    \(GrowListSpecific[InitialList_List]\  := \ 
      GrowListGeneral[InitialList,  .001, 1, 0]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[Nest[GrowListSpecific, {1, 1}, 20000]]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 4.76143e-05 0.308786 0.29177 [
[.26188 .29629 -22 -20 ]
[.26188 .29629 22 0 ]
[.49995 .29629 -27 -20 ]
[.49995 .29629 27 0 ]
[.73802 .29629 -27 -20 ]
[.73802 .29629 27 0 ]
[.9761 .29629 -27 -20 ]
[.9761 .29629 27 0 ]
[.01131 .01702 -26.9375 -10 ]
[.01131 .01702 0 10 ]
[.01131 .1629 -41.9375 -10 ]
[.01131 .1629 0 10 ]
[.01131 .45467 -29 -10 ]
[.01131 .45467 0 10 ]
[.01131 .60056 -14 -10 ]
[.01131 .60056 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.26188 .30879 m
.26188 .31504 L
s
gsave
.26188 .29629 -83 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5000) show
1.000 setlinewidth
grestore
.49995 .30879 m
.49995 .31504 L
s
gsave
.49995 .29629 -88 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10000) show
1.000 setlinewidth
grestore
.73802 .30879 m
.73802 .31504 L
s
gsave
.73802 .29629 -88 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15000) show
1.000 setlinewidth
grestore
.9761 .30879 m
.9761 .31504 L
s
gsave
.9761 .29629 -88 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(20000) show
1.000 setlinewidth
grestore
.125 Mabswid
.07142 .30879 m
.07142 .31254 L
s
.11904 .30879 m
.11904 .31254 L
s
.16665 .30879 m
.16665 .31254 L
s
.21427 .30879 m
.21427 .31254 L
s
.3095 .30879 m
.3095 .31254 L
s
.35711 .30879 m
.35711 .31254 L
s
.40472 .30879 m
.40472 .31254 L
s
.45234 .30879 m
.45234 .31254 L
s
.54757 .30879 m
.54757 .31254 L
s
.59518 .30879 m
.59518 .31254 L
s
.6428 .30879 m
.6428 .31254 L
s
.69041 .30879 m
.69041 .31254 L
s
.78564 .30879 m
.78564 .31254 L
s
.83325 .30879 m
.83325 .31254 L
s
.88087 .30879 m
.88087 .31254 L
s
.92848 .30879 m
.92848 .31254 L
s
.01 w
0 .30879 m
1 .30879 L
s
.25 Mabswid
.02381 .01702 m
.03006 .01702 L
s
gsave
.01131 .01702 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.02381 .1629 m
.03006 .1629 L
s
gsave
.01131 .1629 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.02381 .45467 m
.03006 .45467 L
s
gsave
.01131 .45467 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.02381 .60056 m
.03006 .60056 L
s
gsave
.01131 .60056 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .04619 m
.02756 .04619 L
s
.02381 .07537 m
.02756 .07537 L
s
.02381 .10455 m
.02756 .10455 L
s
.02381 .13372 m
.02756 .13372 L
s
.02381 .19208 m
.02756 .19208 L
s
.02381 .22125 m
.02756 .22125 L
s
.02381 .25043 m
.02756 .25043 L
s
.02381 .27961 m
.02756 .27961 L
s
.02381 .33796 m
.02756 .33796 L
s
.02381 .36714 m
.02756 .36714 L
s
.02381 .39632 m
.02756 .39632 L
s
.02381 .42549 m
.02756 .42549 L
s
.02381 .48385 m
.02756 .48385 L
s
.02381 .51302 m
.02756 .51302 L
s
.02381 .5422 m
.02756 .5422 L
s
.02381 .57138 m
.02756 .57138 L
s
.01 w
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02386 .60056 Mdot
.0239 .60056 Mdot
.02395 .60056 Mdot
.024 .60056 Mdot
.02405 .60055 Mdot
.0241 .60055 Mdot
.02414 .60055 Mdot
.02419 .60055 Mdot
.02424 .60055 Mdot
.02429 .60055 Mdot
.02433 .60054 Mdot
.02438 .60054 Mdot
.02443 .60054 Mdot
.02448 .60053 Mdot
.02452 .60053 Mdot
.02457 .60053 Mdot
.02462 .60052 Mdot
.02467 .60052 Mdot
.02471 .60051 Mdot
.02476 .60051 Mdot
.02481 .6005 Mdot
.02486 .60049 Mdot
.0249 .60049 Mdot
.02495 .60048 Mdot
.025 .60048 Mdot
.02505 .60047 Mdot
.0251 .60046 Mdot
.02514 .60045 Mdot
.02519 .60045 Mdot
.02524 .60044 Mdot
.02529 .60043 Mdot
.02533 .60042 Mdot
.02538 .60041 Mdot
.02543 .6004 Mdot
.02548 .60039 Mdot
.02552 .60038 Mdot
.02557 .60037 Mdot
.02562 .60036 Mdot
.02567 .60035 Mdot
.02571 .60034 Mdot
.02576 .60033 Mdot
.02581 .60032 Mdot
.02586 .6003 Mdot
.0259 .60029 Mdot
.02595 .60028 Mdot
.026 .60027 Mdot
.02605 .60025 Mdot
.0261 .60024 Mdot
.02614 .60023 Mdot
.02619 .60021 Mdot
.02624 .6002 Mdot
.02629 .60018 Mdot
.02633 .60017 Mdot
.02638 .60015 Mdot
.02643 .60014 Mdot
.02648 .60012 Mdot
.02652 .60011 Mdot
.02657 .60009 Mdot
.02662 .60007 Mdot
.02667 .60006 Mdot
.02671 .60004 Mdot
.02676 .60002 Mdot
.02681 .6 Mdot
.02686 .59999 Mdot
.0269 .59997 Mdot
.02695 .59995 Mdot
.027 .59993 Mdot
.02705 .59991 Mdot
.02709 .59989 Mdot
.02714 .59987 Mdot
.02719 .59985 Mdot
.02724 .59983 Mdot
.02729 .59981 Mdot
.02733 .59979 Mdot
.02738 .59977 Mdot
.02743 .59975 Mdot
.02748 .59972 Mdot
.02752 .5997 Mdot
.02757 .59968 Mdot
.02762 .59966 Mdot
.02767 .59963 Mdot
.02771 .59961 Mdot
.02776 .59959 Mdot
.02781 .59956 Mdot
.02786 .59954 Mdot
.0279 .59951 Mdot
.02795 .59949 Mdot
.028 .59947 Mdot
.02805 .59944 Mdot
.02809 .59941 Mdot
.02814 .59939 Mdot
.02819 .59936 Mdot
.02824 .59934 Mdot
.02829 .59931 Mdot
.02833 .59928 Mdot
.02838 .59925 Mdot
.02843 .59923 Mdot
.02848 .5992 Mdot
.02852 .59917 Mdot
.02857 .59914 Mdot
.02862 .59911 Mdot
.02867 .59908 Mdot
.02871 .59905 Mdot
.02876 .59902 Mdot
.02881 .59899 Mdot
.02886 .59896 Mdot
.0289 .59893 Mdot
.02895 .5989 Mdot
.029 .59887 Mdot
.02905 .59884 Mdot
.02909 .59881 Mdot
.02914 .59878 Mdot
.02919 .59874 Mdot
.02924 .59871 Mdot
.02929 .59868 Mdot
.02933 .59865 Mdot
.02938 .59861 Mdot
.02943 .59858 Mdot
.02948 .59854 Mdot
.02952 .59851 Mdot
.02957 .59848 Mdot
.02962 .59844 Mdot
.02967 .5984 Mdot
.02971 .59837 Mdot
.02976 .59833 Mdot
.02981 .5983 Mdot
.02986 .59826 Mdot
.0299 .59822 Mdot
.02995 .59819 Mdot
.03 .59815 Mdot
.03005 .59811 Mdot
.03009 .59807 Mdot
.03014 .59804 Mdot
.03019 .598 Mdot
.03024 .59796 Mdot
.03029 .59792 Mdot
.03033 .59788 Mdot
.03038 .59784 Mdot
.03043 .5978 Mdot
.03048 .59776 Mdot
.03052 .59772 Mdot
.03057 .59768 Mdot
.03062 .59764 Mdot
.03067 .5976 Mdot
.03071 .59756 Mdot
.03076 .59752 Mdot
.03081 .59747 Mdot
.03086 .59743 Mdot
.0309 .59739 Mdot
.03095 .59734 Mdot
.031 .5973 Mdot
.03105 .59726 Mdot
.03109 .59721 Mdot
.03114 .59717 Mdot
.03119 .59713 Mdot
.03124 .59708 Mdot
.03128 .59704 Mdot
.03133 .59699 Mdot
.03138 .59694 Mdot
.03143 .5969 Mdot
.03148 .59685 Mdot
.03152 .59681 Mdot
.03157 .59676 Mdot
.03162 .59671 Mdot
.03167 .59666 Mdot
.03171 .59662 Mdot
.03176 .59657 Mdot
.03181 .59652 Mdot
.03186 .59647 Mdot
.0319 .59642 Mdot
.03195 .59637 Mdot
.032 .59633 Mdot
.03205 .59628 Mdot
.03209 .59623 Mdot
.03214 .59618 Mdot
.03219 .59612 Mdot
.03224 .59607 Mdot
.03228 .59602 Mdot
.03233 .59597 Mdot
.03238 .59592 Mdot
.03243 .59587 Mdot
.03248 .59582 Mdot
.03252 .59576 Mdot
.03257 .59571 Mdot
.03262 .59566 Mdot
.03267 .5956 Mdot
.03271 .59555 Mdot
.03276 .5955 Mdot
.03281 .59544 Mdot
.03286 .59539 Mdot
.0329 .59533 Mdot
.03295 .59528 Mdot
.033 .59522 Mdot
.03305 .59517 Mdot
.03309 .59511 Mdot
.03314 .59505 Mdot
.03319 .595 Mdot
.03324 .59494 Mdot
.03328 .59488 Mdot
.03333 .59483 Mdot
.03338 .59477 Mdot
.03343 .59471 Mdot
.03348 .59465 Mdot
.03352 .59459 Mdot
.03357 .59454 Mdot
.03362 .59448 Mdot
.03367 .59442 Mdot
.03371 .59436 Mdot
.03376 .5943 Mdot
.03381 .59424 Mdot
.03386 .59418 Mdot
.0339 .59412 Mdot
.03395 .59405 Mdot
.034 .59399 Mdot
.03405 .59393 Mdot
.03409 .59387 Mdot
.03414 .59381 Mdot
.03419 .59374 Mdot
.03424 .59368 Mdot
.03428 .59362 Mdot
.03433 .59355 Mdot
.03438 .59349 Mdot
.03443 .59343 Mdot
.03448 .59336 Mdot
.03452 .5933 Mdot
.03457 .59323 Mdot
.03462 .59317 Mdot
.03467 .5931 Mdot
.03471 .59304 Mdot
.03476 .59297 Mdot
.03481 .59291 Mdot
.03486 .59284 Mdot
.0349 .59277 Mdot
.03495 .5927 Mdot
.035 .59264 Mdot
.03505 .59257 Mdot
.03509 .5925 Mdot
.03514 .59243 Mdot
.03519 .59237 Mdot
.03524 .5923 Mdot
.03528 .59223 Mdot
.03533 .59216 Mdot
.03538 .59209 Mdot
.03543 .59202 Mdot
.03548 .59195 Mdot
.03552 .59188 Mdot
.03557 .59181 Mdot
.03562 .59174 Mdot
.03567 .59166 Mdot
.03571 .59159 Mdot
.03576 .59152 Mdot
.03581 .59145 Mdot
.03586 .59138 Mdot
.0359 .5913 Mdot
.03595 .59123 Mdot
.036 .59116 Mdot
.03605 .59108 Mdot
.03609 .59101 Mdot
.03614 .59094 Mdot
.03619 .59086 Mdot
.03624 .59079 Mdot
.03628 .59071 Mdot
.03633 .59064 Mdot
.03638 .59056 Mdot
.03643 .59048 Mdot
.03647 .59041 Mdot
.03652 .59033 Mdot
.03657 .59026 Mdot
.03662 .59018 Mdot
.03667 .5901 Mdot
.03671 .59002 Mdot
.03676 .58995 Mdot
.03681 .58987 Mdot
.03686 .58979 Mdot
.0369 .58971 Mdot
.03695 .58963 Mdot
.037 .58955 Mdot
.03705 .58947 Mdot
.03709 .58939 Mdot
.03714 .58931 Mdot
.03719 .58923 Mdot
.03724 .58915 Mdot
.03728 .58907 Mdot
.03733 .58899 Mdot
.03738 .58891 Mdot
.03743 .58883 Mdot
.03747 .58874 Mdot
.03752 .58866 Mdot
.03757 .58858 Mdot
.03762 .5885 Mdot
.03767 .58841 Mdot
.03771 .58833 Mdot
.03776 .58825 Mdot
.03781 .58816 Mdot
.03786 .58808 Mdot
.0379 .58799 Mdot
.03795 .58791 Mdot
.038 .58782 Mdot
.03805 .58774 Mdot
.03809 .58765 Mdot
.03814 .58757 Mdot
.03819 .58748 Mdot
.03824 .58739 Mdot
.03828 .58731 Mdot
.03833 .58722 Mdot
.03838 .58713 Mdot
.03843 .58704 Mdot
.03847 .58696 Mdot
.03852 .58687 Mdot
.03857 .58678 Mdot
.03862 .58669 Mdot
.03867 .5866 Mdot
.03871 .58651 Mdot
.03876 .58642 Mdot
.03881 .58633 Mdot
.03886 .58624 Mdot
.0389 .58615 Mdot
.03895 .58606 Mdot
.039 .58597 Mdot
.03905 .58588 Mdot
.03909 .58579 Mdot
.03914 .5857 Mdot
.03919 .5856 Mdot
.03924 .58551 Mdot
.03928 .58542 Mdot
.03933 .58533 Mdot
.03938 .58523 Mdot
.03943 .58514 Mdot
.03947 .58505 Mdot
.03952 .58495 Mdot
.03957 .58486 Mdot
.03962 .58476 Mdot
.03967 .58467 Mdot
.03971 .58457 Mdot
.03976 .58448 Mdot
.03981 .58438 Mdot
.03986 .58429 Mdot
.0399 .58419 Mdot
.03995 .58409 Mdot
.04 .584 Mdot
.04005 .5839 Mdot
.04009 .5838 Mdot
.04014 .58371 Mdot
.04019 .58361 Mdot
.04024 .58351 Mdot
.04028 .58341 Mdot
.04033 .58331 Mdot
.04038 .58321 Mdot
.04043 .58311 Mdot
.04047 .58301 Mdot
.04052 .58291 Mdot
.04057 .58281 Mdot
.04062 .58271 Mdot
.04066 .58261 Mdot
.04071 .58251 Mdot
.04076 .58241 Mdot
.04081 .58231 Mdot
.04086 .58221 Mdot
.0409 .58211 Mdot
.04095 .582 Mdot
.041 .5819 Mdot
.04105 .5818 Mdot
.04109 .5817 Mdot
.04114 .58159 Mdot
.04119 .58149 Mdot
.04124 .58139 Mdot
.04128 .58128 Mdot
.04133 .58118 Mdot
.04138 .58107 Mdot
.04143 .58097 Mdot
.04147 .58086 Mdot
.04152 .58076 Mdot
.04157 .58065 Mdot
.04162 .58054 Mdot
.04166 .58044 Mdot
.04171 .58033 Mdot
.04176 .58022 Mdot
.04181 .58012 Mdot
.04186 .58001 Mdot
.0419 .5799 Mdot
.04195 .57979 Mdot
.042 .57969 Mdot
.04205 .57958 Mdot
.04209 .57947 Mdot
.04214 .57936 Mdot
.04219 .57925 Mdot
.04224 .57914 Mdot
.04228 .57903 Mdot
.04233 .57892 Mdot
.04238 .57881 Mdot
.04243 .5787 Mdot
.04247 .57859 Mdot
.04252 .57848 Mdot
.04257 .57837 Mdot
.04262 .57825 Mdot
.04266 .57814 Mdot
.04271 .57803 Mdot
.04276 .57792 Mdot
.04281 .5778 Mdot
.04286 .57769 Mdot
.0429 .57758 Mdot
.04295 .57746 Mdot
.043 .57735 Mdot
.04305 .57724 Mdot
.04309 .57712 Mdot
.04314 .57701 Mdot
.04319 .57689 Mdot
.04324 .57678 Mdot
.04328 .57666 Mdot
.04333 .57655 Mdot
.04338 .57643 Mdot
.04343 .57631 Mdot
.04347 .5762 Mdot
.04352 .57608 Mdot
.04357 .57596 Mdot
.04362 .57584 Mdot
.04366 .57573 Mdot
.04371 .57561 Mdot
.04376 .57549 Mdot
.04381 .57537 Mdot
.04386 .57525 Mdot
.0439 .57513 Mdot
.04395 .57502 Mdot
.044 .5749 Mdot
.04405 .57478 Mdot
.04409 .57466 Mdot
.04414 .57454 Mdot
.04419 .57442 Mdot
.04424 .57429 Mdot
.04428 .57417 Mdot
.04433 .57405 Mdot
.04438 .57393 Mdot
.04443 .57381 Mdot
.04447 .57369 Mdot
.04452 .57356 Mdot
.04457 .57344 Mdot
.04462 .57332 Mdot
.04466 .57319 Mdot
.04471 .57307 Mdot
.04476 .57295 Mdot
.04481 .57282 Mdot
.04486 .5727 Mdot
.0449 .57257 Mdot
.04495 .57245 Mdot
.045 .57232 Mdot
.04505 .5722 Mdot
.04509 .57207 Mdot
.04514 .57195 Mdot
.04519 .57182 Mdot
.04524 .5717 Mdot
.04528 .57157 Mdot
.04533 .57144 Mdot
.04538 .57131 Mdot
.04543 .57119 Mdot
.04547 .57106 Mdot
.04552 .57093 Mdot
.04557 .5708 Mdot
.04562 .57067 Mdot
.04566 .57055 Mdot
.04571 .57042 Mdot
.04576 .57029 Mdot
.04581 .57016 Mdot
.04585 .57003 Mdot
.0459 .5699 Mdot
.04595 .56977 Mdot
.046 .56964 Mdot
.04605 .56951 Mdot
.04609 .56937 Mdot
.04614 .56924 Mdot
.04619 .56911 Mdot
.04624 .56898 Mdot
.04628 .56885 Mdot
.04633 .56872 Mdot
.04638 .56858 Mdot
.04643 .56845 Mdot
.04647 .56832 Mdot
.04652 .56818 Mdot
.04657 .56805 Mdot
.04662 .56792 Mdot
.04666 .56778 Mdot
.04671 .56765 Mdot
.04676 .56751 Mdot
.04681 .56738 Mdot
.04685 .56724 Mdot
.0469 .56711 Mdot
.04695 .56697 Mdot
.047 .56683 Mdot
.04705 .5667 Mdot
.04709 .56656 Mdot
.04714 .56642 Mdot
.04719 .56629 Mdot
.04724 .56615 Mdot
.04728 .56601 Mdot
.04733 .56587 Mdot
.04738 .56574 Mdot
.04743 .5656 Mdot
.04747 .56546 Mdot
.04752 .56532 Mdot
.04757 .56518 Mdot
.04762 .56504 Mdot
.04766 .5649 Mdot
.04771 .56476 Mdot
.04776 .56462 Mdot
.04781 .56448 Mdot
.04785 .56434 Mdot
.0479 .5642 Mdot
.04795 .56406 Mdot
.048 .56392 Mdot
.04805 .56378 Mdot
.04809 .56363 Mdot
.04814 .56349 Mdot
.04819 .56335 Mdot
.04824 .56321 Mdot
.04828 .56306 Mdot
.04833 .56292 Mdot
.04838 .56278 Mdot
.04843 .56263 Mdot
.04847 .56249 Mdot
.04852 .56234 Mdot
.04857 .5622 Mdot
.04862 .56206 Mdot
.04866 .56191 Mdot
.04871 .56177 Mdot
.04876 .56162 Mdot
.04881 .56147 Mdot
.04885 .56133 Mdot
.0489 .56118 Mdot
.04895 .56104 Mdot
.049 .56089 Mdot
.04905 .56074 Mdot
.04909 .56059 Mdot
.04914 .56045 Mdot
.04919 .5603 Mdot
.04924 .56015 Mdot
.04928 .56 Mdot
.04933 .55985 Mdot
.04938 .5597 Mdot
.04943 .55956 Mdot
.04947 .55941 Mdot
.04952 .55926 Mdot
.04957 .55911 Mdot
.04962 .55896 Mdot
.04966 .55881 Mdot
.04971 .55866 Mdot
.04976 .55851 Mdot
.04981 .55835 Mdot
.04985 .5582 Mdot
.0499 .55805 Mdot
.04995 .5579 Mdot
.05 .55775 Mdot
.05004 .5576 Mdot
.05009 .55744 Mdot
.05014 .55729 Mdot
.05019 .55714 Mdot
.05024 .55698 Mdot
.05028 .55683 Mdot
.05033 .55668 Mdot
.05038 .55652 Mdot
.05043 .55637 Mdot
.05047 .55621 Mdot
.05052 .55606 Mdot
.05057 .5559 Mdot
.05062 .55575 Mdot
.05066 .55559 Mdot
.05071 .55544 Mdot
.05076 .55528 Mdot
.05081 .55512 Mdot
.05085 .55497 Mdot
.0509 .55481 Mdot
.05095 .55465 Mdot
.051 .5545 Mdot
.05104 .55434 Mdot
.05109 .55418 Mdot
.05114 .55402 Mdot
.05119 .55387 Mdot
.05124 .55371 Mdot
.05128 .55355 Mdot
.05133 .55339 Mdot
.05138 .55323 Mdot
.05143 .55307 Mdot
.05147 .55291 Mdot
.05152 .55275 Mdot
.05157 .55259 Mdot
.05162 .55243 Mdot
.05166 .55227 Mdot
.05171 .55211 Mdot
.05176 .55195 Mdot
.05181 .55179 Mdot
.05185 .55163 Mdot
.0519 .55146 Mdot
.05195 .5513 Mdot
.052 .55114 Mdot
.05204 .55098 Mdot
.05209 .55081 Mdot
.05214 .55065 Mdot
.05219 .55049 Mdot
.05224 .55032 Mdot
.05228 .55016 Mdot
.05233 .55 Mdot
.05238 .54983 Mdot
.05243 .54967 Mdot
.05247 .5495 Mdot
.05252 .54934 Mdot
.05257 .54917 Mdot
.05262 .54901 Mdot
.05266 .54884 Mdot
.05271 .54867 Mdot
.05276 .54851 Mdot
.05281 .54834 Mdot
.05285 .54817 Mdot
.0529 .54801 Mdot
.05295 .54784 Mdot
.053 .54767 Mdot
.05304 .54751 Mdot
.05309 .54734 Mdot
.05314 .54717 Mdot
.05319 .547 Mdot
.05324 .54683 Mdot
.05328 .54666 Mdot
.05333 .54649 Mdot
.05338 .54632 Mdot
.05343 .54616 Mdot
.05347 .54599 Mdot
.05352 .54582 Mdot
.05357 .54565 Mdot
.05362 .54547 Mdot
.05366 .5453 Mdot
.05371 .54513 Mdot
.05376 .54496 Mdot
.05381 .54479 Mdot
.05385 .54462 Mdot
.0539 .54445 Mdot
.05395 .54427 Mdot
.054 .5441 Mdot
.05404 .54393 Mdot
.05409 .54376 Mdot
.05414 .54358 Mdot
.05419 .54341 Mdot
.05424 .54324 Mdot
.05428 .54306 Mdot
.05433 .54289 Mdot
.05438 .54271 Mdot
.05443 .54254 Mdot
.05447 .54236 Mdot
.05452 .54219 Mdot
.05457 .54201 Mdot
.05462 .54184 Mdot
.05466 .54166 Mdot
.05471 .54149 Mdot
.05476 .54131 Mdot
.05481 .54113 Mdot
.05485 .54096 Mdot
.0549 .54078 Mdot
.05495 .5406 Mdot
.055 .54043 Mdot
.05504 .54025 Mdot
.05509 .54007 Mdot
.05514 .53989 Mdot
.05519 .53972 Mdot
.05523 .53954 Mdot
.05528 .53936 Mdot
.05533 .53918 Mdot
.05538 .539 Mdot
.05543 .53882 Mdot
.05547 .53864 Mdot
.05552 .53846 Mdot
.05557 .53828 Mdot
.05562 .5381 Mdot
.05566 .53792 Mdot
.05571 .53774 Mdot
.05576 .53756 Mdot
.05581 .53738 Mdot
.05585 .5372 Mdot
.0559 .53701 Mdot
.05595 .53683 Mdot
.056 .53665 Mdot
.05604 .53647 Mdot
.05609 .53628 Mdot
.05614 .5361 Mdot
.05619 .53592 Mdot
.05623 .53574 Mdot
.05628 .53555 Mdot
.05633 .53537 Mdot
.05638 .53518 Mdot
.05643 .535 Mdot
.05647 .53482 Mdot
.05652 .53463 Mdot
.05657 .53445 Mdot
.05662 .53426 Mdot
.05666 .53408 Mdot
.05671 .53389 Mdot
.05676 .5337 Mdot
.05681 .53352 Mdot
.05685 .53333 Mdot
.0569 .53315 Mdot
.05695 .53296 Mdot
.057 .53277 Mdot
.05704 .53258 Mdot
.05709 .5324 Mdot
.05714 .53221 Mdot
.05719 .53202 Mdot
.05723 .53183 Mdot
.05728 .53165 Mdot
.05733 .53146 Mdot
.05738 .53127 Mdot
.05743 .53108 Mdot
.05747 .53089 Mdot
.05752 .5307 Mdot
.05757 .53051 Mdot
.05762 .53032 Mdot
.05766 .53013 Mdot
.05771 .52994 Mdot
.05776 .52975 Mdot
.05781 .52956 Mdot
.05785 .52937 Mdot
.0579 .52918 Mdot
.05795 .52899 Mdot
.058 .5288 Mdot
.05804 .5286 Mdot
.05809 .52841 Mdot
.05814 .52822 Mdot
.05819 .52803 Mdot
.05823 .52783 Mdot
.05828 .52764 Mdot
.05833 .52745 Mdot
.05838 .52725 Mdot
.05843 .52706 Mdot
.05847 .52687 Mdot
.05852 .52667 Mdot
.05857 .52648 Mdot
.05862 .52628 Mdot
.05866 .52609 Mdot
.05871 .5259 Mdot
.05876 .5257 Mdot
.05881 .52551 Mdot
.05885 .52531 Mdot
.0589 .52511 Mdot
.05895 .52492 Mdot
.059 .52472 Mdot
.05904 .52453 Mdot
.05909 .52433 Mdot
.05914 .52413 Mdot
.05919 .52393 Mdot
.05923 .52374 Mdot
.05928 .52354 Mdot
.05933 .52334 Mdot
.05938 .52314 Mdot
.05943 .52295 Mdot
.05947 .52275 Mdot
.05952 .52255 Mdot
.05957 .52235 Mdot
.05962 .52215 Mdot
.05966 .52195 Mdot
.05971 .52175 Mdot
.05976 .52155 Mdot
.05981 .52135 Mdot
.05985 .52115 Mdot
.0599 .52095 Mdot
.05995 .52075 Mdot
.06 .52055 Mdot
.06004 .52035 Mdot
.06009 .52015 Mdot
.06014 .51995 Mdot
.06019 .51975 Mdot
.06023 .51955 Mdot
.06028 .51934 Mdot
.06033 .51914 Mdot
.06038 .51894 Mdot
.06042 .51874 Mdot
.06047 .51853 Mdot
.06052 .51833 Mdot
.06057 .51813 Mdot
.06062 .51792 Mdot
.06066 .51772 Mdot
.06071 .51752 Mdot
.06076 .51731 Mdot
.06081 .51711 Mdot
.06085 .5169 Mdot
.0609 .5167 Mdot
.06095 .5165 Mdot
.061 .51629 Mdot
.06104 .51608 Mdot
.06109 .51588 Mdot
.06114 .51567 Mdot
.06119 .51547 Mdot
.06123 .51526 Mdot
.06128 .51506 Mdot
.06133 .51485 Mdot
.06138 .51464 Mdot
.06142 .51444 Mdot
.06147 .51423 Mdot
.06152 .51402 Mdot
.06157 .51381 Mdot
.06162 .51361 Mdot
.06166 .5134 Mdot
.06171 .51319 Mdot
.06176 .51298 Mdot
.06181 .51277 Mdot
.06185 .51256 Mdot
.0619 .51235 Mdot
.06195 .51215 Mdot
.062 .51194 Mdot
.06204 .51173 Mdot
.06209 .51152 Mdot
.06214 .51131 Mdot
.06219 .5111 Mdot
.06223 .51089 Mdot
.06228 .51068 Mdot
.06233 .51046 Mdot
.06238 .51025 Mdot
.06242 .51004 Mdot
.06247 .50983 Mdot
.06252 .50962 Mdot
.06257 .50941 Mdot
.06262 .5092 Mdot
.06266 .50898 Mdot
.06271 .50877 Mdot
.06276 .50856 Mdot
.06281 .50835 Mdot
.06285 .50813 Mdot
.0629 .50792 Mdot
.06295 .50771 Mdot
.063 .50749 Mdot
.06304 .50728 Mdot
.06309 .50706 Mdot
.06314 .50685 Mdot
.06319 .50664 Mdot
.06323 .50642 Mdot
.06328 .50621 Mdot
.06333 .50599 Mdot
.06338 .50578 Mdot
.06342 .50556 Mdot
.06347 .50535 Mdot
.06352 .50513 Mdot
.06357 .50491 Mdot
.06362 .5047 Mdot
.06366 .50448 Mdot
.06371 .50426 Mdot
.06376 .50405 Mdot
.06381 .50383 Mdot
.06385 .50361 Mdot
.0639 .5034 Mdot
.06395 .50318 Mdot
.064 .50296 Mdot
.06404 .50274 Mdot
.06409 .50252 Mdot
.06414 .50231 Mdot
.06419 .50209 Mdot
.06423 .50187 Mdot
.06428 .50165 Mdot
.06433 .50143 Mdot
.06438 .50121 Mdot
.06442 .50099 Mdot
.06447 .50077 Mdot
.06452 .50055 Mdot
.06457 .50033 Mdot
.06461 .50011 Mdot
.06466 .49989 Mdot
.06471 .49967 Mdot
.06476 .49945 Mdot
.06481 .49923 Mdot
.06485 .49901 Mdot
.0649 .49879 Mdot
.06495 .49857 Mdot
.065 .49834 Mdot
.06504 .49812 Mdot
.06509 .4979 Mdot
.06514 .49768 Mdot
.06519 .49745 Mdot
.06523 .49723 Mdot
.06528 .49701 Mdot
.06533 .49679 Mdot
.06538 .49656 Mdot
.06542 .49634 Mdot
.06547 .49612 Mdot
.06552 .49589 Mdot
.06557 .49567 Mdot
.06561 .49544 Mdot
.06566 .49522 Mdot
.06571 .49499 Mdot
.06576 .49477 Mdot
.06581 .49454 Mdot
.06585 .49432 Mdot
.0659 .49409 Mdot
.06595 .49387 Mdot
.066 .49364 Mdot
.06604 .49342 Mdot
.06609 .49319 Mdot
.06614 .49296 Mdot
.06619 .49274 Mdot
.06623 .49251 Mdot
.06628 .49228 Mdot
.06633 .49206 Mdot
.06638 .49183 Mdot
.06642 .4916 Mdot
.06647 .49138 Mdot
.06652 .49115 Mdot
.06657 .49092 Mdot
.06661 .49069 Mdot
.06666 .49046 Mdot
.06671 .49023 Mdot
.06676 .49001 Mdot
.06681 .48978 Mdot
.06685 .48955 Mdot
.0669 .48932 Mdot
.06695 .48909 Mdot
.067 .48886 Mdot
.06704 .48863 Mdot
.06709 .4884 Mdot
.06714 .48817 Mdot
.06719 .48794 Mdot
.06723 .48771 Mdot
.06728 .48748 Mdot
.06733 .48725 Mdot
.06738 .48702 Mdot
.06742 .48679 Mdot
.06747 .48655 Mdot
.06752 .48632 Mdot
.06757 .48609 Mdot
.06761 .48586 Mdot
.06766 .48563 Mdot
.06771 .4854 Mdot
.06776 .48516 Mdot
.06781 .48493 Mdot
.06785 .4847 Mdot
.0679 .48446 Mdot
.06795 .48423 Mdot
.068 .484 Mdot
.06804 .48376 Mdot
.06809 .48353 Mdot
.06814 .4833 Mdot
.06819 .48306 Mdot
.06823 .48283 Mdot
.06828 .48259 Mdot
.06833 .48236 Mdot
.06838 .48213 Mdot
.06842 .48189 Mdot
.06847 .48166 Mdot
.06852 .48142 Mdot
.06857 .48118 Mdot
.06861 .48095 Mdot
.06866 .48071 Mdot
.06871 .48048 Mdot
.06876 .48024 Mdot
.06881 .48001 Mdot
.06885 .47977 Mdot
.0689 .47953 Mdot
.06895 .4793 Mdot
.069 .47906 Mdot
.06904 .47882 Mdot
.06909 .47858 Mdot
.06914 .47835 Mdot
.06919 .47811 Mdot
.06923 .47787 Mdot
.06928 .47763 Mdot
.06933 .4774 Mdot
.06938 .47716 Mdot
.06942 .47692 Mdot
.06947 .47668 Mdot
.06952 .47644 Mdot
.06957 .4762 Mdot
.06961 .47596 Mdot
.06966 .47572 Mdot
.06971 .47548 Mdot
.06976 .47524 Mdot
.0698 .475 Mdot
.06985 .47476 Mdot
.0699 .47452 Mdot
.06995 .47428 Mdot
.07 .47404 Mdot
.07004 .4738 Mdot
.07009 .47356 Mdot
.07014 .47332 Mdot
.07019 .47308 Mdot
.07023 .47284 Mdot
.07028 .4726 Mdot
.07033 .47236 Mdot
.07038 .47211 Mdot
.07042 .47187 Mdot
.07047 .47163 Mdot
.07052 .47139 Mdot
.07057 .47115 Mdot
.07061 .4709 Mdot
.07066 .47066 Mdot
.07071 .47042 Mdot
.07076 .47017 Mdot
.0708 .46993 Mdot
.07085 .46969 Mdot
.0709 .46944 Mdot
.07095 .4692 Mdot
.071 .46896 Mdot
.07104 .46871 Mdot
.07109 .46847 Mdot
.07114 .46822 Mdot
.07119 .46798 Mdot
.07123 .46773 Mdot
.07128 .46749 Mdot
.07133 .46724 Mdot
.07138 .467 Mdot
.07142 .46675 Mdot
.07147 .46651 Mdot
.07152 .46626 Mdot
.07157 .46602 Mdot
.07161 .46577 Mdot
.07166 .46553 Mdot
.07171 .46528 Mdot
.07176 .46503 Mdot
.0718 .46479 Mdot
.07185 .46454 Mdot
.0719 .46429 Mdot
.07195 .46405 Mdot
.072 .4638 Mdot
.07204 .46355 Mdot
.07209 .4633 Mdot
.07214 .46306 Mdot
.07219 .46281 Mdot
.07223 .46256 Mdot
.07228 .46231 Mdot
.07233 .46206 Mdot
.07238 .46181 Mdot
.07242 .46157 Mdot
.07247 .46132 Mdot
.07252 .46107 Mdot
.07257 .46082 Mdot
.07261 .46057 Mdot
.07266 .46032 Mdot
.07271 .46007 Mdot
.07276 .45982 Mdot
.0728 .45957 Mdot
.07285 .45932 Mdot
.0729 .45907 Mdot
.07295 .45882 Mdot
.073 .45857 Mdot
.07304 .45832 Mdot
.07309 .45807 Mdot
.07314 .45782 Mdot
.07319 .45757 Mdot
.07323 .45732 Mdot
.07328 .45707 Mdot
.07333 .45681 Mdot
.07338 .45656 Mdot
.07342 .45631 Mdot
.07347 .45606 Mdot
.07352 .45581 Mdot
.07357 .45555 Mdot
.07361 .4553 Mdot
.07366 .45505 Mdot
.07371 .4548 Mdot
.07376 .45454 Mdot
.0738 .45429 Mdot
.07385 .45404 Mdot
.0739 .45379 Mdot
.07395 .45353 Mdot
.07399 .45328 Mdot
.07404 .45302 Mdot
.07409 .45277 Mdot
.07414 .45252 Mdot
.07419 .45226 Mdot
.07423 .45201 Mdot
.07428 .45175 Mdot
.07433 .4515 Mdot
.07438 .45125 Mdot
.07442 .45099 Mdot
.07447 .45074 Mdot
.07452 .45048 Mdot
.07457 .45023 Mdot
.07461 .44997 Mdot
.07466 .44971 Mdot
.07471 .44946 Mdot
.07476 .4492 Mdot
.0748 .44895 Mdot
.07485 .44869 Mdot
.0749 .44843 Mdot
.07495 .44818 Mdot
.07499 .44792 Mdot
.07504 .44767 Mdot
.07509 .44741 Mdot
.07514 .44715 Mdot
.07519 .44689 Mdot
.07523 .44664 Mdot
.07528 .44638 Mdot
.07533 .44612 Mdot
.07538 .44586 Mdot
.07542 .44561 Mdot
.07547 .44535 Mdot
.07552 .44509 Mdot
.07557 .44483 Mdot
.07561 .44457 Mdot
.07566 .44432 Mdot
.07571 .44406 Mdot
.07576 .4438 Mdot
.0758 .44354 Mdot
.07585 .44328 Mdot
.0759 .44302 Mdot
.07595 .44276 Mdot
.07599 .4425 Mdot
.07604 .44224 Mdot
.07609 .44198 Mdot
.07614 .44172 Mdot
.07619 .44146 Mdot
.07623 .4412 Mdot
.07628 .44094 Mdot
.07633 .44068 Mdot
.07638 .44042 Mdot
.07642 .44016 Mdot
.07647 .4399 Mdot
.07652 .43964 Mdot
.07657 .43938 Mdot
.07661 .43912 Mdot
.07666 .43886 Mdot
.07671 .4386 Mdot
.07676 .43834 Mdot
.0768 .43807 Mdot
.07685 .43781 Mdot
.0769 .43755 Mdot
.07695 .43729 Mdot
.07699 .43703 Mdot
.07704 .43676 Mdot
.07709 .4365 Mdot
.07714 .43624 Mdot
.07719 .43598 Mdot
.07723 .43571 Mdot
.07728 .43545 Mdot
.07733 .43519 Mdot
.07738 .43492 Mdot
.07742 .43466 Mdot
.07747 .4344 Mdot
.07752 .43413 Mdot
.07757 .43387 Mdot
.07761 .43361 Mdot
.07766 .43334 Mdot
.07771 .43308 Mdot
.07776 .43281 Mdot
.0778 .43255 Mdot
.07785 .43229 Mdot
.0779 .43202 Mdot
.07795 .43176 Mdot
.07799 .43149 Mdot
.07804 .43123 Mdot
.07809 .43096 Mdot
.07814 .4307 Mdot
.07819 .43043 Mdot
.07823 .43017 Mdot
.07828 .4299 Mdot
.07833 .42964 Mdot
.07838 .42937 Mdot
.07842 .4291 Mdot
.07847 .42884 Mdot
.07852 .42857 Mdot
.07857 .42831 Mdot
.07861 .42804 Mdot
.07866 .42777 Mdot
.07871 .42751 Mdot
.07876 .42724 Mdot
.0788 .42697 Mdot
.07885 .42671 Mdot
.0789 .42644 Mdot
.07895 .42617 Mdot
.07899 .4259 Mdot
.07904 .42564 Mdot
.07909 .42537 Mdot
.07914 .4251 Mdot
.07918 .42483 Mdot
.07923 .42457 Mdot
.07928 .4243 Mdot
.07933 .42403 Mdot
.07938 .42376 Mdot
.07942 .42349 Mdot
.07947 .42322 Mdot
.07952 .42296 Mdot
.07957 .42269 Mdot
.07961 .42242 Mdot
.07966 .42215 Mdot
.07971 .42188 Mdot
.07976 .42161 Mdot
.0798 .42134 Mdot
.07985 .42107 Mdot
.0799 .4208 Mdot
.07995 .42053 Mdot
.07999 .42026 Mdot
.08004 .41999 Mdot
.08009 .41972 Mdot
.08014 .41945 Mdot
.08018 .41918 Mdot
.08023 .41891 Mdot
.08028 .41864 Mdot
.08033 .41837 Mdot
.08038 .4181 Mdot
.08042 .41783 Mdot
.08047 .41756 Mdot
.08052 .41729 Mdot
.08057 .41702 Mdot
.08061 .41675 Mdot
.08066 .41648 Mdot
.08071 .4162 Mdot
.08076 .41593 Mdot
.0808 .41566 Mdot
.08085 .41539 Mdot
.0809 .41512 Mdot
.08095 .41485 Mdot
.08099 .41457 Mdot
.08104 .4143 Mdot
.08109 .41403 Mdot
.08114 .41376 Mdot
.08118 .41349 Mdot
.08123 .41321 Mdot
.08128 .41294 Mdot
.08133 .41267 Mdot
.08138 .41239 Mdot
.08142 .41212 Mdot
.08147 .41185 Mdot
.08152 .41158 Mdot
.08157 .4113 Mdot
.08161 .41103 Mdot
.08166 .41076 Mdot
.08171 .41048 Mdot
.08176 .41021 Mdot
.0818 .40993 Mdot
.08185 .40966 Mdot
.0819 .40939 Mdot
.08195 .40911 Mdot
.08199 .40884 Mdot
.08204 .40856 Mdot
.08209 .40829 Mdot
.08214 .40802 Mdot
.08218 .40774 Mdot
.08223 .40747 Mdot
.08228 .40719 Mdot
.08233 .40692 Mdot
.08238 .40664 Mdot
.08242 .40637 Mdot
.08247 .40609 Mdot
.08252 .40582 Mdot
.08257 .40554 Mdot
.08261 .40527 Mdot
.08266 .40499 Mdot
.08271 .40471 Mdot
.08276 .40444 Mdot
.0828 .40416 Mdot
.08285 .40389 Mdot
.0829 .40361 Mdot
.08295 .40333 Mdot
.08299 .40306 Mdot
.08304 .40278 Mdot
.08309 .40251 Mdot
.08314 .40223 Mdot
.08318 .40195 Mdot
.08323 .40168 Mdot
.08328 .4014 Mdot
.08333 .40112 Mdot
.08337 .40085 Mdot
.08342 .40057 Mdot
.08347 .40029 Mdot
.08352 .40001 Mdot
.08357 .39974 Mdot
.08361 .39946 Mdot
.08366 .39918 Mdot
.08371 .3989 Mdot
.08376 .39863 Mdot
.0838 .39835 Mdot
.08385 .39807 Mdot
.0839 .39779 Mdot
.08395 .39751 Mdot
.08399 .39724 Mdot
.08404 .39696 Mdot
.08409 .39668 Mdot
.08414 .3964 Mdot
.08418 .39612 Mdot
.08423 .39584 Mdot
.08428 .39557 Mdot
.08433 .39529 Mdot
.08437 .39501 Mdot
.08442 .39473 Mdot
.08447 .39445 Mdot
.08452 .39417 Mdot
.08457 .39389 Mdot
.08461 .39361 Mdot
.08466 .39333 Mdot
.08471 .39305 Mdot
.08476 .39277 Mdot
.0848 .39249 Mdot
.08485 .39221 Mdot
.0849 .39193 Mdot
.08495 .39166 Mdot
.08499 .39138 Mdot
.08504 .3911 Mdot
.08509 .39082 Mdot
.08514 .39053 Mdot
.08518 .39025 Mdot
.08523 .38997 Mdot
.08528 .38969 Mdot
.08533 .38941 Mdot
.08537 .38913 Mdot
.08542 .38885 Mdot
.08547 .38857 Mdot
.08552 .38829 Mdot
.08557 .38801 Mdot
.08561 .38773 Mdot
.08566 .38745 Mdot
.08571 .38717 Mdot
.08576 .38688 Mdot
.0858 .3866 Mdot
.08585 .38632 Mdot
.0859 .38604 Mdot
.08595 .38576 Mdot
.08599 .38548 Mdot
.08604 .3852 Mdot
.08609 .38491 Mdot
.08614 .38463 Mdot
.08618 .38435 Mdot
.08623 .38407 Mdot
.08628 .38379 Mdot
.08633 .3835 Mdot
.08637 .38322 Mdot
.08642 .38294 Mdot
.08647 .38266 Mdot
.08652 .38237 Mdot
.08657 .38209 Mdot
.08661 .38181 Mdot
.08666 .38153 Mdot
.08671 .38124 Mdot
.08676 .38096 Mdot
.0868 .38068 Mdot
.08685 .3804 Mdot
.0869 .38011 Mdot
.08695 .37983 Mdot
.08699 .37955 Mdot
.08704 .37926 Mdot
.08709 .37898 Mdot
.08714 .3787 Mdot
.08718 .37841 Mdot
.08723 .37813 Mdot
.08728 .37785 Mdot
.08733 .37756 Mdot
.08737 .37728 Mdot
.08742 .37699 Mdot
.08747 .37671 Mdot
.08752 .37643 Mdot
.08757 .37614 Mdot
.08761 .37586 Mdot
.08766 .37557 Mdot
.08771 .37529 Mdot
.08776 .37501 Mdot
.0878 .37472 Mdot
.08785 .37444 Mdot
.0879 .37415 Mdot
.08795 .37387 Mdot
.08799 .37358 Mdot
.08804 .3733 Mdot
.08809 .37301 Mdot
.08814 .37273 Mdot
.08818 .37244 Mdot
.08823 .37216 Mdot
.08828 .37187 Mdot
.08833 .37159 Mdot
.08837 .3713 Mdot
.08842 .37102 Mdot
.08847 .37073 Mdot
.08852 .37045 Mdot
.08856 .37016 Mdot
.08861 .36988 Mdot
.08866 .36959 Mdot
.08871 .36931 Mdot
.08876 .36902 Mdot
.0888 .36873 Mdot
.08885 .36845 Mdot
.0889 .36816 Mdot
.08895 .36788 Mdot
.08899 .36759 Mdot
.08904 .36731 Mdot
.08909 .36702 Mdot
.08914 .36673 Mdot
.08918 .36645 Mdot
.08923 .36616 Mdot
.08928 .36587 Mdot
.08933 .36559 Mdot
.08937 .3653 Mdot
.08942 .36502 Mdot
.08947 .36473 Mdot
.08952 .36444 Mdot
.08956 .36416 Mdot
.08961 .36387 Mdot
.08966 .36358 Mdot
.08971 .3633 Mdot
.08976 .36301 Mdot
.0898 .36272 Mdot
.08985 .36243 Mdot
.0899 .36215 Mdot
.08995 .36186 Mdot
.08999 .36157 Mdot
.09004 .36129 Mdot
.09009 .361 Mdot
.09014 .36071 Mdot
.09018 .36042 Mdot
.09023 .36014 Mdot
.09028 .35985 Mdot
.09033 .35956 Mdot
.09037 .35927 Mdot
.09042 .35899 Mdot
.09047 .3587 Mdot
.09052 .35841 Mdot
.09056 .35812 Mdot
.09061 .35784 Mdot
.09066 .35755 Mdot
.09071 .35726 Mdot
.09076 .35697 Mdot
.0908 .35668 Mdot
.09085 .3564 Mdot
.0909 .35611 Mdot
.09095 .35582 Mdot
.09099 .35553 Mdot
.09104 .35524 Mdot
.09109 .35496 Mdot
.09114 .35467 Mdot
.09118 .35438 Mdot
.09123 .35409 Mdot
.09128 .3538 Mdot
.09133 .35351 Mdot
.09137 .35323 Mdot
.09142 .35294 Mdot
.09147 .35265 Mdot
.09152 .35236 Mdot
.09156 .35207 Mdot
.09161 .35178 Mdot
.09166 .35149 Mdot
.09171 .3512 Mdot
.09176 .35092 Mdot
.0918 .35063 Mdot
.09185 .35034 Mdot
.0919 .35005 Mdot
.09195 .34976 Mdot
.09199 .34947 Mdot
.09204 .34918 Mdot
.09209 .34889 Mdot
.09214 .3486 Mdot
.09218 .34831 Mdot
.09223 .34802 Mdot
.09228 .34774 Mdot
.09233 .34745 Mdot
.09237 .34716 Mdot
.09242 .34687 Mdot
.09247 .34658 Mdot
.09252 .34629 Mdot
.09256 .346 Mdot
.09261 .34571 Mdot
.09266 .34542 Mdot
.09271 .34513 Mdot
.09276 .34484 Mdot
.0928 .34455 Mdot
.09285 .34426 Mdot
.0929 .34397 Mdot
.09295 .34368 Mdot
.09299 .34339 Mdot
.09304 .3431 Mdot
.09309 .34281 Mdot
.09314 .34252 Mdot
.09318 .34223 Mdot
.09323 .34194 Mdot
.09328 .34165 Mdot
.09333 .34136 Mdot
.09337 .34107 Mdot
.09342 .34078 Mdot
.09347 .34049 Mdot
.09352 .3402 Mdot
.09356 .33991 Mdot
.09361 .33962 Mdot
.09366 .33933 Mdot
.09371 .33904 Mdot
.09375 .33875 Mdot
.0938 .33846 Mdot
.09385 .33817 Mdot
.0939 .33788 Mdot
.09395 .33759 Mdot
.09399 .3373 Mdot
.09404 .337 Mdot
.09409 .33671 Mdot
.09414 .33642 Mdot
.09418 .33613 Mdot
.09423 .33584 Mdot
.09428 .33555 Mdot
.09433 .33526 Mdot
.09437 .33497 Mdot
.09442 .33468 Mdot
.09447 .33439 Mdot
.09452 .3341 Mdot
.09456 .33381 Mdot
.09461 .33352 Mdot
.09466 .33322 Mdot
.09471 .33293 Mdot
.09475 .33264 Mdot
.0948 .33235 Mdot
.09485 .33206 Mdot
.0949 .33177 Mdot
.09495 .33148 Mdot
.09499 .33119 Mdot
.09504 .3309 Mdot
.09509 .33061 Mdot
.09514 .33031 Mdot
.09518 .33002 Mdot
.09523 .32973 Mdot
.09528 .32944 Mdot
.09533 .32915 Mdot
.09537 .32886 Mdot
.09542 .32857 Mdot
.09547 .32828 Mdot
.09552 .32798 Mdot
.09556 .32769 Mdot
.09561 .3274 Mdot
.09566 .32711 Mdot
.09571 .32682 Mdot
.09575 .32653 Mdot
.0958 .32624 Mdot
.09585 .32594 Mdot
.0959 .32565 Mdot
.09595 .32536 Mdot
.09599 .32507 Mdot
.09604 .32478 Mdot
.09609 .32449 Mdot
.09614 .32419 Mdot
.09618 .3239 Mdot
.09623 .32361 Mdot
.09628 .32332 Mdot
.09633 .32303 Mdot
.09637 .32274 Mdot
.09642 .32245 Mdot
.09647 .32215 Mdot
.09652 .32186 Mdot
.09656 .32157 Mdot
.09661 .32128 Mdot
.09666 .32099 Mdot
.09671 .32069 Mdot
.09675 .3204 Mdot
.0968 .32011 Mdot
.09685 .31982 Mdot
.0969 .31953 Mdot
.09695 .31924 Mdot
.09699 .31894 Mdot
.09704 .31865 Mdot
.09709 .31836 Mdot
.09714 .31807 Mdot
.09718 .31778 Mdot
.09723 .31749 Mdot
.09728 .31719 Mdot
.09733 .3169 Mdot
.09737 .31661 Mdot
.09742 .31632 Mdot
.09747 .31603 Mdot
.09752 .31573 Mdot
.09756 .31544 Mdot
.09761 .31515 Mdot
.09766 .31486 Mdot
.09771 .31457 Mdot
.09775 .31427 Mdot
.0978 .31398 Mdot
.09785 .31369 Mdot
.0979 .3134 Mdot
.09794 .31311 Mdot
.09799 .31281 Mdot
.09804 .31252 Mdot
.09809 .31223 Mdot
.09814 .31194 Mdot
.09818 .31165 Mdot
.09823 .31135 Mdot
.09828 .31106 Mdot
.09833 .31077 Mdot
.09837 .31048 Mdot
.09842 .31019 Mdot
.09847 .30989 Mdot
.09852 .3096 Mdot
.09856 .30931 Mdot
.09861 .30902 Mdot
.09866 .30873 Mdot
.09871 .30843 Mdot
.09875 .30814 Mdot
.0988 .30785 Mdot
.09885 .30756 Mdot
.0989 .30727 Mdot
.09894 .30697 Mdot
.09899 .30668 Mdot
.09904 .30639 Mdot
.09909 .3061 Mdot
.09914 .30581 Mdot
.09918 .30551 Mdot
.09923 .30522 Mdot
.09928 .30493 Mdot
.09933 .30464 Mdot
.09937 .30435 Mdot
.09942 .30405 Mdot
.09947 .30376 Mdot
.09952 .30347 Mdot
.09956 .30318 Mdot
.09961 .30289 Mdot
.09966 .30259 Mdot
.09971 .3023 Mdot
.09975 .30201 Mdot
.0998 .30172 Mdot
.09985 .30143 Mdot
.0999 .30114 Mdot
.09994 .30084 Mdot
.09999 .30055 Mdot
.10004 .30026 Mdot
.10009 .29997 Mdot
.10014 .29968 Mdot
.10018 .29938 Mdot
.10023 .29909 Mdot
.10028 .2988 Mdot
.10033 .29851 Mdot
.10037 .29822 Mdot
.10042 .29792 Mdot
.10047 .29763 Mdot
.10052 .29734 Mdot
.10056 .29705 Mdot
.10061 .29676 Mdot
.10066 .29647 Mdot
.10071 .29617 Mdot
.10075 .29588 Mdot
.1008 .29559 Mdot
.10085 .2953 Mdot
.1009 .29501 Mdot
.10094 .29472 Mdot
.10099 .29442 Mdot
.10104 .29413 Mdot
.10109 .29384 Mdot
.10114 .29355 Mdot
.10118 .29326 Mdot
.10123 .29297 Mdot
.10128 .29267 Mdot
.10133 .29238 Mdot
.10137 .29209 Mdot
.10142 .2918 Mdot
.10147 .29151 Mdot
.10152 .29122 Mdot
.10156 .29093 Mdot
.10161 .29063 Mdot
.10166 .29034 Mdot
.10171 .29005 Mdot
.10175 .28976 Mdot
.1018 .28947 Mdot
.10185 .28918 Mdot
.1019 .28889 Mdot
.10194 .28859 Mdot
.10199 .2883 Mdot
.10204 .28801 Mdot
.10209 .28772 Mdot
.10214 .28743 Mdot
.10218 .28714 Mdot
.10223 .28685 Mdot
.10228 .28656 Mdot
.10233 .28626 Mdot
.10237 .28597 Mdot
.10242 .28568 Mdot
.10247 .28539 Mdot
.10252 .2851 Mdot
.10256 .28481 Mdot
.10261 .28452 Mdot
.10266 .28423 Mdot
.10271 .28394 Mdot
.10275 .28364 Mdot
.1028 .28335 Mdot
.10285 .28306 Mdot
.1029 .28277 Mdot
.10294 .28248 Mdot
.10299 .28219 Mdot
.10304 .2819 Mdot
.10309 .28161 Mdot
.10313 .28132 Mdot
.10318 .28103 Mdot
.10323 .28074 Mdot
.10328 .28045 Mdot
.10333 .28016 Mdot
.10337 .27986 Mdot
.10342 .27957 Mdot
.10347 .27928 Mdot
.10352 .27899 Mdot
.10356 .2787 Mdot
.10361 .27841 Mdot
.10366 .27812 Mdot
.10371 .27783 Mdot
.10375 .27754 Mdot
.1038 .27725 Mdot
.10385 .27696 Mdot
.1039 .27667 Mdot
.10394 .27638 Mdot
.10399 .27609 Mdot
.10404 .2758 Mdot
.10409 .27551 Mdot
.10413 .27522 Mdot
.10418 .27493 Mdot
.10423 .27464 Mdot
.10428 .27435 Mdot
.10433 .27406 Mdot
.10437 .27377 Mdot
.10442 .27348 Mdot
.10447 .27319 Mdot
.10452 .2729 Mdot
.10456 .27261 Mdot
.10461 .27232 Mdot
.10466 .27203 Mdot
.10471 .27174 Mdot
.10475 .27145 Mdot
.1048 .27116 Mdot
.10485 .27087 Mdot
.1049 .27058 Mdot
.10494 .27029 Mdot
.10499 .27 Mdot
.10504 .26971 Mdot
.10509 .26942 Mdot
.10513 .26913 Mdot
.10518 .26885 Mdot
.10523 .26856 Mdot
.10528 .26827 Mdot
.10533 .26798 Mdot
.10537 .26769 Mdot
.10542 .2674 Mdot
.10547 .26711 Mdot
.10552 .26682 Mdot
.10556 .26653 Mdot
.10561 .26624 Mdot
.10566 .26595 Mdot
.10571 .26567 Mdot
.10575 .26538 Mdot
.1058 .26509 Mdot
.10585 .2648 Mdot
.1059 .26451 Mdot
.10594 .26422 Mdot
.10599 .26393 Mdot
.10604 .26364 Mdot
.10609 .26336 Mdot
.10613 .26307 Mdot
.10618 .26278 Mdot
.10623 .26249 Mdot
.10628 .2622 Mdot
.10633 .26191 Mdot
.10637 .26163 Mdot
.10642 .26134 Mdot
.10647 .26105 Mdot
.10652 .26076 Mdot
.10656 .26047 Mdot
.10661 .26019 Mdot
.10666 .2599 Mdot
.10671 .25961 Mdot
.10675 .25932 Mdot
.1068 .25903 Mdot
.10685 .25875 Mdot
.1069 .25846 Mdot
.10694 .25817 Mdot
.10699 .25788 Mdot
.10704 .2576 Mdot
.10709 .25731 Mdot
.10713 .25702 Mdot
.10718 .25673 Mdot
.10723 .25645 Mdot
.10728 .25616 Mdot
.10732 .25587 Mdot
.10737 .25558 Mdot
.10742 .2553 Mdot
.10747 .25501 Mdot
.10752 .25472 Mdot
.10756 .25444 Mdot
.10761 .25415 Mdot
.10766 .25386 Mdot
.10771 .25358 Mdot
.10775 .25329 Mdot
.1078 .253 Mdot
.10785 .25272 Mdot
.1079 .25243 Mdot
.10794 .25214 Mdot
.10799 .25186 Mdot
.10804 .25157 Mdot
.10809 .25128 Mdot
.10813 .251 Mdot
.10818 .25071 Mdot
.10823 .25042 Mdot
.10828 .25014 Mdot
.10832 .24985 Mdot
.10837 .24957 Mdot
.10842 .24928 Mdot
.10847 .24899 Mdot
.10852 .24871 Mdot
.10856 .24842 Mdot
.10861 .24814 Mdot
.10866 .24785 Mdot
.10871 .24757 Mdot
.10875 .24728 Mdot
.1088 .24699 Mdot
.10885 .24671 Mdot
.1089 .24642 Mdot
.10894 .24614 Mdot
.10899 .24585 Mdot
.10904 .24557 Mdot
.10909 .24528 Mdot
.10913 .245 Mdot
.10918 .24471 Mdot
.10923 .24443 Mdot
.10928 .24414 Mdot
.10932 .24386 Mdot
.10937 .24357 Mdot
.10942 .24329 Mdot
.10947 .243 Mdot
.10952 .24272 Mdot
.10956 .24244 Mdot
.10961 .24215 Mdot
.10966 .24187 Mdot
.10971 .24158 Mdot
.10975 .2413 Mdot
.1098 .24101 Mdot
.10985 .24073 Mdot
.1099 .24045 Mdot
.10994 .24016 Mdot
.10999 .23988 Mdot
.11004 .23959 Mdot
.11009 .23931 Mdot
.11013 .23903 Mdot
.11018 .23874 Mdot
.11023 .23846 Mdot
.11028 .23818 Mdot
.11032 .23789 Mdot
.11037 .23761 Mdot
.11042 .23733 Mdot
.11047 .23704 Mdot
.11052 .23676 Mdot
.11056 .23648 Mdot
.11061 .23619 Mdot
.11066 .23591 Mdot
.11071 .23563 Mdot
.11075 .23535 Mdot
.1108 .23506 Mdot
.11085 .23478 Mdot
.1109 .2345 Mdot
.11094 .23422 Mdot
.11099 .23393 Mdot
.11104 .23365 Mdot
.11109 .23337 Mdot
.11113 .23309 Mdot
.11118 .2328 Mdot
.11123 .23252 Mdot
.11128 .23224 Mdot
.11132 .23196 Mdot
.11137 .23168 Mdot
.11142 .2314 Mdot
.11147 .23111 Mdot
.11152 .23083 Mdot
.11156 .23055 Mdot
.11161 .23027 Mdot
.11166 .22999 Mdot
.11171 .22971 Mdot
.11175 .22943 Mdot
.1118 .22915 Mdot
.11185 .22886 Mdot
.1119 .22858 Mdot
.11194 .2283 Mdot
.11199 .22802 Mdot
.11204 .22774 Mdot
.11209 .22746 Mdot
.11213 .22718 Mdot
.11218 .2269 Mdot
.11223 .22662 Mdot
.11228 .22634 Mdot
.11232 .22606 Mdot
.11237 .22578 Mdot
.11242 .2255 Mdot
.11247 .22522 Mdot
.11251 .22494 Mdot
.11256 .22466 Mdot
.11261 .22438 Mdot
.11266 .2241 Mdot
.11271 .22382 Mdot
.11275 .22354 Mdot
.1128 .22326 Mdot
.11285 .22298 Mdot
.1129 .2227 Mdot
.11294 .22242 Mdot
.11299 .22215 Mdot
.11304 .22187 Mdot
.11309 .22159 Mdot
.11313 .22131 Mdot
.11318 .22103 Mdot
.11323 .22075 Mdot
.11328 .22047 Mdot
.11332 .2202 Mdot
.11337 .21992 Mdot
.11342 .21964 Mdot
.11347 .21936 Mdot
.11351 .21908 Mdot
.11356 .2188 Mdot
.11361 .21853 Mdot
.11366 .21825 Mdot
.11371 .21797 Mdot
.11375 .21769 Mdot
.1138 .21742 Mdot
.11385 .21714 Mdot
.1139 .21686 Mdot
.11394 .21658 Mdot
.11399 .21631 Mdot
.11404 .21603 Mdot
.11409 .21575 Mdot
.11413 .21548 Mdot
.11418 .2152 Mdot
.11423 .21492 Mdot
.11428 .21465 Mdot
.11432 .21437 Mdot
.11437 .21409 Mdot
.11442 .21382 Mdot
.11447 .21354 Mdot
.11451 .21327 Mdot
.11456 .21299 Mdot
.11461 .21271 Mdot
.11466 .21244 Mdot
.11471 .21216 Mdot
.11475 .21189 Mdot
.1148 .21161 Mdot
.11485 .21134 Mdot
.1149 .21106 Mdot
.11494 .21078 Mdot
.11499 .21051 Mdot
.11504 .21023 Mdot
.11509 .20996 Mdot
.11513 .20968 Mdot
.11518 .20941 Mdot
.11523 .20914 Mdot
.11528 .20886 Mdot
.11532 .20859 Mdot
.11537 .20831 Mdot
.11542 .20804 Mdot
.11547 .20776 Mdot
.11551 .20749 Mdot
.11556 .20722 Mdot
.11561 .20694 Mdot
.11566 .20667 Mdot
.11571 .20639 Mdot
.11575 .20612 Mdot
.1158 .20585 Mdot
.11585 .20557 Mdot
.1159 .2053 Mdot
.11594 .20503 Mdot
.11599 .20476 Mdot
.11604 .20448 Mdot
.11609 .20421 Mdot
.11613 .20394 Mdot
.11618 .20366 Mdot
.11623 .20339 Mdot
.11628 .20312 Mdot
.11632 .20285 Mdot
.11637 .20258 Mdot
.11642 .2023 Mdot
.11647 .20203 Mdot
.11651 .20176 Mdot
.11656 .20149 Mdot
.11661 .20122 Mdot
.11666 .20094 Mdot
.1167 .20067 Mdot
.11675 .2004 Mdot
.1168 .20013 Mdot
.11685 .19986 Mdot
.1169 .19959 Mdot
.11694 .19932 Mdot
.11699 .19905 Mdot
.11704 .19878 Mdot
.11709 .19851 Mdot
.11713 .19824 Mdot
.11718 .19796 Mdot
.11723 .19769 Mdot
.11728 .19742 Mdot
.11732 .19715 Mdot
.11737 .19688 Mdot
.11742 .19661 Mdot
.11747 .19635 Mdot
.11751 .19608 Mdot
.11756 .19581 Mdot
.11761 .19554 Mdot
.11766 .19527 Mdot
.1177 .195 Mdot
.11775 .19473 Mdot
.1178 .19446 Mdot
.11785 .19419 Mdot
.1179 .19392 Mdot
.11794 .19365 Mdot
.11799 .19339 Mdot
.11804 .19312 Mdot
.11809 .19285 Mdot
.11813 .19258 Mdot
.11818 .19231 Mdot
.11823 .19205 Mdot
.11828 .19178 Mdot
.11832 .19151 Mdot
.11837 .19124 Mdot
.11842 .19098 Mdot
.11847 .19071 Mdot
.11851 .19044 Mdot
.11856 .19017 Mdot
.11861 .18991 Mdot
.11866 .18964 Mdot
.1187 .18937 Mdot
.11875 .18911 Mdot
.1188 .18884 Mdot
.11885 .18857 Mdot
.1189 .18831 Mdot
.11894 .18804 Mdot
.11899 .18778 Mdot
.11904 .18751 Mdot
.11909 .18725 Mdot
.11913 .18698 Mdot
.11918 .18671 Mdot
.11923 .18645 Mdot
.11928 .18618 Mdot
.11932 .18592 Mdot
.11937 .18565 Mdot
.11942 .18539 Mdot
.11947 .18512 Mdot
.11951 .18486 Mdot
.11956 .1846 Mdot
.11961 .18433 Mdot
.11966 .18407 Mdot
.1197 .1838 Mdot
.11975 .18354 Mdot
.1198 .18327 Mdot
.11985 .18301 Mdot
.1199 .18275 Mdot
.11994 .18248 Mdot
.11999 .18222 Mdot
.12004 .18196 Mdot
.12009 .18169 Mdot
.12013 .18143 Mdot
.12018 .18117 Mdot
.12023 .18091 Mdot
.12028 .18064 Mdot
.12032 .18038 Mdot
.12037 .18012 Mdot
.12042 .17986 Mdot
.12047 .17959 Mdot
.12051 .17933 Mdot
.12056 .17907 Mdot
.12061 .17881 Mdot
.12066 .17855 Mdot
.1207 .17829 Mdot
.12075 .17802 Mdot
.1208 .17776 Mdot
.12085 .1775 Mdot
.1209 .17724 Mdot
.12094 .17698 Mdot
.12099 .17672 Mdot
.12104 .17646 Mdot
.12109 .1762 Mdot
.12113 .17594 Mdot
.12118 .17568 Mdot
.12123 .17542 Mdot
.12128 .17516 Mdot
.12132 .1749 Mdot
.12137 .17464 Mdot
.12142 .17438 Mdot
.12147 .17412 Mdot
.12151 .17386 Mdot
.12156 .1736 Mdot
.12161 .17334 Mdot
.12166 .17308 Mdot
.1217 .17283 Mdot
.12175 .17257 Mdot
.1218 .17231 Mdot
.12185 .17205 Mdot
.12189 .17179 Mdot
.12194 .17154 Mdot
.12199 .17128 Mdot
.12204 .17102 Mdot
.12209 .17076 Mdot
.12213 .1705 Mdot
.12218 .17025 Mdot
.12223 .16999 Mdot
.12228 .16973 Mdot
.12232 .16948 Mdot
.12237 .16922 Mdot
.12242 .16896 Mdot
.12247 .16871 Mdot
.12251 .16845 Mdot
.12256 .16819 Mdot
.12261 .16794 Mdot
.12266 .16768 Mdot
.1227 .16743 Mdot
.12275 .16717 Mdot
.1228 .16692 Mdot
.12285 .16666 Mdot
.12289 .16641 Mdot
.12294 .16615 Mdot
.12299 .1659 Mdot
.12304 .16564 Mdot
.12309 .16539 Mdot
.12313 .16513 Mdot
.12318 .16488 Mdot
.12323 .16462 Mdot
.12328 .16437 Mdot
.12332 .16412 Mdot
.12337 .16386 Mdot
.12342 .16361 Mdot
.12347 .16335 Mdot
.12351 .1631 Mdot
.12356 .16285 Mdot
.12361 .1626 Mdot
.12366 .16234 Mdot
.1237 .16209 Mdot
.12375 .16184 Mdot
.1238 .16158 Mdot
.12385 .16133 Mdot
.12389 .16108 Mdot
.12394 .16083 Mdot
.12399 .16058 Mdot
.12404 .16032 Mdot
.12409 .16007 Mdot
.12413 .15982 Mdot
.12418 .15957 Mdot
.12423 .15932 Mdot
.12428 .15907 Mdot
.12432 .15882 Mdot
.12437 .15857 Mdot
.12442 .15832 Mdot
.12447 .15807 Mdot
.12451 .15782 Mdot
.12456 .15757 Mdot
.12461 .15732 Mdot
.12466 .15707 Mdot
.1247 .15682 Mdot
.12475 .15657 Mdot
.1248 .15632 Mdot
.12485 .15607 Mdot
.12489 .15582 Mdot
.12494 .15557 Mdot
.12499 .15532 Mdot
.12504 .15507 Mdot
.12509 .15483 Mdot
.12513 .15458 Mdot
.12518 .15433 Mdot
.12523 .15408 Mdot
.12528 .15383 Mdot
.12532 .15359 Mdot
.12537 .15334 Mdot
.12542 .15309 Mdot
.12547 .15284 Mdot
.12551 .1526 Mdot
.12556 .15235 Mdot
.12561 .1521 Mdot
.12566 .15186 Mdot
.1257 .15161 Mdot
.12575 .15136 Mdot
.1258 .15112 Mdot
.12585 .15087 Mdot
.12589 .15063 Mdot
.12594 .15038 Mdot
.12599 .15014 Mdot
.12604 .14989 Mdot
.12609 .14965 Mdot
.12613 .1494 Mdot
.12618 .14916 Mdot
.12623 .14891 Mdot
.12628 .14867 Mdot
.12632 .14842 Mdot
.12637 .14818 Mdot
.12642 .14793 Mdot
.12647 .14769 Mdot
.12651 .14745 Mdot
.12656 .1472 Mdot
.12661 .14696 Mdot
.12666 .14672 Mdot
.1267 .14647 Mdot
.12675 .14623 Mdot
.1268 .14599 Mdot
.12685 .14575 Mdot
.12689 .1455 Mdot
.12694 .14526 Mdot
.12699 .14502 Mdot
.12704 .14478 Mdot
.12708 .14454 Mdot
.12713 .14429 Mdot
.12718 .14405 Mdot
.12723 .14381 Mdot
.12728 .14357 Mdot
.12732 .14333 Mdot
.12737 .14309 Mdot
.12742 .14285 Mdot
.12747 .14261 Mdot
.12751 .14237 Mdot
.12756 .14213 Mdot
.12761 .14189 Mdot
.12766 .14165 Mdot
.1277 .14141 Mdot
.12775 .14117 Mdot
.1278 .14093 Mdot
.12785 .14069 Mdot
.12789 .14045 Mdot
.12794 .14021 Mdot
.12799 .13998 Mdot
.12804 .13974 Mdot
.12808 .1395 Mdot
.12813 .13926 Mdot
.12818 .13902 Mdot
.12823 .13879 Mdot
.12828 .13855 Mdot
.12832 .13831 Mdot
.12837 .13807 Mdot
.12842 .13784 Mdot
.12847 .1376 Mdot
.12851 .13736 Mdot
.12856 .13713 Mdot
.12861 .13689 Mdot
.12866 .13665 Mdot
.1287 .13642 Mdot
.12875 .13618 Mdot
.1288 .13595 Mdot
.12885 .13571 Mdot
.12889 .13548 Mdot
.12894 .13524 Mdot
.12899 .13501 Mdot
.12904 .13477 Mdot
.12908 .13454 Mdot
.12913 .1343 Mdot
.12918 .13407 Mdot
.12923 .13383 Mdot
.12928 .1336 Mdot
.12932 .13337 Mdot
.12937 .13313 Mdot
.12942 .1329 Mdot
.12947 .13267 Mdot
.12951 .13243 Mdot
.12956 .1322 Mdot
.12961 .13197 Mdot
.12966 .13173 Mdot
.1297 .1315 Mdot
.12975 .13127 Mdot
.1298 .13104 Mdot
.12985 .13081 Mdot
.12989 .13057 Mdot
.12994 .13034 Mdot
.12999 .13011 Mdot
.13004 .12988 Mdot
.13008 .12965 Mdot
.13013 .12942 Mdot
.13018 .12919 Mdot
.13023 .12896 Mdot
.13028 .12873 Mdot
.13032 .1285 Mdot
.13037 .12827 Mdot
.13042 .12804 Mdot
.13047 .12781 Mdot
.13051 .12758 Mdot
.13056 .12735 Mdot
.13061 .12712 Mdot
.13066 .12689 Mdot
.1307 .12666 Mdot
.13075 .12644 Mdot
.1308 .12621 Mdot
.13085 .12598 Mdot
.13089 .12575 Mdot
.13094 .12552 Mdot
.13099 .1253 Mdot
.13104 .12507 Mdot
.13108 .12484 Mdot
.13113 .12462 Mdot
.13118 .12439 Mdot
.13123 .12416 Mdot
.13127 .12394 Mdot
.13132 .12371 Mdot
.13137 .12348 Mdot
.13142 .12326 Mdot
.13147 .12303 Mdot
.13151 .12281 Mdot
.13156 .12258 Mdot
.13161 .12236 Mdot
.13166 .12213 Mdot
.1317 .12191 Mdot
.13175 .12168 Mdot
.1318 .12146 Mdot
.13185 .12123 Mdot
.13189 .12101 Mdot
.13194 .12079 Mdot
.13199 .12056 Mdot
.13204 .12034 Mdot
.13208 .12012 Mdot
.13213 .11989 Mdot
.13218 .11967 Mdot
.13223 .11945 Mdot
.13227 .11923 Mdot
.13232 .119 Mdot
.13237 .11878 Mdot
.13242 .11856 Mdot
.13247 .11834 Mdot
.13251 .11812 Mdot
.13256 .1179 Mdot
.13261 .11767 Mdot
.13266 .11745 Mdot
.1327 .11723 Mdot
.13275 .11701 Mdot
.1328 .11679 Mdot
.13285 .11657 Mdot
.13289 .11635 Mdot
.13294 .11613 Mdot
.13299 .11591 Mdot
.13304 .11569 Mdot
.13308 .11547 Mdot
.13313 .11525 Mdot
.13318 .11504 Mdot
.13323 .11482 Mdot
.13327 .1146 Mdot
.13332 .11438 Mdot
.13337 .11416 Mdot
.13342 .11395 Mdot
.13347 .11373 Mdot
.13351 .11351 Mdot
.13356 .11329 Mdot
.13361 .11308 Mdot
.13366 .11286 Mdot
.1337 .11264 Mdot
.13375 .11243 Mdot
.1338 .11221 Mdot
.13385 .11199 Mdot
.13389 .11178 Mdot
.13394 .11156 Mdot
.13399 .11135 Mdot
.13404 .11113 Mdot
.13408 .11092 Mdot
.13413 .1107 Mdot
.13418 .11049 Mdot
.13423 .11027 Mdot
.13427 .11006 Mdot
.13432 .10984 Mdot
.13437 .10963 Mdot
.13442 .10942 Mdot
.13447 .1092 Mdot
.13451 .10899 Mdot
.13456 .10878 Mdot
.13461 .10856 Mdot
.13466 .10835 Mdot
.1347 .10814 Mdot
.13475 .10793 Mdot
.1348 .10771 Mdot
.13485 .1075 Mdot
.13489 .10729 Mdot
.13494 .10708 Mdot
.13499 .10687 Mdot
.13504 .10666 Mdot
.13508 .10645 Mdot
.13513 .10623 Mdot
.13518 .10602 Mdot
.13523 .10581 Mdot
.13527 .1056 Mdot
.13532 .10539 Mdot
.13537 .10518 Mdot
.13542 .10497 Mdot
.13547 .10477 Mdot
.13551 .10456 Mdot
.13556 .10435 Mdot
.13561 .10414 Mdot
.13566 .10393 Mdot
.1357 .10372 Mdot
.13575 .10351 Mdot
.1358 .10331 Mdot
.13585 .1031 Mdot
.13589 .10289 Mdot
.13594 .10268 Mdot
.13599 .10248 Mdot
.13604 .10227 Mdot
.13608 .10206 Mdot
.13613 .10186 Mdot
.13618 .10165 Mdot
.13623 .10145 Mdot
.13627 .10124 Mdot
.13632 .10103 Mdot
.13637 .10083 Mdot
.13642 .10062 Mdot
.13646 .10042 Mdot
.13651 .10021 Mdot
.13656 .10001 Mdot
.13661 .0998 Mdot
.13666 .0996 Mdot
.1367 .0994 Mdot
.13675 .09919 Mdot
.1368 .09899 Mdot
.13685 .09879 Mdot
.13689 .09858 Mdot
.13694 .09838 Mdot
.13699 .09818 Mdot
.13704 .09798 Mdot
.13708 .09777 Mdot
.13713 .09757 Mdot
.13718 .09737 Mdot
.13723 .09717 Mdot
.13727 .09697 Mdot
.13732 .09677 Mdot
.13737 .09656 Mdot
.13742 .09636 Mdot
.13746 .09616 Mdot
.13751 .09596 Mdot
.13756 .09576 Mdot
.13761 .09556 Mdot
.13766 .09536 Mdot
.1377 .09516 Mdot
.13775 .09496 Mdot
.1378 .09477 Mdot
.13785 .09457 Mdot
.13789 .09437 Mdot
.13794 .09417 Mdot
.13799 .09397 Mdot
.13804 .09377 Mdot
.13808 .09358 Mdot
.13813 .09338 Mdot
.13818 .09318 Mdot
.13823 .09298 Mdot
.13827 .09279 Mdot
.13832 .09259 Mdot
.13837 .09239 Mdot
.13842 .0922 Mdot
.13846 .092 Mdot
.13851 .09181 Mdot
.13856 .09161 Mdot
.13861 .09141 Mdot
.13866 .09122 Mdot
.1387 .09102 Mdot
.13875 .09083 Mdot
.1388 .09064 Mdot
.13885 .09044 Mdot
.13889 .09025 Mdot
.13894 .09005 Mdot
.13899 .08986 Mdot
.13904 .08967 Mdot
.13908 .08947 Mdot
.13913 .08928 Mdot
.13918 .08909 Mdot
.13923 .08889 Mdot
.13927 .0887 Mdot
.13932 .08851 Mdot
.13937 .08832 Mdot
.13942 .08813 Mdot
.13946 .08794 Mdot
.13951 .08774 Mdot
.13956 .08755 Mdot
.13961 .08736 Mdot
.13966 .08717 Mdot
.1397 .08698 Mdot
.13975 .08679 Mdot
.1398 .0866 Mdot
.13985 .08641 Mdot
.13989 .08622 Mdot
.13994 .08603 Mdot
.13999 .08584 Mdot
.14004 .08566 Mdot
.14008 .08547 Mdot
.14013 .08528 Mdot
.14018 .08509 Mdot
.14023 .0849 Mdot
.14027 .08471 Mdot
.14032 .08453 Mdot
.14037 .08434 Mdot
.14042 .08415 Mdot
.14046 .08397 Mdot
.14051 .08378 Mdot
.14056 .08359 Mdot
.14061 .08341 Mdot
.14065 .08322 Mdot
.1407 .08304 Mdot
.14075 .08285 Mdot
.1408 .08267 Mdot
.14085 .08248 Mdot
.14089 .0823 Mdot
.14094 .08211 Mdot
.14099 .08193 Mdot
.14104 .08174 Mdot
.14108 .08156 Mdot
.14113 .08138 Mdot
.14118 .08119 Mdot
.14123 .08101 Mdot
.14127 .08083 Mdot
.14132 .08064 Mdot
.14137 .08046 Mdot
.14142 .08028 Mdot
.14146 .0801 Mdot
.14151 .07992 Mdot
.14156 .07973 Mdot
.14161 .07955 Mdot
.14165 .07937 Mdot
.1417 .07919 Mdot
.14175 .07901 Mdot
.1418 .07883 Mdot
.14185 .07865 Mdot
.14189 .07847 Mdot
.14194 .07829 Mdot
.14199 .07811 Mdot
.14204 .07793 Mdot
.14208 .07775 Mdot
.14213 .07757 Mdot
.14218 .07739 Mdot
.14223 .07722 Mdot
.14227 .07704 Mdot
.14232 .07686 Mdot
.14237 .07668 Mdot
.14242 .0765 Mdot
.14246 .07633 Mdot
.14251 .07615 Mdot
.14256 .07597 Mdot
.14261 .0758 Mdot
.14265 .07562 Mdot
.1427 .07545 Mdot
.14275 .07527 Mdot
.1428 .07509 Mdot
.14285 .07492 Mdot
.14289 .07474 Mdot
.14294 .07457 Mdot
.14299 .07439 Mdot
.14304 .07422 Mdot
.14308 .07405 Mdot
.14313 .07387 Mdot
.14318 .0737 Mdot
.14323 .07352 Mdot
.14327 .07335 Mdot
.14332 .07318 Mdot
.14337 .07301 Mdot
.14342 .07283 Mdot
.14346 .07266 Mdot
.14351 .07249 Mdot
.14356 .07232 Mdot
.14361 .07215 Mdot
.14365 .07197 Mdot
.1437 .0718 Mdot
.14375 .07163 Mdot
.1438 .07146 Mdot
.14385 .07129 Mdot
.14389 .07112 Mdot
.14394 .07095 Mdot
.14399 .07078 Mdot
.14404 .07061 Mdot
.14408 .07044 Mdot
.14413 .07027 Mdot
.14418 .07011 Mdot
.14423 .06994 Mdot
.14427 .06977 Mdot
.14432 .0696 Mdot
.14437 .06943 Mdot
.14442 .06927 Mdot
.14446 .0691 Mdot
.14451 .06893 Mdot
.14456 .06876 Mdot
.14461 .0686 Mdot
.14465 .06843 Mdot
.1447 .06827 Mdot
.14475 .0681 Mdot
.1448 .06793 Mdot
.14485 .06777 Mdot
.14489 .0676 Mdot
.14494 .06744 Mdot
.14499 .06727 Mdot
.14504 .06711 Mdot
.14508 .06695 Mdot
.14513 .06678 Mdot
.14518 .06662 Mdot
.14523 .06646 Mdot
.14527 .06629 Mdot
.14532 .06613 Mdot
.14537 .06597 Mdot
.14542 .0658 Mdot
.14546 .06564 Mdot
.14551 .06548 Mdot
.14556 .06532 Mdot
.14561 .06516 Mdot
.14565 .065 Mdot
.1457 .06483 Mdot
.14575 .06467 Mdot
.1458 .06451 Mdot
.14584 .06435 Mdot
.14589 .06419 Mdot
.14594 .06403 Mdot
.14599 .06387 Mdot
.14604 .06371 Mdot
.14608 .06356 Mdot
.14613 .0634 Mdot
.14618 .06324 Mdot
.14623 .06308 Mdot
.14627 .06292 Mdot
.14632 .06276 Mdot
.14637 .06261 Mdot
.14642 .06245 Mdot
.14646 .06229 Mdot
.14651 .06214 Mdot
.14656 .06198 Mdot
.14661 .06182 Mdot
.14665 .06167 Mdot
.1467 .06151 Mdot
.14675 .06136 Mdot
.1468 .0612 Mdot
.14684 .06104 Mdot
.14689 .06089 Mdot
.14694 .06074 Mdot
.14699 .06058 Mdot
.14704 .06043 Mdot
.14708 .06027 Mdot
.14713 .06012 Mdot
.14718 .05997 Mdot
.14723 .05981 Mdot
.14727 .05966 Mdot
.14732 .05951 Mdot
.14737 .05936 Mdot
.14742 .0592 Mdot
.14746 .05905 Mdot
.14751 .0589 Mdot
.14756 .05875 Mdot
.14761 .0586 Mdot
.14765 .05845 Mdot
.1477 .0583 Mdot
.14775 .05815 Mdot
.1478 .058 Mdot
.14784 .05785 Mdot
.14789 .0577 Mdot
.14794 .05755 Mdot
.14799 .0574 Mdot
.14804 .05725 Mdot
.14808 .0571 Mdot
.14813 .05695 Mdot
.14818 .0568 Mdot
.14823 .05666 Mdot
.14827 .05651 Mdot
.14832 .05636 Mdot
.14837 .05621 Mdot
.14842 .05607 Mdot
.14846 .05592 Mdot
.14851 .05577 Mdot
.14856 .05563 Mdot
.14861 .05548 Mdot
.14865 .05534 Mdot
.1487 .05519 Mdot
.14875 .05505 Mdot
.1488 .0549 Mdot
.14884 .05476 Mdot
.14889 .05461 Mdot
.14894 .05447 Mdot
.14899 .05432 Mdot
.14904 .05418 Mdot
.14908 .05404 Mdot
.14913 .05389 Mdot
.14918 .05375 Mdot
.14923 .05361 Mdot
.14927 .05347 Mdot
.14932 .05332 Mdot
.14937 .05318 Mdot
.14942 .05304 Mdot
.14946 .0529 Mdot
.14951 .05276 Mdot
.14956 .05262 Mdot
.14961 .05248 Mdot
.14965 .05234 Mdot
.1497 .0522 Mdot
.14975 .05206 Mdot
.1498 .05192 Mdot
.14984 .05178 Mdot
.14989 .05164 Mdot
.14994 .0515 Mdot
.14999 .05136 Mdot
.15003 .05123 Mdot
.15008 .05109 Mdot
.15013 .05095 Mdot
.15018 .05081 Mdot
.15023 .05068 Mdot
.15027 .05054 Mdot
.15032 .0504 Mdot
.15037 .05027 Mdot
.15042 .05013 Mdot
.15046 .04999 Mdot
.15051 .04986 Mdot
.15056 .04972 Mdot
.15061 .04959 Mdot
.15065 .04945 Mdot
.1507 .04932 Mdot
.15075 .04918 Mdot
.1508 .04905 Mdot
.15084 .04892 Mdot
.15089 .04878 Mdot
.15094 .04865 Mdot
.15099 .04852 Mdot
.15103 .04838 Mdot
.15108 .04825 Mdot
.15113 .04812 Mdot
.15118 .04799 Mdot
.15123 .04786 Mdot
.15127 .04772 Mdot
.15132 .04759 Mdot
.15137 .04746 Mdot
.15142 .04733 Mdot
.15146 .0472 Mdot
.15151 .04707 Mdot
.15156 .04694 Mdot
.15161 .04681 Mdot
.15165 .04668 Mdot
.1517 .04655 Mdot
.15175 .04642 Mdot
.1518 .0463 Mdot
.15184 .04617 Mdot
.15189 .04604 Mdot
.15194 .04591 Mdot
.15199 .04578 Mdot
.15203 .04566 Mdot
.15208 .04553 Mdot
.15213 .0454 Mdot
.15218 .04528 Mdot
.15223 .04515 Mdot
.15227 .04502 Mdot
.15232 .0449 Mdot
.15237 .04477 Mdot
.15242 .04465 Mdot
.15246 .04452 Mdot
.15251 .0444 Mdot
.15256 .04427 Mdot
.15261 .04415 Mdot
.15265 .04403 Mdot
.1527 .0439 Mdot
.15275 .04378 Mdot
.1528 .04366 Mdot
.15284 .04353 Mdot
.15289 .04341 Mdot
.15294 .04329 Mdot
.15299 .04317 Mdot
.15303 .04305 Mdot
.15308 .04292 Mdot
.15313 .0428 Mdot
.15318 .04268 Mdot
.15323 .04256 Mdot
.15327 .04244 Mdot
.15332 .04232 Mdot
.15337 .0422 Mdot
.15342 .04208 Mdot
.15346 .04196 Mdot
.15351 .04184 Mdot
.15356 .04172 Mdot
.15361 .04161 Mdot
.15365 .04149 Mdot
.1537 .04137 Mdot
.15375 .04125 Mdot
.1538 .04113 Mdot
.15384 .04102 Mdot
.15389 .0409 Mdot
.15394 .04078 Mdot
.15399 .04067 Mdot
.15403 .04055 Mdot
.15408 .04044 Mdot
.15413 .04032 Mdot
.15418 .04021 Mdot
.15423 .04009 Mdot
.15427 .03998 Mdot
.15432 .03986 Mdot
.15437 .03975 Mdot
.15442 .03963 Mdot
.15446 .03952 Mdot
.15451 .03941 Mdot
.15456 .03929 Mdot
.15461 .03918 Mdot
.15465 .03907 Mdot
.1547 .03895 Mdot
.15475 .03884 Mdot
.1548 .03873 Mdot
.15484 .03862 Mdot
.15489 .03851 Mdot
.15494 .0384 Mdot
.15499 .03829 Mdot
.15503 .03818 Mdot
.15508 .03807 Mdot
.15513 .03796 Mdot
.15518 .03785 Mdot
.15522 .03774 Mdot
.15527 .03763 Mdot
.15532 .03752 Mdot
.15537 .03741 Mdot
.15542 .0373 Mdot
.15546 .03719 Mdot
.15551 .03709 Mdot
.15556 .03698 Mdot
.15561 .03687 Mdot
.15565 .03677 Mdot
.1557 .03666 Mdot
.15575 .03655 Mdot
.1558 .03645 Mdot
.15584 .03634 Mdot
.15589 .03623 Mdot
.15594 .03613 Mdot
.15599 .03602 Mdot
.15603 .03592 Mdot
.15608 .03582 Mdot
.15613 .03571 Mdot
.15618 .03561 Mdot
.15622 .0355 Mdot
.15627 .0354 Mdot
.15632 .0353 Mdot
.15637 .03519 Mdot
.15642 .03509 Mdot
.15646 .03499 Mdot
.15651 .03489 Mdot
.15656 .03479 Mdot
.15661 .03468 Mdot
.15665 .03458 Mdot
.1567 .03448 Mdot
.15675 .03438 Mdot
.1568 .03428 Mdot
.15684 .03418 Mdot
.15689 .03408 Mdot
.15694 .03398 Mdot
.15699 .03388 Mdot
.15703 .03378 Mdot
.15708 .03368 Mdot
.15713 .03359 Mdot
.15718 .03349 Mdot
.15722 .03339 Mdot
.15727 .03329 Mdot
.15732 .0332 Mdot
.15737 .0331 Mdot
.15742 .033 Mdot
.15746 .03291 Mdot
.15751 .03281 Mdot
.15756 .03271 Mdot
.15761 .03262 Mdot
.15765 .03252 Mdot
.1577 .03243 Mdot
.15775 .03233 Mdot
.1578 .03224 Mdot
.15784 .03214 Mdot
.15789 .03205 Mdot
.15794 .03196 Mdot
.15799 .03186 Mdot
.15803 .03177 Mdot
.15808 .03168 Mdot
.15813 .03158 Mdot
.15818 .03149 Mdot
.15822 .0314 Mdot
.15827 .03131 Mdot
.15832 .03122 Mdot
.15837 .03112 Mdot
.15842 .03103 Mdot
.15846 .03094 Mdot
.15851 .03085 Mdot
.15856 .03076 Mdot
.15861 .03067 Mdot
.15865 .03058 Mdot
.1587 .03049 Mdot
.15875 .0304 Mdot
.1588 .03032 Mdot
.15884 .03023 Mdot
.15889 .03014 Mdot
.15894 .03005 Mdot
.15899 .02996 Mdot
.15903 .02988 Mdot
.15908 .02979 Mdot
.15913 .0297 Mdot
.15918 .02962 Mdot
.15922 .02953 Mdot
.15927 .02944 Mdot
.15932 .02936 Mdot
.15937 .02927 Mdot
.15942 .02919 Mdot
.15946 .0291 Mdot
.15951 .02902 Mdot
.15956 .02893 Mdot
.15961 .02885 Mdot
.15965 .02877 Mdot
.1597 .02868 Mdot
.15975 .0286 Mdot
.1598 .02852 Mdot
.15984 .02843 Mdot
.15989 .02835 Mdot
.15994 .02827 Mdot
.15999 .02819 Mdot
.16003 .02811 Mdot
.16008 .02803 Mdot
.16013 .02794 Mdot
.16018 .02786 Mdot
.16022 .02778 Mdot
.16027 .0277 Mdot
.16032 .02762 Mdot
.16037 .02754 Mdot
.16041 .02746 Mdot
.16046 .02739 Mdot
.16051 .02731 Mdot
.16056 .02723 Mdot
.16061 .02715 Mdot
.16065 .02707 Mdot
.1607 .027 Mdot
.16075 .02692 Mdot
.1608 .02684 Mdot
.16084 .02676 Mdot
.16089 .02669 Mdot
.16094 .02661 Mdot
.16099 .02654 Mdot
.16103 .02646 Mdot
.16108 .02638 Mdot
.16113 .02631 Mdot
.16118 .02624 Mdot
.16122 .02616 Mdot
.16127 .02609 Mdot
.16132 .02601 Mdot
.16137 .02594 Mdot
.16141 .02587 Mdot
.16146 .02579 Mdot
.16151 .02572 Mdot
.16156 .02565 Mdot
.16161 .02558 Mdot
.16165 .0255 Mdot
.1617 .02543 Mdot
.16175 .02536 Mdot
.1618 .02529 Mdot
.16184 .02522 Mdot
.16189 .02515 Mdot
.16194 .02508 Mdot
.16199 .02501 Mdot
.16203 .02494 Mdot
.16208 .02487 Mdot
.16213 .0248 Mdot
.16218 .02473 Mdot
.16222 .02466 Mdot
.16227 .02459 Mdot
.16232 .02453 Mdot
.16237 .02446 Mdot
.16241 .02439 Mdot
.16246 .02432 Mdot
.16251 .02426 Mdot
.16256 .02419 Mdot
.16261 .02413 Mdot
.16265 .02406 Mdot
.1627 .02399 Mdot
.16275 .02393 Mdot
.1628 .02386 Mdot
.16284 .0238 Mdot
.16289 .02373 Mdot
.16294 .02367 Mdot
.16299 .02361 Mdot
.16303 .02354 Mdot
.16308 .02348 Mdot
.16313 .02342 Mdot
.16318 .02335 Mdot
.16322 .02329 Mdot
.16327 .02323 Mdot
.16332 .02317 Mdot
.16337 .0231 Mdot
.16341 .02304 Mdot
.16346 .02298 Mdot
.16351 .02292 Mdot
.16356 .02286 Mdot
.16361 .0228 Mdot
.16365 .02274 Mdot
.1637 .02268 Mdot
.16375 .02262 Mdot
.1638 .02256 Mdot
.16384 .0225 Mdot
.16389 .02245 Mdot
.16394 .02239 Mdot
.16399 .02233 Mdot
.16403 .02227 Mdot
.16408 .02221 Mdot
.16413 .02216 Mdot
.16418 .0221 Mdot
.16422 .02204 Mdot
.16427 .02199 Mdot
.16432 .02193 Mdot
.16437 .02188 Mdot
.16441 .02182 Mdot
.16446 .02177 Mdot
.16451 .02171 Mdot
.16456 .02166 Mdot
.1646 .0216 Mdot
.16465 .02155 Mdot
.1647 .02149 Mdot
.16475 .02144 Mdot
.1648 .02139 Mdot
.16484 .02134 Mdot
.16489 .02128 Mdot
.16494 .02123 Mdot
.16499 .02118 Mdot
.16503 .02113 Mdot
.16508 .02108 Mdot
.16513 .02102 Mdot
.16518 .02097 Mdot
.16522 .02092 Mdot
.16527 .02087 Mdot
.16532 .02082 Mdot
.16537 .02077 Mdot
.16541 .02072 Mdot
.16546 .02068 Mdot
.16551 .02063 Mdot
.16556 .02058 Mdot
.1656 .02053 Mdot
.16565 .02048 Mdot
.1657 .02043 Mdot
.16575 .02039 Mdot
.1658 .02034 Mdot
.16584 .02029 Mdot
.16589 .02025 Mdot
.16594 .0202 Mdot
.16599 .02016 Mdot
.16603 .02011 Mdot
.16608 .02006 Mdot
.16613 .02002 Mdot
.16618 .01997 Mdot
.16622 .01993 Mdot
.16627 .01989 Mdot
.16632 .01984 Mdot
.16637 .0198 Mdot
.16641 .01976 Mdot
.16646 .01971 Mdot
.16651 .01967 Mdot
.16656 .01963 Mdot
.1666 .01959 Mdot
.16665 .01954 Mdot
.1667 .0195 Mdot
.16675 .01946 Mdot
.1668 .01942 Mdot
.16684 .01938 Mdot
.16689 .01934 Mdot
.16694 .0193 Mdot
.16699 .01926 Mdot
.16703 .01922 Mdot
.16708 .01918 Mdot
.16713 .01914 Mdot
.16718 .0191 Mdot
.16722 .01906 Mdot
.16727 .01903 Mdot
.16732 .01899 Mdot
.16737 .01895 Mdot
.16741 .01891 Mdot
.16746 .01888 Mdot
.16751 .01884 Mdot
.16756 .0188 Mdot
.1676 .01877 Mdot
.16765 .01873 Mdot
.1677 .0187 Mdot
.16775 .01866 Mdot
.1678 .01863 Mdot
.16784 .01859 Mdot
.16789 .01856 Mdot
.16794 .01852 Mdot
.16799 .01849 Mdot
.16803 .01846 Mdot
.16808 .01842 Mdot
.16813 .01839 Mdot
.16818 .01836 Mdot
.16822 .01833 Mdot
.16827 .01829 Mdot
.16832 .01826 Mdot
.16837 .01823 Mdot
.16841 .0182 Mdot
.16846 .01817 Mdot
.16851 .01814 Mdot
.16856 .01811 Mdot
.1686 .01808 Mdot
.16865 .01805 Mdot
.1687 .01802 Mdot
.16875 .01799 Mdot
.1688 .01796 Mdot
.16884 .01793 Mdot
.16889 .01791 Mdot
.16894 .01788 Mdot
.16899 .01785 Mdot
.16903 .01782 Mdot
.16908 .0178 Mdot
.16913 .01777 Mdot
.16918 .01774 Mdot
.16922 .01772 Mdot
.16927 .01769 Mdot
.16932 .01766 Mdot
.16937 .01764 Mdot
.16941 .01761 Mdot
.16946 .01759 Mdot
.16951 .01757 Mdot
.16956 .01754 Mdot
.1696 .01752 Mdot
.16965 .01749 Mdot
.1697 .01747 Mdot
.16975 .01745 Mdot
.16979 .01742 Mdot
.16984 .0174 Mdot
.16989 .01738 Mdot
.16994 .01736 Mdot
.16999 .01734 Mdot
.17003 .01732 Mdot
.17008 .0173 Mdot
.17013 .01727 Mdot
.17018 .01725 Mdot
.17022 .01723 Mdot
.17027 .01721 Mdot
.17032 .0172 Mdot
.17037 .01718 Mdot
.17041 .01716 Mdot
.17046 .01714 Mdot
.17051 .01712 Mdot
.17056 .0171 Mdot
.1706 .01708 Mdot
.17065 .01707 Mdot
.1707 .01705 Mdot
.17075 .01703 Mdot
.17079 .01702 Mdot
.17084 .017 Mdot
.17089 .01698 Mdot
.17094 .01697 Mdot
.17099 .01695 Mdot
.17103 .01694 Mdot
.17108 .01692 Mdot
.17113 .01691 Mdot
.17118 .01689 Mdot
.17122 .01688 Mdot
.17127 .01687 Mdot
.17132 .01685 Mdot
.17137 .01684 Mdot
.17141 .01683 Mdot
.17146 .01682 Mdot
.17151 .0168 Mdot
.17156 .01679 Mdot
.1716 .01678 Mdot
.17165 .01677 Mdot
.1717 .01676 Mdot
.17175 .01675 Mdot
.17179 .01674 Mdot
.17184 .01673 Mdot
.17189 .01672 Mdot
.17194 .01671 Mdot
.17199 .0167 Mdot
.17203 .01669 Mdot
.17208 .01668 Mdot
.17213 .01667 Mdot
.17218 .01666 Mdot
.17222 .01666 Mdot
.17227 .01665 Mdot
.17232 .01664 Mdot
.17237 .01663 Mdot
.17241 .01663 Mdot
.17246 .01662 Mdot
.17251 .01662 Mdot
.17256 .01661 Mdot
.1726 .0166 Mdot
.17265 .0166 Mdot
.1727 .01659 Mdot
.17275 .01659 Mdot
.17279 .01659 Mdot
.17284 .01658 Mdot
.17289 .01658 Mdot
.17294 .01657 Mdot
.17299 .01657 Mdot
.17303 .01657 Mdot
.17308 .01657 Mdot
.17313 .01656 Mdot
.17318 .01656 Mdot
.17322 .01656 Mdot
.17327 .01656 Mdot
.17332 .01656 Mdot
.17337 .01656 Mdot
.17341 .01656 Mdot
.17346 .01656 Mdot
.17351 .01656 Mdot
.17356 .01656 Mdot
.1736 .01656 Mdot
.17365 .01656 Mdot
.1737 .01656 Mdot
.17375 .01656 Mdot
.17379 .01656 Mdot
.17384 .01657 Mdot
.17389 .01657 Mdot
.17394 .01657 Mdot
.17398 .01657 Mdot
.17403 .01658 Mdot
.17408 .01658 Mdot
.17413 .01659 Mdot
.17418 .01659 Mdot
.17422 .01659 Mdot
.17427 .0166 Mdot
.17432 .0166 Mdot
.17437 .01661 Mdot
.17441 .01661 Mdot
.17446 .01662 Mdot
.17451 .01663 Mdot
.17456 .01663 Mdot
.1746 .01664 Mdot
.17465 .01665 Mdot
.1747 .01666 Mdot
.17475 .01666 Mdot
.17479 .01667 Mdot
.17484 .01668 Mdot
.17489 .01669 Mdot
.17494 .0167 Mdot
.17498 .01671 Mdot
.17503 .01672 Mdot
.17508 .01672 Mdot
.17513 .01673 Mdot
.17518 .01675 Mdot
.17522 .01676 Mdot
.17527 .01677 Mdot
.17532 .01678 Mdot
.17537 .01679 Mdot
.17541 .0168 Mdot
.17546 .01681 Mdot
.17551 .01683 Mdot
.17556 .01684 Mdot
.1756 .01685 Mdot
.17565 .01686 Mdot
.1757 .01688 Mdot
.17575 .01689 Mdot
.17579 .01691 Mdot
.17584 .01692 Mdot
.17589 .01694 Mdot
.17594 .01695 Mdot
.17598 .01697 Mdot
.17603 .01698 Mdot
.17608 .017 Mdot
.17613 .01701 Mdot
.17618 .01703 Mdot
.17622 .01705 Mdot
.17627 .01706 Mdot
.17632 .01708 Mdot
.17637 .0171 Mdot
.17641 .01712 Mdot
.17646 .01713 Mdot
.17651 .01715 Mdot
.17656 .01717 Mdot
.1766 .01719 Mdot
.17665 .01721 Mdot
.1767 .01723 Mdot
.17675 .01725 Mdot
.17679 .01727 Mdot
.17684 .01729 Mdot
.17689 .01731 Mdot
.17694 .01733 Mdot
.17698 .01735 Mdot
.17703 .01738 Mdot
.17708 .0174 Mdot
.17713 .01742 Mdot
.17718 .01744 Mdot
.17722 .01747 Mdot
.17727 .01749 Mdot
.17732 .01751 Mdot
.17737 .01754 Mdot
.17741 .01756 Mdot
.17746 .01759 Mdot
.17751 .01761 Mdot
.17756 .01763 Mdot
.1776 .01766 Mdot
.17765 .01769 Mdot
.1777 .01771 Mdot
.17775 .01774 Mdot
.17779 .01776 Mdot
.17784 .01779 Mdot
.17789 .01782 Mdot
.17794 .01784 Mdot
.17798 .01787 Mdot
.17803 .0179 Mdot
.17808 .01793 Mdot
.17813 .01796 Mdot
.17818 .01799 Mdot
.17822 .01801 Mdot
.17827 .01804 Mdot
.17832 .01807 Mdot
.17837 .0181 Mdot
.17841 .01813 Mdot
.17846 .01816 Mdot
.17851 .01819 Mdot
.17856 .01823 Mdot
.1786 .01826 Mdot
.17865 .01829 Mdot
.1787 .01832 Mdot
.17875 .01835 Mdot
.17879 .01838 Mdot
.17884 .01842 Mdot
.17889 .01845 Mdot
.17894 .01848 Mdot
.17898 .01852 Mdot
.17903 .01855 Mdot
.17908 .01859 Mdot
.17913 .01862 Mdot
.17917 .01866 Mdot
.17922 .01869 Mdot
.17927 .01873 Mdot
.17932 .01876 Mdot
.17937 .0188 Mdot
.17941 .01883 Mdot
.17946 .01887 Mdot
.17951 .01891 Mdot
.17956 .01894 Mdot
.1796 .01898 Mdot
.17965 .01902 Mdot
.1797 .01906 Mdot
.17975 .0191 Mdot
.17979 .01913 Mdot
.17984 .01917 Mdot
.17989 .01921 Mdot
.17994 .01925 Mdot
.17998 .01929 Mdot
.18003 .01933 Mdot
.18008 .01937 Mdot
.18013 .01941 Mdot
.18017 .01945 Mdot
.18022 .01949 Mdot
.18027 .01954 Mdot
.18032 .01958 Mdot
.18037 .01962 Mdot
.18041 .01966 Mdot
.18046 .0197 Mdot
.18051 .01975 Mdot
.18056 .01979 Mdot
.1806 .01983 Mdot
.18065 .01988 Mdot
.1807 .01992 Mdot
.18075 .01997 Mdot
.18079 .02001 Mdot
.18084 .02006 Mdot
.18089 .0201 Mdot
.18094 .02015 Mdot
.18098 .02019 Mdot
.18103 .02024 Mdot
.18108 .02029 Mdot
.18113 .02033 Mdot
.18117 .02038 Mdot
.18122 .02043 Mdot
.18127 .02047 Mdot
.18132 .02052 Mdot
.18137 .02057 Mdot
.18141 .02062 Mdot
.18146 .02067 Mdot
.18151 .02072 Mdot
.18156 .02077 Mdot
.1816 .02081 Mdot
.18165 .02086 Mdot
.1817 .02091 Mdot
.18175 .02097 Mdot
.18179 .02102 Mdot
.18184 .02107 Mdot
.18189 .02112 Mdot
.18194 .02117 Mdot
.18198 .02122 Mdot
.18203 .02127 Mdot
.18208 .02133 Mdot
.18213 .02138 Mdot
.18217 .02143 Mdot
.18222 .02149 Mdot
.18227 .02154 Mdot
.18232 .02159 Mdot
.18237 .02165 Mdot
.18241 .0217 Mdot
.18246 .02176 Mdot
.18251 .02181 Mdot
.18256 .02187 Mdot
.1826 .02192 Mdot
.18265 .02198 Mdot
.1827 .02203 Mdot
.18275 .02209 Mdot
.18279 .02215 Mdot
.18284 .0222 Mdot
.18289 .02226 Mdot
.18294 .02232 Mdot
.18298 .02238 Mdot
.18303 .02244 Mdot
.18308 .02249 Mdot
.18313 .02255 Mdot
.18317 .02261 Mdot
.18322 .02267 Mdot
.18327 .02273 Mdot
.18332 .02279 Mdot
.18336 .02285 Mdot
.18341 .02291 Mdot
.18346 .02297 Mdot
.18351 .02303 Mdot
.18356 .02309 Mdot
.1836 .02316 Mdot
.18365 .02322 Mdot
.1837 .02328 Mdot
.18375 .02334 Mdot
.18379 .0234 Mdot
.18384 .02347 Mdot
.18389 .02353 Mdot
.18394 .02359 Mdot
.18398 .02366 Mdot
.18403 .02372 Mdot
.18408 .02379 Mdot
.18413 .02385 Mdot
.18417 .02392 Mdot
.18422 .02398 Mdot
.18427 .02405 Mdot
.18432 .02411 Mdot
.18436 .02418 Mdot
.18441 .02425 Mdot
.18446 .02431 Mdot
.18451 .02438 Mdot
.18456 .02445 Mdot
.1846 .02452 Mdot
.18465 .02458 Mdot
.1847 .02465 Mdot
.18475 .02472 Mdot
.18479 .02479 Mdot
.18484 .02486 Mdot
.18489 .02493 Mdot
.18494 .025 Mdot
.18498 .02507 Mdot
.18503 .02514 Mdot
.18508 .02521 Mdot
.18513 .02528 Mdot
.18517 .02535 Mdot
.18522 .02542 Mdot
.18527 .02549 Mdot
.18532 .02556 Mdot
.18536 .02564 Mdot
.18541 .02571 Mdot
.18546 .02578 Mdot
.18551 .02585 Mdot
.18556 .02593 Mdot
.1856 .026 Mdot
.18565 .02607 Mdot
.1857 .02615 Mdot
.18575 .02622 Mdot
.18579 .0263 Mdot
.18584 .02637 Mdot
.18589 .02645 Mdot
.18594 .02652 Mdot
.18598 .0266 Mdot
.18603 .02668 Mdot
.18608 .02675 Mdot
.18613 .02683 Mdot
.18617 .02691 Mdot
.18622 .02698 Mdot
.18627 .02706 Mdot
.18632 .02714 Mdot
.18636 .02722 Mdot
.18641 .02729 Mdot
.18646 .02737 Mdot
.18651 .02745 Mdot
.18656 .02753 Mdot
.1866 .02761 Mdot
.18665 .02769 Mdot
.1867 .02777 Mdot
.18675 .02785 Mdot
.18679 .02793 Mdot
.18684 .02801 Mdot
.18689 .02809 Mdot
.18694 .02817 Mdot
.18698 .02826 Mdot
.18703 .02834 Mdot
.18708 .02842 Mdot
.18713 .0285 Mdot
.18717 .02859 Mdot
.18722 .02867 Mdot
.18727 .02875 Mdot
.18732 .02884 Mdot
.18736 .02892 Mdot
.18741 .029 Mdot
.18746 .02909 Mdot
.18751 .02917 Mdot
.18756 .02926 Mdot
.1876 .02934 Mdot
.18765 .02943 Mdot
.1877 .02952 Mdot
.18775 .0296 Mdot
.18779 .02969 Mdot
.18784 .02978 Mdot
.18789 .02986 Mdot
.18794 .02995 Mdot
.18798 .03004 Mdot
.18803 .03013 Mdot
.18808 .03021 Mdot
.18813 .0303 Mdot
.18817 .03039 Mdot
.18822 .03048 Mdot
.18827 .03057 Mdot
.18832 .03066 Mdot
.18836 .03075 Mdot
.18841 .03084 Mdot
.18846 .03093 Mdot
.18851 .03102 Mdot
.18855 .03111 Mdot
.1886 .0312 Mdot
.18865 .03129 Mdot
.1887 .03138 Mdot
.18875 .03148 Mdot
.18879 .03157 Mdot
.18884 .03166 Mdot
.18889 .03175 Mdot
.18894 .03185 Mdot
.18898 .03194 Mdot
.18903 .03203 Mdot
.18908 .03213 Mdot
.18913 .03222 Mdot
.18917 .03232 Mdot
.18922 .03241 Mdot
.18927 .03251 Mdot
.18932 .0326 Mdot
.18936 .0327 Mdot
.18941 .03279 Mdot
.18946 .03289 Mdot
.18951 .03299 Mdot
.18955 .03308 Mdot
.1896 .03318 Mdot
.18965 .03328 Mdot
.1897 .03338 Mdot
.18975 .03347 Mdot
.18979 .03357 Mdot
.18984 .03367 Mdot
.18989 .03377 Mdot
.18994 .03387 Mdot
.18998 .03397 Mdot
.19003 .03407 Mdot
.19008 .03417 Mdot
.19013 .03427 Mdot
.19017 .03437 Mdot
.19022 .03447 Mdot
.19027 .03457 Mdot
.19032 .03467 Mdot
.19036 .03477 Mdot
.19041 .03487 Mdot
.19046 .03497 Mdot
.19051 .03508 Mdot
.19055 .03518 Mdot
.1906 .03528 Mdot
.19065 .03539 Mdot
.1907 .03549 Mdot
.19075 .03559 Mdot
.19079 .0357 Mdot
.19084 .0358 Mdot
.19089 .0359 Mdot
.19094 .03601 Mdot
.19098 .03611 Mdot
.19103 .03622 Mdot
.19108 .03633 Mdot
.19113 .03643 Mdot
.19117 .03654 Mdot
.19122 .03664 Mdot
.19127 .03675 Mdot
.19132 .03686 Mdot
.19136 .03696 Mdot
.19141 .03707 Mdot
.19146 .03718 Mdot
.19151 .03729 Mdot
.19155 .0374 Mdot
.1916 .0375 Mdot
.19165 .03761 Mdot
.1917 .03772 Mdot
.19175 .03783 Mdot
.19179 .03794 Mdot
.19184 .03805 Mdot
.19189 .03816 Mdot
.19194 .03827 Mdot
.19198 .03838 Mdot
.19203 .03849 Mdot
.19208 .0386 Mdot
.19213 .03872 Mdot
.19217 .03883 Mdot
.19222 .03894 Mdot
.19227 .03905 Mdot
.19232 .03916 Mdot
.19236 .03928 Mdot
.19241 .03939 Mdot
.19246 .0395 Mdot
.19251 .03962 Mdot
.19255 .03973 Mdot
.1926 .03985 Mdot
.19265 .03996 Mdot
.1927 .04007 Mdot
.19275 .04019 Mdot
.19279 .04031 Mdot
.19284 .04042 Mdot
.19289 .04054 Mdot
.19294 .04065 Mdot
.19298 .04077 Mdot
.19303 .04089 Mdot
.19308 .041 Mdot
.19313 .04112 Mdot
.19317 .04124 Mdot
.19322 .04135 Mdot
.19327 .04147 Mdot
.19332 .04159 Mdot
.19336 .04171 Mdot
.19341 .04183 Mdot
.19346 .04195 Mdot
.19351 .04207 Mdot
.19355 .04219 Mdot
.1936 .04231 Mdot
.19365 .04243 Mdot
.1937 .04255 Mdot
.19374 .04267 Mdot
.19379 .04279 Mdot
.19384 .04291 Mdot
.19389 .04303 Mdot
.19394 .04315 Mdot
.19398 .04327 Mdot
.19403 .0434 Mdot
.19408 .04352 Mdot
.19413 .04364 Mdot
.19417 .04376 Mdot
.19422 .04389 Mdot
.19427 .04401 Mdot
.19432 .04414 Mdot
.19436 .04426 Mdot
.19441 .04438 Mdot
.19446 .04451 Mdot
.19451 .04463 Mdot
.19455 .04476 Mdot
.1946 .04488 Mdot
.19465 .04501 Mdot
.1947 .04514 Mdot
.19474 .04526 Mdot
.19479 .04539 Mdot
.19484 .04551 Mdot
.19489 .04564 Mdot
.19494 .04577 Mdot
.19498 .0459 Mdot
.19503 .04602 Mdot
.19508 .04615 Mdot
.19513 .04628 Mdot
.19517 .04641 Mdot
.19522 .04654 Mdot
.19527 .04667 Mdot
.19532 .0468 Mdot
.19536 .04693 Mdot
.19541 .04706 Mdot
.19546 .04719 Mdot
.19551 .04732 Mdot
.19555 .04745 Mdot
.1956 .04758 Mdot
.19565 .04771 Mdot
.1957 .04784 Mdot
.19574 .04797 Mdot
.19579 .0481 Mdot
.19584 .04824 Mdot
.19589 .04837 Mdot
.19594 .0485 Mdot
.19598 .04863 Mdot
.19603 .04877 Mdot
.19608 .0489 Mdot
.19613 .04904 Mdot
.19617 .04917 Mdot
.19622 .0493 Mdot
.19627 .04944 Mdot
.19632 .04957 Mdot
.19636 .04971 Mdot
.19641 .04984 Mdot
.19646 .04998 Mdot
.19651 .05011 Mdot
.19655 .05025 Mdot
.1966 .05039 Mdot
.19665 .05052 Mdot
.1967 .05066 Mdot
.19674 .0508 Mdot
.19679 .05094 Mdot
.19684 .05107 Mdot
.19689 .05121 Mdot
.19694 .05135 Mdot
.19698 .05149 Mdot
.19703 .05163 Mdot
.19708 .05177 Mdot
.19713 .0519 Mdot
.19717 .05204 Mdot
.19722 .05218 Mdot
.19727 .05232 Mdot
.19732 .05246 Mdot
.19736 .0526 Mdot
.19741 .05275 Mdot
.19746 .05289 Mdot
.19751 .05303 Mdot
.19755 .05317 Mdot
.1976 .05331 Mdot
.19765 .05345 Mdot
.1977 .0536 Mdot
.19774 .05374 Mdot
.19779 .05388 Mdot
.19784 .05402 Mdot
.19789 .05417 Mdot
.19793 .05431 Mdot
.19798 .05445 Mdot
.19803 .0546 Mdot
.19808 .05474 Mdot
.19813 .05489 Mdot
.19817 .05503 Mdot
.19822 .05518 Mdot
.19827 .05532 Mdot
.19832 .05547 Mdot
.19836 .05561 Mdot
.19841 .05576 Mdot
.19846 .05591 Mdot
.19851 .05605 Mdot
.19855 .0562 Mdot
.1986 .05635 Mdot
.19865 .05649 Mdot
.1987 .05664 Mdot
.19874 .05679 Mdot
.19879 .05694 Mdot
.19884 .05709 Mdot
.19889 .05723 Mdot
.19893 .05738 Mdot
.19898 .05753 Mdot
.19903 .05768 Mdot
.19908 .05783 Mdot
.19913 .05798 Mdot
.19917 .05813 Mdot
.19922 .05828 Mdot
.19927 .05843 Mdot
.19932 .05858 Mdot
.19936 .05874 Mdot
.19941 .05889 Mdot
.19946 .05904 Mdot
.19951 .05919 Mdot
.19955 .05934 Mdot
.1996 .05949 Mdot
.19965 .05965 Mdot
.1997 .0598 Mdot
.19974 .05995 Mdot
.19979 .06011 Mdot
.19984 .06026 Mdot
.19989 .06041 Mdot
.19993 .06057 Mdot
.19998 .06072 Mdot
.20003 .06088 Mdot
.20008 .06103 Mdot
.20013 .06119 Mdot
.20017 .06134 Mdot
.20022 .0615 Mdot
.20027 .06165 Mdot
.20032 .06181 Mdot
.20036 .06197 Mdot
.20041 .06212 Mdot
.20046 .06228 Mdot
.20051 .06244 Mdot
.20055 .06259 Mdot
.2006 .06275 Mdot
.20065 .06291 Mdot
.2007 .06307 Mdot
.20074 .06323 Mdot
.20079 .06338 Mdot
.20084 .06354 Mdot
.20089 .0637 Mdot
.20093 .06386 Mdot
.20098 .06402 Mdot
.20103 .06418 Mdot
.20108 .06434 Mdot
.20113 .0645 Mdot
.20117 .06466 Mdot
.20122 .06482 Mdot
.20127 .06498 Mdot
.20132 .06515 Mdot
.20136 .06531 Mdot
.20141 .06547 Mdot
.20146 .06563 Mdot
.20151 .06579 Mdot
.20155 .06596 Mdot
.2016 .06612 Mdot
.20165 .06628 Mdot
.2017 .06644 Mdot
.20174 .06661 Mdot
.20179 .06677 Mdot
.20184 .06694 Mdot
.20189 .0671 Mdot
.20193 .06726 Mdot
.20198 .06743 Mdot
.20203 .06759 Mdot
.20208 .06776 Mdot
.20213 .06792 Mdot
.20217 .06809 Mdot
.20222 .06826 Mdot
.20227 .06842 Mdot
.20232 .06859 Mdot
.20236 .06875 Mdot
.20241 .06892 Mdot
.20246 .06909 Mdot
.20251 .06926 Mdot
.20255 .06942 Mdot
.2026 .06959 Mdot
.20265 .06976 Mdot
.2027 .06993 Mdot
.20274 .0701 Mdot
.20279 .07026 Mdot
.20284 .07043 Mdot
.20289 .0706 Mdot
.20293 .07077 Mdot
.20298 .07094 Mdot
.20303 .07111 Mdot
.20308 .07128 Mdot
.20312 .07145 Mdot
.20317 .07162 Mdot
.20322 .07179 Mdot
.20327 .07197 Mdot
.20332 .07214 Mdot
.20336 .07231 Mdot
.20341 .07248 Mdot
.20346 .07265 Mdot
.20351 .07282 Mdot
.20355 .073 Mdot
.2036 .07317 Mdot
.20365 .07334 Mdot
.2037 .07352 Mdot
.20374 .07369 Mdot
.20379 .07386 Mdot
.20384 .07404 Mdot
.20389 .07421 Mdot
.20393 .07439 Mdot
.20398 .07456 Mdot
.20403 .07474 Mdot
.20408 .07491 Mdot
.20412 .07509 Mdot
.20417 .07526 Mdot
.20422 .07544 Mdot
.20427 .07561 Mdot
.20432 .07579 Mdot
.20436 .07597 Mdot
.20441 .07614 Mdot
.20446 .07632 Mdot
.20451 .0765 Mdot
.20455 .07668 Mdot
.2046 .07685 Mdot
.20465 .07703 Mdot
.2047 .07721 Mdot
.20474 .07739 Mdot
.20479 .07757 Mdot
.20484 .07774 Mdot
.20489 .07792 Mdot
.20493 .0781 Mdot
.20498 .07828 Mdot
.20503 .07846 Mdot
.20508 .07864 Mdot
.20512 .07882 Mdot
.20517 .079 Mdot
.20522 .07918 Mdot
.20527 .07936 Mdot
.20532 .07955 Mdot
.20536 .07973 Mdot
.20541 .07991 Mdot
.20546 .08009 Mdot
.20551 .08027 Mdot
.20555 .08046 Mdot
.2056 .08064 Mdot
.20565 .08082 Mdot
.2057 .081 Mdot
.20574 .08119 Mdot
.20579 .08137 Mdot
.20584 .08155 Mdot
.20589 .08174 Mdot
.20593 .08192 Mdot
.20598 .08211 Mdot
.20603 .08229 Mdot
.20608 .08248 Mdot
.20612 .08266 Mdot
.20617 .08285 Mdot
.20622 .08303 Mdot
.20627 .08322 Mdot
.20632 .0834 Mdot
.20636 .08359 Mdot
.20641 .08378 Mdot
.20646 .08396 Mdot
.20651 .08415 Mdot
.20655 .08434 Mdot
.2066 .08452 Mdot
.20665 .08471 Mdot
.2067 .0849 Mdot
.20674 .08509 Mdot
.20679 .08528 Mdot
.20684 .08546 Mdot
.20689 .08565 Mdot
.20693 .08584 Mdot
.20698 .08603 Mdot
.20703 .08622 Mdot
.20708 .08641 Mdot
.20712 .0866 Mdot
.20717 .08679 Mdot
.20722 .08698 Mdot
.20727 .08717 Mdot
.20731 .08736 Mdot
.20736 .08755 Mdot
.20741 .08774 Mdot
.20746 .08793 Mdot
.20751 .08812 Mdot
.20755 .08832 Mdot
.2076 .08851 Mdot
.20765 .0887 Mdot
.2077 .08889 Mdot
.20774 .08909 Mdot
.20779 .08928 Mdot
.20784 .08947 Mdot
.20789 .08966 Mdot
.20793 .08986 Mdot
.20798 .09005 Mdot
.20803 .09025 Mdot
.20808 .09044 Mdot
.20812 .09063 Mdot
.20817 .09083 Mdot
.20822 .09102 Mdot
.20827 .09122 Mdot
.20831 .09141 Mdot
.20836 .09161 Mdot
.20841 .09181 Mdot
.20846 .092 Mdot
.20851 .0922 Mdot
.20855 .09239 Mdot
.2086 .09259 Mdot
.20865 .09279 Mdot
.2087 .09298 Mdot
.20874 .09318 Mdot
.20879 .09338 Mdot
.20884 .09358 Mdot
.20889 .09377 Mdot
.20893 .09397 Mdot
.20898 .09417 Mdot
.20903 .09437 Mdot
.20908 .09457 Mdot
.20912 .09477 Mdot
.20917 .09497 Mdot
.20922 .09517 Mdot
.20927 .09536 Mdot
.20931 .09556 Mdot
.20936 .09576 Mdot
.20941 .09596 Mdot
.20946 .09617 Mdot
.20951 .09637 Mdot
.20955 .09657 Mdot
.2096 .09677 Mdot
.20965 .09697 Mdot
.2097 .09717 Mdot
.20974 .09737 Mdot
.20979 .09757 Mdot
.20984 .09778 Mdot
.20989 .09798 Mdot
.20993 .09818 Mdot
.20998 .09838 Mdot
.21003 .09859 Mdot
.21008 .09879 Mdot
.21012 .09899 Mdot
.21017 .0992 Mdot
.21022 .0994 Mdot
.21027 .0996 Mdot
.21031 .09981 Mdot
.21036 .10001 Mdot
.21041 .10022 Mdot
.21046 .10042 Mdot
.21051 .10063 Mdot
.21055 .10083 Mdot
.2106 .10104 Mdot
.21065 .10124 Mdot
.2107 .10145 Mdot
.21074 .10166 Mdot
.21079 .10186 Mdot
.21084 .10207 Mdot
.21089 .10228 Mdot
.21093 .10248 Mdot
.21098 .10269 Mdot
.21103 .1029 Mdot
.21108 .1031 Mdot
.21112 .10331 Mdot
.21117 .10352 Mdot
.21122 .10373 Mdot
.21127 .10394 Mdot
.21131 .10415 Mdot
.21136 .10435 Mdot
.21141 .10456 Mdot
.21146 .10477 Mdot
.21151 .10498 Mdot
.21155 .10519 Mdot
.2116 .1054 Mdot
.21165 .10561 Mdot
.2117 .10582 Mdot
.21174 .10603 Mdot
.21179 .10624 Mdot
.21184 .10645 Mdot
.21189 .10666 Mdot
.21193 .10688 Mdot
.21198 .10709 Mdot
.21203 .1073 Mdot
.21208 .10751 Mdot
.21212 .10772 Mdot
.21217 .10793 Mdot
.21222 .10815 Mdot
.21227 .10836 Mdot
.21231 .10857 Mdot
.21236 .10879 Mdot
.21241 .109 Mdot
.21246 .10921 Mdot
.2125 .10943 Mdot
.21255 .10964 Mdot
.2126 .10985 Mdot
.21265 .11007 Mdot
.2127 .11028 Mdot
.21274 .1105 Mdot
.21279 .11071 Mdot
.21284 .11093 Mdot
.21289 .11114 Mdot
.21293 .11136 Mdot
.21298 .11157 Mdot
.21303 .11179 Mdot
.21308 .11201 Mdot
.21312 .11222 Mdot
.21317 .11244 Mdot
.21322 .11265 Mdot
.21327 .11287 Mdot
.21331 .11309 Mdot
.21336 .11331 Mdot
.21341 .11352 Mdot
.21346 .11374 Mdot
.2135 .11396 Mdot
.21355 .11418 Mdot
.2136 .11439 Mdot
.21365 .11461 Mdot
.2137 .11483 Mdot
.21374 .11505 Mdot
.21379 .11527 Mdot
.21384 .11549 Mdot
.21389 .11571 Mdot
.21393 .11593 Mdot
.21398 .11615 Mdot
.21403 .11637 Mdot
.21408 .11659 Mdot
.21412 .11681 Mdot
.21417 .11703 Mdot
.21422 .11725 Mdot
.21427 .11747 Mdot
.21431 .11769 Mdot
.21436 .11791 Mdot
.21441 .11813 Mdot
.21446 .11835 Mdot
.2145 .11858 Mdot
.21455 .1188 Mdot
.2146 .11902 Mdot
.21465 .11924 Mdot
.2147 .11947 Mdot
.21474 .11969 Mdot
.21479 .11991 Mdot
.21484 .12013 Mdot
.21489 .12036 Mdot
.21493 .12058 Mdot
.21498 .1208 Mdot
.21503 .12103 Mdot
.21508 .12125 Mdot
.21512 .12148 Mdot
.21517 .1217 Mdot
.21522 .12193 Mdot
.21527 .12215 Mdot
.21531 .12238 Mdot
.21536 .1226 Mdot
.21541 .12283 Mdot
.21546 .12305 Mdot
.2155 .12328 Mdot
.21555 .1235 Mdot
.2156 .12373 Mdot
.21565 .12396 Mdot
.2157 .12418 Mdot
.21574 .12441 Mdot
.21579 .12464 Mdot
.21584 .12486 Mdot
.21589 .12509 Mdot
.21593 .12532 Mdot
.21598 .12555 Mdot
.21603 .12577 Mdot
.21608 .126 Mdot
.21612 .12623 Mdot
.21617 .12646 Mdot
.21622 .12669 Mdot
.21627 .12692 Mdot
.21631 .12714 Mdot
.21636 .12737 Mdot
.21641 .1276 Mdot
.21646 .12783 Mdot
.2165 .12806 Mdot
.21655 .12829 Mdot
.2166 .12852 Mdot
.21665 .12875 Mdot
.21669 .12898 Mdot
.21674 .12921 Mdot
.21679 .12944 Mdot
.21684 .12967 Mdot
.21689 .12991 Mdot
.21693 .13014 Mdot
.21698 .13037 Mdot
.21703 .1306 Mdot
.21708 .13083 Mdot
.21712 .13106 Mdot
.21717 .1313 Mdot
.21722 .13153 Mdot
.21727 .13176 Mdot
.21731 .13199 Mdot
.21736 .13223 Mdot
.21741 .13246 Mdot
.21746 .13269 Mdot
.2175 .13293 Mdot
.21755 .13316 Mdot
.2176 .13339 Mdot
.21765 .13363 Mdot
.21769 .13386 Mdot
.21774 .1341 Mdot
.21779 .13433 Mdot
.21784 .13456 Mdot
.21789 .1348 Mdot
.21793 .13503 Mdot
.21798 .13527 Mdot
.21803 .1355 Mdot
.21808 .13574 Mdot
.21812 .13598 Mdot
.21817 .13621 Mdot
.21822 .13645 Mdot
.21827 .13668 Mdot
.21831 .13692 Mdot
.21836 .13716 Mdot
.21841 .13739 Mdot
.21846 .13763 Mdot
.2185 .13787 Mdot
.21855 .1381 Mdot
.2186 .13834 Mdot
.21865 .13858 Mdot
.21869 .13882 Mdot
.21874 .13905 Mdot
.21879 .13929 Mdot
.21884 .13953 Mdot
.21889 .13977 Mdot
.21893 .14001 Mdot
.21898 .14025 Mdot
.21903 .14049 Mdot
.21908 .14072 Mdot
.21912 .14096 Mdot
.21917 .1412 Mdot
.21922 .14144 Mdot
.21927 .14168 Mdot
.21931 .14192 Mdot
.21936 .14216 Mdot
.21941 .1424 Mdot
.21946 .14264 Mdot
.2195 .14288 Mdot
.21955 .14312 Mdot
.2196 .14337 Mdot
.21965 .14361 Mdot
.21969 .14385 Mdot
.21974 .14409 Mdot
.21979 .14433 Mdot
.21984 .14457 Mdot
.21989 .14481 Mdot
.21993 .14506 Mdot
.21998 .1453 Mdot
.22003 .14554 Mdot
.22008 .14578 Mdot
.22012 .14603 Mdot
.22017 .14627 Mdot
.22022 .14651 Mdot
.22027 .14676 Mdot
.22031 .147 Mdot
.22036 .14724 Mdot
.22041 .14749 Mdot
.22046 .14773 Mdot
.2205 .14797 Mdot
.22055 .14822 Mdot
.2206 .14846 Mdot
.22065 .14871 Mdot
.22069 .14895 Mdot
.22074 .1492 Mdot
.22079 .14944 Mdot
.22084 .14969 Mdot
.22089 .14993 Mdot
.22093 .15018 Mdot
.22098 .15042 Mdot
.22103 .15067 Mdot
.22108 .15091 Mdot
.22112 .15116 Mdot
.22117 .15141 Mdot
.22122 .15165 Mdot
.22127 .1519 Mdot
.22131 .15215 Mdot
.22136 .15239 Mdot
.22141 .15264 Mdot
.22146 .15289 Mdot
.2215 .15314 Mdot
.22155 .15338 Mdot
.2216 .15363 Mdot
.22165 .15388 Mdot
.22169 .15413 Mdot
.22174 .15437 Mdot
.22179 .15462 Mdot
.22184 .15487 Mdot
.22188 .15512 Mdot
.22193 .15537 Mdot
.22198 .15562 Mdot
.22203 .15587 Mdot
.22208 .15612 Mdot
.22212 .15636 Mdot
.22217 .15661 Mdot
.22222 .15686 Mdot
.22227 .15711 Mdot
.22231 .15736 Mdot
.22236 .15761 Mdot
.22241 .15786 Mdot
.22246 .15811 Mdot
.2225 .15837 Mdot
.22255 .15862 Mdot
.2226 .15887 Mdot
.22265 .15912 Mdot
.22269 .15937 Mdot
.22274 .15962 Mdot
.22279 .15987 Mdot
.22284 .16012 Mdot
.22288 .16038 Mdot
.22293 .16063 Mdot
.22298 .16088 Mdot
.22303 .16113 Mdot
.22308 .16138 Mdot
.22312 .16164 Mdot
.22317 .16189 Mdot
.22322 .16214 Mdot
.22327 .16239 Mdot
.22331 .16265 Mdot
.22336 .1629 Mdot
.22341 .16315 Mdot
.22346 .16341 Mdot
.2235 .16366 Mdot
.22355 .16392 Mdot
.2236 .16417 Mdot
.22365 .16442 Mdot
.22369 .16468 Mdot
.22374 .16493 Mdot
.22379 .16519 Mdot
.22384 .16544 Mdot
.22388 .1657 Mdot
.22393 .16595 Mdot
.22398 .16621 Mdot
.22403 .16646 Mdot
.22408 .16672 Mdot
.22412 .16697 Mdot
.22417 .16723 Mdot
.22422 .16748 Mdot
.22427 .16774 Mdot
.22431 .168 Mdot
.22436 .16825 Mdot
.22441 .16851 Mdot
.22446 .16877 Mdot
.2245 .16902 Mdot
.22455 .16928 Mdot
.2246 .16954 Mdot
.22465 .16979 Mdot
.22469 .17005 Mdot
.22474 .17031 Mdot
.22479 .17056 Mdot
.22484 .17082 Mdot
.22488 .17108 Mdot
.22493 .17134 Mdot
.22498 .1716 Mdot
.22503 .17185 Mdot
.22508 .17211 Mdot
.22512 .17237 Mdot
.22517 .17263 Mdot
.22522 .17289 Mdot
.22527 .17315 Mdot
.22531 .17341 Mdot
.22536 .17367 Mdot
.22541 .17393 Mdot
.22546 .17418 Mdot
.2255 .17444 Mdot
.22555 .1747 Mdot
.2256 .17496 Mdot
.22565 .17522 Mdot
.22569 .17548 Mdot
.22574 .17574 Mdot
.22579 .176 Mdot
.22584 .17626 Mdot
.22588 .17653 Mdot
.22593 .17679 Mdot
.22598 .17705 Mdot
.22603 .17731 Mdot
.22608 .17757 Mdot
.22612 .17783 Mdot
.22617 .17809 Mdot
.22622 .17835 Mdot
.22627 .17862 Mdot
.22631 .17888 Mdot
.22636 .17914 Mdot
.22641 .1794 Mdot
.22646 .17966 Mdot
.2265 .17993 Mdot
.22655 .18019 Mdot
.2266 .18045 Mdot
.22665 .18071 Mdot
.22669 .18098 Mdot
.22674 .18124 Mdot
.22679 .1815 Mdot
.22684 .18177 Mdot
.22688 .18203 Mdot
.22693 .18229 Mdot
.22698 .18256 Mdot
.22703 .18282 Mdot
.22707 .18308 Mdot
.22712 .18335 Mdot
.22717 .18361 Mdot
.22722 .18388 Mdot
.22727 .18414 Mdot
.22731 .1844 Mdot
.22736 .18467 Mdot
.22741 .18493 Mdot
.22746 .1852 Mdot
.2275 .18546 Mdot
.22755 .18573 Mdot
.2276 .18599 Mdot
.22765 .18626 Mdot
.22769 .18653 Mdot
.22774 .18679 Mdot
.22779 .18706 Mdot
.22784 .18732 Mdot
.22788 .18759 Mdot
.22793 .18785 Mdot
.22798 .18812 Mdot
.22803 .18839 Mdot
.22807 .18865 Mdot
.22812 .18892 Mdot
.22817 .18919 Mdot
.22822 .18945 Mdot
.22827 .18972 Mdot
.22831 .18999 Mdot
.22836 .19025 Mdot
.22841 .19052 Mdot
.22846 .19079 Mdot
.2285 .19106 Mdot
.22855 .19132 Mdot
.2286 .19159 Mdot
.22865 .19186 Mdot
.22869 .19213 Mdot
.22874 .1924 Mdot
.22879 .19266 Mdot
.22884 .19293 Mdot
.22888 .1932 Mdot
.22893 .19347 Mdot
.22898 .19374 Mdot
.22903 .19401 Mdot
.22907 .19428 Mdot
.22912 .19455 Mdot
.22917 .19481 Mdot
.22922 .19508 Mdot
.22927 .19535 Mdot
.22931 .19562 Mdot
.22936 .19589 Mdot
.22941 .19616 Mdot
.22946 .19643 Mdot
.2295 .1967 Mdot
.22955 .19697 Mdot
.2296 .19724 Mdot
.22965 .19751 Mdot
.22969 .19778 Mdot
.22974 .19805 Mdot
.22979 .19832 Mdot
.22984 .19859 Mdot
.22988 .19887 Mdot
.22993 .19914 Mdot
.22998 .19941 Mdot
.23003 .19968 Mdot
.23007 .19995 Mdot
.23012 .20022 Mdot
.23017 .20049 Mdot
.23022 .20076 Mdot
.23027 .20104 Mdot
.23031 .20131 Mdot
.23036 .20158 Mdot
.23041 .20185 Mdot
.23046 .20212 Mdot
.2305 .2024 Mdot
.23055 .20267 Mdot
.2306 .20294 Mdot
.23065 .20321 Mdot
.23069 .20349 Mdot
.23074 .20376 Mdot
.23079 .20403 Mdot
.23084 .20431 Mdot
.23088 .20458 Mdot
.23093 .20485 Mdot
.23098 .20513 Mdot
.23103 .2054 Mdot
.23107 .20567 Mdot
.23112 .20595 Mdot
.23117 .20622 Mdot
.23122 .20649 Mdot
.23126 .20677 Mdot
.23131 .20704 Mdot
.23136 .20732 Mdot
.23141 .20759 Mdot
.23146 .20786 Mdot
.2315 .20814 Mdot
.23155 .20841 Mdot
.2316 .20869 Mdot
.23165 .20896 Mdot
.23169 .20924 Mdot
.23174 .20951 Mdot
.23179 .20979 Mdot
.23184 .21006 Mdot
.23188 .21034 Mdot
.23193 .21061 Mdot
.23198 .21089 Mdot
.23203 .21116 Mdot
.23207 .21144 Mdot
.23212 .21172 Mdot
.23217 .21199 Mdot
.23222 .21227 Mdot
.23226 .21254 Mdot
.23231 .21282 Mdot
.23236 .2131 Mdot
.23241 .21337 Mdot
.23246 .21365 Mdot
.2325 .21392 Mdot
.23255 .2142 Mdot
.2326 .21448 Mdot
.23265 .21475 Mdot
.23269 .21503 Mdot
.23274 .21531 Mdot
.23279 .21559 Mdot
.23284 .21586 Mdot
.23288 .21614 Mdot
.23293 .21642 Mdot
.23298 .21669 Mdot
.23303 .21697 Mdot
.23307 .21725 Mdot
.23312 .21753 Mdot
.23317 .21781 Mdot
.23322 .21808 Mdot
.23326 .21836 Mdot
.23331 .21864 Mdot
.23336 .21892 Mdot
.23341 .2192 Mdot
.23346 .21947 Mdot
.2335 .21975 Mdot
.23355 .22003 Mdot
.2336 .22031 Mdot
.23365 .22059 Mdot
.23369 .22087 Mdot
.23374 .22115 Mdot
.23379 .22142 Mdot
.23384 .2217 Mdot
.23388 .22198 Mdot
.23393 .22226 Mdot
.23398 .22254 Mdot
.23403 .22282 Mdot
.23407 .2231 Mdot
.23412 .22338 Mdot
.23417 .22366 Mdot
.23422 .22394 Mdot
.23426 .22422 Mdot
.23431 .2245 Mdot
.23436 .22478 Mdot
.23441 .22506 Mdot
.23446 .22534 Mdot
.2345 .22562 Mdot
.23455 .2259 Mdot
.2346 .22618 Mdot
.23465 .22646 Mdot
.23469 .22674 Mdot
.23474 .22702 Mdot
.23479 .2273 Mdot
.23484 .22758 Mdot
.23488 .22786 Mdot
.23493 .22815 Mdot
.23498 .22843 Mdot
.23503 .22871 Mdot
.23507 .22899 Mdot
.23512 .22927 Mdot
.23517 .22955 Mdot
.23522 .22983 Mdot
.23526 .23012 Mdot
.23531 .2304 Mdot
.23536 .23068 Mdot
.23541 .23096 Mdot
.23546 .23124 Mdot
.2355 .23152 Mdot
.23555 .23181 Mdot
.2356 .23209 Mdot
.23565 .23237 Mdot
.23569 .23265 Mdot
.23574 .23294 Mdot
.23579 .23322 Mdot
.23584 .2335 Mdot
.23588 .23378 Mdot
.23593 .23407 Mdot
.23598 .23435 Mdot
.23603 .23463 Mdot
.23607 .23491 Mdot
.23612 .2352 Mdot
.23617 .23548 Mdot
.23622 .23576 Mdot
.23626 .23605 Mdot
.23631 .23633 Mdot
.23636 .23661 Mdot
.23641 .2369 Mdot
.23645 .23718 Mdot
.2365 .23746 Mdot
.23655 .23775 Mdot
.2366 .23803 Mdot
.23665 .23831 Mdot
.23669 .2386 Mdot
.23674 .23888 Mdot
.23679 .23917 Mdot
.23684 .23945 Mdot
.23688 .23973 Mdot
.23693 .24002 Mdot
.23698 .2403 Mdot
.23703 .24059 Mdot
.23707 .24087 Mdot
.23712 .24115 Mdot
.23717 .24144 Mdot
.23722 .24172 Mdot
.23726 .24201 Mdot
.23731 .24229 Mdot
.23736 .24258 Mdot
.23741 .24286 Mdot
.23745 .24315 Mdot
.2375 .24343 Mdot
.23755 .24372 Mdot
.2376 .244 Mdot
.23765 .24429 Mdot
.23769 .24457 Mdot
.23774 .24486 Mdot
.23779 .24514 Mdot
.23784 .24543 Mdot
.23788 .24571 Mdot
.23793 .246 Mdot
.23798 .24629 Mdot
.23803 .24657 Mdot
.23807 .24686 Mdot
.23812 .24714 Mdot
.23817 .24743 Mdot
.23822 .24771 Mdot
.23826 .248 Mdot
.23831 .24829 Mdot
.23836 .24857 Mdot
.23841 .24886 Mdot
.23845 .24915 Mdot
.2385 .24943 Mdot
.23855 .24972 Mdot
.2386 .25 Mdot
.23865 .25029 Mdot
.23869 .25058 Mdot
.23874 .25086 Mdot
.23879 .25115 Mdot
.23884 .25144 Mdot
.23888 .25172 Mdot
.23893 .25201 Mdot
.23898 .2523 Mdot
.23903 .25258 Mdot
.23907 .25287 Mdot
.23912 .25316 Mdot
.23917 .25345 Mdot
.23922 .25373 Mdot
.23926 .25402 Mdot
.23931 .25431 Mdot
.23936 .25459 Mdot
.23941 .25488 Mdot
.23945 .25517 Mdot
.2395 .25546 Mdot
.23955 .25574 Mdot
.2396 .25603 Mdot
.23965 .25632 Mdot
.23969 .25661 Mdot
.23974 .25689 Mdot
.23979 .25718 Mdot
.23984 .25747 Mdot
.23988 .25776 Mdot
.23993 .25805 Mdot
.23998 .25833 Mdot
.24003 .25862 Mdot
.24007 .25891 Mdot
.24012 .2592 Mdot
.24017 .25949 Mdot
.24022 .25978 Mdot
.24026 .26006 Mdot
.24031 .26035 Mdot
.24036 .26064 Mdot
.24041 .26093 Mdot
.24045 .26122 Mdot
.2405 .26151 Mdot
.24055 .26179 Mdot
.2406 .26208 Mdot
.24064 .26237 Mdot
.24069 .26266 Mdot
.24074 .26295 Mdot
.24079 .26324 Mdot
.24084 .26353 Mdot
.24088 .26382 Mdot
.24093 .2641 Mdot
.24098 .26439 Mdot
.24103 .26468 Mdot
.24107 .26497 Mdot
.24112 .26526 Mdot
.24117 .26555 Mdot
.24122 .26584 Mdot
.24126 .26613 Mdot
.24131 .26642 Mdot
.24136 .26671 Mdot
.24141 .267 Mdot
.24145 .26729 Mdot
.2415 .26758 Mdot
.24155 .26787 Mdot
.2416 .26815 Mdot
.24164 .26844 Mdot
.24169 .26873 Mdot
.24174 .26902 Mdot
.24179 .26931 Mdot
.24184 .2696 Mdot
.24188 .26989 Mdot
.24193 .27018 Mdot
.24198 .27047 Mdot
.24203 .27076 Mdot
.24207 .27105 Mdot
.24212 .27134 Mdot
.24217 .27163 Mdot
.24222 .27192 Mdot
.24226 .27221 Mdot
.24231 .2725 Mdot
.24236 .27279 Mdot
.24241 .27308 Mdot
.24245 .27337 Mdot
.2425 .27366 Mdot
.24255 .27395 Mdot
.2426 .27424 Mdot
.24264 .27453 Mdot
.24269 .27483 Mdot
.24274 .27512 Mdot
.24279 .27541 Mdot
.24284 .2757 Mdot
.24288 .27599 Mdot
.24293 .27628 Mdot
.24298 .27657 Mdot
.24303 .27686 Mdot
.24307 .27715 Mdot
.24312 .27744 Mdot
.24317 .27773 Mdot
.24322 .27802 Mdot
.24326 .27831 Mdot
.24331 .2786 Mdot
.24336 .27889 Mdot
.24341 .27919 Mdot
.24345 .27948 Mdot
.2435 .27977 Mdot
.24355 .28006 Mdot
.2436 .28035 Mdot
.24364 .28064 Mdot
.24369 .28093 Mdot
.24374 .28122 Mdot
.24379 .28151 Mdot
.24384 .28181 Mdot
.24388 .2821 Mdot
.24393 .28239 Mdot
.24398 .28268 Mdot
.24403 .28297 Mdot
.24407 .28326 Mdot
.24412 .28355 Mdot
.24417 .28384 Mdot
.24422 .28414 Mdot
.24426 .28443 Mdot
.24431 .28472 Mdot
.24436 .28501 Mdot
.24441 .2853 Mdot
.24445 .28559 Mdot
.2445 .28588 Mdot
.24455 .28618 Mdot
.2446 .28647 Mdot
.24464 .28676 Mdot
.24469 .28705 Mdot
.24474 .28734 Mdot
.24479 .28763 Mdot
.24484 .28793 Mdot
.24488 .28822 Mdot
.24493 .28851 Mdot
.24498 .2888 Mdot
.24503 .28909 Mdot
.24507 .28938 Mdot
.24512 .28968 Mdot
.24517 .28997 Mdot
.24522 .29026 Mdot
.24526 .29055 Mdot
.24531 .29084 Mdot
.24536 .29114 Mdot
.24541 .29143 Mdot
.24545 .29172 Mdot
.2455 .29201 Mdot
.24555 .2923 Mdot
.2456 .2926 Mdot
.24564 .29289 Mdot
.24569 .29318 Mdot
.24574 .29347 Mdot
.24579 .29376 Mdot
.24583 .29406 Mdot
.24588 .29435 Mdot
.24593 .29464 Mdot
.24598 .29493 Mdot
.24603 .29522 Mdot
.24607 .29552 Mdot
.24612 .29581 Mdot
.24617 .2961 Mdot
.24622 .29639 Mdot
.24626 .29668 Mdot
.24631 .29698 Mdot
.24636 .29727 Mdot
.24641 .29756 Mdot
.24645 .29785 Mdot
.2465 .29815 Mdot
.24655 .29844 Mdot
.2466 .29873 Mdot
.24664 .29902 Mdot
.24669 .29931 Mdot
.24674 .29961 Mdot
.24679 .2999 Mdot
.24683 .30019 Mdot
.24688 .30048 Mdot
.24693 .30078 Mdot
.24698 .30107 Mdot
.24703 .30136 Mdot
.24707 .30165 Mdot
.24712 .30195 Mdot
.24717 .30224 Mdot
.24722 .30253 Mdot
.24726 .30282 Mdot
.24731 .30312 Mdot
.24736 .30341 Mdot
.24741 .3037 Mdot
.24745 .30399 Mdot
.2475 .30428 Mdot
.24755 .30458 Mdot
.2476 .30487 Mdot
.24764 .30516 Mdot
.24769 .30545 Mdot
.24774 .30575 Mdot
.24779 .30604 Mdot
.24783 .30633 Mdot
.24788 .30662 Mdot
.24793 .30692 Mdot
.24798 .30721 Mdot
.24803 .3075 Mdot
.24807 .30779 Mdot
.24812 .30809 Mdot
.24817 .30838 Mdot
.24822 .30867 Mdot
.24826 .30896 Mdot
.24831 .30926 Mdot
.24836 .30955 Mdot
.24841 .30984 Mdot
.24845 .31013 Mdot
.2485 .31043 Mdot
.24855 .31072 Mdot
.2486 .31101 Mdot
.24864 .3113 Mdot
.24869 .3116 Mdot
.24874 .31189 Mdot
.24879 .31218 Mdot
.24883 .31247 Mdot
.24888 .31277 Mdot
.24893 .31306 Mdot
.24898 .31335 Mdot
.24903 .31364 Mdot
.24907 .31394 Mdot
.24912 .31423 Mdot
.24917 .31452 Mdot
.24922 .31481 Mdot
.24926 .31511 Mdot
.24931 .3154 Mdot
.24936 .31569 Mdot
.24941 .31598 Mdot
.24945 .31627 Mdot
.2495 .31657 Mdot
.24955 .31686 Mdot
.2496 .31715 Mdot
.24964 .31744 Mdot
.24969 .31774 Mdot
.24974 .31803 Mdot
.24979 .31832 Mdot
.24983 .31861 Mdot
.24988 .31891 Mdot
.24993 .3192 Mdot
.24998 .31949 Mdot
.25002 .31978 Mdot
.25007 .32007 Mdot
.25012 .32037 Mdot
.25017 .32066 Mdot
.25022 .32095 Mdot
.25026 .32124 Mdot
.25031 .32154 Mdot
.25036 .32183 Mdot
.25041 .32212 Mdot
.25045 .32241 Mdot
.2505 .3227 Mdot
.25055 .323 Mdot
.2506 .32329 Mdot
.25064 .32358 Mdot
.25069 .32387 Mdot
.25074 .32417 Mdot
.25079 .32446 Mdot
.25083 .32475 Mdot
.25088 .32504 Mdot
.25093 .32533 Mdot
.25098 .32563 Mdot
.25102 .32592 Mdot
.25107 .32621 Mdot
.25112 .3265 Mdot
.25117 .32679 Mdot
.25122 .32709 Mdot
.25126 .32738 Mdot
.25131 .32767 Mdot
.25136 .32796 Mdot
.25141 .32825 Mdot
.25145 .32854 Mdot
.2515 .32884 Mdot
.25155 .32913 Mdot
.2516 .32942 Mdot
.25164 .32971 Mdot
.25169 .33 Mdot
.25174 .33029 Mdot
.25179 .33059 Mdot
.25183 .33088 Mdot
.25188 .33117 Mdot
.25193 .33146 Mdot
.25198 .33175 Mdot
.25202 .33204 Mdot
.25207 .33234 Mdot
.25212 .33263 Mdot
.25217 .33292 Mdot
.25222 .33321 Mdot
.25226 .3335 Mdot
.25231 .33379 Mdot
.25236 .33408 Mdot
.25241 .33438 Mdot
.25245 .33467 Mdot
.2525 .33496 Mdot
.25255 .33525 Mdot
.2526 .33554 Mdot
.25264 .33583 Mdot
.25269 .33612 Mdot
.25274 .33642 Mdot
.25279 .33671 Mdot
.25283 .337 Mdot
.25288 .33729 Mdot
.25293 .33758 Mdot
.25298 .33787 Mdot
.25302 .33816 Mdot
.25307 .33845 Mdot
.25312 .33874 Mdot
.25317 .33903 Mdot
.25322 .33933 Mdot
.25326 .33962 Mdot
.25331 .33991 Mdot
.25336 .3402 Mdot
.25341 .34049 Mdot
.25345 .34078 Mdot
.2535 .34107 Mdot
.25355 .34136 Mdot
.2536 .34165 Mdot
.25364 .34194 Mdot
.25369 .34223 Mdot
.25374 .34252 Mdot
.25379 .34281 Mdot
.25383 .3431 Mdot
.25388 .34339 Mdot
.25393 .34369 Mdot
.25398 .34398 Mdot
.25402 .34427 Mdot
.25407 .34456 Mdot
.25412 .34485 Mdot
.25417 .34514 Mdot
.25422 .34543 Mdot
.25426 .34572 Mdot
.25431 .34601 Mdot
.25436 .3463 Mdot
.25441 .34659 Mdot
.25445 .34688 Mdot
.2545 .34717 Mdot
.25455 .34746 Mdot
.2546 .34775 Mdot
.25464 .34804 Mdot
.25469 .34833 Mdot
.25474 .34862 Mdot
.25479 .34891 Mdot
.25483 .3492 Mdot
.25488 .34949 Mdot
.25493 .34978 Mdot
.25498 .35007 Mdot
.25502 .35035 Mdot
.25507 .35064 Mdot
.25512 .35093 Mdot
.25517 .35122 Mdot
.25521 .35151 Mdot
.25526 .3518 Mdot
.25531 .35209 Mdot
.25536 .35238 Mdot
.25541 .35267 Mdot
.25545 .35296 Mdot
.2555 .35325 Mdot
.25555 .35354 Mdot
.2556 .35383 Mdot
.25564 .35412 Mdot
.25569 .3544 Mdot
.25574 .35469 Mdot
.25579 .35498 Mdot
.25583 .35527 Mdot
.25588 .35556 Mdot
.25593 .35585 Mdot
.25598 .35614 Mdot
.25602 .35643 Mdot
.25607 .35671 Mdot
.25612 .357 Mdot
.25617 .35729 Mdot
.25621 .35758 Mdot
.25626 .35787 Mdot
.25631 .35816 Mdot
.25636 .35844 Mdot
.25641 .35873 Mdot
.25645 .35902 Mdot
.2565 .35931 Mdot
.25655 .3596 Mdot
.2566 .35989 Mdot
.25664 .36017 Mdot
.25669 .36046 Mdot
.25674 .36075 Mdot
.25679 .36104 Mdot
.25683 .36132 Mdot
.25688 .36161 Mdot
.25693 .3619 Mdot
.25698 .36219 Mdot
.25702 .36248 Mdot
.25707 .36276 Mdot
.25712 .36305 Mdot
.25717 .36334 Mdot
.25721 .36362 Mdot
.25726 .36391 Mdot
.25731 .3642 Mdot
.25736 .36449 Mdot
.25741 .36477 Mdot
.25745 .36506 Mdot
.2575 .36535 Mdot
.25755 .36563 Mdot
.2576 .36592 Mdot
.25764 .36621 Mdot
.25769 .3665 Mdot
.25774 .36678 Mdot
.25779 .36707 Mdot
.25783 .36736 Mdot
.25788 .36764 Mdot
.25793 .36793 Mdot
.25798 .36821 Mdot
.25802 .3685 Mdot
.25807 .36879 Mdot
.25812 .36907 Mdot
.25817 .36936 Mdot
.25821 .36965 Mdot
.25826 .36993 Mdot
.25831 .37022 Mdot
.25836 .3705 Mdot
.25841 .37079 Mdot
.25845 .37108 Mdot
.2585 .37136 Mdot
.25855 .37165 Mdot
.2586 .37193 Mdot
.25864 .37222 Mdot
.25869 .3725 Mdot
.25874 .37279 Mdot
.25879 .37308 Mdot
.25883 .37336 Mdot
.25888 .37365 Mdot
.25893 .37393 Mdot
.25898 .37422 Mdot
.25902 .3745 Mdot
.25907 .37479 Mdot
.25912 .37507 Mdot
.25917 .37536 Mdot
.25921 .37564 Mdot
.25926 .37593 Mdot
.25931 .37621 Mdot
.25936 .3765 Mdot
.25941 .37678 Mdot
.25945 .37706 Mdot
.2595 .37735 Mdot
.25955 .37763 Mdot
.2596 .37792 Mdot
.25964 .3782 Mdot
.25969 .37849 Mdot
.25974 .37877 Mdot
.25979 .37905 Mdot
.25983 .37934 Mdot
.25988 .37962 Mdot
.25993 .37991 Mdot
.25998 .38019 Mdot
.26002 .38047 Mdot
.26007 .38076 Mdot
.26012 .38104 Mdot
.26017 .38132 Mdot
.26021 .38161 Mdot
.26026 .38189 Mdot
.26031 .38217 Mdot
.26036 .38246 Mdot
.2604 .38274 Mdot
.26045 .38302 Mdot
.2605 .3833 Mdot
.26055 .38359 Mdot
.2606 .38387 Mdot
.26064 .38415 Mdot
.26069 .38444 Mdot
.26074 .38472 Mdot
.26079 .385 Mdot
.26083 .38528 Mdot
.26088 .38557 Mdot
.26093 .38585 Mdot
.26098 .38613 Mdot
.26102 .38641 Mdot
.26107 .38669 Mdot
.26112 .38698 Mdot
.26117 .38726 Mdot
.26121 .38754 Mdot
.26126 .38782 Mdot
.26131 .3881 Mdot
.26136 .38838 Mdot
.2614 .38867 Mdot
.26145 .38895 Mdot
.2615 .38923 Mdot
.26155 .38951 Mdot
.2616 .38979 Mdot
.26164 .39007 Mdot
.26169 .39035 Mdot
.26174 .39063 Mdot
.26179 .39091 Mdot
.26183 .3912 Mdot
.26188 .39148 Mdot
.26193 .39176 Mdot
.26198 .39204 Mdot
.26202 .39232 Mdot
.26207 .3926 Mdot
.26212 .39288 Mdot
.26217 .39316 Mdot
.26221 .39344 Mdot
.26226 .39372 Mdot
.26231 .394 Mdot
.26236 .39428 Mdot
.2624 .39456 Mdot
.26245 .39484 Mdot
.2625 .39512 Mdot
.26255 .3954 Mdot
.2626 .39568 Mdot
.26264 .39596 Mdot
.26269 .39623 Mdot
.26274 .39651 Mdot
.26279 .39679 Mdot
.26283 .39707 Mdot
.26288 .39735 Mdot
.26293 .39763 Mdot
.26298 .39791 Mdot
.26302 .39819 Mdot
.26307 .39846 Mdot
.26312 .39874 Mdot
.26317 .39902 Mdot
.26321 .3993 Mdot
.26326 .39958 Mdot
.26331 .39986 Mdot
.26336 .40013 Mdot
.2634 .40041 Mdot
.26345 .40069 Mdot
.2635 .40097 Mdot
.26355 .40124 Mdot
.2636 .40152 Mdot
.26364 .4018 Mdot
.26369 .40208 Mdot
.26374 .40235 Mdot
.26379 .40263 Mdot
.26383 .40291 Mdot
.26388 .40319 Mdot
.26393 .40346 Mdot
.26398 .40374 Mdot
.26402 .40402 Mdot
.26407 .40429 Mdot
.26412 .40457 Mdot
.26417 .40485 Mdot
.26421 .40512 Mdot
.26426 .4054 Mdot
.26431 .40567 Mdot
.26436 .40595 Mdot
.2644 .40623 Mdot
.26445 .4065 Mdot
.2645 .40678 Mdot
.26455 .40705 Mdot
.26459 .40733 Mdot
.26464 .4076 Mdot
.26469 .40788 Mdot
.26474 .40815 Mdot
.26479 .40843 Mdot
.26483 .4087 Mdot
.26488 .40898 Mdot
.26493 .40925 Mdot
.26498 .40953 Mdot
.26502 .4098 Mdot
.26507 .41008 Mdot
.26512 .41035 Mdot
.26517 .41063 Mdot
.26521 .4109 Mdot
.26526 .41118 Mdot
.26531 .41145 Mdot
.26536 .41172 Mdot
.2654 .412 Mdot
.26545 .41227 Mdot
.2655 .41254 Mdot
.26555 .41282 Mdot
.26559 .41309 Mdot
.26564 .41336 Mdot
.26569 .41364 Mdot
.26574 .41391 Mdot
.26579 .41418 Mdot
.26583 .41446 Mdot
.26588 .41473 Mdot
.26593 .415 Mdot
.26598 .41527 Mdot
.26602 .41555 Mdot
.26607 .41582 Mdot
.26612 .41609 Mdot
.26617 .41636 Mdot
.26621 .41664 Mdot
.26626 .41691 Mdot
.26631 .41718 Mdot
.26636 .41745 Mdot
.2664 .41772 Mdot
.26645 .41799 Mdot
.2665 .41827 Mdot
.26655 .41854 Mdot
.26659 .41881 Mdot
.26664 .41908 Mdot
.26669 .41935 Mdot
.26674 .41962 Mdot
.26679 .41989 Mdot
.26683 .42016 Mdot
.26688 .42043 Mdot
.26693 .4207 Mdot
.26698 .42097 Mdot
.26702 .42124 Mdot
.26707 .42151 Mdot
.26712 .42178 Mdot
.26717 .42205 Mdot
.26721 .42232 Mdot
.26726 .42259 Mdot
.26731 .42286 Mdot
.26736 .42313 Mdot
.2674 .4234 Mdot
.26745 .42367 Mdot
.2675 .42394 Mdot
.26755 .42421 Mdot
.26759 .42448 Mdot
.26764 .42474 Mdot
.26769 .42501 Mdot
.26774 .42528 Mdot
.26779 .42555 Mdot
.26783 .42582 Mdot
.26788 .42609 Mdot
.26793 .42635 Mdot
.26798 .42662 Mdot
.26802 .42689 Mdot
.26807 .42716 Mdot
.26812 .42742 Mdot
.26817 .42769 Mdot
.26821 .42796 Mdot
.26826 .42823 Mdot
.26831 .42849 Mdot
.26836 .42876 Mdot
.2684 .42903 Mdot
.26845 .42929 Mdot
.2685 .42956 Mdot
.26855 .42983 Mdot
.26859 .43009 Mdot
.26864 .43036 Mdot
.26869 .43063 Mdot
.26874 .43089 Mdot
.26879 .43116 Mdot
.26883 .43142 Mdot
.26888 .43169 Mdot
.26893 .43195 Mdot
.26898 .43222 Mdot
.26902 .43248 Mdot
.26907 .43275 Mdot
.26912 .43301 Mdot
.26917 .43328 Mdot
.26921 .43354 Mdot
.26926 .43381 Mdot
.26931 .43407 Mdot
.26936 .43434 Mdot
.2694 .4346 Mdot
.26945 .43487 Mdot
.2695 .43513 Mdot
.26955 .43539 Mdot
.26959 .43566 Mdot
.26964 .43592 Mdot
.26969 .43618 Mdot
.26974 .43645 Mdot
.26978 .43671 Mdot
.26983 .43697 Mdot
.26988 .43724 Mdot
.26993 .4375 Mdot
.26998 .43776 Mdot
.27002 .43802 Mdot
.27007 .43829 Mdot
.27012 .43855 Mdot
.27017 .43881 Mdot
.27021 .43907 Mdot
.27026 .43934 Mdot
.27031 .4396 Mdot
.27036 .43986 Mdot
.2704 .44012 Mdot
.27045 .44038 Mdot
.2705 .44064 Mdot
.27055 .4409 Mdot
.27059 .44117 Mdot
.27064 .44143 Mdot
.27069 .44169 Mdot
.27074 .44195 Mdot
.27078 .44221 Mdot
.27083 .44247 Mdot
.27088 .44273 Mdot
.27093 .44299 Mdot
.27098 .44325 Mdot
.27102 .44351 Mdot
.27107 .44377 Mdot
.27112 .44403 Mdot
.27117 .44429 Mdot
.27121 .44455 Mdot
.27126 .44481 Mdot
.27131 .44506 Mdot
.27136 .44532 Mdot
.2714 .44558 Mdot
.27145 .44584 Mdot
.2715 .4461 Mdot
.27155 .44636 Mdot
.27159 .44662 Mdot
.27164 .44687 Mdot
.27169 .44713 Mdot
.27174 .44739 Mdot
.27178 .44765 Mdot
.27183 .4479 Mdot
.27188 .44816 Mdot
.27193 .44842 Mdot
.27198 .44868 Mdot
.27202 .44893 Mdot
.27207 .44919 Mdot
.27212 .44945 Mdot
.27217 .4497 Mdot
.27221 .44996 Mdot
.27226 .45022 Mdot
.27231 .45047 Mdot
.27236 .45073 Mdot
.2724 .45098 Mdot
.27245 .45124 Mdot
.2725 .45149 Mdot
.27255 .45175 Mdot
.27259 .452 Mdot
.27264 .45226 Mdot
.27269 .45251 Mdot
.27274 .45277 Mdot
.27278 .45302 Mdot
.27283 .45328 Mdot
.27288 .45353 Mdot
.27293 .45379 Mdot
.27298 .45404 Mdot
.27302 .4543 Mdot
.27307 .45455 Mdot
.27312 .4548 Mdot
.27317 .45506 Mdot
.27321 .45531 Mdot
.27326 .45556 Mdot
.27331 .45582 Mdot
.27336 .45607 Mdot
.2734 .45632 Mdot
.27345 .45657 Mdot
.2735 .45683 Mdot
.27355 .45708 Mdot
.27359 .45733 Mdot
.27364 .45758 Mdot
.27369 .45783 Mdot
.27374 .45809 Mdot
.27378 .45834 Mdot
.27383 .45859 Mdot
.27388 .45884 Mdot
.27393 .45909 Mdot
.27397 .45934 Mdot
.27402 .45959 Mdot
.27407 .45984 Mdot
.27412 .46009 Mdot
.27417 .46035 Mdot
.27421 .4606 Mdot
.27426 .46085 Mdot
.27431 .4611 Mdot
.27436 .46135 Mdot
.2744 .46159 Mdot
.27445 .46184 Mdot
.2745 .46209 Mdot
.27455 .46234 Mdot
.27459 .46259 Mdot
.27464 .46284 Mdot
.27469 .46309 Mdot
.27474 .46334 Mdot
.27478 .46359 Mdot
.27483 .46383 Mdot
.27488 .46408 Mdot
.27493 .46433 Mdot
.27497 .46458 Mdot
.27502 .46483 Mdot
.27507 .46507 Mdot
.27512 .46532 Mdot
.27517 .46557 Mdot
.27521 .46581 Mdot
.27526 .46606 Mdot
.27531 .46631 Mdot
.27536 .46655 Mdot
.2754 .4668 Mdot
.27545 .46705 Mdot
.2755 .46729 Mdot
.27555 .46754 Mdot
.27559 .46778 Mdot
.27564 .46803 Mdot
.27569 .46828 Mdot
.27574 .46852 Mdot
.27578 .46877 Mdot
.27583 .46901 Mdot
.27588 .46926 Mdot
.27593 .4695 Mdot
.27597 .46974 Mdot
.27602 .46999 Mdot
.27607 .47023 Mdot
.27612 .47048 Mdot
.27617 .47072 Mdot
.27621 .47096 Mdot
.27626 .47121 Mdot
.27631 .47145 Mdot
.27636 .47169 Mdot
.2764 .47194 Mdot
.27645 .47218 Mdot
.2765 .47242 Mdot
.27655 .47267 Mdot
.27659 .47291 Mdot
.27664 .47315 Mdot
.27669 .47339 Mdot
.27674 .47363 Mdot
.27678 .47388 Mdot
.27683 .47412 Mdot
.27688 .47436 Mdot
.27693 .4746 Mdot
.27697 .47484 Mdot
.27702 .47508 Mdot
.27707 .47532 Mdot
.27712 .47556 Mdot
.27717 .4758 Mdot
.27721 .47604 Mdot
.27726 .47628 Mdot
.27731 .47652 Mdot
.27736 .47676 Mdot
.2774 .477 Mdot
.27745 .47724 Mdot
.2775 .47748 Mdot
.27755 .47772 Mdot
.27759 .47796 Mdot
.27764 .4782 Mdot
.27769 .47844 Mdot
.27774 .47867 Mdot
.27778 .47891 Mdot
.27783 .47915 Mdot
.27788 .47939 Mdot
.27793 .47963 Mdot
.27797 .47986 Mdot
.27802 .4801 Mdot
.27807 .48034 Mdot
.27812 .48057 Mdot
.27817 .48081 Mdot
.27821 .48105 Mdot
.27826 .48128 Mdot
.27831 .48152 Mdot
.27836 .48176 Mdot
.2784 .48199 Mdot
.27845 .48223 Mdot
.2785 .48246 Mdot
.27855 .4827 Mdot
.27859 .48293 Mdot
.27864 .48317 Mdot
.27869 .4834 Mdot
.27874 .48364 Mdot
.27878 .48387 Mdot
.27883 .48411 Mdot
.27888 .48434 Mdot
.27893 .48458 Mdot
.27897 .48481 Mdot
.27902 .48504 Mdot
.27907 .48528 Mdot
.27912 .48551 Mdot
.27916 .48574 Mdot
.27921 .48598 Mdot
.27926 .48621 Mdot
.27931 .48644 Mdot
.27936 .48667 Mdot
.2794 .48691 Mdot
.27945 .48714 Mdot
.2795 .48737 Mdot
.27955 .4876 Mdot
.27959 .48783 Mdot
.27964 .48807 Mdot
.27969 .4883 Mdot
.27974 .48853 Mdot
.27978 .48876 Mdot
.27983 .48899 Mdot
.27988 .48922 Mdot
.27993 .48945 Mdot
.27997 .48968 Mdot
.28002 .48991 Mdot
.28007 .49014 Mdot
.28012 .49037 Mdot
.28016 .4906 Mdot
.28021 .49083 Mdot
.28026 .49106 Mdot
.28031 .49129 Mdot
.28036 .49151 Mdot
.2804 .49174 Mdot
.28045 .49197 Mdot
.2805 .4922 Mdot
.28055 .49243 Mdot
.28059 .49266 Mdot
.28064 .49288 Mdot
.28069 .49311 Mdot
.28074 .49334 Mdot
.28078 .49356 Mdot
.28083 .49379 Mdot
.28088 .49402 Mdot
.28093 .49424 Mdot
.28097 .49447 Mdot
.28102 .4947 Mdot
.28107 .49492 Mdot
.28112 .49515 Mdot
.28116 .49537 Mdot
.28121 .4956 Mdot
.28126 .49582 Mdot
.28131 .49605 Mdot
.28136 .49627 Mdot
.2814 .4965 Mdot
.28145 .49672 Mdot
.2815 .49695 Mdot
.28155 .49717 Mdot
.28159 .4974 Mdot
.28164 .49762 Mdot
.28169 .49784 Mdot
.28174 .49807 Mdot
.28178 .49829 Mdot
.28183 .49851 Mdot
.28188 .49873 Mdot
.28193 .49896 Mdot
.28197 .49918 Mdot
.28202 .4994 Mdot
.28207 .49962 Mdot
.28212 .49984 Mdot
.28216 .50007 Mdot
.28221 .50029 Mdot
.28226 .50051 Mdot
.28231 .50073 Mdot
.28236 .50095 Mdot
.2824 .50117 Mdot
.28245 .50139 Mdot
.2825 .50161 Mdot
.28255 .50183 Mdot
.28259 .50205 Mdot
.28264 .50227 Mdot
.28269 .50249 Mdot
.28274 .50271 Mdot
.28278 .50293 Mdot
.28283 .50315 Mdot
.28288 .50337 Mdot
.28293 .50359 Mdot
.28297 .5038 Mdot
.28302 .50402 Mdot
.28307 .50424 Mdot
.28312 .50446 Mdot
.28316 .50467 Mdot
.28321 .50489 Mdot
.28326 .50511 Mdot
.28331 .50533 Mdot
.28335 .50554 Mdot
.2834 .50576 Mdot
.28345 .50598 Mdot
.2835 .50619 Mdot
.28355 .50641 Mdot
.28359 .50662 Mdot
.28364 .50684 Mdot
.28369 .50705 Mdot
.28374 .50727 Mdot
.28378 .50748 Mdot
.28383 .5077 Mdot
.28388 .50791 Mdot
.28393 .50813 Mdot
.28397 .50834 Mdot
.28402 .50856 Mdot
.28407 .50877 Mdot
.28412 .50898 Mdot
.28416 .5092 Mdot
.28421 .50941 Mdot
.28426 .50962 Mdot
.28431 .50984 Mdot
.28435 .51005 Mdot
.2844 .51026 Mdot
.28445 .51047 Mdot
.2845 .51068 Mdot
.28455 .5109 Mdot
.28459 .51111 Mdot
.28464 .51132 Mdot
.28469 .51153 Mdot
.28474 .51174 Mdot
.28478 .51195 Mdot
.28483 .51216 Mdot
.28488 .51237 Mdot
.28493 .51258 Mdot
.28497 .51279 Mdot
.28502 .513 Mdot
.28507 .51321 Mdot
.28512 .51342 Mdot
.28516 .51363 Mdot
.28521 .51384 Mdot
.28526 .51405 Mdot
.28531 .51426 Mdot
.28535 .51446 Mdot
.2854 .51467 Mdot
.28545 .51488 Mdot
.2855 .51509 Mdot
.28555 .5153 Mdot
.28559 .5155 Mdot
.28564 .51571 Mdot
.28569 .51592 Mdot
.28574 .51612 Mdot
.28578 .51633 Mdot
.28583 .51654 Mdot
.28588 .51674 Mdot
.28593 .51695 Mdot
.28597 .51715 Mdot
.28602 .51736 Mdot
.28607 .51756 Mdot
.28612 .51777 Mdot
.28616 .51797 Mdot
.28621 .51818 Mdot
.28626 .51838 Mdot
.28631 .51859 Mdot
.28635 .51879 Mdot
.2864 .51899 Mdot
.28645 .5192 Mdot
.2865 .5194 Mdot
.28655 .5196 Mdot
.28659 .51981 Mdot
.28664 .52001 Mdot
.28669 .52021 Mdot
.28674 .52041 Mdot
.28678 .52062 Mdot
.28683 .52082 Mdot
.28688 .52102 Mdot
.28693 .52122 Mdot
.28697 .52142 Mdot
.28702 .52162 Mdot
.28707 .52182 Mdot
.28712 .52202 Mdot
.28716 .52223 Mdot
.28721 .52243 Mdot
.28726 .52263 Mdot
.28731 .52282 Mdot
.28735 .52302 Mdot
.2874 .52322 Mdot
.28745 .52342 Mdot
.2875 .52362 Mdot
.28755 .52382 Mdot
.28759 .52402 Mdot
.28764 .52422 Mdot
.28769 .52441 Mdot
.28774 .52461 Mdot
.28778 .52481 Mdot
.28783 .52501 Mdot
.28788 .5252 Mdot
.28793 .5254 Mdot
.28797 .5256 Mdot
.28802 .52579 Mdot
.28807 .52599 Mdot
.28812 .52619 Mdot
.28816 .52638 Mdot
.28821 .52658 Mdot
.28826 .52677 Mdot
.28831 .52697 Mdot
.28835 .52716 Mdot
.2884 .52736 Mdot
.28845 .52755 Mdot
.2885 .52775 Mdot
.28854 .52794 Mdot
.28859 .52813 Mdot
.28864 .52833 Mdot
.28869 .52852 Mdot
.28874 .52872 Mdot
.28878 .52891 Mdot
.28883 .5291 Mdot
.28888 .52929 Mdot
.28893 .52949 Mdot
.28897 .52968 Mdot
.28902 .52987 Mdot
.28907 .53006 Mdot
.28912 .53025 Mdot
.28916 .53044 Mdot
.28921 .53063 Mdot
.28926 .53083 Mdot
.28931 .53102 Mdot
.28935 .53121 Mdot
.2894 .5314 Mdot
.28945 .53159 Mdot
.2895 .53178 Mdot
.28954 .53197 Mdot
.28959 .53215 Mdot
.28964 .53234 Mdot
.28969 .53253 Mdot
.28974 .53272 Mdot
.28978 .53291 Mdot
.28983 .5331 Mdot
.28988 .53329 Mdot
.28993 .53347 Mdot
.28997 .53366 Mdot
.29002 .53385 Mdot
.29007 .53403 Mdot
.29012 .53422 Mdot
.29016 .53441 Mdot
.29021 .53459 Mdot
.29026 .53478 Mdot
.29031 .53497 Mdot
.29035 .53515 Mdot
.2904 .53534 Mdot
.29045 .53552 Mdot
.2905 .53571 Mdot
.29054 .53589 Mdot
.29059 .53608 Mdot
.29064 .53626 Mdot
.29069 .53644 Mdot
.29074 .53663 Mdot
.29078 .53681 Mdot
.29083 .537 Mdot
.29088 .53718 Mdot
.29093 .53736 Mdot
.29097 .53754 Mdot
.29102 .53773 Mdot
.29107 .53791 Mdot
.29112 .53809 Mdot
.29116 .53827 Mdot
.29121 .53845 Mdot
.29126 .53863 Mdot
.29131 .53882 Mdot
.29135 .539 Mdot
.2914 .53918 Mdot
.29145 .53936 Mdot
.2915 .53954 Mdot
.29154 .53972 Mdot
.29159 .5399 Mdot
.29164 .54008 Mdot
.29169 .54026 Mdot
.29174 .54043 Mdot
.29178 .54061 Mdot
.29183 .54079 Mdot
.29188 .54097 Mdot
.29193 .54115 Mdot
.29197 .54133 Mdot
.29202 .5415 Mdot
.29207 .54168 Mdot
.29212 .54186 Mdot
.29216 .54204 Mdot
.29221 .54221 Mdot
.29226 .54239 Mdot
.29231 .54256 Mdot
.29235 .54274 Mdot
.2924 .54292 Mdot
.29245 .54309 Mdot
.2925 .54327 Mdot
.29254 .54344 Mdot
.29259 .54362 Mdot
.29264 .54379 Mdot
.29269 .54397 Mdot
.29274 .54414 Mdot
.29278 .54431 Mdot
.29283 .54449 Mdot
.29288 .54466 Mdot
.29293 .54483 Mdot
.29297 .54501 Mdot
.29302 .54518 Mdot
.29307 .54535 Mdot
.29312 .54552 Mdot
.29316 .5457 Mdot
.29321 .54587 Mdot
.29326 .54604 Mdot
.29331 .54621 Mdot
.29335 .54638 Mdot
.2934 .54655 Mdot
.29345 .54672 Mdot
.2935 .54689 Mdot
.29354 .54706 Mdot
.29359 .54723 Mdot
.29364 .5474 Mdot
.29369 .54757 Mdot
.29373 .54774 Mdot
.29378 .54791 Mdot
.29383 .54808 Mdot
.29388 .54825 Mdot
.29393 .54841 Mdot
.29397 .54858 Mdot
.29402 .54875 Mdot
.29407 .54892 Mdot
.29412 .54908 Mdot
.29416 .54925 Mdot
.29421 .54942 Mdot
.29426 .54958 Mdot
.29431 .54975 Mdot
.29435 .54992 Mdot
.2944 .55008 Mdot
.29445 .55025 Mdot
.2945 .55041 Mdot
.29454 .55058 Mdot
.29459 .55074 Mdot
.29464 .55091 Mdot
.29469 .55107 Mdot
.29473 .55124 Mdot
.29478 .5514 Mdot
.29483 .55156 Mdot
.29488 .55173 Mdot
.29493 .55189 Mdot
.29497 .55205 Mdot
.29502 .55222 Mdot
.29507 .55238 Mdot
.29512 .55254 Mdot
.29516 .5527 Mdot
.29521 .55286 Mdot
.29526 .55302 Mdot
.29531 .55319 Mdot
.29535 .55335 Mdot
.2954 .55351 Mdot
.29545 .55367 Mdot
.2955 .55383 Mdot
.29554 .55399 Mdot
.29559 .55415 Mdot
.29564 .55431 Mdot
.29569 .55447 Mdot
.29573 .55463 Mdot
.29578 .55478 Mdot
.29583 .55494 Mdot
.29588 .5551 Mdot
.29593 .55526 Mdot
.29597 .55542 Mdot
.29602 .55557 Mdot
.29607 .55573 Mdot
.29612 .55589 Mdot
.29616 .55604 Mdot
.29621 .5562 Mdot
.29626 .55636 Mdot
.29631 .55651 Mdot
.29635 .55667 Mdot
.2964 .55682 Mdot
.29645 .55698 Mdot
.2965 .55713 Mdot
.29654 .55729 Mdot
.29659 .55744 Mdot
.29664 .5576 Mdot
.29669 .55775 Mdot
.29673 .55791 Mdot
.29678 .55806 Mdot
.29683 .55821 Mdot
.29688 .55837 Mdot
.29693 .55852 Mdot
.29697 .55867 Mdot
.29702 .55882 Mdot
.29707 .55897 Mdot
.29712 .55913 Mdot
.29716 .55928 Mdot
.29721 .55943 Mdot
.29726 .55958 Mdot
.29731 .55973 Mdot
.29735 .55988 Mdot
.2974 .56003 Mdot
.29745 .56018 Mdot
.2975 .56033 Mdot
.29754 .56048 Mdot
.29759 .56063 Mdot
.29764 .56078 Mdot
.29769 .56093 Mdot
.29773 .56108 Mdot
.29778 .56122 Mdot
.29783 .56137 Mdot
.29788 .56152 Mdot
.29792 .56167 Mdot
.29797 .56182 Mdot
.29802 .56196 Mdot
.29807 .56211 Mdot
.29812 .56226 Mdot
.29816 .5624 Mdot
.29821 .56255 Mdot
.29826 .56269 Mdot
.29831 .56284 Mdot
.29835 .56298 Mdot
.2984 .56313 Mdot
.29845 .56327 Mdot
.2985 .56342 Mdot
.29854 .56356 Mdot
.29859 .56371 Mdot
.29864 .56385 Mdot
.29869 .56399 Mdot
.29873 .56414 Mdot
.29878 .56428 Mdot
.29883 .56442 Mdot
.29888 .56456 Mdot
.29892 .56471 Mdot
.29897 .56485 Mdot
.29902 .56499 Mdot
.29907 .56513 Mdot
.29912 .56527 Mdot
.29916 .56541 Mdot
.29921 .56555 Mdot
.29926 .56569 Mdot
.29931 .56583 Mdot
.29935 .56597 Mdot
.2994 .56611 Mdot
.29945 .56625 Mdot
.2995 .56639 Mdot
.29954 .56653 Mdot
.29959 .56667 Mdot
.29964 .56681 Mdot
.29969 .56695 Mdot
.29973 .56708 Mdot
.29978 .56722 Mdot
.29983 .56736 Mdot
.29988 .56749 Mdot
.29992 .56763 Mdot
.29997 .56777 Mdot
.30002 .5679 Mdot
.30007 .56804 Mdot
.30012 .56818 Mdot
.30016 .56831 Mdot
.30021 .56845 Mdot
.30026 .56858 Mdot
.30031 .56872 Mdot
.30035 .56885 Mdot
.3004 .56898 Mdot
.30045 .56912 Mdot
.3005 .56925 Mdot
.30054 .56939 Mdot
.30059 .56952 Mdot
.30064 .56965 Mdot
.30069 .56978 Mdot
.30073 .56992 Mdot
.30078 .57005 Mdot
.30083 .57018 Mdot
.30088 .57031 Mdot
.30092 .57044 Mdot
.30097 .57057 Mdot
.30102 .5707 Mdot
.30107 .57083 Mdot
.30112 .57097 Mdot
.30116 .5711 Mdot
.30121 .57122 Mdot
.30126 .57135 Mdot
.30131 .57148 Mdot
.30135 .57161 Mdot
.3014 .57174 Mdot
.30145 .57187 Mdot
.3015 .572 Mdot
.30154 .57213 Mdot
.30159 .57225 Mdot
.30164 .57238 Mdot
.30169 .57251 Mdot
.30173 .57263 Mdot
.30178 .57276 Mdot
.30183 .57289 Mdot
.30188 .57301 Mdot
.30192 .57314 Mdot
.30197 .57326 Mdot
.30202 .57339 Mdot
.30207 .57351 Mdot
.30212 .57364 Mdot
.30216 .57376 Mdot
.30221 .57389 Mdot
.30226 .57401 Mdot
.30231 .57414 Mdot
.30235 .57426 Mdot
.3024 .57438 Mdot
.30245 .5745 Mdot
.3025 .57463 Mdot
.30254 .57475 Mdot
.30259 .57487 Mdot
.30264 .57499 Mdot
.30269 .57511 Mdot
.30273 .57524 Mdot
.30278 .57536 Mdot
.30283 .57548 Mdot
.30288 .5756 Mdot
.30292 .57572 Mdot
.30297 .57584 Mdot
.30302 .57596 Mdot
.30307 .57608 Mdot
.30311 .5762 Mdot
.30316 .57632 Mdot
.30321 .57643 Mdot
.30326 .57655 Mdot
.30331 .57667 Mdot
.30335 .57679 Mdot
.3034 .57691 Mdot
.30345 .57702 Mdot
.3035 .57714 Mdot
.30354 .57726 Mdot
.30359 .57737 Mdot
.30364 .57749 Mdot
.30369 .5776 Mdot
.30373 .57772 Mdot
.30378 .57784 Mdot
.30383 .57795 Mdot
.30388 .57807 Mdot
.30392 .57818 Mdot
.30397 .57829 Mdot
.30402 .57841 Mdot
.30407 .57852 Mdot
.30411 .57864 Mdot
.30416 .57875 Mdot
.30421 .57886 Mdot
.30426 .57897 Mdot
.30431 .57909 Mdot
.30435 .5792 Mdot
.3044 .57931 Mdot
.30445 .57942 Mdot
.3045 .57953 Mdot
.30454 .57964 Mdot
.30459 .57976 Mdot
.30464 .57987 Mdot
.30469 .57998 Mdot
.30473 .58009 Mdot
.30478 .5802 Mdot
.30483 .58031 Mdot
.30488 .58041 Mdot
.30492 .58052 Mdot
.30497 .58063 Mdot
.30502 .58074 Mdot
.30507 .58085 Mdot
.30511 .58096 Mdot
.30516 .58106 Mdot
.30521 .58117 Mdot
.30526 .58128 Mdot
.30531 .58138 Mdot
.30535 .58149 Mdot
.3054 .5816 Mdot
.30545 .5817 Mdot
.3055 .58181 Mdot
.30554 .58191 Mdot
.30559 .58202 Mdot
.30564 .58212 Mdot
.30569 .58223 Mdot
.30573 .58233 Mdot
.30578 .58244 Mdot
.30583 .58254 Mdot
.30588 .58264 Mdot
.30592 .58275 Mdot
.30597 .58285 Mdot
.30602 .58295 Mdot
.30607 .58305 Mdot
.30611 .58316 Mdot
.30616 .58326 Mdot
.30621 .58336 Mdot
.30626 .58346 Mdot
.30631 .58356 Mdot
.30635 .58366 Mdot
.3064 .58376 Mdot
.30645 .58386 Mdot
.3065 .58396 Mdot
.30654 .58406 Mdot
.30659 .58416 Mdot
.30664 .58426 Mdot
.30669 .58436 Mdot
.30673 .58446 Mdot
.30678 .58456 Mdot
.30683 .58465 Mdot
.30688 .58475 Mdot
.30692 .58485 Mdot
.30697 .58495 Mdot
.30702 .58504 Mdot
.30707 .58514 Mdot
.30711 .58524 Mdot
.30716 .58533 Mdot
.30721 .58543 Mdot
.30726 .58552 Mdot
.3073 .58562 Mdot
.30735 .58571 Mdot
.3074 .58581 Mdot
.30745 .5859 Mdot
.3075 .586 Mdot
.30754 .58609 Mdot
.30759 .58618 Mdot
.30764 .58628 Mdot
.30769 .58637 Mdot
.30773 .58646 Mdot
.30778 .58655 Mdot
.30783 .58665 Mdot
.30788 .58674 Mdot
.30792 .58683 Mdot
.30797 .58692 Mdot
.30802 .58701 Mdot
.30807 .5871 Mdot
.30811 .58719 Mdot
.30816 .58728 Mdot
.30821 .58737 Mdot
.30826 .58746 Mdot
.3083 .58755 Mdot
.30835 .58764 Mdot
.3084 .58773 Mdot
.30845 .58782 Mdot
.3085 .58791 Mdot
.30854 .58799 Mdot
.30859 .58808 Mdot
.30864 .58817 Mdot
.30869 .58826 Mdot
.30873 .58834 Mdot
.30878 .58843 Mdot
.30883 .58852 Mdot
.30888 .5886 Mdot
.30892 .58869 Mdot
.30897 .58877 Mdot
.30902 .58886 Mdot
.30907 .58894 Mdot
.30911 .58903 Mdot
.30916 .58911 Mdot
.30921 .5892 Mdot
.30926 .58928 Mdot
.3093 .58936 Mdot
.30935 .58945 Mdot
.3094 .58953 Mdot
.30945 .58961 Mdot
.3095 .58969 Mdot
.30954 .58978 Mdot
.30959 .58986 Mdot
.30964 .58994 Mdot
.30969 .59002 Mdot
.30973 .5901 Mdot
.30978 .59018 Mdot
.30983 .59026 Mdot
.30988 .59034 Mdot
.30992 .59042 Mdot
.30997 .5905 Mdot
.31002 .59058 Mdot
.31007 .59066 Mdot
.31011 .59074 Mdot
.31016 .59082 Mdot
.31021 .5909 Mdot
.31026 .59097 Mdot
.3103 .59105 Mdot
.31035 .59113 Mdot
.3104 .59121 Mdot
.31045 .59128 Mdot
.3105 .59136 Mdot
.31054 .59143 Mdot
.31059 .59151 Mdot
.31064 .59159 Mdot
.31069 .59166 Mdot
.31073 .59174 Mdot
.31078 .59181 Mdot
.31083 .59189 Mdot
.31088 .59196 Mdot
.31092 .59203 Mdot
.31097 .59211 Mdot
.31102 .59218 Mdot
.31107 .59225 Mdot
.31111 .59233 Mdot
.31116 .5924 Mdot
.31121 .59247 Mdot
.31126 .59254 Mdot
.3113 .59261 Mdot
.31135 .59269 Mdot
.3114 .59276 Mdot
.31145 .59283 Mdot
.3115 .5929 Mdot
.31154 .59297 Mdot
.31159 .59304 Mdot
.31164 .59311 Mdot
.31169 .59318 Mdot
.31173 .59325 Mdot
.31178 .59331 Mdot
.31183 .59338 Mdot
.31188 .59345 Mdot
.31192 .59352 Mdot
.31197 .59359 Mdot
.31202 .59365 Mdot
.31207 .59372 Mdot
.31211 .59379 Mdot
.31216 .59385 Mdot
.31221 .59392 Mdot
.31226 .59399 Mdot
.3123 .59405 Mdot
.31235 .59412 Mdot
.3124 .59418 Mdot
.31245 .59425 Mdot
.31249 .59431 Mdot
.31254 .59438 Mdot
.31259 .59444 Mdot
.31264 .5945 Mdot
.31269 .59457 Mdot
.31273 .59463 Mdot
.31278 .59469 Mdot
.31283 .59476 Mdot
.31288 .59482 Mdot
.31292 .59488 Mdot
.31297 .59494 Mdot
.31302 .595 Mdot
.31307 .59506 Mdot
.31311 .59512 Mdot
.31316 .59518 Mdot
.31321 .59524 Mdot
.31326 .5953 Mdot
.3133 .59536 Mdot
.31335 .59542 Mdot
.3134 .59548 Mdot
.31345 .59554 Mdot
.31349 .5956 Mdot
.31354 .59566 Mdot
.31359 .59572 Mdot
.31364 .59577 Mdot
.31369 .59583 Mdot
.31373 .59589 Mdot
.31378 .59595 Mdot
.31383 .596 Mdot
.31388 .59606 Mdot
.31392 .59611 Mdot
.31397 .59617 Mdot
.31402 .59622 Mdot
.31407 .59628 Mdot
.31411 .59633 Mdot
.31416 .59639 Mdot
.31421 .59644 Mdot
.31426 .5965 Mdot
.3143 .59655 Mdot
.31435 .5966 Mdot
.3144 .59666 Mdot
.31445 .59671 Mdot
.31449 .59676 Mdot
.31454 .59681 Mdot
.31459 .59687 Mdot
.31464 .59692 Mdot
.31469 .59697 Mdot
.31473 .59702 Mdot
.31478 .59707 Mdot
.31483 .59712 Mdot
.31488 .59717 Mdot
.31492 .59722 Mdot
.31497 .59727 Mdot
.31502 .59732 Mdot
.31507 .59737 Mdot
.31511 .59742 Mdot
.31516 .59747 Mdot
.31521 .59751 Mdot
.31526 .59756 Mdot
.3153 .59761 Mdot
.31535 .59766 Mdot
.3154 .5977 Mdot
.31545 .59775 Mdot
.31549 .5978 Mdot
.31554 .59784 Mdot
.31559 .59789 Mdot
.31564 .59793 Mdot
.31569 .59798 Mdot
.31573 .59802 Mdot
.31578 .59807 Mdot
.31583 .59811 Mdot
.31588 .59816 Mdot
.31592 .5982 Mdot
.31597 .59824 Mdot
.31602 .59829 Mdot
.31607 .59833 Mdot
.31611 .59837 Mdot
.31616 .59842 Mdot
.31621 .59846 Mdot
.31626 .5985 Mdot
.3163 .59854 Mdot
.31635 .59858 Mdot
.3164 .59862 Mdot
.31645 .59866 Mdot
.31649 .5987 Mdot
.31654 .59874 Mdot
.31659 .59878 Mdot
.31664 .59882 Mdot
.31668 .59886 Mdot
.31673 .5989 Mdot
.31678 .59894 Mdot
.31683 .59898 Mdot
.31688 .59902 Mdot
.31692 .59905 Mdot
.31697 .59909 Mdot
.31702 .59913 Mdot
.31707 .59917 Mdot
.31711 .5992 Mdot
.31716 .59924 Mdot
.31721 .59927 Mdot
.31726 .59931 Mdot
.3173 .59935 Mdot
.31735 .59938 Mdot
.3174 .59942 Mdot
.31745 .59945 Mdot
.31749 .59948 Mdot
.31754 .59952 Mdot
.31759 .59955 Mdot
.31764 .59958 Mdot
.31768 .59962 Mdot
.31773 .59965 Mdot
.31778 .59968 Mdot
.31783 .59972 Mdot
.31788 .59975 Mdot
.31792 .59978 Mdot
.31797 .59981 Mdot
.31802 .59984 Mdot
.31807 .59987 Mdot
.31811 .5999 Mdot
.31816 .59993 Mdot
.31821 .59996 Mdot
.31826 .59999 Mdot
.3183 .60002 Mdot
.31835 .60005 Mdot
.3184 .60008 Mdot
.31845 .60011 Mdot
.31849 .60014 Mdot
.31854 .60016 Mdot
.31859 .60019 Mdot
.31864 .60022 Mdot
.31868 .60024 Mdot
.31873 .60027 Mdot
.31878 .6003 Mdot
.31883 .60032 Mdot
.31888 .60035 Mdot
.31892 .60038 Mdot
.31897 .6004 Mdot
.31902 .60043 Mdot
.31907 .60045 Mdot
.31911 .60047 Mdot
.31916 .6005 Mdot
.31921 .60052 Mdot
.31926 .60055 Mdot
.3193 .60057 Mdot
.31935 .60059 Mdot
.3194 .60061 Mdot
.31945 .60064 Mdot
.31949 .60066 Mdot
.31954 .60068 Mdot
.31959 .6007 Mdot
.31964 .60072 Mdot
.31968 .60074 Mdot
.31973 .60076 Mdot
.31978 .60078 Mdot
.31983 .6008 Mdot
.31988 .60082 Mdot
.31992 .60084 Mdot
.31997 .60086 Mdot
.32002 .60088 Mdot
.32007 .6009 Mdot
.32011 .60092 Mdot
.32016 .60094 Mdot
.32021 .60095 Mdot
.32026 .60097 Mdot
.3203 .60099 Mdot
.32035 .601 Mdot
.3204 .60102 Mdot
.32045 .60104 Mdot
.32049 .60105 Mdot
.32054 .60107 Mdot
.32059 .60108 Mdot
.32064 .6011 Mdot
.32068 .60111 Mdot
.32073 .60113 Mdot
.32078 .60114 Mdot
.32083 .60116 Mdot
.32088 .60117 Mdot
.32092 .60118 Mdot
.32097 .60119 Mdot
.32102 .60121 Mdot
.32107 .60122 Mdot
.32111 .60123 Mdot
.32116 .60124 Mdot
.32121 .60126 Mdot
.32126 .60127 Mdot
.3213 .60128 Mdot
.32135 .60129 Mdot
.3214 .6013 Mdot
.32145 .60131 Mdot
.32149 .60132 Mdot
.32154 .60133 Mdot
.32159 .60134 Mdot
.32164 .60135 Mdot
.32168 .60135 Mdot
.32173 .60136 Mdot
.32178 .60137 Mdot
.32183 .60138 Mdot
.32187 .60138 Mdot
.32192 .60139 Mdot
.32197 .6014 Mdot
.32202 .60141 Mdot
.32207 .60141 Mdot
.32211 .60142 Mdot
.32216 .60142 Mdot
.32221 .60143 Mdot
.32226 .60143 Mdot
.3223 .60144 Mdot
.32235 .60144 Mdot
.3224 .60145 Mdot
.32245 .60145 Mdot
.32249 .60145 Mdot
.32254 .60146 Mdot
.32259 .60146 Mdot
.32264 .60146 Mdot
.32268 .60147 Mdot
.32273 .60147 Mdot
.32278 .60147 Mdot
.32283 .60147 Mdot
.32287 .60147 Mdot
.32292 .60147 Mdot
.32297 .60147 Mdot
.32302 .60147 Mdot
.32307 .60147 Mdot
.32311 .60147 Mdot
.32316 .60147 Mdot
.32321 .60147 Mdot
.32326 .60147 Mdot
.3233 .60147 Mdot
.32335 .60147 Mdot
.3234 .60147 Mdot
.32345 .60146 Mdot
.32349 .60146 Mdot
.32354 .60146 Mdot
.32359 .60146 Mdot
.32364 .60145 Mdot
.32368 .60145 Mdot
.32373 .60144 Mdot
.32378 .60144 Mdot
.32383 .60144 Mdot
.32387 .60143 Mdot
.32392 .60143 Mdot
.32397 .60142 Mdot
.32402 .60141 Mdot
.32407 .60141 Mdot
.32411 .6014 Mdot
.32416 .60139 Mdot
.32421 .60139 Mdot
.32426 .60138 Mdot
.3243 .60137 Mdot
.32435 .60136 Mdot
.3244 .60136 Mdot
.32445 .60135 Mdot
.32449 .60134 Mdot
.32454 .60133 Mdot
.32459 .60132 Mdot
.32464 .60131 Mdot
.32468 .6013 Mdot
.32473 .60129 Mdot
.32478 .60128 Mdot
.32483 .60127 Mdot
.32487 .60126 Mdot
.32492 .60125 Mdot
.32497 .60124 Mdot
.32502 .60122 Mdot
.32507 .60121 Mdot
.32511 .6012 Mdot
.32516 .60119 Mdot
.32521 .60117 Mdot
.32526 .60116 Mdot
.3253 .60115 Mdot
.32535 .60113 Mdot
.3254 .60112 Mdot
.32545 .6011 Mdot
.32549 .60109 Mdot
.32554 .60107 Mdot
.32559 .60106 Mdot
.32564 .60104 Mdot
.32568 .60103 Mdot
.32573 .60101 Mdot
.32578 .60099 Mdot
.32583 .60098 Mdot
.32587 .60096 Mdot
.32592 .60094 Mdot
.32597 .60092 Mdot
.32602 .60091 Mdot
.32607 .60089 Mdot
.32611 .60087 Mdot
.32616 .60085 Mdot
.32621 .60083 Mdot
.32626 .60081 Mdot
.3263 .60079 Mdot
.32635 .60077 Mdot
.3264 .60075 Mdot
.32645 .60073 Mdot
.32649 .60071 Mdot
.32654 .60069 Mdot
.32659 .60067 Mdot
.32664 .60064 Mdot
.32668 .60062 Mdot
.32673 .6006 Mdot
.32678 .60058 Mdot
.32683 .60055 Mdot
.32687 .60053 Mdot
.32692 .60051 Mdot
.32697 .60048 Mdot
.32702 .60046 Mdot
.32706 .60043 Mdot
.32711 .60041 Mdot
.32716 .60038 Mdot
.32721 .60036 Mdot
.32726 .60033 Mdot
.3273 .60031 Mdot
.32735 .60028 Mdot
.3274 .60025 Mdot
.32745 .60023 Mdot
.32749 .6002 Mdot
.32754 .60017 Mdot
.32759 .60015 Mdot
.32764 .60012 Mdot
.32768 .60009 Mdot
.32773 .60006 Mdot
.32778 .60003 Mdot
.32783 .6 Mdot
.32787 .59997 Mdot
.32792 .59994 Mdot
.32797 .59991 Mdot
.32802 .59988 Mdot
.32806 .59985 Mdot
.32811 .59982 Mdot
.32816 .59979 Mdot
.32821 .59976 Mdot
.32826 .59973 Mdot
.3283 .59969 Mdot
.32835 .59966 Mdot
.3284 .59963 Mdot
.32845 .5996 Mdot
.32849 .59956 Mdot
.32854 .59953 Mdot
.32859 .5995 Mdot
.32864 .59946 Mdot
.32868 .59943 Mdot
.32873 .59939 Mdot
.32878 .59936 Mdot
.32883 .59932 Mdot
.32887 .59929 Mdot
.32892 .59925 Mdot
.32897 .59922 Mdot
.32902 .59918 Mdot
.32906 .59914 Mdot
.32911 .59911 Mdot
.32916 .59907 Mdot
.32921 .59903 Mdot
.32926 .59899 Mdot
.3293 .59895 Mdot
.32935 .59892 Mdot
.3294 .59888 Mdot
.32945 .59884 Mdot
.32949 .5988 Mdot
.32954 .59876 Mdot
.32959 .59872 Mdot
.32964 .59868 Mdot
.32968 .59864 Mdot
.32973 .5986 Mdot
.32978 .59856 Mdot
.32983 .59852 Mdot
.32987 .59847 Mdot
.32992 .59843 Mdot
.32997 .59839 Mdot
.33002 .59835 Mdot
.33006 .5983 Mdot
.33011 .59826 Mdot
.33016 .59822 Mdot
.33021 .59817 Mdot
.33026 .59813 Mdot
.3303 .59809 Mdot
.33035 .59804 Mdot
.3304 .598 Mdot
.33045 .59795 Mdot
.33049 .59791 Mdot
.33054 .59786 Mdot
.33059 .59781 Mdot
.33064 .59777 Mdot
.33068 .59772 Mdot
.33073 .59767 Mdot
.33078 .59763 Mdot
.33083 .59758 Mdot
.33087 .59753 Mdot
.33092 .59748 Mdot
.33097 .59744 Mdot
.33102 .59739 Mdot
.33106 .59734 Mdot
.33111 .59729 Mdot
.33116 .59724 Mdot
.33121 .59719 Mdot
.33125 .59714 Mdot
.3313 .59709 Mdot
.33135 .59704 Mdot
.3314 .59699 Mdot
.33145 .59694 Mdot
.33149 .59688 Mdot
.33154 .59683 Mdot
.33159 .59678 Mdot
.33164 .59673 Mdot
.33168 .59668 Mdot
.33173 .59662 Mdot
.33178 .59657 Mdot
.33183 .59652 Mdot
.33187 .59646 Mdot
.33192 .59641 Mdot
.33197 .59635 Mdot
.33202 .5963 Mdot
.33206 .59624 Mdot
.33211 .59619 Mdot
.33216 .59613 Mdot
.33221 .59608 Mdot
.33225 .59602 Mdot
.3323 .59597 Mdot
.33235 .59591 Mdot
.3324 .59585 Mdot
.33245 .59579 Mdot
.33249 .59574 Mdot
.33254 .59568 Mdot
.33259 .59562 Mdot
.33264 .59556 Mdot
.33268 .5955 Mdot
.33273 .59545 Mdot
.33278 .59539 Mdot
.33283 .59533 Mdot
.33287 .59527 Mdot
.33292 .59521 Mdot
.33297 .59515 Mdot
.33302 .59509 Mdot
.33306 .59502 Mdot
.33311 .59496 Mdot
.33316 .5949 Mdot
.33321 .59484 Mdot
.33325 .59478 Mdot
.3333 .59472 Mdot
.33335 .59465 Mdot
.3334 .59459 Mdot
.33345 .59453 Mdot
.33349 .59446 Mdot
.33354 .5944 Mdot
.33359 .59433 Mdot
.33364 .59427 Mdot
.33368 .59421 Mdot
.33373 .59414 Mdot
.33378 .59408 Mdot
.33383 .59401 Mdot
.33387 .59394 Mdot
.33392 .59388 Mdot
.33397 .59381 Mdot
.33402 .59375 Mdot
.33406 .59368 Mdot
.33411 .59361 Mdot
.33416 .59354 Mdot
.33421 .59348 Mdot
.33425 .59341 Mdot
.3343 .59334 Mdot
.33435 .59327 Mdot
.3344 .5932 Mdot
.33445 .59313 Mdot
.33449 .59306 Mdot
.33454 .59299 Mdot
.33459 .59292 Mdot
.33464 .59285 Mdot
.33468 .59278 Mdot
.33473 .59271 Mdot
.33478 .59264 Mdot
.33483 .59257 Mdot
.33487 .5925 Mdot
.33492 .59242 Mdot
.33497 .59235 Mdot
.33502 .59228 Mdot
.33506 .59221 Mdot
.33511 .59213 Mdot
.33516 .59206 Mdot
.33521 .59199 Mdot
.33525 .59191 Mdot
.3353 .59184 Mdot
.33535 .59176 Mdot
.3354 .59169 Mdot
.33545 .59161 Mdot
.33549 .59154 Mdot
.33554 .59146 Mdot
.33559 .59139 Mdot
.33564 .59131 Mdot
.33568 .59123 Mdot
.33573 .59116 Mdot
.33578 .59108 Mdot
.33583 .591 Mdot
.33587 .59092 Mdot
.33592 .59084 Mdot
.33597 .59077 Mdot
.33602 .59069 Mdot
.33606 .59061 Mdot
.33611 .59053 Mdot
.33616 .59045 Mdot
.33621 .59037 Mdot
.33625 .59029 Mdot
.3363 .59021 Mdot
.33635 .59013 Mdot
.3364 .59005 Mdot
.33644 .58997 Mdot
.33649 .58989 Mdot
.33654 .5898 Mdot
.33659 .58972 Mdot
.33664 .58964 Mdot
.33668 .58956 Mdot
.33673 .58948 Mdot
.33678 .58939 Mdot
.33683 .58931 Mdot
.33687 .58923 Mdot
.33692 .58914 Mdot
.33697 .58906 Mdot
.33702 .58897 Mdot
.33706 .58889 Mdot
.33711 .5888 Mdot
.33716 .58872 Mdot
.33721 .58863 Mdot
.33725 .58855 Mdot
.3373 .58846 Mdot
.33735 .58837 Mdot
.3374 .58829 Mdot
.33744 .5882 Mdot
.33749 .58811 Mdot
.33754 .58802 Mdot
.33759 .58794 Mdot
.33764 .58785 Mdot
.33768 .58776 Mdot
.33773 .58767 Mdot
.33778 .58758 Mdot
.33783 .58749 Mdot
.33787 .5874 Mdot
.33792 .58731 Mdot
.33797 .58722 Mdot
.33802 .58713 Mdot
.33806 .58704 Mdot
.33811 .58695 Mdot
.33816 .58686 Mdot
.33821 .58677 Mdot
.33825 .58668 Mdot
.3383 .58659 Mdot
.33835 .58649 Mdot
.3384 .5864 Mdot
.33844 .58631 Mdot
.33849 .58621 Mdot
.33854 .58612 Mdot
.33859 .58603 Mdot
.33864 .58593 Mdot
.33868 .58584 Mdot
.33873 .58574 Mdot
.33878 .58565 Mdot
.33883 .58555 Mdot
.33887 .58546 Mdot
.33892 .58536 Mdot
.33897 .58527 Mdot
.33902 .58517 Mdot
.33906 .58508 Mdot
.33911 .58498 Mdot
.33916 .58488 Mdot
.33921 .58478 Mdot
.33925 .58469 Mdot
.3393 .58459 Mdot
.33935 .58449 Mdot
.3394 .58439 Mdot
.33944 .58429 Mdot
.33949 .58419 Mdot
.33954 .5841 Mdot
.33959 .584 Mdot
.33964 .5839 Mdot
.33968 .5838 Mdot
.33973 .5837 Mdot
.33978 .5836 Mdot
.33983 .58349 Mdot
.33987 .58339 Mdot
.33992 .58329 Mdot
.33997 .58319 Mdot
.34002 .58309 Mdot
.34006 .58299 Mdot
.34011 .58288 Mdot
.34016 .58278 Mdot
.34021 .58268 Mdot
.34025 .58257 Mdot
.3403 .58247 Mdot
.34035 .58237 Mdot
.3404 .58226 Mdot
.34044 .58216 Mdot
.34049 .58205 Mdot
.34054 .58195 Mdot
.34059 .58184 Mdot
.34063 .58174 Mdot
.34068 .58163 Mdot
.34073 .58153 Mdot
.34078 .58142 Mdot
.34083 .58131 Mdot
.34087 .58121 Mdot
.34092 .5811 Mdot
.34097 .58099 Mdot
.34102 .58088 Mdot
.34106 .58078 Mdot
.34111 .58067 Mdot
.34116 .58056 Mdot
.34121 .58045 Mdot
.34125 .58034 Mdot
.3413 .58023 Mdot
.34135 .58012 Mdot
.3414 .58001 Mdot
.34144 .5799 Mdot
.34149 .57979 Mdot
.34154 .57968 Mdot
.34159 .57957 Mdot
.34163 .57946 Mdot
.34168 .57935 Mdot
.34173 .57923 Mdot
.34178 .57912 Mdot
.34183 .57901 Mdot
.34187 .5789 Mdot
.34192 .57879 Mdot
.34197 .57867 Mdot
.34202 .57856 Mdot
.34206 .57844 Mdot
.34211 .57833 Mdot
.34216 .57822 Mdot
.34221 .5781 Mdot
.34225 .57799 Mdot
.3423 .57787 Mdot
.34235 .57776 Mdot
.3424 .57764 Mdot
.34244 .57753 Mdot
.34249 .57741 Mdot
.34254 .57729 Mdot
.34259 .57718 Mdot
.34263 .57706 Mdot
.34268 .57694 Mdot
.34273 .57683 Mdot
.34278 .57671 Mdot
.34283 .57659 Mdot
.34287 .57647 Mdot
.34292 .57635 Mdot
.34297 .57623 Mdot
.34302 .57611 Mdot
.34306 .576 Mdot
.34311 .57588 Mdot
.34316 .57576 Mdot
.34321 .57564 Mdot
.34325 .57552 Mdot
.3433 .57539 Mdot
.34335 .57527 Mdot
.3434 .57515 Mdot
.34344 .57503 Mdot
.34349 .57491 Mdot
.34354 .57479 Mdot
.34359 .57467 Mdot
.34363 .57454 Mdot
.34368 .57442 Mdot
.34373 .5743 Mdot
.34378 .57417 Mdot
.34383 .57405 Mdot
.34387 .57393 Mdot
.34392 .5738 Mdot
.34397 .57368 Mdot
.34402 .57355 Mdot
.34406 .57343 Mdot
.34411 .5733 Mdot
.34416 .57318 Mdot
.34421 .57305 Mdot
.34425 .57293 Mdot
.3443 .5728 Mdot
.34435 .57267 Mdot
.3444 .57255 Mdot
.34444 .57242 Mdot
.34449 .57229 Mdot
.34454 .57216 Mdot
.34459 .57204 Mdot
.34463 .57191 Mdot
.34468 .57178 Mdot
.34473 .57165 Mdot
.34478 .57152 Mdot
.34483 .57139 Mdot
.34487 .57126 Mdot
.34492 .57113 Mdot
.34497 .571 Mdot
.34502 .57087 Mdot
.34506 .57074 Mdot
.34511 .57061 Mdot
.34516 .57048 Mdot
.34521 .57035 Mdot
.34525 .57022 Mdot
.3453 .57009 Mdot
.34535 .56996 Mdot
.3454 .56982 Mdot
.34544 .56969 Mdot
.34549 .56956 Mdot
.34554 .56943 Mdot
.34559 .56929 Mdot
.34563 .56916 Mdot
.34568 .56902 Mdot
.34573 .56889 Mdot
.34578 .56876 Mdot
.34582 .56862 Mdot
.34587 .56849 Mdot
.34592 .56835 Mdot
.34597 .56822 Mdot
.34602 .56808 Mdot
.34606 .56794 Mdot
.34611 .56781 Mdot
.34616 .56767 Mdot
.34621 .56754 Mdot
.34625 .5674 Mdot
.3463 .56726 Mdot
.34635 .56712 Mdot
.3464 .56699 Mdot
.34644 .56685 Mdot
.34649 .56671 Mdot
.34654 .56657 Mdot
.34659 .56643 Mdot
.34663 .56629 Mdot
.34668 .56615 Mdot
.34673 .56601 Mdot
.34678 .56587 Mdot
.34682 .56573 Mdot
.34687 .56559 Mdot
.34692 .56545 Mdot
.34697 .56531 Mdot
.34702 .56517 Mdot
.34706 .56503 Mdot
.34711 .56489 Mdot
.34716 .56475 Mdot
.34721 .5646 Mdot
.34725 .56446 Mdot
.3473 .56432 Mdot
.34735 .56418 Mdot
.3474 .56403 Mdot
.34744 .56389 Mdot
.34749 .56375 Mdot
.34754 .5636 Mdot
.34759 .56346 Mdot
.34763 .56331 Mdot
.34768 .56317 Mdot
.34773 .56302 Mdot
.34778 .56288 Mdot
.34782 .56273 Mdot
.34787 .56259 Mdot
.34792 .56244 Mdot
.34797 .5623 Mdot
.34802 .56215 Mdot
.34806 .562 Mdot
.34811 .56186 Mdot
.34816 .56171 Mdot
.34821 .56156 Mdot
.34825 .56141 Mdot
.3483 .56127 Mdot
.34835 .56112 Mdot
.3484 .56097 Mdot
.34844 .56082 Mdot
.34849 .56067 Mdot
.34854 .56052 Mdot
.34859 .56037 Mdot
.34863 .56022 Mdot
.34868 .56007 Mdot
.34873 .55992 Mdot
.34878 .55977 Mdot
.34882 .55962 Mdot
.34887 .55947 Mdot
.34892 .55932 Mdot
.34897 .55917 Mdot
.34902 .55902 Mdot
.34906 .55886 Mdot
.34911 .55871 Mdot
.34916 .55856 Mdot
.34921 .55841 Mdot
.34925 .55825 Mdot
.3493 .5581 Mdot
.34935 .55795 Mdot
.3494 .55779 Mdot
.34944 .55764 Mdot
.34949 .55749 Mdot
.34954 .55733 Mdot
.34959 .55718 Mdot
.34963 .55702 Mdot
.34968 .55687 Mdot
.34973 .55671 Mdot
.34978 .55655 Mdot
.34982 .5564 Mdot
.34987 .55624 Mdot
.34992 .55609 Mdot
.34997 .55593 Mdot
.35001 .55577 Mdot
.35006 .55562 Mdot
.35011 .55546 Mdot
.35016 .5553 Mdot
.35021 .55514 Mdot
.35025 .55498 Mdot
.3503 .55483 Mdot
.35035 .55467 Mdot
.3504 .55451 Mdot
.35044 .55435 Mdot
.35049 .55419 Mdot
.35054 .55403 Mdot
.35059 .55387 Mdot
.35063 .55371 Mdot
.35068 .55355 Mdot
.35073 .55339 Mdot
.35078 .55323 Mdot
.35082 .55307 Mdot
.35087 .55291 Mdot
.35092 .55274 Mdot
.35097 .55258 Mdot
.35101 .55242 Mdot
.35106 .55226 Mdot
.35111 .55209 Mdot
.35116 .55193 Mdot
.35121 .55177 Mdot
.35125 .55161 Mdot
.3513 .55144 Mdot
.35135 .55128 Mdot
.3514 .55111 Mdot
.35144 .55095 Mdot
.35149 .55079 Mdot
.35154 .55062 Mdot
.35159 .55046 Mdot
.35163 .55029 Mdot
.35168 .55012 Mdot
.35173 .54996 Mdot
.35178 .54979 Mdot
.35182 .54963 Mdot
.35187 .54946 Mdot
.35192 .54929 Mdot
.35197 .54913 Mdot
.35201 .54896 Mdot
.35206 .54879 Mdot
.35211 .54862 Mdot
.35216 .54846 Mdot
.35221 .54829 Mdot
.35225 .54812 Mdot
.3523 .54795 Mdot
.35235 .54778 Mdot
.3524 .54761 Mdot
.35244 .54744 Mdot
.35249 .54727 Mdot
.35254 .5471 Mdot
.35259 .54693 Mdot
.35263 .54676 Mdot
.35268 .54659 Mdot
.35273 .54642 Mdot
.35278 .54625 Mdot
.35282 .54608 Mdot
.35287 .54591 Mdot
.35292 .54574 Mdot
.35297 .54557 Mdot
.35301 .54539 Mdot
.35306 .54522 Mdot
.35311 .54505 Mdot
.35316 .54487 Mdot
.35321 .5447 Mdot
.35325 .54453 Mdot
.3533 .54435 Mdot
.35335 .54418 Mdot
.3534 .54401 Mdot
.35344 .54383 Mdot
.35349 .54366 Mdot
.35354 .54348 Mdot
.35359 .54331 Mdot
.35363 .54313 Mdot
.35368 .54296 Mdot
.35373 .54278 Mdot
.35378 .54261 Mdot
.35382 .54243 Mdot
.35387 .54225 Mdot
.35392 .54208 Mdot
.35397 .5419 Mdot
.35401 .54172 Mdot
.35406 .54154 Mdot
.35411 .54137 Mdot
.35416 .54119 Mdot
.35421 .54101 Mdot
.35425 .54083 Mdot
.3543 .54065 Mdot
.35435 .54048 Mdot
.3544 .5403 Mdot
.35444 .54012 Mdot
.35449 .53994 Mdot
.35454 .53976 Mdot
.35459 .53958 Mdot
.35463 .5394 Mdot
.35468 .53922 Mdot
.35473 .53904 Mdot
.35478 .53886 Mdot
.35482 .53868 Mdot
.35487 .53849 Mdot
.35492 .53831 Mdot
.35497 .53813 Mdot
.35501 .53795 Mdot
.35506 .53777 Mdot
.35511 .53758 Mdot
.35516 .5374 Mdot
.3552 .53722 Mdot
.35525 .53703 Mdot
.3553 .53685 Mdot
.35535 .53667 Mdot
.3554 .53648 Mdot
.35544 .5363 Mdot
.35549 .53612 Mdot
.35554 .53593 Mdot
.35559 .53575 Mdot
.35563 .53556 Mdot
.35568 .53538 Mdot
.35573 .53519 Mdot
.35578 .53501 Mdot
.35582 .53482 Mdot
.35587 .53463 Mdot
.35592 .53445 Mdot
.35597 .53426 Mdot
.35601 .53407 Mdot
.35606 .53389 Mdot
.35611 .5337 Mdot
.35616 .53351 Mdot
.3562 .53332 Mdot
.35625 .53314 Mdot
.3563 .53295 Mdot
.35635 .53276 Mdot
.3564 .53257 Mdot
.35644 .53238 Mdot
.35649 .53219 Mdot
.35654 .532 Mdot
.35659 .53181 Mdot
.35663 .53163 Mdot
.35668 .53144 Mdot
.35673 .53124 Mdot
.35678 .53105 Mdot
.35682 .53086 Mdot
.35687 .53067 Mdot
.35692 .53048 Mdot
.35697 .53029 Mdot
.35701 .5301 Mdot
.35706 .52991 Mdot
.35711 .52972 Mdot
.35716 .52952 Mdot
.3572 .52933 Mdot
.35725 .52914 Mdot
.3573 .52895 Mdot
.35735 .52875 Mdot
.3574 .52856 Mdot
.35744 .52837 Mdot
.35749 .52817 Mdot
.35754 .52798 Mdot
.35759 .52778 Mdot
.35763 .52759 Mdot
.35768 .5274 Mdot
.35773 .5272 Mdot
.35778 .52701 Mdot
.35782 .52681 Mdot
.35787 .52662 Mdot
.35792 .52642 Mdot
.35797 .52622 Mdot
.35801 .52603 Mdot
.35806 .52583 Mdot
.35811 .52563 Mdot
.35816 .52544 Mdot
.3582 .52524 Mdot
.35825 .52504 Mdot
.3583 .52485 Mdot
.35835 .52465 Mdot
.3584 .52445 Mdot
.35844 .52425 Mdot
.35849 .52405 Mdot
.35854 .52386 Mdot
.35859 .52366 Mdot
.35863 .52346 Mdot
.35868 .52326 Mdot
.35873 .52306 Mdot
.35878 .52286 Mdot
.35882 .52266 Mdot
.35887 .52246 Mdot
.35892 .52226 Mdot
.35897 .52206 Mdot
.35901 .52186 Mdot
.35906 .52166 Mdot
.35911 .52146 Mdot
.35916 .52126 Mdot
.3592 .52106 Mdot
.35925 .52085 Mdot
.3593 .52065 Mdot
.35935 .52045 Mdot
.3594 .52025 Mdot
.35944 .52004 Mdot
.35949 .51984 Mdot
.35954 .51964 Mdot
.35959 .51944 Mdot
.35963 .51923 Mdot
.35968 .51903 Mdot
.35973 .51883 Mdot
.35978 .51862 Mdot
.35982 .51842 Mdot
.35987 .51821 Mdot
.35992 .51801 Mdot
.35997 .5178 Mdot
.36001 .5176 Mdot
.36006 .51739 Mdot
.36011 .51719 Mdot
.36016 .51698 Mdot
.3602 .51678 Mdot
.36025 .51657 Mdot
.3603 .51636 Mdot
.36035 .51616 Mdot
.36039 .51595 Mdot
.36044 .51574 Mdot
.36049 .51554 Mdot
.36054 .51533 Mdot
.36059 .51512 Mdot
.36063 .51491 Mdot
.36068 .51471 Mdot
.36073 .5145 Mdot
.36078 .51429 Mdot
.36082 .51408 Mdot
.36087 .51387 Mdot
.36092 .51366 Mdot
.36097 .51345 Mdot
.36101 .51324 Mdot
.36106 .51303 Mdot
.36111 .51282 Mdot
.36116 .51261 Mdot
.3612 .5124 Mdot
.36125 .51219 Mdot
.3613 .51198 Mdot
.36135 .51177 Mdot
.36139 .51156 Mdot
.36144 .51135 Mdot
.36149 .51114 Mdot
.36154 .51093 Mdot
.36159 .51072 Mdot
.36163 .5105 Mdot
.36168 .51029 Mdot
.36173 .51008 Mdot
.36178 .50987 Mdot
.36182 .50965 Mdot
.36187 .50944 Mdot
.36192 .50923 Mdot
.36197 .50901 Mdot
.36201 .5088 Mdot
.36206 .50859 Mdot
.36211 .50837 Mdot
.36216 .50816 Mdot
.3622 .50794 Mdot
.36225 .50773 Mdot
.3623 .50751 Mdot
.36235 .5073 Mdot
.36239 .50708 Mdot
.36244 .50687 Mdot
.36249 .50665 Mdot
.36254 .50644 Mdot
.36259 .50622 Mdot
.36263 .506 Mdot
.36268 .50579 Mdot
.36273 .50557 Mdot
.36278 .50535 Mdot
.36282 .50514 Mdot
.36287 .50492 Mdot
.36292 .5047 Mdot
.36297 .50449 Mdot
.36301 .50427 Mdot
.36306 .50405 Mdot
.36311 .50383 Mdot
.36316 .50361 Mdot
.3632 .50339 Mdot
.36325 .50318 Mdot
.3633 .50296 Mdot
.36335 .50274 Mdot
.36339 .50252 Mdot
.36344 .5023 Mdot
.36349 .50208 Mdot
.36354 .50186 Mdot
.36359 .50164 Mdot
.36363 .50142 Mdot
.36368 .5012 Mdot
.36373 .50098 Mdot
.36378 .50076 Mdot
.36382 .50053 Mdot
.36387 .50031 Mdot
.36392 .50009 Mdot
.36397 .49987 Mdot
.36401 .49965 Mdot
.36406 .49943 Mdot
.36411 .4992 Mdot
.36416 .49898 Mdot
.3642 .49876 Mdot
.36425 .49854 Mdot
.3643 .49831 Mdot
.36435 .49809 Mdot
.36439 .49787 Mdot
.36444 .49764 Mdot
.36449 .49742 Mdot
.36454 .4972 Mdot
.36458 .49697 Mdot
.36463 .49675 Mdot
.36468 .49652 Mdot
.36473 .4963 Mdot
.36478 .49607 Mdot
.36482 .49585 Mdot
.36487 .49562 Mdot
.36492 .4954 Mdot
.36497 .49517 Mdot
.36501 .49495 Mdot
.36506 .49472 Mdot
.36511 .49449 Mdot
.36516 .49427 Mdot
.3652 .49404 Mdot
.36525 .49381 Mdot
.3653 .49359 Mdot
.36535 .49336 Mdot
.36539 .49313 Mdot
.36544 .4929 Mdot
.36549 .49268 Mdot
.36554 .49245 Mdot
.36558 .49222 Mdot
.36563 .49199 Mdot
.36568 .49176 Mdot
.36573 .49154 Mdot
.36578 .49131 Mdot
.36582 .49108 Mdot
.36587 .49085 Mdot
.36592 .49062 Mdot
.36597 .49039 Mdot
.36601 .49016 Mdot
.36606 .48993 Mdot
.36611 .4897 Mdot
.36616 .48947 Mdot
.3662 .48924 Mdot
.36625 .48901 Mdot
.3663 .48878 Mdot
.36635 .48855 Mdot
.36639 .48832 Mdot
.36644 .48808 Mdot
.36649 .48785 Mdot
.36654 .48762 Mdot
.36658 .48739 Mdot
.36663 .48716 Mdot
.36668 .48693 Mdot
.36673 .48669 Mdot
.36678 .48646 Mdot
.36682 .48623 Mdot
.36687 .48599 Mdot
.36692 .48576 Mdot
.36697 .48553 Mdot
.36701 .48529 Mdot
.36706 .48506 Mdot
.36711 .48483 Mdot
.36716 .48459 Mdot
.3672 .48436 Mdot
.36725 .48412 Mdot
.3673 .48389 Mdot
.36735 .48366 Mdot
.36739 .48342 Mdot
.36744 .48319 Mdot
.36749 .48295 Mdot
.36754 .48271 Mdot
.36758 .48248 Mdot
.36763 .48224 Mdot
.36768 .48201 Mdot
.36773 .48177 Mdot
.36778 .48154 Mdot
.36782 .4813 Mdot
.36787 .48106 Mdot
.36792 .48083 Mdot
.36797 .48059 Mdot
.36801 .48035 Mdot
.36806 .48011 Mdot
.36811 .47988 Mdot
.36816 .47964 Mdot
.3682 .4794 Mdot
.36825 .47916 Mdot
.3683 .47893 Mdot
.36835 .47869 Mdot
.36839 .47845 Mdot
.36844 .47821 Mdot
.36849 .47797 Mdot
.36854 .47773 Mdot
.36858 .47749 Mdot
.36863 .47725 Mdot
.36868 .47701 Mdot
.36873 .47677 Mdot
.36878 .47653 Mdot
.36882 .47629 Mdot
.36887 .47605 Mdot
.36892 .47581 Mdot
.36897 .47557 Mdot
.36901 .47533 Mdot
.36906 .47509 Mdot
.36911 .47485 Mdot
.36916 .47461 Mdot
.3692 .47437 Mdot
.36925 .47413 Mdot
.3693 .47388 Mdot
.36935 .47364 Mdot
.36939 .4734 Mdot
.36944 .47316 Mdot
.36949 .47292 Mdot
.36954 .47267 Mdot
.36958 .47243 Mdot
.36963 .47219 Mdot
.36968 .47195 Mdot
.36973 .4717 Mdot
.36977 .47146 Mdot
.36982 .47122 Mdot
.36987 .47097 Mdot
.36992 .47073 Mdot
.36997 .47048 Mdot
.37001 .47024 Mdot
.37006 .47 Mdot
.37011 .46975 Mdot
.37016 .46951 Mdot
.3702 .46926 Mdot
.37025 .46902 Mdot
.3703 .46877 Mdot
.37035 .46853 Mdot
.37039 .46828 Mdot
.37044 .46804 Mdot
.37049 .46779 Mdot
.37054 .46754 Mdot
.37058 .4673 Mdot
.37063 .46705 Mdot
.37068 .4668 Mdot
.37073 .46656 Mdot
.37077 .46631 Mdot
.37082 .46606 Mdot
.37087 .46582 Mdot
.37092 .46557 Mdot
.37097 .46532 Mdot
.37101 .46508 Mdot
.37106 .46483 Mdot
.37111 .46458 Mdot
.37116 .46433 Mdot
.3712 .46408 Mdot
.37125 .46384 Mdot
.3713 .46359 Mdot
.37135 .46334 Mdot
.37139 .46309 Mdot
.37144 .46284 Mdot
.37149 .46259 Mdot
.37154 .46234 Mdot
.37158 .46209 Mdot
.37163 .46184 Mdot
.37168 .46159 Mdot
.37173 .46134 Mdot
.37177 .46109 Mdot
.37182 .46084 Mdot
.37187 .46059 Mdot
.37192 .46034 Mdot
.37197 .46009 Mdot
.37201 .45984 Mdot
.37206 .45959 Mdot
.37211 .45934 Mdot
.37216 .45909 Mdot
.3722 .45884 Mdot
.37225 .45859 Mdot
.3723 .45834 Mdot
.37235 .45808 Mdot
.37239 .45783 Mdot
.37244 .45758 Mdot
.37249 .45733 Mdot
.37254 .45708 Mdot
.37258 .45682 Mdot
.37263 .45657 Mdot
.37268 .45632 Mdot
.37273 .45606 Mdot
.37277 .45581 Mdot
.37282 .45556 Mdot
.37287 .4553 Mdot
.37292 .45505 Mdot
.37297 .4548 Mdot
.37301 .45454 Mdot
.37306 .45429 Mdot
.37311 .45404 Mdot
.37316 .45378 Mdot
.3732 .45353 Mdot
.37325 .45327 Mdot
.3733 .45302 Mdot
.37335 .45276 Mdot
.37339 .45251 Mdot
.37344 .45225 Mdot
.37349 .452 Mdot
.37354 .45174 Mdot
.37358 .45149 Mdot
.37363 .45123 Mdot
.37368 .45097 Mdot
.37373 .45072 Mdot
.37377 .45046 Mdot
.37382 .45021 Mdot
.37387 .44995 Mdot
.37392 .44969 Mdot
.37396 .44944 Mdot
.37401 .44918 Mdot
.37406 .44892 Mdot
.37411 .44866 Mdot
.37416 .44841 Mdot
.3742 .44815 Mdot
.37425 .44789 Mdot
.3743 .44764 Mdot
.37435 .44738 Mdot
.37439 .44712 Mdot
.37444 .44686 Mdot
.37449 .4466 Mdot
.37454 .44634 Mdot
.37458 .44609 Mdot
.37463 .44583 Mdot
.37468 .44557 Mdot
.37473 .44531 Mdot
.37477 .44505 Mdot
.37482 .44479 Mdot
.37487 .44453 Mdot
.37492 .44427 Mdot
.37496 .44401 Mdot
.37501 .44375 Mdot
.37506 .44349 Mdot
.37511 .44323 Mdot
.37516 .44297 Mdot
.3752 .44271 Mdot
.37525 .44245 Mdot
.3753 .44219 Mdot
.37535 .44193 Mdot
.37539 .44167 Mdot
.37544 .44141 Mdot
.37549 .44115 Mdot
.37554 .44089 Mdot
.37558 .44063 Mdot
.37563 .44036 Mdot
.37568 .4401 Mdot
.37573 .43984 Mdot
.37577 .43958 Mdot
.37582 .43932 Mdot
.37587 .43905 Mdot
.37592 .43879 Mdot
.37596 .43853 Mdot
.37601 .43827 Mdot
.37606 .438 Mdot
.37611 .43774 Mdot
.37616 .43748 Mdot
.3762 .43722 Mdot
.37625 .43695 Mdot
.3763 .43669 Mdot
.37635 .43643 Mdot
.37639 .43616 Mdot
.37644 .4359 Mdot
.37649 .43563 Mdot
.37654 .43537 Mdot
.37658 .43511 Mdot
.37663 .43484 Mdot
.37668 .43458 Mdot
.37673 .43431 Mdot
.37677 .43405 Mdot
.37682 .43378 Mdot
.37687 .43352 Mdot
.37692 .43325 Mdot
.37696 .43299 Mdot
.37701 .43272 Mdot
.37706 .43246 Mdot
.37711 .43219 Mdot
.37716 .43193 Mdot
.3772 .43166 Mdot
.37725 .4314 Mdot
.3773 .43113 Mdot
.37735 .43086 Mdot
.37739 .4306 Mdot
.37744 .43033 Mdot
.37749 .43007 Mdot
.37754 .4298 Mdot
.37758 .42953 Mdot
.37763 .42927 Mdot
.37768 .429 Mdot
.37773 .42873 Mdot
.37777 .42846 Mdot
.37782 .4282 Mdot
.37787 .42793 Mdot
.37792 .42766 Mdot
.37796 .42739 Mdot
.37801 .42713 Mdot
.37806 .42686 Mdot
.37811 .42659 Mdot
.37816 .42632 Mdot
.3782 .42605 Mdot
.37825 .42579 Mdot
.3783 .42552 Mdot
.37835 .42525 Mdot
.37839 .42498 Mdot
.37844 .42471 Mdot
.37849 .42444 Mdot
.37854 .42417 Mdot
.37858 .4239 Mdot
.37863 .42363 Mdot
.37868 .42337 Mdot
.37873 .4231 Mdot
.37877 .42283 Mdot
.37882 .42256 Mdot
.37887 .42229 Mdot
.37892 .42202 Mdot
.37896 .42175 Mdot
.37901 .42148 Mdot
.37906 .42121 Mdot
.37911 .42094 Mdot
.37915 .42067 Mdot
.3792 .42039 Mdot
.37925 .42012 Mdot
.3793 .41985 Mdot
.37935 .41958 Mdot
.37939 .41931 Mdot
.37944 .41904 Mdot
.37949 .41877 Mdot
.37954 .4185 Mdot
.37958 .41823 Mdot
.37963 .41795 Mdot
.37968 .41768 Mdot
.37973 .41741 Mdot
.37977 .41714 Mdot
.37982 .41687 Mdot
.37987 .41659 Mdot
.37992 .41632 Mdot
.37996 .41605 Mdot
.38001 .41578 Mdot
.38006 .4155 Mdot
.38011 .41523 Mdot
.38015 .41496 Mdot
.3802 .41469 Mdot
.38025 .41441 Mdot
.3803 .41414 Mdot
.38035 .41387 Mdot
.38039 .41359 Mdot
.38044 .41332 Mdot
.38049 .41305 Mdot
.38054 .41277 Mdot
.38058 .4125 Mdot
.38063 .41222 Mdot
.38068 .41195 Mdot
.38073 .41168 Mdot
.38077 .4114 Mdot
.38082 .41113 Mdot
.38087 .41085 Mdot
.38092 .41058 Mdot
.38096 .4103 Mdot
.38101 .41003 Mdot
.38106 .40975 Mdot
.38111 .40948 Mdot
.38115 .4092 Mdot
.3812 .40893 Mdot
.38125 .40865 Mdot
.3813 .40838 Mdot
.38135 .4081 Mdot
.38139 .40783 Mdot
.38144 .40755 Mdot
.38149 .40728 Mdot
.38154 .407 Mdot
.38158 .40673 Mdot
.38163 .40645 Mdot
.38168 .40617 Mdot
.38173 .4059 Mdot
.38177 .40562 Mdot
.38182 .40534 Mdot
.38187 .40507 Mdot
.38192 .40479 Mdot
.38196 .40451 Mdot
.38201 .40424 Mdot
.38206 .40396 Mdot
.38211 .40368 Mdot
.38215 .40341 Mdot
.3822 .40313 Mdot
.38225 .40285 Mdot
.3823 .40258 Mdot
.38235 .4023 Mdot
.38239 .40202 Mdot
.38244 .40174 Mdot
.38249 .40146 Mdot
.38254 .40119 Mdot
.38258 .40091 Mdot
.38263 .40063 Mdot
.38268 .40035 Mdot
.38273 .40007 Mdot
.38277 .3998 Mdot
.38282 .39952 Mdot
.38287 .39924 Mdot
.38292 .39896 Mdot
.38296 .39868 Mdot
.38301 .3984 Mdot
.38306 .39812 Mdot
.38311 .39785 Mdot
.38315 .39757 Mdot
.3832 .39729 Mdot
.38325 .39701 Mdot
.3833 .39673 Mdot
.38334 .39645 Mdot
.38339 .39617 Mdot
.38344 .39589 Mdot
.38349 .39561 Mdot
.38354 .39533 Mdot
.38358 .39505 Mdot
.38363 .39477 Mdot
.38368 .39449 Mdot
.38373 .39421 Mdot
.38377 .39393 Mdot
.38382 .39365 Mdot
.38387 .39337 Mdot
.38392 .39309 Mdot
.38396 .39281 Mdot
.38401 .39253 Mdot
.38406 .39225 Mdot
.38411 .39197 Mdot
.38415 .39169 Mdot
.3842 .39141 Mdot
.38425 .39113 Mdot
.3843 .39084 Mdot
.38434 .39056 Mdot
.38439 .39028 Mdot
.38444 .39 Mdot
.38449 .38972 Mdot
.38454 .38944 Mdot
.38458 .38916 Mdot
.38463 .38887 Mdot
.38468 .38859 Mdot
.38473 .38831 Mdot
.38477 .38803 Mdot
.38482 .38775 Mdot
.38487 .38747 Mdot
.38492 .38718 Mdot
.38496 .3869 Mdot
.38501 .38662 Mdot
.38506 .38634 Mdot
.38511 .38605 Mdot
.38515 .38577 Mdot
.3852 .38549 Mdot
.38525 .38521 Mdot
.3853 .38492 Mdot
.38534 .38464 Mdot
.38539 .38436 Mdot
.38544 .38408 Mdot
.38549 .38379 Mdot
.38554 .38351 Mdot
.38558 .38323 Mdot
.38563 .38294 Mdot
.38568 .38266 Mdot
.38573 .38238 Mdot
.38577 .38209 Mdot
.38582 .38181 Mdot
.38587 .38153 Mdot
.38592 .38124 Mdot
.38596 .38096 Mdot
.38601 .38067 Mdot
.38606 .38039 Mdot
.38611 .38011 Mdot
.38615 .37982 Mdot
.3862 .37954 Mdot
.38625 .37925 Mdot
.3863 .37897 Mdot
.38634 .37868 Mdot
.38639 .3784 Mdot
.38644 .37812 Mdot
.38649 .37783 Mdot
.38654 .37755 Mdot
.38658 .37726 Mdot
.38663 .37698 Mdot
.38668 .37669 Mdot
.38673 .37641 Mdot
.38677 .37612 Mdot
.38682 .37584 Mdot
.38687 .37555 Mdot
.38692 .37527 Mdot
.38696 .37498 Mdot
.38701 .3747 Mdot
.38706 .37441 Mdot
.38711 .37413 Mdot
.38715 .37384 Mdot
.3872 .37355 Mdot
.38725 .37327 Mdot
.3873 .37298 Mdot
.38734 .3727 Mdot
.38739 .37241 Mdot
.38744 .37213 Mdot
.38749 .37184 Mdot
.38754 .37155 Mdot
.38758 .37127 Mdot
.38763 .37098 Mdot
.38768 .3707 Mdot
.38773 .37041 Mdot
.38777 .37012 Mdot
.38782 .36984 Mdot
.38787 .36955 Mdot
.38792 .36926 Mdot
.38796 .36898 Mdot
.38801 .36869 Mdot
.38806 .3684 Mdot
.38811 .36812 Mdot
.38815 .36783 Mdot
.3882 .36754 Mdot
.38825 .36726 Mdot
.3883 .36697 Mdot
.38834 .36668 Mdot
.38839 .3664 Mdot
.38844 .36611 Mdot
.38849 .36582 Mdot
.38853 .36553 Mdot
.38858 .36525 Mdot
.38863 .36496 Mdot
.38868 .36467 Mdot
.38873 .36438 Mdot
.38877 .3641 Mdot
.38882 .36381 Mdot
.38887 .36352 Mdot
.38892 .36323 Mdot
.38896 .36295 Mdot
.38901 .36266 Mdot
.38906 .36237 Mdot
.38911 .36208 Mdot
.38915 .36179 Mdot
.3892 .36151 Mdot
.38925 .36122 Mdot
.3893 .36093 Mdot
.38934 .36064 Mdot
.38939 .36035 Mdot
.38944 .36006 Mdot
.38949 .35978 Mdot
.38953 .35949 Mdot
.38958 .3592 Mdot
.38963 .35891 Mdot
.38968 .35862 Mdot
.38973 .35833 Mdot
.38977 .35804 Mdot
.38982 .35776 Mdot
.38987 .35747 Mdot
.38992 .35718 Mdot
.38996 .35689 Mdot
.39001 .3566 Mdot
.39006 .35631 Mdot
.39011 .35602 Mdot
.39015 .35573 Mdot
.3902 .35544 Mdot
.39025 .35516 Mdot
.3903 .35487 Mdot
.39034 .35458 Mdot
.39039 .35429 Mdot
.39044 .354 Mdot
.39049 .35371 Mdot
.39053 .35342 Mdot
.39058 .35313 Mdot
.39063 .35284 Mdot
.39068 .35255 Mdot
.39073 .35226 Mdot
.39077 .35197 Mdot
.39082 .35168 Mdot
.39087 .35139 Mdot
.39092 .3511 Mdot
.39096 .35081 Mdot
.39101 .35052 Mdot
.39106 .35023 Mdot
.39111 .34994 Mdot
.39115 .34965 Mdot
.3912 .34936 Mdot
.39125 .34907 Mdot
.3913 .34878 Mdot
.39134 .34849 Mdot
.39139 .3482 Mdot
.39144 .34791 Mdot
.39149 .34762 Mdot
.39153 .34733 Mdot
.39158 .34704 Mdot
.39163 .34675 Mdot
.39168 .34646 Mdot
.39173 .34617 Mdot
.39177 .34588 Mdot
.39182 .34559 Mdot
.39187 .3453 Mdot
.39192 .34501 Mdot
.39196 .34472 Mdot
.39201 .34443 Mdot
.39206 .34414 Mdot
.39211 .34385 Mdot
.39215 .34355 Mdot
.3922 .34326 Mdot
.39225 .34297 Mdot
.3923 .34268 Mdot
.39234 .34239 Mdot
.39239 .3421 Mdot
.39244 .34181 Mdot
.39249 .34152 Mdot
.39253 .34123 Mdot
.39258 .34094 Mdot
.39263 .34064 Mdot
.39268 .34035 Mdot
.39273 .34006 Mdot
.39277 .33977 Mdot
.39282 .33948 Mdot
.39287 .33919 Mdot
.39292 .3389 Mdot
.39296 .33861 Mdot
.39301 .33831 Mdot
.39306 .33802 Mdot
.39311 .33773 Mdot
.39315 .33744 Mdot
.3932 .33715 Mdot
.39325 .33686 Mdot
.3933 .33657 Mdot
.39334 .33627 Mdot
.39339 .33598 Mdot
.39344 .33569 Mdot
.39349 .3354 Mdot
.39353 .33511 Mdot
.39358 .33482 Mdot
.39363 .33452 Mdot
.39368 .33423 Mdot
.39372 .33394 Mdot
.39377 .33365 Mdot
.39382 .33336 Mdot
.39387 .33306 Mdot
.39392 .33277 Mdot
.39396 .33248 Mdot
.39401 .33219 Mdot
.39406 .3319 Mdot
.39411 .3316 Mdot
.39415 .33131 Mdot
.3942 .33102 Mdot
.39425 .33073 Mdot
.3943 .33044 Mdot
.39434 .33014 Mdot
.39439 .32985 Mdot
.39444 .32956 Mdot
.39449 .32927 Mdot
.39453 .32898 Mdot
.39458 .32868 Mdot
.39463 .32839 Mdot
.39468 .3281 Mdot
.39472 .32781 Mdot
.39477 .32751 Mdot
.39482 .32722 Mdot
.39487 .32693 Mdot
.39492 .32664 Mdot
.39496 .32635 Mdot
.39501 .32605 Mdot
.39506 .32576 Mdot
.39511 .32547 Mdot
.39515 .32518 Mdot
.3952 .32488 Mdot
.39525 .32459 Mdot
.3953 .3243 Mdot
.39534 .32401 Mdot
.39539 .32371 Mdot
.39544 .32342 Mdot
.39549 .32313 Mdot
.39553 .32284 Mdot
.39558 .32254 Mdot
.39563 .32225 Mdot
.39568 .32196 Mdot
.39572 .32167 Mdot
.39577 .32137 Mdot
.39582 .32108 Mdot
.39587 .32079 Mdot
.39592 .32049 Mdot
.39596 .3202 Mdot
.39601 .31991 Mdot
.39606 .31962 Mdot
.39611 .31932 Mdot
.39615 .31903 Mdot
.3962 .31874 Mdot
.39625 .31845 Mdot
.3963 .31815 Mdot
.39634 .31786 Mdot
.39639 .31757 Mdot
.39644 .31727 Mdot
.39649 .31698 Mdot
.39653 .31669 Mdot
.39658 .3164 Mdot
.39663 .3161 Mdot
.39668 .31581 Mdot
.39672 .31552 Mdot
.39677 .31522 Mdot
.39682 .31493 Mdot
.39687 .31464 Mdot
.39692 .31435 Mdot
.39696 .31405 Mdot
.39701 .31376 Mdot
.39706 .31347 Mdot
.39711 .31317 Mdot
.39715 .31288 Mdot
.3972 .31259 Mdot
.39725 .3123 Mdot
.3973 .312 Mdot
.39734 .31171 Mdot
.39739 .31142 Mdot
.39744 .31112 Mdot
.39749 .31083 Mdot
.39753 .31054 Mdot
.39758 .31025 Mdot
.39763 .30995 Mdot
.39768 .30966 Mdot
.39772 .30937 Mdot
.39777 .30907 Mdot
.39782 .30878 Mdot
.39787 .30849 Mdot
.39791 .3082 Mdot
.39796 .3079 Mdot
.39801 .30761 Mdot
.39806 .30732 Mdot
.39811 .30702 Mdot
.39815 .30673 Mdot
.3982 .30644 Mdot
.39825 .30614 Mdot
.3983 .30585 Mdot
.39834 .30556 Mdot
.39839 .30527 Mdot
.39844 .30497 Mdot
.39849 .30468 Mdot
.39853 .30439 Mdot
.39858 .30409 Mdot
.39863 .3038 Mdot
.39868 .30351 Mdot
.39872 .30322 Mdot
.39877 .30292 Mdot
.39882 .30263 Mdot
.39887 .30234 Mdot
.39891 .30204 Mdot
.39896 .30175 Mdot
.39901 .30146 Mdot
.39906 .30117 Mdot
.39911 .30087 Mdot
.39915 .30058 Mdot
.3992 .30029 Mdot
.39925 .29999 Mdot
.3993 .2997 Mdot
.39934 .29941 Mdot
.39939 .29912 Mdot
.39944 .29882 Mdot
.39949 .29853 Mdot
.39953 .29824 Mdot
.39958 .29795 Mdot
.39963 .29765 Mdot
.39968 .29736 Mdot
.39972 .29707 Mdot
.39977 .29677 Mdot
.39982 .29648 Mdot
.39987 .29619 Mdot
.39991 .2959 Mdot
.39996 .2956 Mdot
.40001 .29531 Mdot
.40006 .29502 Mdot
.40011 .29473 Mdot
.40015 .29443 Mdot
.4002 .29414 Mdot
.40025 .29385 Mdot
.4003 .29356 Mdot
.40034 .29326 Mdot
.40039 .29297 Mdot
.40044 .29268 Mdot
.40049 .29239 Mdot
.40053 .29209 Mdot
.40058 .2918 Mdot
.40063 .29151 Mdot
.40068 .29122 Mdot
.40072 .29092 Mdot
.40077 .29063 Mdot
.40082 .29034 Mdot
.40087 .29005 Mdot
.40091 .28975 Mdot
.40096 .28946 Mdot
.40101 .28917 Mdot
.40106 .28888 Mdot
.40111 .28859 Mdot
.40115 .28829 Mdot
.4012 .288 Mdot
.40125 .28771 Mdot
.4013 .28742 Mdot
.40134 .28712 Mdot
.40139 .28683 Mdot
.40144 .28654 Mdot
.40149 .28625 Mdot
.40153 .28596 Mdot
.40158 .28566 Mdot
.40163 .28537 Mdot
.40168 .28508 Mdot
.40172 .28479 Mdot
.40177 .2845 Mdot
.40182 .2842 Mdot
.40187 .28391 Mdot
.40191 .28362 Mdot
.40196 .28333 Mdot
.40201 .28304 Mdot
.40206 .28274 Mdot
.40211 .28245 Mdot
.40215 .28216 Mdot
.4022 .28187 Mdot
.40225 .28158 Mdot
.4023 .28129 Mdot
.40234 .28099 Mdot
.40239 .2807 Mdot
.40244 .28041 Mdot
.40249 .28012 Mdot
.40253 .27983 Mdot
.40258 .27954 Mdot
.40263 .27925 Mdot
.40268 .27895 Mdot
.40272 .27866 Mdot
.40277 .27837 Mdot
.40282 .27808 Mdot
.40287 .27779 Mdot
.40291 .2775 Mdot
.40296 .27721 Mdot
.40301 .27691 Mdot
.40306 .27662 Mdot
.4031 .27633 Mdot
.40315 .27604 Mdot
.4032 .27575 Mdot
.40325 .27546 Mdot
.4033 .27517 Mdot
.40334 .27488 Mdot
.40339 .27459 Mdot
.40344 .2743 Mdot
.40349 .274 Mdot
.40353 .27371 Mdot
.40358 .27342 Mdot
.40363 .27313 Mdot
.40368 .27284 Mdot
.40372 .27255 Mdot
.40377 .27226 Mdot
.40382 .27197 Mdot
.40387 .27168 Mdot
.40391 .27139 Mdot
.40396 .2711 Mdot
.40401 .27081 Mdot
.40406 .27052 Mdot
.4041 .27023 Mdot
.40415 .26994 Mdot
.4042 .26964 Mdot
.40425 .26935 Mdot
.4043 .26906 Mdot
.40434 .26877 Mdot
.40439 .26848 Mdot
.40444 .26819 Mdot
.40449 .2679 Mdot
.40453 .26761 Mdot
.40458 .26732 Mdot
.40463 .26703 Mdot
.40468 .26674 Mdot
.40472 .26645 Mdot
.40477 .26616 Mdot
.40482 .26587 Mdot
.40487 .26558 Mdot
.40491 .26529 Mdot
.40496 .265 Mdot
.40501 .26472 Mdot
.40506 .26443 Mdot
.4051 .26414 Mdot
.40515 .26385 Mdot
.4052 .26356 Mdot
.40525 .26327 Mdot
.4053 .26298 Mdot
.40534 .26269 Mdot
.40539 .2624 Mdot
.40544 .26211 Mdot
.40549 .26182 Mdot
.40553 .26153 Mdot
.40558 .26124 Mdot
.40563 .26095 Mdot
.40568 .26066 Mdot
.40572 .26038 Mdot
.40577 .26009 Mdot
.40582 .2598 Mdot
.40587 .25951 Mdot
.40591 .25922 Mdot
.40596 .25893 Mdot
.40601 .25864 Mdot
.40606 .25835 Mdot
.4061 .25807 Mdot
.40615 .25778 Mdot
.4062 .25749 Mdot
.40625 .2572 Mdot
.4063 .25691 Mdot
.40634 .25662 Mdot
.40639 .25634 Mdot
.40644 .25605 Mdot
.40649 .25576 Mdot
.40653 .25547 Mdot
.40658 .25518 Mdot
.40663 .2549 Mdot
.40668 .25461 Mdot
.40672 .25432 Mdot
.40677 .25403 Mdot
.40682 .25374 Mdot
.40687 .25346 Mdot
.40691 .25317 Mdot
.40696 .25288 Mdot
.40701 .25259 Mdot
.40706 .25231 Mdot
.4071 .25202 Mdot
.40715 .25173 Mdot
.4072 .25144 Mdot
.40725 .25116 Mdot
.40729 .25087 Mdot
.40734 .25058 Mdot
.40739 .25029 Mdot
.40744 .25001 Mdot
.40749 .24972 Mdot
.40753 .24943 Mdot
.40758 .24915 Mdot
.40763 .24886 Mdot
.40768 .24857 Mdot
.40772 .24829 Mdot
.40777 .248 Mdot
.40782 .24771 Mdot
.40787 .24743 Mdot
.40791 .24714 Mdot
.40796 .24685 Mdot
.40801 .24657 Mdot
.40806 .24628 Mdot
.4081 .246 Mdot
.40815 .24571 Mdot
.4082 .24542 Mdot
.40825 .24514 Mdot
.40829 .24485 Mdot
.40834 .24457 Mdot
.40839 .24428 Mdot
.40844 .24399 Mdot
.40849 .24371 Mdot
.40853 .24342 Mdot
.40858 .24314 Mdot
.40863 .24285 Mdot
.40868 .24257 Mdot
.40872 .24228 Mdot
.40877 .24199 Mdot
.40882 .24171 Mdot
.40887 .24142 Mdot
.40891 .24114 Mdot
.40896 .24085 Mdot
.40901 .24057 Mdot
.40906 .24028 Mdot
.4091 .24 Mdot
.40915 .23971 Mdot
.4092 .23943 Mdot
.40925 .23915 Mdot
.40929 .23886 Mdot
.40934 .23858 Mdot
.40939 .23829 Mdot
.40944 .23801 Mdot
.40949 .23772 Mdot
.40953 .23744 Mdot
.40958 .23716 Mdot
.40963 .23687 Mdot
.40968 .23659 Mdot
.40972 .2363 Mdot
.40977 .23602 Mdot
.40982 .23574 Mdot
.40987 .23545 Mdot
.40991 .23517 Mdot
.40996 .23488 Mdot
.41001 .2346 Mdot
.41006 .23432 Mdot
.4101 .23403 Mdot
.41015 .23375 Mdot
.4102 .23347 Mdot
.41025 .23318 Mdot
.41029 .2329 Mdot
.41034 .23262 Mdot
.41039 .23234 Mdot
.41044 .23205 Mdot
.41049 .23177 Mdot
.41053 .23149 Mdot
.41058 .23121 Mdot
.41063 .23092 Mdot
.41068 .23064 Mdot
.41072 .23036 Mdot
.41077 .23008 Mdot
.41082 .22979 Mdot
.41087 .22951 Mdot
.41091 .22923 Mdot
.41096 .22895 Mdot
.41101 .22867 Mdot
.41106 .22838 Mdot
.4111 .2281 Mdot
.41115 .22782 Mdot
.4112 .22754 Mdot
.41125 .22726 Mdot
.41129 .22698 Mdot
.41134 .22669 Mdot
.41139 .22641 Mdot
.41144 .22613 Mdot
.41149 .22585 Mdot
.41153 .22557 Mdot
.41158 .22529 Mdot
.41163 .22501 Mdot
.41168 .22473 Mdot
.41172 .22445 Mdot
.41177 .22417 Mdot
.41182 .22389 Mdot
.41187 .22361 Mdot
.41191 .22333 Mdot
.41196 .22305 Mdot
.41201 .22277 Mdot
.41206 .22249 Mdot
.4121 .22221 Mdot
.41215 .22193 Mdot
.4122 .22165 Mdot
.41225 .22137 Mdot
.41229 .22109 Mdot
.41234 .22081 Mdot
.41239 .22053 Mdot
.41244 .22025 Mdot
.41248 .21997 Mdot
.41253 .21969 Mdot
.41258 .21941 Mdot
.41263 .21913 Mdot
.41268 .21885 Mdot
.41272 .21857 Mdot
.41277 .21829 Mdot
.41282 .21802 Mdot
.41287 .21774 Mdot
.41291 .21746 Mdot
.41296 .21718 Mdot
.41301 .2169 Mdot
.41306 .21662 Mdot
.4131 .21635 Mdot
.41315 .21607 Mdot
.4132 .21579 Mdot
.41325 .21551 Mdot
.41329 .21523 Mdot
.41334 .21496 Mdot
.41339 .21468 Mdot
.41344 .2144 Mdot
.41348 .21412 Mdot
.41353 .21385 Mdot
.41358 .21357 Mdot
.41363 .21329 Mdot
.41368 .21302 Mdot
.41372 .21274 Mdot
.41377 .21246 Mdot
.41382 .21219 Mdot
.41387 .21191 Mdot
.41391 .21163 Mdot
.41396 .21136 Mdot
.41401 .21108 Mdot
.41406 .2108 Mdot
.4141 .21053 Mdot
.41415 .21025 Mdot
.4142 .20998 Mdot
.41425 .2097 Mdot
.41429 .20942 Mdot
.41434 .20915 Mdot
.41439 .20887 Mdot
.41444 .2086 Mdot
.41448 .20832 Mdot
.41453 .20805 Mdot
.41458 .20777 Mdot
.41463 .2075 Mdot
.41468 .20722 Mdot
.41472 .20695 Mdot
.41477 .20667 Mdot
.41482 .2064 Mdot
.41487 .20612 Mdot
.41491 .20585 Mdot
.41496 .20558 Mdot
.41501 .2053 Mdot
.41506 .20503 Mdot
.4151 .20475 Mdot
.41515 .20448 Mdot
.4152 .20421 Mdot
.41525 .20393 Mdot
.41529 .20366 Mdot
.41534 .20338 Mdot
.41539 .20311 Mdot
.41544 .20284 Mdot
.41548 .20257 Mdot
.41553 .20229 Mdot
.41558 .20202 Mdot
.41563 .20175 Mdot
.41568 .20147 Mdot
.41572 .2012 Mdot
.41577 .20093 Mdot
.41582 .20066 Mdot
.41587 .20038 Mdot
.41591 .20011 Mdot
.41596 .19984 Mdot
.41601 .19957 Mdot
.41606 .1993 Mdot
.4161 .19902 Mdot
.41615 .19875 Mdot
.4162 .19848 Mdot
.41625 .19821 Mdot
.41629 .19794 Mdot
.41634 .19767 Mdot
.41639 .1974 Mdot
.41644 .19712 Mdot
.41648 .19685 Mdot
.41653 .19658 Mdot
.41658 .19631 Mdot
.41663 .19604 Mdot
.41667 .19577 Mdot
.41672 .1955 Mdot
.41677 .19523 Mdot
.41682 .19496 Mdot
.41687 .19469 Mdot
.41691 .19442 Mdot
.41696 .19415 Mdot
.41701 .19388 Mdot
.41706 .19361 Mdot
.4171 .19334 Mdot
.41715 .19307 Mdot
.4172 .1928 Mdot
.41725 .19254 Mdot
.41729 .19227 Mdot
.41734 .192 Mdot
.41739 .19173 Mdot
.41744 .19146 Mdot
.41748 .19119 Mdot
.41753 .19092 Mdot
.41758 .19066 Mdot
.41763 .19039 Mdot
.41767 .19012 Mdot
.41772 .18985 Mdot
.41777 .18958 Mdot
.41782 .18932 Mdot
.41787 .18905 Mdot
.41791 .18878 Mdot
.41796 .18851 Mdot
.41801 .18825 Mdot
.41806 .18798 Mdot
.4181 .18771 Mdot
.41815 .18745 Mdot
.4182 .18718 Mdot
.41825 .18691 Mdot
.41829 .18665 Mdot
.41834 .18638 Mdot
.41839 .18611 Mdot
.41844 .18585 Mdot
.41848 .18558 Mdot
.41853 .18532 Mdot
.41858 .18505 Mdot
.41863 .18478 Mdot
.41867 .18452 Mdot
.41872 .18425 Mdot
.41877 .18399 Mdot
.41882 .18372 Mdot
.41887 .18346 Mdot
.41891 .18319 Mdot
.41896 .18293 Mdot
.41901 .18266 Mdot
.41906 .1824 Mdot
.4191 .18214 Mdot
.41915 .18187 Mdot
.4192 .18161 Mdot
.41925 .18134 Mdot
.41929 .18108 Mdot
.41934 .18082 Mdot
.41939 .18055 Mdot
.41944 .18029 Mdot
.41948 .18003 Mdot
.41953 .17976 Mdot
.41958 .1795 Mdot
.41963 .17924 Mdot
.41967 .17897 Mdot
.41972 .17871 Mdot
.41977 .17845 Mdot
.41982 .17819 Mdot
.41987 .17792 Mdot
.41991 .17766 Mdot
.41996 .1774 Mdot
.42001 .17714 Mdot
.42006 .17688 Mdot
.4201 .17661 Mdot
.42015 .17635 Mdot
.4202 .17609 Mdot
.42025 .17583 Mdot
.42029 .17557 Mdot
.42034 .17531 Mdot
.42039 .17505 Mdot
.42044 .17479 Mdot
.42048 .17453 Mdot
.42053 .17427 Mdot
.42058 .17401 Mdot
.42063 .17375 Mdot
.42067 .17349 Mdot
.42072 .17323 Mdot
.42077 .17297 Mdot
.42082 .17271 Mdot
.42087 .17245 Mdot
.42091 .17219 Mdot
.42096 .17193 Mdot
.42101 .17167 Mdot
.42106 .17141 Mdot
.4211 .17115 Mdot
.42115 .17089 Mdot
.4212 .17063 Mdot
.42125 .17038 Mdot
.42129 .17012 Mdot
.42134 .16986 Mdot
.42139 .1696 Mdot
.42144 .16934 Mdot
.42148 .16909 Mdot
.42153 .16883 Mdot
.42158 .16857 Mdot
.42163 .16831 Mdot
.42167 .16806 Mdot
.42172 .1678 Mdot
.42177 .16754 Mdot
.42182 .16729 Mdot
.42186 .16703 Mdot
.42191 .16677 Mdot
.42196 .16652 Mdot
.42201 .16626 Mdot
.42206 .16601 Mdot
.4221 .16575 Mdot
.42215 .16549 Mdot
.4222 .16524 Mdot
.42225 .16498 Mdot
.42229 .16473 Mdot
.42234 .16447 Mdot
.42239 .16422 Mdot
.42244 .16396 Mdot
.42248 .16371 Mdot
.42253 .16345 Mdot
.42258 .1632 Mdot
.42263 .16294 Mdot
.42267 .16269 Mdot
.42272 .16244 Mdot
.42277 .16218 Mdot
.42282 .16193 Mdot
.42286 .16168 Mdot
.42291 .16142 Mdot
.42296 .16117 Mdot
.42301 .16092 Mdot
.42306 .16066 Mdot
.4231 .16041 Mdot
.42315 .16016 Mdot
.4232 .1599 Mdot
.42325 .15965 Mdot
.42329 .1594 Mdot
.42334 .15915 Mdot
.42339 .1589 Mdot
.42344 .15864 Mdot
.42348 .15839 Mdot
.42353 .15814 Mdot
.42358 .15789 Mdot
.42363 .15764 Mdot
.42367 .15739 Mdot
.42372 .15714 Mdot
.42377 .15689 Mdot
.42382 .15664 Mdot
.42386 .15639 Mdot
.42391 .15614 Mdot
.42396 .15589 Mdot
.42401 .15564 Mdot
.42406 .15539 Mdot
.4241 .15514 Mdot
.42415 .15489 Mdot
.4242 .15464 Mdot
.42425 .15439 Mdot
.42429 .15414 Mdot
.42434 .15389 Mdot
.42439 .15364 Mdot
.42444 .15339 Mdot
.42448 .15314 Mdot
.42453 .1529 Mdot
.42458 .15265 Mdot
.42463 .1524 Mdot
.42467 .15215 Mdot
.42472 .1519 Mdot
.42477 .15166 Mdot
.42482 .15141 Mdot
.42486 .15116 Mdot
.42491 .15092 Mdot
.42496 .15067 Mdot
.42501 .15042 Mdot
.42506 .15018 Mdot
.4251 .14993 Mdot
.42515 .14968 Mdot
.4252 .14944 Mdot
.42525 .14919 Mdot
.42529 .14895 Mdot
.42534 .1487 Mdot
.42539 .14845 Mdot
.42544 .14821 Mdot
.42548 .14796 Mdot
.42553 .14772 Mdot
.42558 .14747 Mdot
.42563 .14723 Mdot
.42567 .14699 Mdot
.42572 .14674 Mdot
.42577 .1465 Mdot
.42582 .14625 Mdot
.42586 .14601 Mdot
.42591 .14577 Mdot
.42596 .14552 Mdot
.42601 .14528 Mdot
.42606 .14504 Mdot
.4261 .14479 Mdot
.42615 .14455 Mdot
.4262 .14431 Mdot
.42625 .14406 Mdot
.42629 .14382 Mdot
.42634 .14358 Mdot
.42639 .14334 Mdot
.42644 .1431 Mdot
.42648 .14285 Mdot
.42653 .14261 Mdot
.42658 .14237 Mdot
.42663 .14213 Mdot
.42667 .14189 Mdot
.42672 .14165 Mdot
.42677 .14141 Mdot
.42682 .14117 Mdot
.42686 .14093 Mdot
.42691 .14069 Mdot
.42696 .14045 Mdot
.42701 .14021 Mdot
.42705 .13997 Mdot
.4271 .13973 Mdot
.42715 .13949 Mdot
.4272 .13925 Mdot
.42725 .13901 Mdot
.42729 .13877 Mdot
.42734 .13853 Mdot
.42739 .1383 Mdot
.42744 .13806 Mdot
.42748 .13782 Mdot
.42753 .13758 Mdot
.42758 .13734 Mdot
.42763 .13711 Mdot
.42767 .13687 Mdot
.42772 .13663 Mdot
.42777 .13639 Mdot
.42782 .13616 Mdot
.42786 .13592 Mdot
.42791 .13568 Mdot
.42796 .13545 Mdot
.42801 .13521 Mdot
.42805 .13497 Mdot
.4281 .13474 Mdot
.42815 .1345 Mdot
.4282 .13427 Mdot
.42825 .13403 Mdot
.42829 .1338 Mdot
.42834 .13356 Mdot
.42839 .13333 Mdot
.42844 .13309 Mdot
.42848 .13286 Mdot
.42853 .13262 Mdot
.42858 .13239 Mdot
.42863 .13216 Mdot
.42867 .13192 Mdot
.42872 .13169 Mdot
.42877 .13145 Mdot
.42882 .13122 Mdot
.42886 .13099 Mdot
.42891 .13076 Mdot
.42896 .13052 Mdot
.42901 .13029 Mdot
.42905 .13006 Mdot
.4291 .12983 Mdot
.42915 .12959 Mdot
.4292 .12936 Mdot
.42925 .12913 Mdot
.42929 .1289 Mdot
.42934 .12867 Mdot
.42939 .12844 Mdot
.42944 .12821 Mdot
.42948 .12797 Mdot
.42953 .12774 Mdot
.42958 .12751 Mdot
.42963 .12728 Mdot
.42967 .12705 Mdot
.42972 .12682 Mdot
.42977 .12659 Mdot
.42982 .12636 Mdot
.42986 .12613 Mdot
.42991 .12591 Mdot
.42996 .12568 Mdot
.43001 .12545 Mdot
.43005 .12522 Mdot
.4301 .12499 Mdot
.43015 .12476 Mdot
.4302 .12453 Mdot
.43025 .12431 Mdot
.43029 .12408 Mdot
.43034 .12385 Mdot
.43039 .12362 Mdot
.43044 .1234 Mdot
.43048 .12317 Mdot
.43053 .12294 Mdot
.43058 .12272 Mdot
.43063 .12249 Mdot
.43067 .12226 Mdot
.43072 .12204 Mdot
.43077 .12181 Mdot
.43082 .12159 Mdot
.43086 .12136 Mdot
.43091 .12114 Mdot
.43096 .12091 Mdot
.43101 .12069 Mdot
.43105 .12046 Mdot
.4311 .12024 Mdot
.43115 .12001 Mdot
.4312 .11979 Mdot
.43124 .11957 Mdot
.43129 .11934 Mdot
.43134 .11912 Mdot
.43139 .11889 Mdot
.43144 .11867 Mdot
.43148 .11845 Mdot
.43153 .11823 Mdot
.43158 .118 Mdot
.43163 .11778 Mdot
.43167 .11756 Mdot
.43172 .11734 Mdot
.43177 .11711 Mdot
.43182 .11689 Mdot
.43186 .11667 Mdot
.43191 .11645 Mdot
.43196 .11623 Mdot
.43201 .11601 Mdot
.43205 .11579 Mdot
.4321 .11557 Mdot
.43215 .11535 Mdot
.4322 .11513 Mdot
.43224 .11491 Mdot
.43229 .11469 Mdot
.43234 .11447 Mdot
.43239 .11425 Mdot
.43244 .11403 Mdot
.43248 .11381 Mdot
.43253 .11359 Mdot
.43258 .11337 Mdot
.43263 .11315 Mdot
.43267 .11294 Mdot
.43272 .11272 Mdot
.43277 .1125 Mdot
.43282 .11228 Mdot
.43286 .11207 Mdot
.43291 .11185 Mdot
.43296 .11163 Mdot
.43301 .11141 Mdot
.43305 .1112 Mdot
.4331 .11098 Mdot
.43315 .11077 Mdot
.4332 .11055 Mdot
.43324 .11033 Mdot
.43329 .11012 Mdot
.43334 .1099 Mdot
.43339 .10969 Mdot
.43344 .10947 Mdot
.43348 .10926 Mdot
.43353 .10904 Mdot
.43358 .10883 Mdot
.43363 .10861 Mdot
.43367 .1084 Mdot
.43372 .10819 Mdot
.43377 .10797 Mdot
.43382 .10776 Mdot
.43386 .10755 Mdot
.43391 .10733 Mdot
.43396 .10712 Mdot
.43401 .10691 Mdot
.43405 .1067 Mdot
.4341 .10648 Mdot
.43415 .10627 Mdot
.4342 .10606 Mdot
.43424 .10585 Mdot
.43429 .10564 Mdot
.43434 .10543 Mdot
.43439 .10521 Mdot
.43444 .105 Mdot
.43448 .10479 Mdot
.43453 .10458 Mdot
.43458 .10437 Mdot
.43463 .10416 Mdot
.43467 .10395 Mdot
.43472 .10374 Mdot
.43477 .10353 Mdot
.43482 .10333 Mdot
.43486 .10312 Mdot
.43491 .10291 Mdot
.43496 .1027 Mdot
.43501 .10249 Mdot
.43505 .10228 Mdot
.4351 .10207 Mdot
.43515 .10187 Mdot
.4352 .10166 Mdot
.43524 .10145 Mdot
.43529 .10125 Mdot
.43534 .10104 Mdot
.43539 .10083 Mdot
.43544 .10063 Mdot
.43548 .10042 Mdot
.43553 .10021 Mdot
.43558 .10001 Mdot
.43563 .0998 Mdot
.43567 .0996 Mdot
.43572 .09939 Mdot
.43577 .09919 Mdot
.43582 .09898 Mdot
.43586 .09878 Mdot
.43591 .09857 Mdot
.43596 .09837 Mdot
.43601 .09816 Mdot
.43605 .09796 Mdot
.4361 .09776 Mdot
.43615 .09755 Mdot
.4362 .09735 Mdot
.43624 .09715 Mdot
.43629 .09694 Mdot
.43634 .09674 Mdot
.43639 .09654 Mdot
.43643 .09634 Mdot
.43648 .09614 Mdot
.43653 .09593 Mdot
.43658 .09573 Mdot
.43663 .09553 Mdot
.43667 .09533 Mdot
.43672 .09513 Mdot
.43677 .09493 Mdot
.43682 .09473 Mdot
.43686 .09453 Mdot
.43691 .09433 Mdot
.43696 .09413 Mdot
.43701 .09393 Mdot
.43705 .09373 Mdot
.4371 .09353 Mdot
.43715 .09333 Mdot
.4372 .09313 Mdot
.43724 .09294 Mdot
.43729 .09274 Mdot
.43734 .09254 Mdot
.43739 .09234 Mdot
.43743 .09214 Mdot
.43748 .09195 Mdot
.43753 .09175 Mdot
.43758 .09155 Mdot
.43763 .09136 Mdot
.43767 .09116 Mdot
.43772 .09096 Mdot
.43777 .09077 Mdot
.43782 .09057 Mdot
.43786 .09038 Mdot
.43791 .09018 Mdot
.43796 .08999 Mdot
.43801 .08979 Mdot
.43805 .0896 Mdot
.4381 .0894 Mdot
.43815 .08921 Mdot
.4382 .08901 Mdot
.43824 .08882 Mdot
.43829 .08863 Mdot
.43834 .08843 Mdot
.43839 .08824 Mdot
.43843 .08805 Mdot
.43848 .08785 Mdot
.43853 .08766 Mdot
.43858 .08747 Mdot
.43863 .08728 Mdot
.43867 .08708 Mdot
.43872 .08689 Mdot
.43877 .0867 Mdot
.43882 .08651 Mdot
.43886 .08632 Mdot
.43891 .08613 Mdot
.43896 .08594 Mdot
.43901 .08575 Mdot
.43905 .08556 Mdot
.4391 .08537 Mdot
.43915 .08518 Mdot
.4392 .08499 Mdot
.43924 .0848 Mdot
.43929 .08461 Mdot
.43934 .08442 Mdot
.43939 .08423 Mdot
.43943 .08405 Mdot
.43948 .08386 Mdot
.43953 .08367 Mdot
.43958 .08348 Mdot
.43963 .08329 Mdot
.43967 .08311 Mdot
.43972 .08292 Mdot
.43977 .08273 Mdot
.43982 .08255 Mdot
.43986 .08236 Mdot
.43991 .08217 Mdot
.43996 .08199 Mdot
.44001 .0818 Mdot
.44005 .08162 Mdot
.4401 .08143 Mdot
.44015 .08125 Mdot
.4402 .08106 Mdot
.44024 .08088 Mdot
.44029 .08069 Mdot
.44034 .08051 Mdot
.44039 .08033 Mdot
.44043 .08014 Mdot
.44048 .07996 Mdot
.44053 .07978 Mdot
.44058 .07959 Mdot
.44062 .07941 Mdot
.44067 .07923 Mdot
.44072 .07905 Mdot
.44077 .07886 Mdot
.44082 .07868 Mdot
.44086 .0785 Mdot
.44091 .07832 Mdot
.44096 .07814 Mdot
.44101 .07796 Mdot
.44105 .07778 Mdot
.4411 .0776 Mdot
.44115 .07742 Mdot
.4412 .07724 Mdot
.44124 .07706 Mdot
.44129 .07688 Mdot
.44134 .0767 Mdot
.44139 .07652 Mdot
.44143 .07634 Mdot
.44148 .07616 Mdot
.44153 .07599 Mdot
.44158 .07581 Mdot
.44162 .07563 Mdot
.44167 .07545 Mdot
.44172 .07527 Mdot
.44177 .0751 Mdot
.44182 .07492 Mdot
.44186 .07474 Mdot
.44191 .07457 Mdot
.44196 .07439 Mdot
.44201 .07422 Mdot
.44205 .07404 Mdot
.4421 .07386 Mdot
.44215 .07369 Mdot
.4422 .07351 Mdot
.44224 .07334 Mdot
.44229 .07317 Mdot
.44234 .07299 Mdot
.44239 .07282 Mdot
.44243 .07264 Mdot
.44248 .07247 Mdot
.44253 .0723 Mdot
.44258 .07212 Mdot
.44262 .07195 Mdot
.44267 .07178 Mdot
.44272 .07161 Mdot
.44277 .07143 Mdot
.44282 .07126 Mdot
.44286 .07109 Mdot
.44291 .07092 Mdot
.44296 .07075 Mdot
.44301 .07058 Mdot
.44305 .07041 Mdot
.4431 .07024 Mdot
.44315 .07007 Mdot
.4432 .0699 Mdot
.44324 .06973 Mdot
.44329 .06956 Mdot
.44334 .06939 Mdot
.44339 .06922 Mdot
.44343 .06905 Mdot
.44348 .06888 Mdot
.44353 .06871 Mdot
.44358 .06854 Mdot
.44362 .06838 Mdot
.44367 .06821 Mdot
.44372 .06804 Mdot
.44377 .06787 Mdot
.44382 .06771 Mdot
.44386 .06754 Mdot
.44391 .06737 Mdot
.44396 .06721 Mdot
.44401 .06704 Mdot
.44405 .06688 Mdot
.4441 .06671 Mdot
.44415 .06655 Mdot
.4442 .06638 Mdot
.44424 .06622 Mdot
.44429 .06605 Mdot
.44434 .06589 Mdot
.44439 .06572 Mdot
.44443 .06556 Mdot
.44448 .0654 Mdot
.44453 .06523 Mdot
.44458 .06507 Mdot
.44462 .06491 Mdot
.44467 .06474 Mdot
.44472 .06458 Mdot
.44477 .06442 Mdot
.44482 .06426 Mdot
.44486 .0641 Mdot
.44491 .06394 Mdot
.44496 .06377 Mdot
.44501 .06361 Mdot
.44505 .06345 Mdot
.4451 .06329 Mdot
.44515 .06313 Mdot
.4452 .06297 Mdot
.44524 .06281 Mdot
.44529 .06265 Mdot
.44534 .0625 Mdot
.44539 .06234 Mdot
.44543 .06218 Mdot
.44548 .06202 Mdot
.44553 .06186 Mdot
.44558 .0617 Mdot
.44562 .06155 Mdot
.44567 .06139 Mdot
.44572 .06123 Mdot
.44577 .06107 Mdot
.44581 .06092 Mdot
.44586 .06076 Mdot
.44591 .06061 Mdot
.44596 .06045 Mdot
.44601 .06029 Mdot
.44605 .06014 Mdot
.4461 .05998 Mdot
.44615 .05983 Mdot
.4462 .05967 Mdot
.44624 .05952 Mdot
.44629 .05937 Mdot
.44634 .05921 Mdot
.44639 .05906 Mdot
.44643 .0589 Mdot
.44648 .05875 Mdot
.44653 .0586 Mdot
.44658 .05845 Mdot
.44662 .05829 Mdot
.44667 .05814 Mdot
.44672 .05799 Mdot
.44677 .05784 Mdot
.44681 .05769 Mdot
.44686 .05754 Mdot
.44691 .05738 Mdot
.44696 .05723 Mdot
.44701 .05708 Mdot
.44705 .05693 Mdot
.4471 .05678 Mdot
.44715 .05663 Mdot
.4472 .05648 Mdot
.44724 .05634 Mdot
.44729 .05619 Mdot
.44734 .05604 Mdot
.44739 .05589 Mdot
.44743 .05574 Mdot
.44748 .05559 Mdot
.44753 .05545 Mdot
.44758 .0553 Mdot
.44762 .05515 Mdot
.44767 .05501 Mdot
.44772 .05486 Mdot
.44777 .05471 Mdot
.44781 .05457 Mdot
.44786 .05442 Mdot
.44791 .05427 Mdot
.44796 .05413 Mdot
.44801 .05398 Mdot
.44805 .05384 Mdot
.4481 .0537 Mdot
.44815 .05355 Mdot
.4482 .05341 Mdot
.44824 .05326 Mdot
.44829 .05312 Mdot
.44834 .05298 Mdot
.44839 .05283 Mdot
.44843 .05269 Mdot
.44848 .05255 Mdot
.44853 .05241 Mdot
.44858 .05226 Mdot
.44862 .05212 Mdot
.44867 .05198 Mdot
.44872 .05184 Mdot
.44877 .0517 Mdot
.44881 .05156 Mdot
.44886 .05142 Mdot
.44891 .05128 Mdot
.44896 .05114 Mdot
.44901 .051 Mdot
.44905 .05086 Mdot
.4491 .05072 Mdot
.44915 .05058 Mdot
.4492 .05044 Mdot
.44924 .0503 Mdot
.44929 .05016 Mdot
.44934 .05003 Mdot
.44939 .04989 Mdot
.44943 .04975 Mdot
.44948 .04961 Mdot
.44953 .04948 Mdot
.44958 .04934 Mdot
.44962 .0492 Mdot
.44967 .04907 Mdot
.44972 .04893 Mdot
.44977 .0488 Mdot
.44981 .04866 Mdot
.44986 .04853 Mdot
.44991 .04839 Mdot
.44996 .04826 Mdot
.45 .04812 Mdot
.45005 .04799 Mdot
.4501 .04786 Mdot
.45015 .04772 Mdot
.4502 .04759 Mdot
.45024 .04746 Mdot
.45029 .04732 Mdot
.45034 .04719 Mdot
.45039 .04706 Mdot
.45043 .04693 Mdot
.45048 .0468 Mdot
.45053 .04666 Mdot
.45058 .04653 Mdot
.45062 .0464 Mdot
.45067 .04627 Mdot
.45072 .04614 Mdot
.45077 .04601 Mdot
.45081 .04588 Mdot
.45086 .04575 Mdot
.45091 .04562 Mdot
.45096 .04549 Mdot
.451 .04537 Mdot
.45105 .04524 Mdot
.4511 .04511 Mdot
.45115 .04498 Mdot
.4512 .04485 Mdot
.45124 .04473 Mdot
.45129 .0446 Mdot
.45134 .04447 Mdot
.45139 .04434 Mdot
.45143 .04422 Mdot
.45148 .04409 Mdot
.45153 .04397 Mdot
.45158 .04384 Mdot
.45162 .04372 Mdot
.45167 .04359 Mdot
.45172 .04347 Mdot
.45177 .04334 Mdot
.45181 .04322 Mdot
.45186 .04309 Mdot
.45191 .04297 Mdot
.45196 .04285 Mdot
.452 .04272 Mdot
.45205 .0426 Mdot
.4521 .04248 Mdot
.45215 .04235 Mdot
.4522 .04223 Mdot
.45224 .04211 Mdot
.45229 .04199 Mdot
.45234 .04187 Mdot
.45239 .04175 Mdot
.45243 .04163 Mdot
.45248 .04151 Mdot
.45253 .04139 Mdot
.45258 .04127 Mdot
.45262 .04115 Mdot
.45267 .04103 Mdot
.45272 .04091 Mdot
.45277 .04079 Mdot
.45281 .04067 Mdot
.45286 .04055 Mdot
.45291 .04043 Mdot
.45296 .04031 Mdot
.453 .0402 Mdot
.45305 .04008 Mdot
.4531 .03996 Mdot
.45315 .03985 Mdot
.4532 .03973 Mdot
.45324 .03961 Mdot
.45329 .0395 Mdot
.45334 .03938 Mdot
.45339 .03927 Mdot
.45343 .03915 Mdot
.45348 .03904 Mdot
.45353 .03892 Mdot
.45358 .03881 Mdot
.45362 .03869 Mdot
.45367 .03858 Mdot
.45372 .03847 Mdot
.45377 .03835 Mdot
.45381 .03824 Mdot
.45386 .03813 Mdot
.45391 .03801 Mdot
.45396 .0379 Mdot
.454 .03779 Mdot
.45405 .03768 Mdot
.4541 .03757 Mdot
.45415 .03746 Mdot
.4542 .03735 Mdot
.45424 .03723 Mdot
.45429 .03712 Mdot
.45434 .03701 Mdot
.45439 .0369 Mdot
.45443 .0368 Mdot
.45448 .03669 Mdot
.45453 .03658 Mdot
.45458 .03647 Mdot
.45462 .03636 Mdot
.45467 .03625 Mdot
.45472 .03614 Mdot
.45477 .03604 Mdot
.45481 .03593 Mdot
.45486 .03582 Mdot
.45491 .03572 Mdot
.45496 .03561 Mdot
.455 .0355 Mdot
.45505 .0354 Mdot
.4551 .03529 Mdot
.45515 .03519 Mdot
.45519 .03508 Mdot
.45524 .03498 Mdot
.45529 .03487 Mdot
.45534 .03477 Mdot
.45539 .03466 Mdot
.45543 .03456 Mdot
.45548 .03446 Mdot
.45553 .03435 Mdot
.45558 .03425 Mdot
.45562 .03415 Mdot
.45567 .03404 Mdot
.45572 .03394 Mdot
.45577 .03384 Mdot
.45581 .03374 Mdot
.45586 .03364 Mdot
.45591 .03354 Mdot
.45596 .03344 Mdot
.456 .03334 Mdot
.45605 .03324 Mdot
.4561 .03314 Mdot
.45615 .03304 Mdot
.45619 .03294 Mdot
.45624 .03284 Mdot
.45629 .03274 Mdot
.45634 .03264 Mdot
.45639 .03254 Mdot
.45643 .03244 Mdot
.45648 .03235 Mdot
.45653 .03225 Mdot
.45658 .03215 Mdot
.45662 .03206 Mdot
.45667 .03196 Mdot
.45672 .03186 Mdot
.45677 .03177 Mdot
.45681 .03167 Mdot
.45686 .03158 Mdot
.45691 .03148 Mdot
.45696 .03139 Mdot
.457 .03129 Mdot
.45705 .0312 Mdot
.4571 .0311 Mdot
.45715 .03101 Mdot
.45719 .03091 Mdot
.45724 .03082 Mdot
.45729 .03073 Mdot
.45734 .03064 Mdot
.45739 .03054 Mdot
.45743 .03045 Mdot
.45748 .03036 Mdot
.45753 .03027 Mdot
.45758 .03018 Mdot
.45762 .03009 Mdot
.45767 .02999 Mdot
.45772 .0299 Mdot
.45777 .02981 Mdot
.45781 .02972 Mdot
.45786 .02963 Mdot
.45791 .02955 Mdot
.45796 .02946 Mdot
.458 .02937 Mdot
.45805 .02928 Mdot
.4581 .02919 Mdot
.45815 .0291 Mdot
.45819 .02901 Mdot
.45824 .02893 Mdot
.45829 .02884 Mdot
.45834 .02875 Mdot
.45839 .02867 Mdot
.45843 .02858 Mdot
.45848 .02849 Mdot
.45853 .02841 Mdot
.45858 .02832 Mdot
.45862 .02824 Mdot
.45867 .02815 Mdot
.45872 .02807 Mdot
.45877 .02798 Mdot
.45881 .0279 Mdot
.45886 .02782 Mdot
.45891 .02773 Mdot
.45896 .02765 Mdot
.459 .02757 Mdot
.45905 .02748 Mdot
.4591 .0274 Mdot
.45915 .02732 Mdot
.45919 .02724 Mdot
.45924 .02716 Mdot
.45929 .02708 Mdot
.45934 .02699 Mdot
.45939 .02691 Mdot
.45943 .02683 Mdot
.45948 .02675 Mdot
.45953 .02667 Mdot
.45958 .02659 Mdot
.45962 .02652 Mdot
.45967 .02644 Mdot
.45972 .02636 Mdot
.45977 .02628 Mdot
.45981 .0262 Mdot
.45986 .02612 Mdot
.45991 .02605 Mdot
.45996 .02597 Mdot
.46 .02589 Mdot
.46005 .02581 Mdot
.4601 .02574 Mdot
.46015 .02566 Mdot
.46019 .02559 Mdot
.46024 .02551 Mdot
.46029 .02544 Mdot
.46034 .02536 Mdot
.46038 .02529 Mdot
.46043 .02521 Mdot
.46048 .02514 Mdot
.46053 .02506 Mdot
.46058 .02499 Mdot
.46062 .02492 Mdot
.46067 .02484 Mdot
.46072 .02477 Mdot
.46077 .0247 Mdot
.46081 .02463 Mdot
.46086 .02455 Mdot
.46091 .02448 Mdot
.46096 .02441 Mdot
.461 .02434 Mdot
.46105 .02427 Mdot
.4611 .0242 Mdot
.46115 .02413 Mdot
.46119 .02406 Mdot
.46124 .02399 Mdot
.46129 .02392 Mdot
.46134 .02385 Mdot
.46138 .02378 Mdot
.46143 .02371 Mdot
.46148 .02365 Mdot
.46153 .02358 Mdot
.46158 .02351 Mdot
.46162 .02344 Mdot
.46167 .02338 Mdot
.46172 .02331 Mdot
.46177 .02324 Mdot
.46181 .02318 Mdot
.46186 .02311 Mdot
.46191 .02304 Mdot
.46196 .02298 Mdot
.462 .02291 Mdot
.46205 .02285 Mdot
.4621 .02278 Mdot
.46215 .02272 Mdot
.46219 .02266 Mdot
.46224 .02259 Mdot
.46229 .02253 Mdot
.46234 .02247 Mdot
.46238 .0224 Mdot
.46243 .02234 Mdot
.46248 .02228 Mdot
.46253 .02222 Mdot
.46258 .02216 Mdot
.46262 .02209 Mdot
.46267 .02203 Mdot
.46272 .02197 Mdot
.46277 .02191 Mdot
.46281 .02185 Mdot
.46286 .02179 Mdot
.46291 .02173 Mdot
.46296 .02167 Mdot
.463 .02161 Mdot
.46305 .02156 Mdot
.4631 .0215 Mdot
.46315 .02144 Mdot
.46319 .02138 Mdot
.46324 .02132 Mdot
.46329 .02127 Mdot
.46334 .02121 Mdot
.46338 .02115 Mdot
.46343 .0211 Mdot
.46348 .02104 Mdot
.46353 .02098 Mdot
.46358 .02093 Mdot
.46362 .02087 Mdot
.46367 .02082 Mdot
.46372 .02076 Mdot
.46377 .02071 Mdot
.46381 .02065 Mdot
.46386 .0206 Mdot
.46391 .02055 Mdot
.46396 .02049 Mdot
.464 .02044 Mdot
.46405 .02039 Mdot
.4641 .02034 Mdot
.46415 .02028 Mdot
.46419 .02023 Mdot
.46424 .02018 Mdot
.46429 .02013 Mdot
.46434 .02008 Mdot
.46438 .02003 Mdot
.46443 .01998 Mdot
.46448 .01993 Mdot
.46453 .01988 Mdot
.46457 .01983 Mdot
.46462 .01978 Mdot
.46467 .01973 Mdot
.46472 .01968 Mdot
.46477 .01963 Mdot
.46481 .01958 Mdot
.46486 .01954 Mdot
.46491 .01949 Mdot
.46496 .01944 Mdot
.465 .01939 Mdot
.46505 .01935 Mdot
.4651 .0193 Mdot
.46515 .01926 Mdot
.46519 .01921 Mdot
.46524 .01916 Mdot
.46529 .01912 Mdot
.46534 .01907 Mdot
.46538 .01903 Mdot
.46543 .01899 Mdot
.46548 .01894 Mdot
.46553 .0189 Mdot
.46557 .01885 Mdot
.46562 .01881 Mdot
.46567 .01877 Mdot
.46572 .01873 Mdot
.46577 .01868 Mdot
.46581 .01864 Mdot
.46586 .0186 Mdot
.46591 .01856 Mdot
.46596 .01852 Mdot
.466 .01848 Mdot
.46605 .01844 Mdot
.4661 .0184 Mdot
.46615 .01836 Mdot
.46619 .01832 Mdot
.46624 .01828 Mdot
.46629 .01824 Mdot
.46634 .0182 Mdot
.46638 .01816 Mdot
.46643 .01812 Mdot
.46648 .01808 Mdot
.46653 .01805 Mdot
.46657 .01801 Mdot
.46662 .01797 Mdot
.46667 .01793 Mdot
.46672 .0179 Mdot
.46677 .01786 Mdot
.46681 .01783 Mdot
.46686 .01779 Mdot
.46691 .01776 Mdot
.46696 .01772 Mdot
.467 .01769 Mdot
.46705 .01765 Mdot
.4671 .01762 Mdot
.46715 .01758 Mdot
.46719 .01755 Mdot
.46724 .01752 Mdot
.46729 .01748 Mdot
.46734 .01745 Mdot
.46738 .01742 Mdot
.46743 .01739 Mdot
.46748 .01735 Mdot
.46753 .01732 Mdot
.46757 .01729 Mdot
.46762 .01726 Mdot
.46767 .01723 Mdot
.46772 .0172 Mdot
.46777 .01717 Mdot
.46781 .01714 Mdot
.46786 .01711 Mdot
.46791 .01708 Mdot
.46796 .01705 Mdot
.468 .01702 Mdot
.46805 .017 Mdot
.4681 .01697 Mdot
.46815 .01694 Mdot
.46819 .01691 Mdot
.46824 .01688 Mdot
.46829 .01686 Mdot
.46834 .01683 Mdot
.46838 .01681 Mdot
.46843 .01678 Mdot
.46848 .01675 Mdot
.46853 .01673 Mdot
.46857 .0167 Mdot
.46862 .01668 Mdot
.46867 .01665 Mdot
.46872 .01663 Mdot
.46877 .01661 Mdot
.46881 .01658 Mdot
.46886 .01656 Mdot
.46891 .01654 Mdot
.46896 .01651 Mdot
.469 .01649 Mdot
.46905 .01647 Mdot
.4691 .01645 Mdot
.46915 .01642 Mdot
.46919 .0164 Mdot
.46924 .01638 Mdot
.46929 .01636 Mdot
.46934 .01634 Mdot
.46938 .01632 Mdot
.46943 .0163 Mdot
.46948 .01628 Mdot
.46953 .01626 Mdot
.46957 .01624 Mdot
.46962 .01622 Mdot
.46967 .01621 Mdot
.46972 .01619 Mdot
.46976 .01617 Mdot
.46981 .01615 Mdot
.46986 .01614 Mdot
.46991 .01612 Mdot
.46996 .0161 Mdot
.47 .01609 Mdot
.47005 .01607 Mdot
.4701 .01605 Mdot
.47015 .01604 Mdot
.47019 .01602 Mdot
.47024 .01601 Mdot
.47029 .01599 Mdot
.47034 .01598 Mdot
.47038 .01597 Mdot
.47043 .01595 Mdot
.47048 .01594 Mdot
.47053 .01592 Mdot
.47057 .01591 Mdot
.47062 .0159 Mdot
.47067 .01589 Mdot
.47072 .01588 Mdot
.47076 .01586 Mdot
.47081 .01585 Mdot
.47086 .01584 Mdot
.47091 .01583 Mdot
.47096 .01582 Mdot
.471 .01581 Mdot
.47105 .0158 Mdot
.4711 .01579 Mdot
.47115 .01578 Mdot
.47119 .01577 Mdot
.47124 .01576 Mdot
.47129 .01575 Mdot
.47134 .01575 Mdot
.47138 .01574 Mdot
.47143 .01573 Mdot
.47148 .01572 Mdot
.47153 .01572 Mdot
.47157 .01571 Mdot
.47162 .0157 Mdot
.47167 .0157 Mdot
.47172 .01569 Mdot
.47176 .01569 Mdot
.47181 .01568 Mdot
.47186 .01568 Mdot
.47191 .01567 Mdot
.47196 .01567 Mdot
.472 .01566 Mdot
.47205 .01566 Mdot
.4721 .01566 Mdot
.47215 .01565 Mdot
.47219 .01565 Mdot
.47224 .01565 Mdot
.47229 .01565 Mdot
.47234 .01564 Mdot
.47238 .01564 Mdot
.47243 .01564 Mdot
.47248 .01564 Mdot
.47253 .01564 Mdot
.47257 .01564 Mdot
.47262 .01564 Mdot
.47267 .01564 Mdot
.47272 .01564 Mdot
.47276 .01564 Mdot
.47281 .01564 Mdot
.47286 .01564 Mdot
.47291 .01564 Mdot
.47296 .01564 Mdot
.473 .01565 Mdot
.47305 .01565 Mdot
.4731 .01565 Mdot
.47315 .01565 Mdot
.47319 .01566 Mdot
.47324 .01566 Mdot
.47329 .01567 Mdot
.47334 .01567 Mdot
.47338 .01567 Mdot
.47343 .01568 Mdot
.47348 .01568 Mdot
.47353 .01569 Mdot
.47357 .01569 Mdot
.47362 .0157 Mdot
.47367 .01571 Mdot
.47372 .01571 Mdot
.47376 .01572 Mdot
.47381 .01573 Mdot
.47386 .01573 Mdot
.47391 .01574 Mdot
.47395 .01575 Mdot
.474 .01576 Mdot
.47405 .01577 Mdot
.4741 .01578 Mdot
.47415 .01578 Mdot
.47419 .01579 Mdot
.47424 .0158 Mdot
.47429 .01581 Mdot
.47434 .01582 Mdot
.47438 .01584 Mdot
.47443 .01585 Mdot
.47448 .01586 Mdot
.47453 .01587 Mdot
.47457 .01588 Mdot
.47462 .01589 Mdot
.47467 .0159 Mdot
.47472 .01592 Mdot
.47476 .01593 Mdot
.47481 .01594 Mdot
.47486 .01596 Mdot
.47491 .01597 Mdot
.47495 .01599 Mdot
.475 .016 Mdot
.47505 .01601 Mdot
.4751 .01603 Mdot
.47515 .01604 Mdot
.47519 .01606 Mdot
.47524 .01608 Mdot
.47529 .01609 Mdot
.47534 .01611 Mdot
.47538 .01613 Mdot
.47543 .01614 Mdot
.47548 .01616 Mdot
.47553 .01618 Mdot
.47557 .0162 Mdot
.47562 .01621 Mdot
.47567 .01623 Mdot
.47572 .01625 Mdot
.47576 .01627 Mdot
.47581 .01629 Mdot
.47586 .01631 Mdot
.47591 .01633 Mdot
.47595 .01635 Mdot
.476 .01637 Mdot
.47605 .01639 Mdot
.4761 .01641 Mdot
.47615 .01643 Mdot
.47619 .01646 Mdot
.47624 .01648 Mdot
.47629 .0165 Mdot
.47634 .01652 Mdot
.47638 .01655 Mdot
.47643 .01657 Mdot
.47648 .01659 Mdot
.47653 .01662 Mdot
.47657 .01664 Mdot
.47662 .01666 Mdot
.47667 .01669 Mdot
.47672 .01671 Mdot
.47676 .01674 Mdot
.47681 .01676 Mdot
.47686 .01679 Mdot
.47691 .01682 Mdot
.47695 .01684 Mdot
.477 .01687 Mdot
.47705 .0169 Mdot
.4771 .01692 Mdot
.47715 .01695 Mdot
.47719 .01698 Mdot
.47724 .01701 Mdot
.47729 .01704 Mdot
.47734 .01706 Mdot
.47738 .01709 Mdot
.47743 .01712 Mdot
.47748 .01715 Mdot
.47753 .01718 Mdot
.47757 .01721 Mdot
.47762 .01724 Mdot
.47767 .01727 Mdot
.47772 .01731 Mdot
.47776 .01734 Mdot
.47781 .01737 Mdot
.47786 .0174 Mdot
.47791 .01743 Mdot
.47795 .01747 Mdot
.478 .0175 Mdot
.47805 .01753 Mdot
.4781 .01756 Mdot
.47815 .0176 Mdot
.47819 .01763 Mdot
.47824 .01767 Mdot
.47829 .0177 Mdot
.47834 .01774 Mdot
.47838 .01777 Mdot
.47843 .01781 Mdot
.47848 .01784 Mdot
.47853 .01788 Mdot
.47857 .01791 Mdot
.47862 .01795 Mdot
.47867 .01799 Mdot
.47872 .01803 Mdot
.47876 .01806 Mdot
.47881 .0181 Mdot
.47886 .01814 Mdot
.47891 .01818 Mdot
.47895 .01822 Mdot
.479 .01825 Mdot
.47905 .01829 Mdot
.4791 .01833 Mdot
.47914 .01837 Mdot
.47919 .01841 Mdot
.47924 .01845 Mdot
.47929 .01849 Mdot
.47934 .01854 Mdot
.47938 .01858 Mdot
.47943 .01862 Mdot
.47948 .01866 Mdot
.47953 .0187 Mdot
.47957 .01874 Mdot
.47962 .01879 Mdot
.47967 .01883 Mdot
.47972 .01887 Mdot
.47976 .01892 Mdot
.47981 .01896 Mdot
.47986 .01901 Mdot
.47991 .01905 Mdot
.47995 .01909 Mdot
.48 .01914 Mdot
.48005 .01918 Mdot
.4801 .01923 Mdot
.48014 .01928 Mdot
.48019 .01932 Mdot
.48024 .01937 Mdot
.48029 .01942 Mdot
.48034 .01946 Mdot
.48038 .01951 Mdot
.48043 .01956 Mdot
.48048 .01961 Mdot
.48053 .01965 Mdot
.48057 .0197 Mdot
.48062 .01975 Mdot
.48067 .0198 Mdot
.48072 .01985 Mdot
.48076 .0199 Mdot
.48081 .01995 Mdot
.48086 .02 Mdot
.48091 .02005 Mdot
.48095 .0201 Mdot
.481 .02015 Mdot
.48105 .0202 Mdot
.4811 .02025 Mdot
.48114 .02031 Mdot
.48119 .02036 Mdot
.48124 .02041 Mdot
.48129 .02046 Mdot
.48134 .02052 Mdot
.48138 .02057 Mdot
.48143 .02062 Mdot
.48148 .02068 Mdot
.48153 .02073 Mdot
.48157 .02079 Mdot
.48162 .02084 Mdot
.48167 .0209 Mdot
.48172 .02095 Mdot
.48176 .02101 Mdot
.48181 .02106 Mdot
.48186 .02112 Mdot
.48191 .02118 Mdot
.48195 .02123 Mdot
.482 .02129 Mdot
.48205 .02135 Mdot
.4821 .02141 Mdot
.48214 .02146 Mdot
.48219 .02152 Mdot
.48224 .02158 Mdot
.48229 .02164 Mdot
.48234 .0217 Mdot
.48238 .02176 Mdot
.48243 .02182 Mdot
.48248 .02188 Mdot
.48253 .02194 Mdot
.48257 .022 Mdot
.48262 .02206 Mdot
.48267 .02212 Mdot
.48272 .02218 Mdot
.48276 .02225 Mdot
.48281 .02231 Mdot
.48286 .02237 Mdot
.48291 .02243 Mdot
.48295 .0225 Mdot
.483 .02256 Mdot
.48305 .02262 Mdot
.4831 .02269 Mdot
.48314 .02275 Mdot
.48319 .02281 Mdot
.48324 .02288 Mdot
.48329 .02294 Mdot
.48333 .02301 Mdot
.48338 .02307 Mdot
.48343 .02314 Mdot
.48348 .02321 Mdot
.48353 .02327 Mdot
.48357 .02334 Mdot
.48362 .02341 Mdot
.48367 .02347 Mdot
.48372 .02354 Mdot
.48376 .02361 Mdot
.48381 .02368 Mdot
.48386 .02374 Mdot
.48391 .02381 Mdot
.48395 .02388 Mdot
.484 .02395 Mdot
.48405 .02402 Mdot
.4841 .02409 Mdot
.48414 .02416 Mdot
.48419 .02423 Mdot
.48424 .0243 Mdot
.48429 .02437 Mdot
.48433 .02444 Mdot
.48438 .02452 Mdot
.48443 .02459 Mdot
.48448 .02466 Mdot
.48453 .02473 Mdot
.48457 .0248 Mdot
.48462 .02488 Mdot
.48467 .02495 Mdot
.48472 .02502 Mdot
.48476 .0251 Mdot
.48481 .02517 Mdot
.48486 .02525 Mdot
.48491 .02532 Mdot
.48495 .02539 Mdot
.485 .02547 Mdot
.48505 .02555 Mdot
.4851 .02562 Mdot
.48514 .0257 Mdot
.48519 .02577 Mdot
.48524 .02585 Mdot
.48529 .02593 Mdot
.48533 .026 Mdot
.48538 .02608 Mdot
.48543 .02616 Mdot
.48548 .02624 Mdot
.48553 .02632 Mdot
.48557 .02639 Mdot
.48562 .02647 Mdot
.48567 .02655 Mdot
.48572 .02663 Mdot
.48576 .02671 Mdot
.48581 .02679 Mdot
.48586 .02687 Mdot
.48591 .02695 Mdot
.48595 .02703 Mdot
.486 .02711 Mdot
.48605 .02719 Mdot
.4861 .02728 Mdot
.48614 .02736 Mdot
.48619 .02744 Mdot
.48624 .02752 Mdot
.48629 .02761 Mdot
.48633 .02769 Mdot
.48638 .02777 Mdot
.48643 .02786 Mdot
.48648 .02794 Mdot
.48653 .02802 Mdot
.48657 .02811 Mdot
.48662 .02819 Mdot
.48667 .02828 Mdot
.48672 .02836 Mdot
.48676 .02845 Mdot
.48681 .02853 Mdot
.48686 .02862 Mdot
.48691 .02871 Mdot
.48695 .02879 Mdot
.487 .02888 Mdot
.48705 .02897 Mdot
.4871 .02906 Mdot
.48714 .02914 Mdot
.48719 .02923 Mdot
.48724 .02932 Mdot
.48729 .02941 Mdot
.48733 .0295 Mdot
.48738 .02959 Mdot
.48743 .02968 Mdot
.48748 .02977 Mdot
.48753 .02986 Mdot
.48757 .02995 Mdot
.48762 .03004 Mdot
.48767 .03013 Mdot
.48772 .03022 Mdot
.48776 .03031 Mdot
.48781 .0304 Mdot
.48786 .03049 Mdot
.48791 .03059 Mdot
.48795 .03068 Mdot
.488 .03077 Mdot
.48805 .03087 Mdot
.4881 .03096 Mdot
.48814 .03105 Mdot
.48819 .03115 Mdot
.48824 .03124 Mdot
.48829 .03134 Mdot
.48833 .03143 Mdot
.48838 .03153 Mdot
.48843 .03162 Mdot
.48848 .03172 Mdot
.48852 .03181 Mdot
.48857 .03191 Mdot
.48862 .032 Mdot
.48867 .0321 Mdot
.48872 .0322 Mdot
.48876 .0323 Mdot
.48881 .03239 Mdot
.48886 .03249 Mdot
.48891 .03259 Mdot
.48895 .03269 Mdot
.489 .03279 Mdot
.48905 .03289 Mdot
.4891 .03298 Mdot
.48914 .03308 Mdot
.48919 .03318 Mdot
.48924 .03328 Mdot
.48929 .03338 Mdot
.48933 .03348 Mdot
.48938 .03359 Mdot
.48943 .03369 Mdot
.48948 .03379 Mdot
.48952 .03389 Mdot
.48957 .03399 Mdot
.48962 .03409 Mdot
.48967 .0342 Mdot
.48972 .0343 Mdot
.48976 .0344 Mdot
.48981 .03451 Mdot
.48986 .03461 Mdot
.48991 .03471 Mdot
.48995 .03482 Mdot
.49 .03492 Mdot
.49005 .03503 Mdot
.4901 .03513 Mdot
.49014 .03524 Mdot
.49019 .03534 Mdot
.49024 .03545 Mdot
.49029 .03555 Mdot
.49033 .03566 Mdot
.49038 .03577 Mdot
.49043 .03587 Mdot
.49048 .03598 Mdot
.49052 .03609 Mdot
.49057 .0362 Mdot
.49062 .0363 Mdot
.49067 .03641 Mdot
.49072 .03652 Mdot
.49076 .03663 Mdot
.49081 .03674 Mdot
.49086 .03685 Mdot
.49091 .03696 Mdot
.49095 .03707 Mdot
.491 .03718 Mdot
.49105 .03729 Mdot
.4911 .0374 Mdot
.49114 .03751 Mdot
.49119 .03762 Mdot
.49124 .03773 Mdot
.49129 .03785 Mdot
.49133 .03796 Mdot
.49138 .03807 Mdot
.49143 .03818 Mdot
.49148 .0383 Mdot
.49152 .03841 Mdot
.49157 .03852 Mdot
.49162 .03864 Mdot
.49167 .03875 Mdot
.49172 .03886 Mdot
.49176 .03898 Mdot
.49181 .03909 Mdot
.49186 .03921 Mdot
.49191 .03932 Mdot
.49195 .03944 Mdot
.492 .03955 Mdot
.49205 .03967 Mdot
.4921 .03979 Mdot
.49214 .0399 Mdot
.49219 .04002 Mdot
.49224 .04014 Mdot
.49229 .04026 Mdot
.49233 .04037 Mdot
.49238 .04049 Mdot
.49243 .04061 Mdot
.49248 .04073 Mdot
.49252 .04085 Mdot
.49257 .04097 Mdot
.49262 .04109 Mdot
.49267 .0412 Mdot
.49272 .04132 Mdot
.49276 .04144 Mdot
.49281 .04157 Mdot
.49286 .04169 Mdot
.49291 .04181 Mdot
.49295 .04193 Mdot
.493 .04205 Mdot
.49305 .04217 Mdot
.4931 .04229 Mdot
.49314 .04242 Mdot
.49319 .04254 Mdot
.49324 .04266 Mdot
.49329 .04278 Mdot
.49333 .04291 Mdot
.49338 .04303 Mdot
.49343 .04316 Mdot
.49348 .04328 Mdot
.49352 .0434 Mdot
.49357 .04353 Mdot
.49362 .04365 Mdot
.49367 .04378 Mdot
.49371 .0439 Mdot
.49376 .04403 Mdot
.49381 .04416 Mdot
.49386 .04428 Mdot
.49391 .04441 Mdot
.49395 .04454 Mdot
.494 .04466 Mdot
.49405 .04479 Mdot
.4941 .04492 Mdot
.49414 .04505 Mdot
.49419 .04517 Mdot
.49424 .0453 Mdot
.49429 .04543 Mdot
.49433 .04556 Mdot
.49438 .04569 Mdot
.49443 .04582 Mdot
.49448 .04595 Mdot
.49452 .04608 Mdot
.49457 .04621 Mdot
.49462 .04634 Mdot
.49467 .04647 Mdot
.49471 .0466 Mdot
.49476 .04673 Mdot
.49481 .04686 Mdot
.49486 .04699 Mdot
.49491 .04713 Mdot
.49495 .04726 Mdot
.495 .04739 Mdot
.49505 .04752 Mdot
.4951 .04766 Mdot
.49514 .04779 Mdot
.49519 .04792 Mdot
.49524 .04806 Mdot
.49529 .04819 Mdot
.49533 .04833 Mdot
.49538 .04846 Mdot
.49543 .0486 Mdot
.49548 .04873 Mdot
.49552 .04887 Mdot
.49557 .049 Mdot
.49562 .04914 Mdot
.49567 .04928 Mdot
.49571 .04941 Mdot
.49576 .04955 Mdot
.49581 .04969 Mdot
.49586 .04982 Mdot
.49591 .04996 Mdot
.49595 .0501 Mdot
.496 .05024 Mdot
.49605 .05037 Mdot
.4961 .05051 Mdot
.49614 .05065 Mdot
.49619 .05079 Mdot
.49624 .05093 Mdot
.49629 .05107 Mdot
.49633 .05121 Mdot
.49638 .05135 Mdot
.49643 .05149 Mdot
.49648 .05163 Mdot
.49652 .05177 Mdot
.49657 .05191 Mdot
.49662 .05205 Mdot
.49667 .0522 Mdot
.49671 .05234 Mdot
.49676 .05248 Mdot
.49681 .05262 Mdot
.49686 .05277 Mdot
.49691 .05291 Mdot
.49695 .05305 Mdot
.497 .05319 Mdot
.49705 .05334 Mdot
.4971 .05348 Mdot
.49714 .05363 Mdot
.49719 .05377 Mdot
.49724 .05392 Mdot
.49729 .05406 Mdot
.49733 .05421 Mdot
.49738 .05435 Mdot
.49743 .0545 Mdot
.49748 .05464 Mdot
.49752 .05479 Mdot
.49757 .05494 Mdot
.49762 .05508 Mdot
.49767 .05523 Mdot
.49771 .05538 Mdot
.49776 .05552 Mdot
.49781 .05567 Mdot
.49786 .05582 Mdot
.4979 .05597 Mdot
.49795 .05612 Mdot
.498 .05627 Mdot
.49805 .05642 Mdot
.4981 .05656 Mdot
.49814 .05671 Mdot
.49819 .05686 Mdot
.49824 .05701 Mdot
.49829 .05716 Mdot
.49833 .05732 Mdot
.49838 .05747 Mdot
.49843 .05762 Mdot
.49848 .05777 Mdot
.49852 .05792 Mdot
.49857 .05807 Mdot
.49862 .05822 Mdot
.49867 .05838 Mdot
.49871 .05853 Mdot
.49876 .05868 Mdot
.49881 .05883 Mdot
.49886 .05899 Mdot
.4989 .05914 Mdot
.49895 .0593 Mdot
.499 .05945 Mdot
.49905 .0596 Mdot
.4991 .05976 Mdot
.49914 .05991 Mdot
.49919 .06007 Mdot
.49924 .06022 Mdot
.49929 .06038 Mdot
.49933 .06053 Mdot
.49938 .06069 Mdot
.49943 .06085 Mdot
.49948 .061 Mdot
.49952 .06116 Mdot
.49957 .06132 Mdot
.49962 .06147 Mdot
.49967 .06163 Mdot
.49971 .06179 Mdot
.49976 .06195 Mdot
.49981 .06211 Mdot
.49986 .06227 Mdot
.4999 .06242 Mdot
.49995 .06258 Mdot
.5 .06274 Mdot
.50005 .0629 Mdot
.5001 .06306 Mdot
.50014 .06322 Mdot
.50019 .06338 Mdot
.50024 .06354 Mdot
.50029 .0637 Mdot
.50033 .06386 Mdot
.50038 .06403 Mdot
.50043 .06419 Mdot
.50048 .06435 Mdot
.50052 .06451 Mdot
.50057 .06467 Mdot
.50062 .06484 Mdot
.50067 .065 Mdot
.50071 .06516 Mdot
.50076 .06532 Mdot
.50081 .06549 Mdot
.50086 .06565 Mdot
.5009 .06582 Mdot
.50095 .06598 Mdot
.501 .06614 Mdot
.50105 .06631 Mdot
.5011 .06647 Mdot
.50114 .06664 Mdot
.50119 .0668 Mdot
.50124 .06697 Mdot
.50129 .06714 Mdot
.50133 .0673 Mdot
.50138 .06747 Mdot
.50143 .06763 Mdot
.50148 .0678 Mdot
.50152 .06797 Mdot
.50157 .06814 Mdot
.50162 .0683 Mdot
.50167 .06847 Mdot
.50171 .06864 Mdot
.50176 .06881 Mdot
.50181 .06898 Mdot
.50186 .06914 Mdot
.5019 .06931 Mdot
.50195 .06948 Mdot
.502 .06965 Mdot
.50205 .06982 Mdot
.5021 .06999 Mdot
.50214 .07016 Mdot
.50219 .07033 Mdot
.50224 .0705 Mdot
.50229 .07067 Mdot
.50233 .07085 Mdot
.50238 .07102 Mdot
.50243 .07119 Mdot
.50248 .07136 Mdot
.50252 .07153 Mdot
.50257 .0717 Mdot
.50262 .07188 Mdot
.50267 .07205 Mdot
.50271 .07222 Mdot
.50276 .0724 Mdot
.50281 .07257 Mdot
.50286 .07274 Mdot
.5029 .07292 Mdot
.50295 .07309 Mdot
.503 .07327 Mdot
.50305 .07344 Mdot
.50309 .07362 Mdot
.50314 .07379 Mdot
.50319 .07397 Mdot
.50324 .07414 Mdot
.50329 .07432 Mdot
.50333 .07449 Mdot
.50338 .07467 Mdot
.50343 .07485 Mdot
.50348 .07502 Mdot
.50352 .0752 Mdot
.50357 .07538 Mdot
.50362 .07556 Mdot
.50367 .07573 Mdot
.50371 .07591 Mdot
.50376 .07609 Mdot
.50381 .07627 Mdot
.50386 .07645 Mdot
.5039 .07663 Mdot
.50395 .0768 Mdot
.504 .07698 Mdot
.50405 .07716 Mdot
.50409 .07734 Mdot
.50414 .07752 Mdot
.50419 .0777 Mdot
.50424 .07788 Mdot
.50429 .07807 Mdot
.50433 .07825 Mdot
.50438 .07843 Mdot
.50443 .07861 Mdot
.50448 .07879 Mdot
.50452 .07897 Mdot
.50457 .07915 Mdot
.50462 .07934 Mdot
.50467 .07952 Mdot
.50471 .0797 Mdot
.50476 .07989 Mdot
.50481 .08007 Mdot
.50486 .08025 Mdot
.5049 .08044 Mdot
.50495 .08062 Mdot
.505 .0808 Mdot
.50505 .08099 Mdot
.50509 .08117 Mdot
.50514 .08136 Mdot
.50519 .08154 Mdot
.50524 .08173 Mdot
.50529 .08191 Mdot
.50533 .0821 Mdot
.50538 .08229 Mdot
.50543 .08247 Mdot
.50548 .08266 Mdot
.50552 .08285 Mdot
.50557 .08303 Mdot
.50562 .08322 Mdot
.50567 .08341 Mdot
.50571 .08359 Mdot
.50576 .08378 Mdot
.50581 .08397 Mdot
.50586 .08416 Mdot
.5059 .08435 Mdot
.50595 .08454 Mdot
.506 .08473 Mdot
.50605 .08491 Mdot
.50609 .0851 Mdot
.50614 .08529 Mdot
.50619 .08548 Mdot
.50624 .08567 Mdot
.50629 .08586 Mdot
.50633 .08605 Mdot
.50638 .08625 Mdot
.50643 .08644 Mdot
.50648 .08663 Mdot
.50652 .08682 Mdot
.50657 .08701 Mdot
.50662 .0872 Mdot
.50667 .08739 Mdot
.50671 .08759 Mdot
.50676 .08778 Mdot
.50681 .08797 Mdot
.50686 .08816 Mdot
.5069 .08836 Mdot
.50695 .08855 Mdot
.507 .08875 Mdot
.50705 .08894 Mdot
.50709 .08913 Mdot
.50714 .08933 Mdot
.50719 .08952 Mdot
.50724 .08972 Mdot
.50728 .08991 Mdot
.50733 .09011 Mdot
.50738 .0903 Mdot
.50743 .0905 Mdot
.50748 .09069 Mdot
.50752 .09089 Mdot
.50757 .09109 Mdot
.50762 .09128 Mdot
.50767 .09148 Mdot
.50771 .09168 Mdot
.50776 .09187 Mdot
.50781 .09207 Mdot
.50786 .09227 Mdot
.5079 .09247 Mdot
.50795 .09266 Mdot
.508 .09286 Mdot
.50805 .09306 Mdot
.50809 .09326 Mdot
.50814 .09346 Mdot
.50819 .09366 Mdot
.50824 .09386 Mdot
.50828 .09406 Mdot
.50833 .09426 Mdot
.50838 .09446 Mdot
.50843 .09466 Mdot
.50848 .09486 Mdot
.50852 .09506 Mdot
.50857 .09526 Mdot
.50862 .09546 Mdot
.50867 .09566 Mdot
.50871 .09586 Mdot
.50876 .09606 Mdot
.50881 .09626 Mdot
.50886 .09647 Mdot
.5089 .09667 Mdot
.50895 .09687 Mdot
.509 .09707 Mdot
.50905 .09728 Mdot
.50909 .09748 Mdot
.50914 .09768 Mdot
.50919 .09789 Mdot
.50924 .09809 Mdot
.50928 .0983 Mdot
.50933 .0985 Mdot
.50938 .0987 Mdot
.50943 .09891 Mdot
.50948 .09911 Mdot
.50952 .09932 Mdot
.50957 .09952 Mdot
.50962 .09973 Mdot
.50967 .09993 Mdot
.50971 .10014 Mdot
.50976 .10035 Mdot
.50981 .10055 Mdot
.50986 .10076 Mdot
.5099 .10097 Mdot
.50995 .10117 Mdot
.51 .10138 Mdot
.51005 .10159 Mdot
.51009 .10179 Mdot
.51014 .102 Mdot
.51019 .10221 Mdot
.51024 .10242 Mdot
.51028 .10263 Mdot
.51033 .10284 Mdot
.51038 .10304 Mdot
.51043 .10325 Mdot
.51048 .10346 Mdot
.51052 .10367 Mdot
.51057 .10388 Mdot
.51062 .10409 Mdot
.51067 .1043 Mdot
.51071 .10451 Mdot
.51076 .10472 Mdot
.51081 .10493 Mdot
.51086 .10514 Mdot
.5109 .10535 Mdot
.51095 .10557 Mdot
.511 .10578 Mdot
.51105 .10599 Mdot
.51109 .1062 Mdot
.51114 .10641 Mdot
.51119 .10663 Mdot
.51124 .10684 Mdot
.51128 .10705 Mdot
.51133 .10726 Mdot
.51138 .10748 Mdot
.51143 .10769 Mdot
.51148 .1079 Mdot
.51152 .10812 Mdot
.51157 .10833 Mdot
.51162 .10854 Mdot
.51167 .10876 Mdot
.51171 .10897 Mdot
.51176 .10919 Mdot
.51181 .1094 Mdot
.51186 .10962 Mdot
.5119 .10983 Mdot
.51195 .11005 Mdot
.512 .11026 Mdot
.51205 .11048 Mdot
.51209 .1107 Mdot
.51214 .11091 Mdot
.51219 .11113 Mdot
.51224 .11135 Mdot
.51228 .11156 Mdot
.51233 .11178 Mdot
.51238 .112 Mdot
.51243 .11221 Mdot
.51247 .11243 Mdot
.51252 .11265 Mdot
.51257 .11287 Mdot
.51262 .11309 Mdot
.51267 .1133 Mdot
.51271 .11352 Mdot
.51276 .11374 Mdot
.51281 .11396 Mdot
.51286 .11418 Mdot
.5129 .1144 Mdot
.51295 .11462 Mdot
.513 .11484 Mdot
.51305 .11506 Mdot
.51309 .11528 Mdot
.51314 .1155 Mdot
.51319 .11572 Mdot
.51324 .11594 Mdot
.51328 .11616 Mdot
.51333 .11638 Mdot
.51338 .1166 Mdot
.51343 .11683 Mdot
.51347 .11705 Mdot
.51352 .11727 Mdot
.51357 .11749 Mdot
.51362 .11771 Mdot
.51367 .11794 Mdot
.51371 .11816 Mdot
.51376 .11838 Mdot
.51381 .1186 Mdot
.51386 .11883 Mdot
.5139 .11905 Mdot
.51395 .11927 Mdot
.514 .1195 Mdot
.51405 .11972 Mdot
.51409 .11995 Mdot
.51414 .12017 Mdot
.51419 .1204 Mdot
.51424 .12062 Mdot
.51428 .12085 Mdot
.51433 .12107 Mdot
.51438 .1213 Mdot
.51443 .12152 Mdot
.51447 .12175 Mdot
.51452 .12197 Mdot
.51457 .1222 Mdot
.51462 .12243 Mdot
.51467 .12265 Mdot
.51471 .12288 Mdot
.51476 .12311 Mdot
.51481 .12333 Mdot
.51486 .12356 Mdot
.5149 .12379 Mdot
.51495 .12401 Mdot
.515 .12424 Mdot
.51505 .12447 Mdot
.51509 .1247 Mdot
.51514 .12493 Mdot
.51519 .12516 Mdot
.51524 .12538 Mdot
.51528 .12561 Mdot
.51533 .12584 Mdot
.51538 .12607 Mdot
.51543 .1263 Mdot
.51547 .12653 Mdot
.51552 .12676 Mdot
.51557 .12699 Mdot
.51562 .12722 Mdot
.51567 .12745 Mdot
.51571 .12768 Mdot
.51576 .12791 Mdot
.51581 .12814 Mdot
.51586 .12837 Mdot
.5159 .1286 Mdot
.51595 .12884 Mdot
.516 .12907 Mdot
.51605 .1293 Mdot
.51609 .12953 Mdot
.51614 .12976 Mdot
.51619 .13 Mdot
.51624 .13023 Mdot
.51628 .13046 Mdot
.51633 .13069 Mdot
.51638 .13093 Mdot
.51643 .13116 Mdot
.51647 .13139 Mdot
.51652 .13163 Mdot
.51657 .13186 Mdot
.51662 .13209 Mdot
.51667 .13233 Mdot
.51671 .13256 Mdot
.51676 .1328 Mdot
.51681 .13303 Mdot
.51686 .13327 Mdot
.5169 .1335 Mdot
.51695 .13374 Mdot
.517 .13397 Mdot
.51705 .13421 Mdot
.51709 .13444 Mdot
.51714 .13468 Mdot
.51719 .13492 Mdot
.51724 .13515 Mdot
.51728 .13539 Mdot
.51733 .13562 Mdot
.51738 .13586 Mdot
.51743 .1361 Mdot
.51747 .13633 Mdot
.51752 .13657 Mdot
.51757 .13681 Mdot
.51762 .13705 Mdot
.51766 .13728 Mdot
.51771 .13752 Mdot
.51776 .13776 Mdot
.51781 .138 Mdot
.51786 .13824 Mdot
.5179 .13848 Mdot
.51795 .13871 Mdot
.518 .13895 Mdot
.51805 .13919 Mdot
.51809 .13943 Mdot
.51814 .13967 Mdot
.51819 .13991 Mdot
.51824 .14015 Mdot
.51828 .14039 Mdot
.51833 .14063 Mdot
.51838 .14087 Mdot
.51843 .14111 Mdot
.51847 .14135 Mdot
.51852 .14159 Mdot
.51857 .14183 Mdot
.51862 .14208 Mdot
.51866 .14232 Mdot
.51871 .14256 Mdot
.51876 .1428 Mdot
.51881 .14304 Mdot
.51886 .14328 Mdot
.5189 .14353 Mdot
.51895 .14377 Mdot
.519 .14401 Mdot
.51905 .14425 Mdot
.51909 .1445 Mdot
.51914 .14474 Mdot
.51919 .14498 Mdot
.51924 .14523 Mdot
.51928 .14547 Mdot
.51933 .14571 Mdot
.51938 .14596 Mdot
.51943 .1462 Mdot
.51947 .14644 Mdot
.51952 .14669 Mdot
.51957 .14693 Mdot
.51962 .14718 Mdot
.51966 .14742 Mdot
.51971 .14767 Mdot
.51976 .14791 Mdot
.51981 .14816 Mdot
.51986 .1484 Mdot
.5199 .14865 Mdot
.51995 .14889 Mdot
.52 .14914 Mdot
.52005 .14939 Mdot
.52009 .14963 Mdot
.52014 .14988 Mdot
.52019 .15013 Mdot
.52024 .15037 Mdot
.52028 .15062 Mdot
.52033 .15087 Mdot
.52038 .15111 Mdot
.52043 .15136 Mdot
.52047 .15161 Mdot
.52052 .15186 Mdot
.52057 .1521 Mdot
.52062 .15235 Mdot
.52066 .1526 Mdot
.52071 .15285 Mdot
.52076 .1531 Mdot
.52081 .15334 Mdot
.52086 .15359 Mdot
.5209 .15384 Mdot
.52095 .15409 Mdot
.521 .15434 Mdot
.52105 .15459 Mdot
.52109 .15484 Mdot
.52114 .15509 Mdot
.52119 .15534 Mdot
.52124 .15559 Mdot
.52128 .15584 Mdot
.52133 .15609 Mdot
.52138 .15634 Mdot
.52143 .15659 Mdot
.52147 .15684 Mdot
.52152 .15709 Mdot
.52157 .15734 Mdot
.52162 .15759 Mdot
.52166 .15784 Mdot
.52171 .1581 Mdot
.52176 .15835 Mdot
.52181 .1586 Mdot
.52185 .15885 Mdot
.5219 .1591 Mdot
.52195 .15936 Mdot
.522 .15961 Mdot
.52205 .15986 Mdot
.52209 .16011 Mdot
.52214 .16037 Mdot
.52219 .16062 Mdot
.52224 .16087 Mdot
.52228 .16113 Mdot
.52233 .16138 Mdot
.52238 .16163 Mdot
.52243 .16189 Mdot
.52247 .16214 Mdot
.52252 .16239 Mdot
.52257 .16265 Mdot
.52262 .1629 Mdot
.52266 .16316 Mdot
.52271 .16341 Mdot
.52276 .16367 Mdot
.52281 .16392 Mdot
.52285 .16418 Mdot
.5229 .16443 Mdot
.52295 .16469 Mdot
.523 .16494 Mdot
.52305 .1652 Mdot
.52309 .16545 Mdot
.52314 .16571 Mdot
.52319 .16597 Mdot
.52324 .16622 Mdot
.52328 .16648 Mdot
.52333 .16673 Mdot
.52338 .16699 Mdot
.52343 .16725 Mdot
.52347 .1675 Mdot
.52352 .16776 Mdot
.52357 .16802 Mdot
.52362 .16828 Mdot
.52366 .16853 Mdot
.52371 .16879 Mdot
.52376 .16905 Mdot
.52381 .16931 Mdot
.52385 .16957 Mdot
.5239 .16982 Mdot
.52395 .17008 Mdot
.524 .17034 Mdot
.52405 .1706 Mdot
.52409 .17086 Mdot
.52414 .17112 Mdot
.52419 .17138 Mdot
.52424 .17163 Mdot
.52428 .17189 Mdot
.52433 .17215 Mdot
.52438 .17241 Mdot
.52443 .17267 Mdot
.52447 .17293 Mdot
.52452 .17319 Mdot
.52457 .17345 Mdot
.52462 .17371 Mdot
.52466 .17397 Mdot
.52471 .17423 Mdot
.52476 .17449 Mdot
.52481 .17475 Mdot
.52485 .17502 Mdot
.5249 .17528 Mdot
.52495 .17554 Mdot
.525 .1758 Mdot
.52505 .17606 Mdot
.52509 .17632 Mdot
.52514 .17658 Mdot
.52519 .17685 Mdot
.52524 .17711 Mdot
.52528 .17737 Mdot
.52533 .17763 Mdot
.52538 .17789 Mdot
.52543 .17816 Mdot
.52547 .17842 Mdot
.52552 .17868 Mdot
.52557 .17894 Mdot
.52562 .17921 Mdot
.52566 .17947 Mdot
.52571 .17973 Mdot
.52576 .18 Mdot
.52581 .18026 Mdot
.52585 .18052 Mdot
.5259 .18079 Mdot
.52595 .18105 Mdot
.526 .18132 Mdot
.52605 .18158 Mdot
.52609 .18184 Mdot
.52614 .18211 Mdot
.52619 .18237 Mdot
.52624 .18264 Mdot
.52628 .1829 Mdot
.52633 .18317 Mdot
.52638 .18343 Mdot
.52643 .1837 Mdot
.52647 .18396 Mdot
.52652 .18423 Mdot
.52657 .18449 Mdot
.52662 .18476 Mdot
.52666 .18503 Mdot
.52671 .18529 Mdot
.52676 .18556 Mdot
.52681 .18582 Mdot
.52685 .18609 Mdot
.5269 .18636 Mdot
.52695 .18662 Mdot
.527 .18689 Mdot
.52704 .18716 Mdot
.52709 .18742 Mdot
.52714 .18769 Mdot
.52719 .18796 Mdot
.52724 .18823 Mdot
.52728 .18849 Mdot
.52733 .18876 Mdot
.52738 .18903 Mdot
.52743 .1893 Mdot
.52747 .18956 Mdot
.52752 .18983 Mdot
.52757 .1901 Mdot
.52762 .19037 Mdot
.52766 .19064 Mdot
.52771 .1909 Mdot
.52776 .19117 Mdot
.52781 .19144 Mdot
.52785 .19171 Mdot
.5279 .19198 Mdot
.52795 .19225 Mdot
.528 .19252 Mdot
.52804 .19279 Mdot
.52809 .19306 Mdot
.52814 .19333 Mdot
.52819 .1936 Mdot
.52824 .19387 Mdot
.52828 .19414 Mdot
.52833 .19441 Mdot
.52838 .19468 Mdot
.52843 .19495 Mdot
.52847 .19522 Mdot
.52852 .19549 Mdot
.52857 .19576 Mdot
.52862 .19603 Mdot
.52866 .1963 Mdot
.52871 .19657 Mdot
.52876 .19684 Mdot
.52881 .19711 Mdot
.52885 .19738 Mdot
.5289 .19765 Mdot
.52895 .19793 Mdot
.529 .1982 Mdot
.52904 .19847 Mdot
.52909 .19874 Mdot
.52914 .19901 Mdot
.52919 .19928 Mdot
.52924 .19956 Mdot
.52928 .19983 Mdot
.52933 .2001 Mdot
.52938 .20037 Mdot
.52943 .20065 Mdot
.52947 .20092 Mdot
.52952 .20119 Mdot
.52957 .20146 Mdot
.52962 .20174 Mdot
.52966 .20201 Mdot
.52971 .20228 Mdot
.52976 .20256 Mdot
.52981 .20283 Mdot
.52985 .2031 Mdot
.5299 .20338 Mdot
.52995 .20365 Mdot
.53 .20393 Mdot
.53004 .2042 Mdot
.53009 .20447 Mdot
.53014 .20475 Mdot
.53019 .20502 Mdot
.53024 .2053 Mdot
.53028 .20557 Mdot
.53033 .20585 Mdot
.53038 .20612 Mdot
.53043 .20639 Mdot
.53047 .20667 Mdot
.53052 .20694 Mdot
.53057 .20722 Mdot
.53062 .20749 Mdot
.53066 .20777 Mdot
.53071 .20805 Mdot
.53076 .20832 Mdot
.53081 .2086 Mdot
.53085 .20887 Mdot
.5309 .20915 Mdot
.53095 .20942 Mdot
.531 .2097 Mdot
.53104 .20998 Mdot
.53109 .21025 Mdot
.53114 .21053 Mdot
.53119 .2108 Mdot
.53123 .21108 Mdot
.53128 .21136 Mdot
.53133 .21163 Mdot
.53138 .21191 Mdot
.53143 .21219 Mdot
.53147 .21247 Mdot
.53152 .21274 Mdot
.53157 .21302 Mdot
.53162 .2133 Mdot
.53166 .21357 Mdot
.53171 .21385 Mdot
.53176 .21413 Mdot
.53181 .21441 Mdot
.53185 .21468 Mdot
.5319 .21496 Mdot
.53195 .21524 Mdot
.532 .21552 Mdot
.53204 .2158 Mdot
.53209 .21607 Mdot
.53214 .21635 Mdot
.53219 .21663 Mdot
.53223 .21691 Mdot
.53228 .21719 Mdot
.53233 .21747 Mdot
.53238 .21775 Mdot
.53243 .21802 Mdot
.53247 .2183 Mdot
.53252 .21858 Mdot
.53257 .21886 Mdot
.53262 .21914 Mdot
.53266 .21942 Mdot
.53271 .2197 Mdot
.53276 .21998 Mdot
.53281 .22026 Mdot
.53285 .22054 Mdot
.5329 .22082 Mdot
.53295 .2211 Mdot
.533 .22138 Mdot
.53304 .22166 Mdot
.53309 .22194 Mdot
.53314 .22222 Mdot
.53319 .2225 Mdot
.53323 .22278 Mdot
.53328 .22306 Mdot
.53333 .22334 Mdot
.53338 .22362 Mdot
.53343 .2239 Mdot
.53347 .22418 Mdot
.53352 .22446 Mdot
.53357 .22474 Mdot
.53362 .22502 Mdot
.53366 .22531 Mdot
.53371 .22559 Mdot
.53376 .22587 Mdot
.53381 .22615 Mdot
.53385 .22643 Mdot
.5339 .22671 Mdot
.53395 .22699 Mdot
.534 .22728 Mdot
.53404 .22756 Mdot
.53409 .22784 Mdot
.53414 .22812 Mdot
.53419 .2284 Mdot
.53423 .22869 Mdot
.53428 .22897 Mdot
.53433 .22925 Mdot
.53438 .22953 Mdot
.53443 .22981 Mdot
.53447 .2301 Mdot
.53452 .23038 Mdot
.53457 .23066 Mdot
.53462 .23095 Mdot
.53466 .23123 Mdot
.53471 .23151 Mdot
.53476 .23179 Mdot
.53481 .23208 Mdot
.53485 .23236 Mdot
.5349 .23264 Mdot
.53495 .23293 Mdot
.535 .23321 Mdot
.53504 .23349 Mdot
.53509 .23378 Mdot
.53514 .23406 Mdot
.53519 .23434 Mdot
.53523 .23463 Mdot
.53528 .23491 Mdot
.53533 .2352 Mdot
.53538 .23548 Mdot
.53543 .23576 Mdot
.53547 .23605 Mdot
.53552 .23633 Mdot
.53557 .23662 Mdot
.53562 .2369 Mdot
.53566 .23718 Mdot
.53571 .23747 Mdot
.53576 .23775 Mdot
.53581 .23804 Mdot
.53585 .23832 Mdot
.5359 .23861 Mdot
.53595 .23889 Mdot
.536 .23918 Mdot
.53604 .23946 Mdot
.53609 .23975 Mdot
.53614 .24003 Mdot
.53619 .24032 Mdot
.53623 .2406 Mdot
.53628 .24089 Mdot
.53633 .24117 Mdot
.53638 .24146 Mdot
.53642 .24174 Mdot
.53647 .24203 Mdot
.53652 .24232 Mdot
.53657 .2426 Mdot
.53662 .24289 Mdot
.53666 .24317 Mdot
.53671 .24346 Mdot
.53676 .24375 Mdot
.53681 .24403 Mdot
.53685 .24432 Mdot
.5369 .2446 Mdot
.53695 .24489 Mdot
.537 .24518 Mdot
.53704 .24546 Mdot
.53709 .24575 Mdot
.53714 .24604 Mdot
.53719 .24632 Mdot
.53723 .24661 Mdot
.53728 .2469 Mdot
.53733 .24718 Mdot
.53738 .24747 Mdot
.53742 .24776 Mdot
.53747 .24804 Mdot
.53752 .24833 Mdot
.53757 .24862 Mdot
.53762 .2489 Mdot
.53766 .24919 Mdot
.53771 .24948 Mdot
.53776 .24977 Mdot
.53781 .25005 Mdot
.53785 .25034 Mdot
.5379 .25063 Mdot
.53795 .25092 Mdot
.538 .2512 Mdot
.53804 .25149 Mdot
.53809 .25178 Mdot
.53814 .25207 Mdot
.53819 .25235 Mdot
.53823 .25264 Mdot
.53828 .25293 Mdot
.53833 .25322 Mdot
.53838 .25351 Mdot
.53842 .25379 Mdot
.53847 .25408 Mdot
.53852 .25437 Mdot
.53857 .25466 Mdot
.53862 .25495 Mdot
.53866 .25523 Mdot
.53871 .25552 Mdot
.53876 .25581 Mdot
.53881 .2561 Mdot
.53885 .25639 Mdot
.5389 .25668 Mdot
.53895 .25697 Mdot
.539 .25725 Mdot
.53904 .25754 Mdot
.53909 .25783 Mdot
.53914 .25812 Mdot
.53919 .25841 Mdot
.53923 .2587 Mdot
.53928 .25899 Mdot
.53933 .25928 Mdot
.53938 .25957 Mdot
.53942 .25986 Mdot
.53947 .26015 Mdot
.53952 .26043 Mdot
.53957 .26072 Mdot
.53962 .26101 Mdot
.53966 .2613 Mdot
.53971 .26159 Mdot
.53976 .26188 Mdot
.53981 .26217 Mdot
.53985 .26246 Mdot
.5399 .26275 Mdot
.53995 .26304 Mdot
.54 .26333 Mdot
.54004 .26362 Mdot
.54009 .26391 Mdot
.54014 .2642 Mdot
.54019 .26449 Mdot
.54023 .26478 Mdot
.54028 .26507 Mdot
.54033 .26536 Mdot
.54038 .26565 Mdot
.54042 .26594 Mdot
.54047 .26623 Mdot
.54052 .26652 Mdot
.54057 .26681 Mdot
.54061 .2671 Mdot
.54066 .26739 Mdot
.54071 .26768 Mdot
.54076 .26797 Mdot
.54081 .26826 Mdot
.54085 .26855 Mdot
.5409 .26884 Mdot
.54095 .26913 Mdot
.541 .26943 Mdot
.54104 .26972 Mdot
.54109 .27001 Mdot
.54114 .2703 Mdot
.54119 .27059 Mdot
.54123 .27088 Mdot
.54128 .27117 Mdot
.54133 .27146 Mdot
.54138 .27175 Mdot
.54142 .27204 Mdot
.54147 .27233 Mdot
.54152 .27263 Mdot
.54157 .27292 Mdot
.54161 .27321 Mdot
.54166 .2735 Mdot
.54171 .27379 Mdot
.54176 .27408 Mdot
.54181 .27437 Mdot
.54185 .27466 Mdot
.5419 .27496 Mdot
.54195 .27525 Mdot
.542 .27554 Mdot
.54204 .27583 Mdot
.54209 .27612 Mdot
.54214 .27641 Mdot
.54219 .2767 Mdot
.54223 .277 Mdot
.54228 .27729 Mdot
.54233 .27758 Mdot
.54238 .27787 Mdot
.54242 .27816 Mdot
.54247 .27845 Mdot
.54252 .27875 Mdot
.54257 .27904 Mdot
.54261 .27933 Mdot
.54266 .27962 Mdot
.54271 .27991 Mdot
.54276 .28021 Mdot
.54281 .2805 Mdot
.54285 .28079 Mdot
.5429 .28108 Mdot
.54295 .28137 Mdot
.543 .28167 Mdot
.54304 .28196 Mdot
.54309 .28225 Mdot
.54314 .28254 Mdot
.54319 .28283 Mdot
.54323 .28313 Mdot
.54328 .28342 Mdot
.54333 .28371 Mdot
.54338 .284 Mdot
.54342 .2843 Mdot
.54347 .28459 Mdot
.54352 .28488 Mdot
.54357 .28517 Mdot
.54361 .28546 Mdot
.54366 .28576 Mdot
.54371 .28605 Mdot
.54376 .28634 Mdot
.54381 .28663 Mdot
.54385 .28693 Mdot
.5439 .28722 Mdot
.54395 .28751 Mdot
.544 .28781 Mdot
.54404 .2881 Mdot
.54409 .28839 Mdot
.54414 .28868 Mdot
.54419 .28898 Mdot
.54423 .28927 Mdot
.54428 .28956 Mdot
.54433 .28985 Mdot
.54438 .29015 Mdot
.54442 .29044 Mdot
.54447 .29073 Mdot
.54452 .29102 Mdot
.54457 .29132 Mdot
.54461 .29161 Mdot
.54466 .2919 Mdot
.54471 .2922 Mdot
.54476 .29249 Mdot
.54481 .29278 Mdot
.54485 .29308 Mdot
.5449 .29337 Mdot
.54495 .29366 Mdot
.545 .29395 Mdot
.54504 .29425 Mdot
.54509 .29454 Mdot
.54514 .29483 Mdot
.54519 .29513 Mdot
.54523 .29542 Mdot
.54528 .29571 Mdot
.54533 .29601 Mdot
.54538 .2963 Mdot
.54542 .29659 Mdot
.54547 .29688 Mdot
.54552 .29718 Mdot
.54557 .29747 Mdot
.54561 .29776 Mdot
.54566 .29806 Mdot
.54571 .29835 Mdot
.54576 .29864 Mdot
.5458 .29894 Mdot
.54585 .29923 Mdot
.5459 .29952 Mdot
.54595 .29982 Mdot
.546 .30011 Mdot
.54604 .3004 Mdot
.54609 .3007 Mdot
.54614 .30099 Mdot
.54619 .30128 Mdot
.54623 .30158 Mdot
.54628 .30187 Mdot
.54633 .30216 Mdot
.54638 .30246 Mdot
.54642 .30275 Mdot
.54647 .30304 Mdot
.54652 .30334 Mdot
.54657 .30363 Mdot
.54661 .30392 Mdot
.54666 .30422 Mdot
.54671 .30451 Mdot
.54676 .3048 Mdot
.5468 .3051 Mdot
.54685 .30539 Mdot
.5469 .30568 Mdot
.54695 .30598 Mdot
.547 .30627 Mdot
.54704 .30656 Mdot
.54709 .30686 Mdot
.54714 .30715 Mdot
.54719 .30744 Mdot
.54723 .30774 Mdot
.54728 .30803 Mdot
.54733 .30832 Mdot
.54738 .30862 Mdot
.54742 .30891 Mdot
.54747 .3092 Mdot
.54752 .3095 Mdot
.54757 .30979 Mdot
.54761 .31008 Mdot
.54766 .31038 Mdot
.54771 .31067 Mdot
.54776 .31096 Mdot
.5478 .31126 Mdot
.54785 .31155 Mdot
.5479 .31184 Mdot
.54795 .31214 Mdot
.548 .31243 Mdot
.54804 .31272 Mdot
.54809 .31302 Mdot
.54814 .31331 Mdot
.54819 .3136 Mdot
.54823 .3139 Mdot
.54828 .31419 Mdot
.54833 .31448 Mdot
.54838 .31478 Mdot
.54842 .31507 Mdot
.54847 .31536 Mdot
.54852 .31566 Mdot
.54857 .31595 Mdot
.54861 .31624 Mdot
.54866 .31654 Mdot
.54871 .31683 Mdot
.54876 .31712 Mdot
.5488 .31742 Mdot
.54885 .31771 Mdot
.5489 .318 Mdot
.54895 .3183 Mdot
.549 .31859 Mdot
.54904 .31888 Mdot
.54909 .31918 Mdot
.54914 .31947 Mdot
.54919 .31976 Mdot
.54923 .32006 Mdot
.54928 .32035 Mdot
.54933 .32064 Mdot
.54938 .32093 Mdot
.54942 .32123 Mdot
.54947 .32152 Mdot
.54952 .32181 Mdot
.54957 .32211 Mdot
.54961 .3224 Mdot
.54966 .32269 Mdot
.54971 .32299 Mdot
.54976 .32328 Mdot
.5498 .32357 Mdot
.54985 .32387 Mdot
.5499 .32416 Mdot
.54995 .32445 Mdot
.55 .32474 Mdot
.55004 .32504 Mdot
.55009 .32533 Mdot
.55014 .32562 Mdot
.55019 .32592 Mdot
.55023 .32621 Mdot
.55028 .3265 Mdot
.55033 .32679 Mdot
.55038 .32709 Mdot
.55042 .32738 Mdot
.55047 .32767 Mdot
.55052 .32797 Mdot
.55057 .32826 Mdot
.55061 .32855 Mdot
.55066 .32884 Mdot
.55071 .32914 Mdot
.55076 .32943 Mdot
.5508 .32972 Mdot
.55085 .33002 Mdot
.5509 .33031 Mdot
.55095 .3306 Mdot
.55099 .33089 Mdot
.55104 .33119 Mdot
.55109 .33148 Mdot
.55114 .33177 Mdot
.55119 .33206 Mdot
.55123 .33236 Mdot
.55128 .33265 Mdot
.55133 .33294 Mdot
.55138 .33323 Mdot
.55142 .33353 Mdot
.55147 .33382 Mdot
.55152 .33411 Mdot
.55157 .3344 Mdot
.55161 .33469 Mdot
.55166 .33499 Mdot
.55171 .33528 Mdot
.55176 .33557 Mdot
.5518 .33586 Mdot
.55185 .33616 Mdot
.5519 .33645 Mdot
.55195 .33674 Mdot
.55199 .33703 Mdot
.55204 .33732 Mdot
.55209 .33762 Mdot
.55214 .33791 Mdot
.55219 .3382 Mdot
.55223 .33849 Mdot
.55228 .33878 Mdot
.55233 .33908 Mdot
.55238 .33937 Mdot
.55242 .33966 Mdot
.55247 .33995 Mdot
.55252 .34024 Mdot
.55257 .34053 Mdot
.55261 .34083 Mdot
.55266 .34112 Mdot
.55271 .34141 Mdot
.55276 .3417 Mdot
.5528 .34199 Mdot
.55285 .34228 Mdot
.5529 .34258 Mdot
.55295 .34287 Mdot
.55299 .34316 Mdot
.55304 .34345 Mdot
.55309 .34374 Mdot
.55314 .34403 Mdot
.55319 .34432 Mdot
.55323 .34461 Mdot
.55328 .34491 Mdot
.55333 .3452 Mdot
.55338 .34549 Mdot
.55342 .34578 Mdot
.55347 .34607 Mdot
.55352 .34636 Mdot
.55357 .34665 Mdot
.55361 .34694 Mdot
.55366 .34723 Mdot
.55371 .34752 Mdot
.55376 .34782 Mdot
.5538 .34811 Mdot
.55385 .3484 Mdot
.5539 .34869 Mdot
.55395 .34898 Mdot
.55399 .34927 Mdot
.55404 .34956 Mdot
.55409 .34985 Mdot
.55414 .35014 Mdot
.55419 .35043 Mdot
.55423 .35072 Mdot
.55428 .35101 Mdot
.55433 .3513 Mdot
.55438 .35159 Mdot
.55442 .35188 Mdot
.55447 .35217 Mdot
.55452 .35246 Mdot
.55457 .35275 Mdot
.55461 .35304 Mdot
.55466 .35333 Mdot
.55471 .35362 Mdot
.55476 .35391 Mdot
.5548 .3542 Mdot
.55485 .35449 Mdot
.5549 .35478 Mdot
.55495 .35507 Mdot
.55499 .35536 Mdot
.55504 .35565 Mdot
.55509 .35594 Mdot
.55514 .35623 Mdot
.55518 .35652 Mdot
.55523 .35681 Mdot
.55528 .3571 Mdot
.55533 .35739 Mdot
.55538 .35768 Mdot
.55542 .35797 Mdot
.55547 .35826 Mdot
.55552 .35855 Mdot
.55557 .35884 Mdot
.55561 .35912 Mdot
.55566 .35941 Mdot
.55571 .3597 Mdot
.55576 .35999 Mdot
.5558 .36028 Mdot
.55585 .36057 Mdot
.5559 .36086 Mdot
.55595 .36115 Mdot
.55599 .36144 Mdot
.55604 .36172 Mdot
.55609 .36201 Mdot
.55614 .3623 Mdot
.55618 .36259 Mdot
.55623 .36288 Mdot
.55628 .36317 Mdot
.55633 .36346 Mdot
.55638 .36374 Mdot
.55642 .36403 Mdot
.55647 .36432 Mdot
.55652 .36461 Mdot
.55657 .3649 Mdot
.55661 .36518 Mdot
.55666 .36547 Mdot
.55671 .36576 Mdot
.55676 .36605 Mdot
.5568 .36634 Mdot
.55685 .36662 Mdot
.5569 .36691 Mdot
.55695 .3672 Mdot
.55699 .36749 Mdot
.55704 .36777 Mdot
.55709 .36806 Mdot
.55714 .36835 Mdot
.55718 .36864 Mdot
.55723 .36892 Mdot
.55728 .36921 Mdot
.55733 .3695 Mdot
.55738 .36978 Mdot
.55742 .37007 Mdot
.55747 .37036 Mdot
.55752 .37064 Mdot
.55757 .37093 Mdot
.55761 .37122 Mdot
.55766 .37151 Mdot
.55771 .37179 Mdot
.55776 .37208 Mdot
.5578 .37236 Mdot
.55785 .37265 Mdot
.5579 .37294 Mdot
.55795 .37322 Mdot
.55799 .37351 Mdot
.55804 .3738 Mdot
.55809 .37408 Mdot
.55814 .37437 Mdot
.55818 .37465 Mdot
.55823 .37494 Mdot
.55828 .37523 Mdot
.55833 .37551 Mdot
.55838 .3758 Mdot
.55842 .37608 Mdot
.55847 .37637 Mdot
.55852 .37665 Mdot
.55857 .37694 Mdot
.55861 .37723 Mdot
.55866 .37751 Mdot
.55871 .3778 Mdot
.55876 .37808 Mdot
.5588 .37837 Mdot
.55885 .37865 Mdot
.5589 .37894 Mdot
.55895 .37922 Mdot
.55899 .37951 Mdot
.55904 .37979 Mdot
.55909 .38008 Mdot
.55914 .38036 Mdot
.55918 .38064 Mdot
.55923 .38093 Mdot
.55928 .38121 Mdot
.55933 .3815 Mdot
.55938 .38178 Mdot
.55942 .38207 Mdot
.55947 .38235 Mdot
.55952 .38263 Mdot
.55957 .38292 Mdot
.55961 .3832 Mdot
.55966 .38349 Mdot
.55971 .38377 Mdot
.55976 .38405 Mdot
.5598 .38434 Mdot
.55985 .38462 Mdot
.5599 .3849 Mdot
.55995 .38519 Mdot
.55999 .38547 Mdot
.56004 .38575 Mdot
.56009 .38604 Mdot
.56014 .38632 Mdot
.56018 .3866 Mdot
.56023 .38689 Mdot
.56028 .38717 Mdot
.56033 .38745 Mdot
.56037 .38773 Mdot
.56042 .38802 Mdot
.56047 .3883 Mdot
.56052 .38858 Mdot
.56057 .38886 Mdot
.56061 .38915 Mdot
.56066 .38943 Mdot
.56071 .38971 Mdot
.56076 .38999 Mdot
.5608 .39027 Mdot
.56085 .39056 Mdot
.5609 .39084 Mdot
.56095 .39112 Mdot
.56099 .3914 Mdot
.56104 .39168 Mdot
.56109 .39197 Mdot
.56114 .39225 Mdot
.56118 .39253 Mdot
.56123 .39281 Mdot
.56128 .39309 Mdot
.56133 .39337 Mdot
.56137 .39365 Mdot
.56142 .39393 Mdot
.56147 .39421 Mdot
.56152 .39449 Mdot
.56157 .39478 Mdot
.56161 .39506 Mdot
.56166 .39534 Mdot
.56171 .39562 Mdot
.56176 .3959 Mdot
.5618 .39618 Mdot
.56185 .39646 Mdot
.5619 .39674 Mdot
.56195 .39702 Mdot
.56199 .3973 Mdot
.56204 .39758 Mdot
.56209 .39786 Mdot
.56214 .39814 Mdot
.56218 .39842 Mdot
.56223 .39869 Mdot
.56228 .39897 Mdot
.56233 .39925 Mdot
.56237 .39953 Mdot
.56242 .39981 Mdot
.56247 .40009 Mdot
.56252 .40037 Mdot
.56257 .40065 Mdot
.56261 .40093 Mdot
.56266 .40121 Mdot
.56271 .40148 Mdot
.56276 .40176 Mdot
.5628 .40204 Mdot
.56285 .40232 Mdot
.5629 .4026 Mdot
.56295 .40287 Mdot
.56299 .40315 Mdot
.56304 .40343 Mdot
.56309 .40371 Mdot
.56314 .40399 Mdot
.56318 .40426 Mdot
.56323 .40454 Mdot
.56328 .40482 Mdot
.56333 .4051 Mdot
.56337 .40537 Mdot
.56342 .40565 Mdot
.56347 .40593 Mdot
.56352 .4062 Mdot
.56357 .40648 Mdot
.56361 .40676 Mdot
.56366 .40703 Mdot
.56371 .40731 Mdot
.56376 .40759 Mdot
.5638 .40786 Mdot
.56385 .40814 Mdot
.5639 .40842 Mdot
.56395 .40869 Mdot
.56399 .40897 Mdot
.56404 .40924 Mdot
.56409 .40952 Mdot
.56414 .40979 Mdot
.56418 .41007 Mdot
.56423 .41035 Mdot
.56428 .41062 Mdot
.56433 .4109 Mdot
.56437 .41117 Mdot
.56442 .41145 Mdot
.56447 .41172 Mdot
.56452 .412 Mdot
.56456 .41227 Mdot
.56461 .41254 Mdot
.56466 .41282 Mdot
.56471 .41309 Mdot
.56476 .41337 Mdot
.5648 .41364 Mdot
.56485 .41392 Mdot
.5649 .41419 Mdot
.56495 .41446 Mdot
.56499 .41474 Mdot
.56504 .41501 Mdot
.56509 .41528 Mdot
.56514 .41556 Mdot
.56518 .41583 Mdot
.56523 .4161 Mdot
.56528 .41638 Mdot
.56533 .41665 Mdot
.56537 .41692 Mdot
.56542 .4172 Mdot
.56547 .41747 Mdot
.56552 .41774 Mdot
.56556 .41801 Mdot
.56561 .41829 Mdot
.56566 .41856 Mdot
.56571 .41883 Mdot
.56576 .4191 Mdot
.5658 .41937 Mdot
.56585 .41965 Mdot
.5659 .41992 Mdot
.56595 .42019 Mdot
.56599 .42046 Mdot
.56604 .42073 Mdot
.56609 .421 Mdot
.56614 .42128 Mdot
.56618 .42155 Mdot
.56623 .42182 Mdot
.56628 .42209 Mdot
.56633 .42236 Mdot
.56637 .42263 Mdot
.56642 .4229 Mdot
.56647 .42317 Mdot
.56652 .42344 Mdot
.56656 .42371 Mdot
.56661 .42398 Mdot
.56666 .42425 Mdot
.56671 .42452 Mdot
.56676 .42479 Mdot
.5668 .42506 Mdot
.56685 .42533 Mdot
.5669 .4256 Mdot
.56695 .42587 Mdot
.56699 .42614 Mdot
.56704 .4264 Mdot
.56709 .42667 Mdot
.56714 .42694 Mdot
.56718 .42721 Mdot
.56723 .42748 Mdot
.56728 .42775 Mdot
.56733 .42802 Mdot
.56737 .42828 Mdot
.56742 .42855 Mdot
.56747 .42882 Mdot
.56752 .42909 Mdot
.56756 .42936 Mdot
.56761 .42962 Mdot
.56766 .42989 Mdot
.56771 .43016 Mdot
.56776 .43042 Mdot
.5678 .43069 Mdot
.56785 .43096 Mdot
.5679 .43123 Mdot
.56795 .43149 Mdot
.56799 .43176 Mdot
.56804 .43203 Mdot
.56809 .43229 Mdot
.56814 .43256 Mdot
.56818 .43282 Mdot
.56823 .43309 Mdot
.56828 .43336 Mdot
.56833 .43362 Mdot
.56837 .43389 Mdot
.56842 .43415 Mdot
.56847 .43442 Mdot
.56852 .43468 Mdot
.56856 .43495 Mdot
.56861 .43521 Mdot
.56866 .43548 Mdot
.56871 .43574 Mdot
.56876 .43601 Mdot
.5688 .43627 Mdot
.56885 .43654 Mdot
.5689 .4368 Mdot
.56895 .43706 Mdot
.56899 .43733 Mdot
.56904 .43759 Mdot
.56909 .43786 Mdot
.56914 .43812 Mdot
.56918 .43838 Mdot
.56923 .43865 Mdot
.56928 .43891 Mdot
.56933 .43917 Mdot
.56937 .43943 Mdot
.56942 .4397 Mdot
.56947 .43996 Mdot
.56952 .44022 Mdot
.56956 .44048 Mdot
.56961 .44075 Mdot
.56966 .44101 Mdot
.56971 .44127 Mdot
.56975 .44153 Mdot
.5698 .44179 Mdot
.56985 .44206 Mdot
.5699 .44232 Mdot
.56995 .44258 Mdot
.56999 .44284 Mdot
.57004 .4431 Mdot
.57009 .44336 Mdot
.57014 .44362 Mdot
.57018 .44388 Mdot
.57023 .44414 Mdot
.57028 .4444 Mdot
.57033 .44466 Mdot
.57037 .44492 Mdot
.57042 .44518 Mdot
.57047 .44544 Mdot
.57052 .4457 Mdot
.57056 .44596 Mdot
.57061 .44622 Mdot
.57066 .44648 Mdot
.57071 .44674 Mdot
.57075 .447 Mdot
.5708 .44726 Mdot
.57085 .44752 Mdot
.5709 .44778 Mdot
.57095 .44804 Mdot
.57099 .44829 Mdot
.57104 .44855 Mdot
.57109 .44881 Mdot
.57114 .44907 Mdot
.57118 .44933 Mdot
.57123 .44958 Mdot
.57128 .44984 Mdot
.57133 .4501 Mdot
.57137 .45035 Mdot
.57142 .45061 Mdot
.57147 .45087 Mdot
.57152 .45113 Mdot
.57156 .45138 Mdot
.57161 .45164 Mdot
.57166 .4519 Mdot
.57171 .45215 Mdot
.57175 .45241 Mdot
.5718 .45266 Mdot
.57185 .45292 Mdot
.5719 .45317 Mdot
.57195 .45343 Mdot
.57199 .45369 Mdot
.57204 .45394 Mdot
.57209 .4542 Mdot
.57214 .45445 Mdot
.57218 .45471 Mdot
.57223 .45496 Mdot
.57228 .45521 Mdot
.57233 .45547 Mdot
.57237 .45572 Mdot
.57242 .45598 Mdot
.57247 .45623 Mdot
.57252 .45648 Mdot
.57256 .45674 Mdot
.57261 .45699 Mdot
.57266 .45724 Mdot
.57271 .4575 Mdot
.57275 .45775 Mdot
.5728 .458 Mdot
.57285 .45826 Mdot
.5729 .45851 Mdot
.57295 .45876 Mdot
.57299 .45901 Mdot
.57304 .45927 Mdot
.57309 .45952 Mdot
.57314 .45977 Mdot
.57318 .46002 Mdot
.57323 .46027 Mdot
.57328 .46052 Mdot
.57333 .46077 Mdot
.57337 .46103 Mdot
.57342 .46128 Mdot
.57347 .46153 Mdot
.57352 .46178 Mdot
.57356 .46203 Mdot
.57361 .46228 Mdot
.57366 .46253 Mdot
.57371 .46278 Mdot
.57375 .46303 Mdot
.5738 .46328 Mdot
.57385 .46353 Mdot
.5739 .46378 Mdot
.57394 .46403 Mdot
.57399 .46428 Mdot
.57404 .46452 Mdot
.57409 .46477 Mdot
.57414 .46502 Mdot
.57418 .46527 Mdot
.57423 .46552 Mdot
.57428 .46577 Mdot
.57433 .46601 Mdot
.57437 .46626 Mdot
.57442 .46651 Mdot
.57447 .46676 Mdot
.57452 .467 Mdot
.57456 .46725 Mdot
.57461 .4675 Mdot
.57466 .46775 Mdot
.57471 .46799 Mdot
.57475 .46824 Mdot
.5748 .46849 Mdot
.57485 .46873 Mdot
.5749 .46898 Mdot
.57494 .46922 Mdot
.57499 .46947 Mdot
.57504 .46971 Mdot
.57509 .46996 Mdot
.57514 .47021 Mdot
.57518 .47045 Mdot
.57523 .4707 Mdot
.57528 .47094 Mdot
.57533 .47118 Mdot
.57537 .47143 Mdot
.57542 .47167 Mdot
.57547 .47192 Mdot
.57552 .47216 Mdot
.57556 .47241 Mdot
.57561 .47265 Mdot
.57566 .47289 Mdot
.57571 .47314 Mdot
.57575 .47338 Mdot
.5758 .47362 Mdot
.57585 .47386 Mdot
.5759 .47411 Mdot
.57594 .47435 Mdot
.57599 .47459 Mdot
.57604 .47483 Mdot
.57609 .47508 Mdot
.57614 .47532 Mdot
.57618 .47556 Mdot
.57623 .4758 Mdot
.57628 .47604 Mdot
.57633 .47628 Mdot
.57637 .47652 Mdot
.57642 .47677 Mdot
.57647 .47701 Mdot
.57652 .47725 Mdot
.57656 .47749 Mdot
.57661 .47773 Mdot
.57666 .47797 Mdot
.57671 .47821 Mdot
.57675 .47845 Mdot
.5768 .47869 Mdot
.57685 .47892 Mdot
.5769 .47916 Mdot
.57694 .4794 Mdot
.57699 .47964 Mdot
.57704 .47988 Mdot
.57709 .48012 Mdot
.57714 .48036 Mdot
.57718 .48059 Mdot
.57723 .48083 Mdot
.57728 .48107 Mdot
.57733 .48131 Mdot
.57737 .48155 Mdot
.57742 .48178 Mdot
.57747 .48202 Mdot
.57752 .48226 Mdot
.57756 .48249 Mdot
.57761 .48273 Mdot
.57766 .48297 Mdot
.57771 .4832 Mdot
.57775 .48344 Mdot
.5778 .48367 Mdot
.57785 .48391 Mdot
.5779 .48415 Mdot
.57794 .48438 Mdot
.57799 .48462 Mdot
.57804 .48485 Mdot
.57809 .48509 Mdot
.57814 .48532 Mdot
.57818 .48555 Mdot
.57823 .48579 Mdot
.57828 .48602 Mdot
.57833 .48626 Mdot
.57837 .48649 Mdot
.57842 .48672 Mdot
.57847 .48696 Mdot
.57852 .48719 Mdot
.57856 .48742 Mdot
.57861 .48766 Mdot
.57866 .48789 Mdot
.57871 .48812 Mdot
.57875 .48835 Mdot
.5788 .48859 Mdot
.57885 .48882 Mdot
.5789 .48905 Mdot
.57894 .48928 Mdot
.57899 .48951 Mdot
.57904 .48974 Mdot
.57909 .48998 Mdot
.57913 .49021 Mdot
.57918 .49044 Mdot
.57923 .49067 Mdot
.57928 .4909 Mdot
.57933 .49113 Mdot
.57937 .49136 Mdot
.57942 .49159 Mdot
.57947 .49182 Mdot
.57952 .49205 Mdot
.57956 .49228 Mdot
.57961 .4925 Mdot
.57966 .49273 Mdot
.57971 .49296 Mdot
.57975 .49319 Mdot
.5798 .49342 Mdot
.57985 .49365 Mdot
.5799 .49388 Mdot
.57994 .4941 Mdot
.57999 .49433 Mdot
.58004 .49456 Mdot
.58009 .49479 Mdot
.58013 .49501 Mdot
.58018 .49524 Mdot
.58023 .49547 Mdot
.58028 .49569 Mdot
.58033 .49592 Mdot
.58037 .49614 Mdot
.58042 .49637 Mdot
.58047 .4966 Mdot
.58052 .49682 Mdot
.58056 .49705 Mdot
.58061 .49727 Mdot
.58066 .4975 Mdot
.58071 .49772 Mdot
.58075 .49795 Mdot
.5808 .49817 Mdot
.58085 .4984 Mdot
.5809 .49862 Mdot
.58094 .49884 Mdot
.58099 .49907 Mdot
.58104 .49929 Mdot
.58109 .49951 Mdot
.58113 .49974 Mdot
.58118 .49996 Mdot
.58123 .50018 Mdot
.58128 .5004 Mdot
.58133 .50063 Mdot
.58137 .50085 Mdot
.58142 .50107 Mdot
.58147 .50129 Mdot
.58152 .50151 Mdot
.58156 .50174 Mdot
.58161 .50196 Mdot
.58166 .50218 Mdot
.58171 .5024 Mdot
.58175 .50262 Mdot
.5818 .50284 Mdot
.58185 .50306 Mdot
.5819 .50328 Mdot
.58194 .5035 Mdot
.58199 .50372 Mdot
.58204 .50394 Mdot
.58209 .50416 Mdot
.58213 .50438 Mdot
.58218 .50459 Mdot
.58223 .50481 Mdot
.58228 .50503 Mdot
.58233 .50525 Mdot
.58237 .50547 Mdot
.58242 .50569 Mdot
.58247 .5059 Mdot
.58252 .50612 Mdot
.58256 .50634 Mdot
.58261 .50656 Mdot
.58266 .50677 Mdot
.58271 .50699 Mdot
.58275 .50721 Mdot
.5828 .50742 Mdot
.58285 .50764 Mdot
.5829 .50785 Mdot
.58294 .50807 Mdot
.58299 .50828 Mdot
.58304 .5085 Mdot
.58309 .50871 Mdot
.58313 .50893 Mdot
.58318 .50914 Mdot
.58323 .50936 Mdot
.58328 .50957 Mdot
.58333 .50979 Mdot
.58337 .51 Mdot
.58342 .51021 Mdot
.58347 .51043 Mdot
.58352 .51064 Mdot
.58356 .51085 Mdot
.58361 .51107 Mdot
.58366 .51128 Mdot
.58371 .51149 Mdot
.58375 .5117 Mdot
.5838 .51192 Mdot
.58385 .51213 Mdot
.5839 .51234 Mdot
.58394 .51255 Mdot
.58399 .51276 Mdot
.58404 .51297 Mdot
.58409 .51318 Mdot
.58413 .5134 Mdot
.58418 .51361 Mdot
.58423 .51382 Mdot
.58428 .51403 Mdot
.58432 .51424 Mdot
.58437 .51445 Mdot
.58442 .51465 Mdot
.58447 .51486 Mdot
.58452 .51507 Mdot
.58456 .51528 Mdot
.58461 .51549 Mdot
.58466 .5157 Mdot
.58471 .51591 Mdot
.58475 .51611 Mdot
.5848 .51632 Mdot
.58485 .51653 Mdot
.5849 .51674 Mdot
.58494 .51694 Mdot
.58499 .51715 Mdot
.58504 .51736 Mdot
.58509 .51756 Mdot
.58513 .51777 Mdot
.58518 .51798 Mdot
.58523 .51818 Mdot
.58528 .51839 Mdot
.58532 .51859 Mdot
.58537 .5188 Mdot
.58542 .519 Mdot
.58547 .51921 Mdot
.58552 .51941 Mdot
.58556 .51962 Mdot
.58561 .51982 Mdot
.58566 .52003 Mdot
.58571 .52023 Mdot
.58575 .52043 Mdot
.5858 .52064 Mdot
.58585 .52084 Mdot
.5859 .52104 Mdot
.58594 .52125 Mdot
.58599 .52145 Mdot
.58604 .52165 Mdot
.58609 .52185 Mdot
.58613 .52205 Mdot
.58618 .52226 Mdot
.58623 .52246 Mdot
.58628 .52266 Mdot
.58632 .52286 Mdot
.58637 .52306 Mdot
.58642 .52326 Mdot
.58647 .52346 Mdot
.58652 .52366 Mdot
.58656 .52386 Mdot
.58661 .52406 Mdot
.58666 .52426 Mdot
.58671 .52446 Mdot
.58675 .52466 Mdot
.5868 .52486 Mdot
.58685 .52506 Mdot
.5869 .52525 Mdot
.58694 .52545 Mdot
.58699 .52565 Mdot
.58704 .52585 Mdot
.58709 .52605 Mdot
.58713 .52624 Mdot
.58718 .52644 Mdot
.58723 .52664 Mdot
.58728 .52683 Mdot
.58732 .52703 Mdot
.58737 .52723 Mdot
.58742 .52742 Mdot
.58747 .52762 Mdot
.58752 .52781 Mdot
.58756 .52801 Mdot
.58761 .5282 Mdot
.58766 .5284 Mdot
.58771 .52859 Mdot
.58775 .52879 Mdot
.5878 .52898 Mdot
.58785 .52918 Mdot
.5879 .52937 Mdot
.58794 .52956 Mdot
.58799 .52976 Mdot
.58804 .52995 Mdot
.58809 .53014 Mdot
.58813 .53034 Mdot
.58818 .53053 Mdot
.58823 .53072 Mdot
.58828 .53091 Mdot
.58832 .53111 Mdot
.58837 .5313 Mdot
.58842 .53149 Mdot
.58847 .53168 Mdot
.58851 .53187 Mdot
.58856 .53206 Mdot
.58861 .53225 Mdot
.58866 .53244 Mdot
.58871 .53263 Mdot
.58875 .53282 Mdot
.5888 .53301 Mdot
.58885 .5332 Mdot
.5889 .53339 Mdot
.58894 .53358 Mdot
.58899 .53377 Mdot
.58904 .53396 Mdot
.58909 .53414 Mdot
.58913 .53433 Mdot
.58918 .53452 Mdot
.58923 .53471 Mdot
.58928 .5349 Mdot
.58932 .53508 Mdot
.58937 .53527 Mdot
.58942 .53546 Mdot
.58947 .53564 Mdot
.58951 .53583 Mdot
.58956 .53601 Mdot
.58961 .5362 Mdot
.58966 .53639 Mdot
.58971 .53657 Mdot
.58975 .53676 Mdot
.5898 .53694 Mdot
.58985 .53713 Mdot
.5899 .53731 Mdot
.58994 .53749 Mdot
.58999 .53768 Mdot
.59004 .53786 Mdot
.59009 .53805 Mdot
.59013 .53823 Mdot
.59018 .53841 Mdot
.59023 .5386 Mdot
.59028 .53878 Mdot
.59032 .53896 Mdot
.59037 .53914 Mdot
.59042 .53932 Mdot
.59047 .53951 Mdot
.59051 .53969 Mdot
.59056 .53987 Mdot
.59061 .54005 Mdot
.59066 .54023 Mdot
.59071 .54041 Mdot
.59075 .54059 Mdot
.5908 .54077 Mdot
.59085 .54095 Mdot
.5909 .54113 Mdot
.59094 .54131 Mdot
.59099 .54149 Mdot
.59104 .54167 Mdot
.59109 .54185 Mdot
.59113 .54202 Mdot
.59118 .5422 Mdot
.59123 .54238 Mdot
.59128 .54256 Mdot
.59132 .54274 Mdot
.59137 .54291 Mdot
.59142 .54309 Mdot
.59147 .54327 Mdot
.59151 .54344 Mdot
.59156 .54362 Mdot
.59161 .5438 Mdot
.59166 .54397 Mdot
.59171 .54415 Mdot
.59175 .54432 Mdot
.5918 .5445 Mdot
.59185 .54467 Mdot
.5919 .54485 Mdot
.59194 .54502 Mdot
.59199 .5452 Mdot
.59204 .54537 Mdot
.59209 .54554 Mdot
.59213 .54572 Mdot
.59218 .54589 Mdot
.59223 .54606 Mdot
.59228 .54624 Mdot
.59232 .54641 Mdot
.59237 .54658 Mdot
.59242 .54675 Mdot
.59247 .54693 Mdot
.59251 .5471 Mdot
.59256 .54727 Mdot
.59261 .54744 Mdot
.59266 .54761 Mdot
.59271 .54778 Mdot
.59275 .54795 Mdot
.5928 .54812 Mdot
.59285 .54829 Mdot
.5929 .54846 Mdot
.59294 .54863 Mdot
.59299 .5488 Mdot
.59304 .54897 Mdot
.59309 .54914 Mdot
.59313 .54931 Mdot
.59318 .54947 Mdot
.59323 .54964 Mdot
.59328 .54981 Mdot
.59332 .54998 Mdot
.59337 .55014 Mdot
.59342 .55031 Mdot
.59347 .55048 Mdot
.59351 .55064 Mdot
.59356 .55081 Mdot
.59361 .55098 Mdot
.59366 .55114 Mdot
.5937 .55131 Mdot
.59375 .55147 Mdot
.5938 .55164 Mdot
.59385 .5518 Mdot
.5939 .55197 Mdot
.59394 .55213 Mdot
.59399 .5523 Mdot
.59404 .55246 Mdot
.59409 .55262 Mdot
.59413 .55279 Mdot
.59418 .55295 Mdot
.59423 .55311 Mdot
.59428 .55328 Mdot
.59432 .55344 Mdot
.59437 .5536 Mdot
.59442 .55376 Mdot
.59447 .55392 Mdot
.59451 .55409 Mdot
.59456 .55425 Mdot
.59461 .55441 Mdot
.59466 .55457 Mdot
.5947 .55473 Mdot
.59475 .55489 Mdot
.5948 .55505 Mdot
.59485 .55521 Mdot
.5949 .55537 Mdot
.59494 .55553 Mdot
.59499 .55569 Mdot
.59504 .55585 Mdot
.59509 .556 Mdot
.59513 .55616 Mdot
.59518 .55632 Mdot
.59523 .55648 Mdot
.59528 .55664 Mdot
.59532 .55679 Mdot
.59537 .55695 Mdot
.59542 .55711 Mdot
.59547 .55726 Mdot
.59551 .55742 Mdot
.59556 .55758 Mdot
.59561 .55773 Mdot
.59566 .55789 Mdot
.5957 .55804 Mdot
.59575 .5582 Mdot
.5958 .55835 Mdot
.59585 .55851 Mdot
.5959 .55866 Mdot
.59594 .55881 Mdot
.59599 .55897 Mdot
.59604 .55912 Mdot
.59609 .55928 Mdot
.59613 .55943 Mdot
.59618 .55958 Mdot
.59623 .55973 Mdot
.59628 .55989 Mdot
.59632 .56004 Mdot
.59637 .56019 Mdot
.59642 .56034 Mdot
.59647 .56049 Mdot
.59651 .56064 Mdot
.59656 .56079 Mdot
.59661 .56094 Mdot
.59666 .56109 Mdot
.5967 .56124 Mdot
.59675 .56139 Mdot
.5968 .56154 Mdot
.59685 .56169 Mdot
.5969 .56184 Mdot
.59694 .56199 Mdot
.59699 .56214 Mdot
.59704 .56229 Mdot
.59709 .56244 Mdot
.59713 .56258 Mdot
.59718 .56273 Mdot
.59723 .56288 Mdot
.59728 .56303 Mdot
.59732 .56317 Mdot
.59737 .56332 Mdot
.59742 .56346 Mdot
.59747 .56361 Mdot
.59751 .56376 Mdot
.59756 .5639 Mdot
.59761 .56405 Mdot
.59766 .56419 Mdot
.5977 .56434 Mdot
.59775 .56448 Mdot
.5978 .56462 Mdot
.59785 .56477 Mdot
.59789 .56491 Mdot
.59794 .56506 Mdot
.59799 .5652 Mdot
.59804 .56534 Mdot
.59809 .56548 Mdot
.59813 .56563 Mdot
.59818 .56577 Mdot
.59823 .56591 Mdot
.59828 .56605 Mdot
.59832 .56619 Mdot
.59837 .56633 Mdot
.59842 .56648 Mdot
.59847 .56662 Mdot
.59851 .56676 Mdot
.59856 .5669 Mdot
.59861 .56704 Mdot
.59866 .56718 Mdot
.5987 .56732 Mdot
.59875 .56745 Mdot
.5988 .56759 Mdot
.59885 .56773 Mdot
.59889 .56787 Mdot
.59894 .56801 Mdot
.59899 .56815 Mdot
.59904 .56828 Mdot
.59909 .56842 Mdot
.59913 .56856 Mdot
.59918 .56869 Mdot
.59923 .56883 Mdot
.59928 .56897 Mdot
.59932 .5691 Mdot
.59937 .56924 Mdot
.59942 .56937 Mdot
.59947 .56951 Mdot
.59951 .56964 Mdot
.59956 .56978 Mdot
.59961 .56991 Mdot
.59966 .57005 Mdot
.5997 .57018 Mdot
.59975 .57031 Mdot
.5998 .57045 Mdot
.59985 .57058 Mdot
.59989 .57071 Mdot
.59994 .57085 Mdot
.59999 .57098 Mdot
.60004 .57111 Mdot
.60009 .57124 Mdot
.60013 .57137 Mdot
.60018 .5715 Mdot
.60023 .57163 Mdot
.60028 .57177 Mdot
.60032 .5719 Mdot
.60037 .57203 Mdot
.60042 .57216 Mdot
.60047 .57229 Mdot
.60051 .57242 Mdot
.60056 .57254 Mdot
.60061 .57267 Mdot
.60066 .5728 Mdot
.6007 .57293 Mdot
.60075 .57306 Mdot
.6008 .57319 Mdot
.60085 .57331 Mdot
.60089 .57344 Mdot
.60094 .57357 Mdot
.60099 .57369 Mdot
.60104 .57382 Mdot
.60109 .57395 Mdot
.60113 .57407 Mdot
.60118 .5742 Mdot
.60123 .57432 Mdot
.60128 .57445 Mdot
.60132 .57457 Mdot
.60137 .5747 Mdot
.60142 .57482 Mdot
.60147 .57495 Mdot
.60151 .57507 Mdot
.60156 .57519 Mdot
.60161 .57532 Mdot
.60166 .57544 Mdot
.6017 .57556 Mdot
.60175 .57569 Mdot
.6018 .57581 Mdot
.60185 .57593 Mdot
.60189 .57605 Mdot
.60194 .57617 Mdot
.60199 .57629 Mdot
.60204 .57641 Mdot
.60209 .57654 Mdot
.60213 .57666 Mdot
.60218 .57678 Mdot
.60223 .5769 Mdot
.60228 .57702 Mdot
.60232 .57713 Mdot
.60237 .57725 Mdot
.60242 .57737 Mdot
.60247 .57749 Mdot
.60251 .57761 Mdot
.60256 .57773 Mdot
.60261 .57784 Mdot
.60266 .57796 Mdot
.6027 .57808 Mdot
.60275 .5782 Mdot
.6028 .57831 Mdot
.60285 .57843 Mdot
.60289 .57854 Mdot
.60294 .57866 Mdot
.60299 .57878 Mdot
.60304 .57889 Mdot
.60308 .57901 Mdot
.60313 .57912 Mdot
.60318 .57924 Mdot
.60323 .57935 Mdot
.60328 .57946 Mdot
.60332 .57958 Mdot
.60337 .57969 Mdot
.60342 .5798 Mdot
.60347 .57992 Mdot
.60351 .58003 Mdot
.60356 .58014 Mdot
.60361 .58025 Mdot
.60366 .58036 Mdot
.6037 .58048 Mdot
.60375 .58059 Mdot
.6038 .5807 Mdot
.60385 .58081 Mdot
.60389 .58092 Mdot
.60394 .58103 Mdot
.60399 .58114 Mdot
.60404 .58125 Mdot
.60408 .58136 Mdot
.60413 .58147 Mdot
.60418 .58158 Mdot
.60423 .58168 Mdot
.60428 .58179 Mdot
.60432 .5819 Mdot
.60437 .58201 Mdot
.60442 .58211 Mdot
.60447 .58222 Mdot
.60451 .58233 Mdot
.60456 .58244 Mdot
.60461 .58254 Mdot
.60466 .58265 Mdot
.6047 .58275 Mdot
.60475 .58286 Mdot
.6048 .58296 Mdot
.60485 .58307 Mdot
.60489 .58317 Mdot
.60494 .58328 Mdot
.60499 .58338 Mdot
.60504 .58349 Mdot
.60508 .58359 Mdot
.60513 .58369 Mdot
.60518 .5838 Mdot
.60523 .5839 Mdot
.60528 .584 Mdot
.60532 .5841 Mdot
.60537 .5842 Mdot
.60542 .58431 Mdot
.60547 .58441 Mdot
.60551 .58451 Mdot
.60556 .58461 Mdot
.60561 .58471 Mdot
.60566 .58481 Mdot
.6057 .58491 Mdot
.60575 .58501 Mdot
.6058 .58511 Mdot
.60585 .58521 Mdot
.60589 .58531 Mdot
.60594 .58541 Mdot
.60599 .5855 Mdot
.60604 .5856 Mdot
.60608 .5857 Mdot
.60613 .5858 Mdot
.60618 .58589 Mdot
.60623 .58599 Mdot
.60628 .58609 Mdot
.60632 .58618 Mdot
.60637 .58628 Mdot
.60642 .58638 Mdot
.60647 .58647 Mdot
.60651 .58657 Mdot
.60656 .58666 Mdot
.60661 .58676 Mdot
.60666 .58685 Mdot
.6067 .58694 Mdot
.60675 .58704 Mdot
.6068 .58713 Mdot
.60685 .58723 Mdot
.60689 .58732 Mdot
.60694 .58741 Mdot
.60699 .5875 Mdot
.60704 .5876 Mdot
.60708 .58769 Mdot
.60713 .58778 Mdot
.60718 .58787 Mdot
.60723 .58796 Mdot
.60727 .58805 Mdot
.60732 .58814 Mdot
.60737 .58823 Mdot
.60742 .58832 Mdot
.60747 .58841 Mdot
.60751 .5885 Mdot
.60756 .58859 Mdot
.60761 .58868 Mdot
.60766 .58877 Mdot
.6077 .58886 Mdot
.60775 .58894 Mdot
.6078 .58903 Mdot
.60785 .58912 Mdot
.60789 .58921 Mdot
.60794 .58929 Mdot
.60799 .58938 Mdot
.60804 .58947 Mdot
.60808 .58955 Mdot
.60813 .58964 Mdot
.60818 .58972 Mdot
.60823 .58981 Mdot
.60827 .58989 Mdot
.60832 .58998 Mdot
.60837 .59006 Mdot
.60842 .59015 Mdot
.60847 .59023 Mdot
.60851 .59031 Mdot
.60856 .5904 Mdot
.60861 .59048 Mdot
.60866 .59056 Mdot
.6087 .59065 Mdot
.60875 .59073 Mdot
.6088 .59081 Mdot
.60885 .59089 Mdot
.60889 .59097 Mdot
.60894 .59105 Mdot
.60899 .59113 Mdot
.60904 .59121 Mdot
.60908 .59129 Mdot
.60913 .59137 Mdot
.60918 .59145 Mdot
.60923 .59153 Mdot
.60927 .59161 Mdot
.60932 .59169 Mdot
.60937 .59177 Mdot
.60942 .59185 Mdot
.60947 .59192 Mdot
.60951 .592 Mdot
.60956 .59208 Mdot
.60961 .59216 Mdot
.60966 .59223 Mdot
.6097 .59231 Mdot
.60975 .59239 Mdot
.6098 .59246 Mdot
.60985 .59254 Mdot
.60989 .59261 Mdot
.60994 .59269 Mdot
.60999 .59276 Mdot
.61004 .59284 Mdot
.61008 .59291 Mdot
.61013 .59298 Mdot
.61018 .59306 Mdot
.61023 .59313 Mdot
.61027 .5932 Mdot
.61032 .59328 Mdot
.61037 .59335 Mdot
.61042 .59342 Mdot
.61047 .59349 Mdot
.61051 .59357 Mdot
.61056 .59364 Mdot
.61061 .59371 Mdot
.61066 .59378 Mdot
.6107 .59385 Mdot
.61075 .59392 Mdot
.6108 .59399 Mdot
.61085 .59406 Mdot
.61089 .59413 Mdot
.61094 .5942 Mdot
.61099 .59427 Mdot
.61104 .59433 Mdot
.61108 .5944 Mdot
.61113 .59447 Mdot
.61118 .59454 Mdot
.61123 .59461 Mdot
.61127 .59467 Mdot
.61132 .59474 Mdot
.61137 .59481 Mdot
.61142 .59487 Mdot
.61147 .59494 Mdot
.61151 .595 Mdot
.61156 .59507 Mdot
.61161 .59513 Mdot
.61166 .5952 Mdot
.6117 .59526 Mdot
.61175 .59533 Mdot
.6118 .59539 Mdot
.61185 .59545 Mdot
.61189 .59552 Mdot
.61194 .59558 Mdot
.61199 .59564 Mdot
.61204 .59571 Mdot
.61208 .59577 Mdot
.61213 .59583 Mdot
.61218 .59589 Mdot
.61223 .59595 Mdot
.61227 .59601 Mdot
.61232 .59607 Mdot
.61237 .59614 Mdot
.61242 .5962 Mdot
.61246 .59626 Mdot
.61251 .59631 Mdot
.61256 .59637 Mdot
.61261 .59643 Mdot
.61266 .59649 Mdot
.6127 .59655 Mdot
.61275 .59661 Mdot
.6128 .59667 Mdot
.61285 .59672 Mdot
.61289 .59678 Mdot
.61294 .59684 Mdot
.61299 .59689 Mdot
.61304 .59695 Mdot
.61308 .59701 Mdot
.61313 .59706 Mdot
.61318 .59712 Mdot
.61323 .59717 Mdot
.61327 .59723 Mdot
.61332 .59728 Mdot
.61337 .59734 Mdot
.61342 .59739 Mdot
.61346 .59745 Mdot
.61351 .5975 Mdot
.61356 .59755 Mdot
.61361 .59761 Mdot
.61366 .59766 Mdot
.6137 .59771 Mdot
.61375 .59776 Mdot
.6138 .59781 Mdot
.61385 .59787 Mdot
.61389 .59792 Mdot
.61394 .59797 Mdot
.61399 .59802 Mdot
.61404 .59807 Mdot
.61408 .59812 Mdot
.61413 .59817 Mdot
.61418 .59822 Mdot
.61423 .59827 Mdot
.61427 .59832 Mdot
.61432 .59837 Mdot
.61437 .59841 Mdot
.61442 .59846 Mdot
.61446 .59851 Mdot
.61451 .59856 Mdot
.61456 .5986 Mdot
.61461 .59865 Mdot
.61466 .5987 Mdot
.6147 .59874 Mdot
.61475 .59879 Mdot
.6148 .59884 Mdot
.61485 .59888 Mdot
.61489 .59893 Mdot
.61494 .59897 Mdot
.61499 .59902 Mdot
.61504 .59906 Mdot
.61508 .5991 Mdot
.61513 .59915 Mdot
.61518 .59919 Mdot
.61523 .59923 Mdot
.61527 .59928 Mdot
.61532 .59932 Mdot
.61537 .59936 Mdot
.61542 .5994 Mdot
.61546 .59945 Mdot
.61551 .59949 Mdot
.61556 .59953 Mdot
.61561 .59957 Mdot
.61566 .59961 Mdot
.6157 .59965 Mdot
.61575 .59969 Mdot
.6158 .59973 Mdot
.61585 .59977 Mdot
.61589 .59981 Mdot
.61594 .59985 Mdot
.61599 .59988 Mdot
.61604 .59992 Mdot
.61608 .59996 Mdot
.61613 .6 Mdot
.61618 .60004 Mdot
.61623 .60007 Mdot
.61627 .60011 Mdot
.61632 .60015 Mdot
.61637 .60018 Mdot
.61642 .60022 Mdot
.61646 .60025 Mdot
.61651 .60029 Mdot
.61656 .60032 Mdot
.61661 .60036 Mdot
.61666 .60039 Mdot
.6167 .60043 Mdot
.61675 .60046 Mdot
.6168 .60049 Mdot
.61685 .60053 Mdot
.61689 .60056 Mdot
.61694 .60059 Mdot
.61699 .60062 Mdot
.61704 .60066 Mdot
.61708 .60069 Mdot
.61713 .60072 Mdot
.61718 .60075 Mdot
.61723 .60078 Mdot
.61727 .60081 Mdot
.61732 .60084 Mdot
.61737 .60087 Mdot
.61742 .6009 Mdot
.61746 .60093 Mdot
.61751 .60096 Mdot
.61756 .60099 Mdot
.61761 .60102 Mdot
.61765 .60105 Mdot
.6177 .60107 Mdot
.61775 .6011 Mdot
.6178 .60113 Mdot
.61785 .60116 Mdot
.61789 .60118 Mdot
.61794 .60121 Mdot
.61799 .60124 Mdot
.61804 .60126 Mdot
.61808 .60129 Mdot
.61813 .60131 Mdot
.61818 .60134 Mdot
.61823 .60136 Mdot
.61827 .60139 Mdot
.61832 .60141 Mdot
.61837 .60144 Mdot
.61842 .60146 Mdot
.61846 .60148 Mdot
.61851 .60151 Mdot
.61856 .60153 Mdot
.61861 .60155 Mdot
.61865 .60157 Mdot
.6187 .60159 Mdot
.61875 .60162 Mdot
.6188 .60164 Mdot
.61885 .60166 Mdot
.61889 .60168 Mdot
.61894 .6017 Mdot
.61899 .60172 Mdot
.61904 .60174 Mdot
.61908 .60176 Mdot
.61913 .60178 Mdot
.61918 .6018 Mdot
.61923 .60181 Mdot
.61927 .60183 Mdot
.61932 .60185 Mdot
.61937 .60187 Mdot
.61942 .60189 Mdot
.61946 .6019 Mdot
.61951 .60192 Mdot
.61956 .60194 Mdot
.61961 .60195 Mdot
.61965 .60197 Mdot
.6197 .60198 Mdot
.61975 .602 Mdot
.6198 .60202 Mdot
.61985 .60203 Mdot
.61989 .60204 Mdot
.61994 .60206 Mdot
.61999 .60207 Mdot
.62004 .60209 Mdot
.62008 .6021 Mdot
.62013 .60211 Mdot
.62018 .60213 Mdot
.62023 .60214 Mdot
.62027 .60215 Mdot
.62032 .60216 Mdot
.62037 .60217 Mdot
.62042 .60218 Mdot
.62046 .6022 Mdot
.62051 .60221 Mdot
.62056 .60222 Mdot
.62061 .60223 Mdot
.62065 .60224 Mdot
.6207 .60225 Mdot
.62075 .60226 Mdot
.6208 .60226 Mdot
.62085 .60227 Mdot
.62089 .60228 Mdot
.62094 .60229 Mdot
.62099 .6023 Mdot
.62104 .6023 Mdot
.62108 .60231 Mdot
.62113 .60232 Mdot
.62118 .60232 Mdot
.62123 .60233 Mdot
.62127 .60234 Mdot
.62132 .60234 Mdot
.62137 .60235 Mdot
.62142 .60235 Mdot
.62146 .60236 Mdot
.62151 .60236 Mdot
.62156 .60237 Mdot
.62161 .60237 Mdot
.62165 .60237 Mdot
.6217 .60238 Mdot
.62175 .60238 Mdot
.6218 .60238 Mdot
.62184 .60239 Mdot
.62189 .60239 Mdot
.62194 .60239 Mdot
.62199 .60239 Mdot
.62204 .60239 Mdot
.62208 .60239 Mdot
.62213 .60239 Mdot
.62218 .60239 Mdot
.62223 .6024 Mdot
.62227 .60239 Mdot
.62232 .60239 Mdot
.62237 .60239 Mdot
.62242 .60239 Mdot
.62246 .60239 Mdot
.62251 .60239 Mdot
.62256 .60239 Mdot
.62261 .60239 Mdot
.62265 .60238 Mdot
.6227 .60238 Mdot
.62275 .60238 Mdot
.6228 .60237 Mdot
.62284 .60237 Mdot
.62289 .60237 Mdot
.62294 .60236 Mdot
.62299 .60236 Mdot
.62304 .60235 Mdot
.62308 .60235 Mdot
.62313 .60234 Mdot
.62318 .60234 Mdot
.62323 .60233 Mdot
.62327 .60232 Mdot
.62332 .60232 Mdot
.62337 .60231 Mdot
.62342 .6023 Mdot
.62346 .60229 Mdot
.62351 .60229 Mdot
.62356 .60228 Mdot
.62361 .60227 Mdot
.62365 .60226 Mdot
.6237 .60225 Mdot
.62375 .60224 Mdot
.6238 .60223 Mdot
.62384 .60222 Mdot
.62389 .60221 Mdot
.62394 .6022 Mdot
.62399 .60219 Mdot
.62404 .60218 Mdot
.62408 .60217 Mdot
.62413 .60216 Mdot
.62418 .60215 Mdot
.62423 .60213 Mdot
.62427 .60212 Mdot
.62432 .60211 Mdot
.62437 .6021 Mdot
.62442 .60208 Mdot
.62446 .60207 Mdot
.62451 .60206 Mdot
.62456 .60204 Mdot
.62461 .60203 Mdot
.62465 .60201 Mdot
.6247 .602 Mdot
.62475 .60198 Mdot
.6248 .60197 Mdot
.62484 .60195 Mdot
.62489 .60193 Mdot
.62494 .60192 Mdot
.62499 .6019 Mdot
.62504 .60188 Mdot
.62508 .60186 Mdot
.62513 .60185 Mdot
.62518 .60183 Mdot
.62523 .60181 Mdot
.62527 .60179 Mdot
.62532 .60177 Mdot
.62537 .60175 Mdot
.62542 .60173 Mdot
.62546 .60171 Mdot
.62551 .60169 Mdot
.62556 .60167 Mdot
.62561 .60165 Mdot
.62565 .60163 Mdot
.6257 .60161 Mdot
.62575 .60159 Mdot
.6258 .60157 Mdot
.62584 .60154 Mdot
.62589 .60152 Mdot
.62594 .6015 Mdot
.62599 .60148 Mdot
.62604 .60145 Mdot
.62608 .60143 Mdot
.62613 .60141 Mdot
.62618 .60138 Mdot
.62623 .60136 Mdot
.62627 .60133 Mdot
.62632 .60131 Mdot
.62637 .60128 Mdot
.62642 .60126 Mdot
.62646 .60123 Mdot
.62651 .6012 Mdot
.62656 .60118 Mdot
.62661 .60115 Mdot
.62665 .60112 Mdot
.6267 .6011 Mdot
.62675 .60107 Mdot
.6268 .60104 Mdot
.62684 .60101 Mdot
.62689 .60098 Mdot
.62694 .60095 Mdot
.62699 .60092 Mdot
.62703 .6009 Mdot
.62708 .60087 Mdot
.62713 .60084 Mdot
.62718 .6008 Mdot
.62723 .60077 Mdot
.62727 .60074 Mdot
.62732 .60071 Mdot
.62737 .60068 Mdot
.62742 .60065 Mdot
.62746 .60062 Mdot
.62751 .60058 Mdot
.62756 .60055 Mdot
.62761 .60052 Mdot
.62765 .60048 Mdot
.6277 .60045 Mdot
.62775 .60042 Mdot
.6278 .60038 Mdot
.62784 .60035 Mdot
.62789 .60031 Mdot
.62794 .60028 Mdot
.62799 .60024 Mdot
.62803 .60021 Mdot
.62808 .60017 Mdot
.62813 .60014 Mdot
.62818 .6001 Mdot
.62823 .60006 Mdot
.62827 .60003 Mdot
.62832 .59999 Mdot
.62837 .59995 Mdot
.62842 .59991 Mdot
.62846 .59987 Mdot
.62851 .59984 Mdot
.62856 .5998 Mdot
.62861 .59976 Mdot
.62865 .59972 Mdot
.6287 .59968 Mdot
.62875 .59964 Mdot
.6288 .5996 Mdot
.62884 .59956 Mdot
.62889 .59952 Mdot
.62894 .59948 Mdot
.62899 .59943 Mdot
.62903 .59939 Mdot
.62908 .59935 Mdot
.62913 .59931 Mdot
.62918 .59927 Mdot
.62923 .59922 Mdot
.62927 .59918 Mdot
.62932 .59914 Mdot
.62937 .59909 Mdot
.62942 .59905 Mdot
.62946 .599 Mdot
.62951 .59896 Mdot
.62956 .59891 Mdot
.62961 .59887 Mdot
.62965 .59882 Mdot
.6297 .59878 Mdot
.62975 .59873 Mdot
.6298 .59869 Mdot
.62984 .59864 Mdot
.62989 .59859 Mdot
.62994 .59854 Mdot
.62999 .5985 Mdot
.63003 .59845 Mdot
.63008 .5984 Mdot
.63013 .59835 Mdot
.63018 .5983 Mdot
.63023 .59825 Mdot
.63027 .59821 Mdot
.63032 .59816 Mdot
.63037 .59811 Mdot
.63042 .59806 Mdot
.63046 .59801 Mdot
.63051 .59795 Mdot
.63056 .5979 Mdot
.63061 .59785 Mdot
.63065 .5978 Mdot
.6307 .59775 Mdot
.63075 .5977 Mdot
.6308 .59764 Mdot
.63084 .59759 Mdot
.63089 .59754 Mdot
.63094 .59749 Mdot
.63099 .59743 Mdot
.63103 .59738 Mdot
.63108 .59732 Mdot
.63113 .59727 Mdot
.63118 .59721 Mdot
.63122 .59716 Mdot
.63127 .5971 Mdot
.63132 .59705 Mdot
.63137 .59699 Mdot
.63142 .59694 Mdot
.63146 .59688 Mdot
.63151 .59682 Mdot
.63156 .59677 Mdot
.63161 .59671 Mdot
.63165 .59665 Mdot
.6317 .59659 Mdot
.63175 .59653 Mdot
.6318 .59648 Mdot
.63184 .59642 Mdot
.63189 .59636 Mdot
.63194 .5963 Mdot
.63199 .59624 Mdot
.63203 .59618 Mdot
.63208 .59612 Mdot
.63213 .59606 Mdot
.63218 .596 Mdot
.63222 .59594 Mdot
.63227 .59588 Mdot
.63232 .59581 Mdot
.63237 .59575 Mdot
.63242 .59569 Mdot
.63246 .59563 Mdot
.63251 .59556 Mdot
.63256 .5955 Mdot
.63261 .59544 Mdot
.63265 .59537 Mdot
.6327 .59531 Mdot
.63275 .59525 Mdot
.6328 .59518 Mdot
.63284 .59512 Mdot
.63289 .59505 Mdot
.63294 .59499 Mdot
.63299 .59492 Mdot
.63303 .59485 Mdot
.63308 .59479 Mdot
.63313 .59472 Mdot
.63318 .59465 Mdot
.63322 .59459 Mdot
.63327 .59452 Mdot
.63332 .59445 Mdot
.63337 .59438 Mdot
.63342 .59432 Mdot
.63346 .59425 Mdot
.63351 .59418 Mdot
.63356 .59411 Mdot
.63361 .59404 Mdot
.63365 .59397 Mdot
.6337 .5939 Mdot
.63375 .59383 Mdot
.6338 .59376 Mdot
.63384 .59369 Mdot
.63389 .59362 Mdot
.63394 .59355 Mdot
.63399 .59347 Mdot
.63403 .5934 Mdot
.63408 .59333 Mdot
.63413 .59326 Mdot
.63418 .59318 Mdot
.63422 .59311 Mdot
.63427 .59304 Mdot
.63432 .59296 Mdot
.63437 .59289 Mdot
.63442 .59282 Mdot
.63446 .59274 Mdot
.63451 .59267 Mdot
.63456 .59259 Mdot
.63461 .59252 Mdot
.63465 .59244 Mdot
.6347 .59236 Mdot
.63475 .59229 Mdot
.6348 .59221 Mdot
.63484 .59214 Mdot
.63489 .59206 Mdot
.63494 .59198 Mdot
.63499 .5919 Mdot
.63503 .59183 Mdot
.63508 .59175 Mdot
.63513 .59167 Mdot
.63518 .59159 Mdot
.63522 .59151 Mdot
.63527 .59143 Mdot
.63532 .59135 Mdot
.63537 .59127 Mdot
.63542 .59119 Mdot
.63546 .59111 Mdot
.63551 .59103 Mdot
.63556 .59095 Mdot
.63561 .59087 Mdot
.63565 .59079 Mdot
.6357 .5907 Mdot
.63575 .59062 Mdot
.6358 .59054 Mdot
.63584 .59046 Mdot
.63589 .59037 Mdot
.63594 .59029 Mdot
.63599 .59021 Mdot
.63603 .59012 Mdot
.63608 .59004 Mdot
.63613 .58995 Mdot
.63618 .58987 Mdot
.63622 .58979 Mdot
.63627 .5897 Mdot
.63632 .58961 Mdot
.63637 .58953 Mdot
.63641 .58944 Mdot
.63646 .58936 Mdot
.63651 .58927 Mdot
.63656 .58918 Mdot
.63661 .5891 Mdot
.63665 .58901 Mdot
.6367 .58892 Mdot
.63675 .58883 Mdot
.6368 .58874 Mdot
.63684 .58865 Mdot
.63689 .58857 Mdot
.63694 .58848 Mdot
.63699 .58839 Mdot
.63703 .5883 Mdot
.63708 .58821 Mdot
.63713 .58812 Mdot
.63718 .58803 Mdot
.63722 .58794 Mdot
.63727 .58784 Mdot
.63732 .58775 Mdot
.63737 .58766 Mdot
.63741 .58757 Mdot
.63746 .58748 Mdot
.63751 .58738 Mdot
.63756 .58729 Mdot
.63761 .5872 Mdot
.63765 .58711 Mdot
.6377 .58701 Mdot
.63775 .58692 Mdot
.6378 .58682 Mdot
.63784 .58673 Mdot
.63789 .58663 Mdot
.63794 .58654 Mdot
.63799 .58644 Mdot
.63803 .58635 Mdot
.63808 .58625 Mdot
.63813 .58616 Mdot
.63818 .58606 Mdot
.63822 .58596 Mdot
.63827 .58587 Mdot
.63832 .58577 Mdot
.63837 .58567 Mdot
.63841 .58557 Mdot
.63846 .58548 Mdot
.63851 .58538 Mdot
.63856 .58528 Mdot
.63861 .58518 Mdot
.63865 .58508 Mdot
.6387 .58498 Mdot
.63875 .58488 Mdot
.6388 .58478 Mdot
.63884 .58468 Mdot
.63889 .58458 Mdot
.63894 .58448 Mdot
.63899 .58438 Mdot
.63903 .58428 Mdot
.63908 .58417 Mdot
.63913 .58407 Mdot
.63918 .58397 Mdot
.63922 .58387 Mdot
.63927 .58376 Mdot
.63932 .58366 Mdot
.63937 .58356 Mdot
.63941 .58345 Mdot
.63946 .58335 Mdot
.63951 .58325 Mdot
.63956 .58314 Mdot
.63961 .58304 Mdot
.63965 .58293 Mdot
.6397 .58283 Mdot
.63975 .58272 Mdot
.6398 .58262 Mdot
.63984 .58251 Mdot
.63989 .5824 Mdot
.63994 .5823 Mdot
.63999 .58219 Mdot
.64003 .58208 Mdot
.64008 .58198 Mdot
.64013 .58187 Mdot
.64018 .58176 Mdot
.64022 .58165 Mdot
.64027 .58154 Mdot
.64032 .58143 Mdot
.64037 .58132 Mdot
.64041 .58122 Mdot
.64046 .58111 Mdot
.64051 .581 Mdot
.64056 .58089 Mdot
.6406 .58078 Mdot
.64065 .58066 Mdot
.6407 .58055 Mdot
.64075 .58044 Mdot
.6408 .58033 Mdot
.64084 .58022 Mdot
.64089 .58011 Mdot
.64094 .57999 Mdot
.64099 .57988 Mdot
.64103 .57977 Mdot
.64108 .57966 Mdot
.64113 .57954 Mdot
.64118 .57943 Mdot
.64122 .57931 Mdot
.64127 .5792 Mdot
.64132 .57909 Mdot
.64137 .57897 Mdot
.64141 .57886 Mdot
.64146 .57874 Mdot
.64151 .57863 Mdot
.64156 .57851 Mdot
.6416 .57839 Mdot
.64165 .57828 Mdot
.6417 .57816 Mdot
.64175 .57804 Mdot
.6418 .57793 Mdot
.64184 .57781 Mdot
.64189 .57769 Mdot
.64194 .57757 Mdot
.64199 .57745 Mdot
.64203 .57734 Mdot
.64208 .57722 Mdot
.64213 .5771 Mdot
.64218 .57698 Mdot
.64222 .57686 Mdot
.64227 .57674 Mdot
.64232 .57662 Mdot
.64237 .5765 Mdot
.64241 .57638 Mdot
.64246 .57626 Mdot
.64251 .57614 Mdot
.64256 .57601 Mdot
.6426 .57589 Mdot
.64265 .57577 Mdot
.6427 .57565 Mdot
.64275 .57552 Mdot
.6428 .5754 Mdot
.64284 .57528 Mdot
.64289 .57516 Mdot
.64294 .57503 Mdot
.64299 .57491 Mdot
.64303 .57478 Mdot
.64308 .57466 Mdot
.64313 .57453 Mdot
.64318 .57441 Mdot
.64322 .57428 Mdot
.64327 .57416 Mdot
.64332 .57403 Mdot
.64337 .57391 Mdot
.64341 .57378 Mdot
.64346 .57365 Mdot
.64351 .57353 Mdot
.64356 .5734 Mdot
.6436 .57327 Mdot
.64365 .57315 Mdot
.6437 .57302 Mdot
.64375 .57289 Mdot
.6438 .57276 Mdot
.64384 .57263 Mdot
.64389 .5725 Mdot
.64394 .57237 Mdot
.64399 .57224 Mdot
.64403 .57211 Mdot
.64408 .57198 Mdot
.64413 .57185 Mdot
.64418 .57172 Mdot
.64422 .57159 Mdot
.64427 .57146 Mdot
.64432 .57133 Mdot
.64437 .5712 Mdot
.64441 .57107 Mdot
.64446 .57093 Mdot
.64451 .5708 Mdot
.64456 .57067 Mdot
.6446 .57054 Mdot
.64465 .5704 Mdot
.6447 .57027 Mdot
.64475 .57014 Mdot
.6448 .57 Mdot
.64484 .56987 Mdot
.64489 .56973 Mdot
.64494 .5696 Mdot
.64499 .56946 Mdot
.64503 .56933 Mdot
.64508 .56919 Mdot
.64513 .56906 Mdot
.64518 .56892 Mdot
.64522 .56879 Mdot
.64527 .56865 Mdot
.64532 .56851 Mdot
.64537 .56837 Mdot
.64541 .56824 Mdot
.64546 .5681 Mdot
.64551 .56796 Mdot
.64556 .56782 Mdot
.6456 .56769 Mdot
.64565 .56755 Mdot
.6457 .56741 Mdot
.64575 .56727 Mdot
.64579 .56713 Mdot
.64584 .56699 Mdot
.64589 .56685 Mdot
.64594 .56671 Mdot
.64599 .56657 Mdot
.64603 .56643 Mdot
.64608 .56629 Mdot
.64613 .56615 Mdot
.64618 .566 Mdot
.64622 .56586 Mdot
.64627 .56572 Mdot
.64632 .56558 Mdot
.64637 .56544 Mdot
.64641 .56529 Mdot
.64646 .56515 Mdot
.64651 .56501 Mdot
.64656 .56486 Mdot
.6466 .56472 Mdot
.64665 .56458 Mdot
.6467 .56443 Mdot
.64675 .56429 Mdot
.64679 .56414 Mdot
.64684 .564 Mdot
.64689 .56385 Mdot
.64694 .56371 Mdot
.64699 .56356 Mdot
.64703 .56341 Mdot
.64708 .56327 Mdot
.64713 .56312 Mdot
.64718 .56297 Mdot
.64722 .56283 Mdot
.64727 .56268 Mdot
.64732 .56253 Mdot
.64737 .56238 Mdot
.64741 .56224 Mdot
.64746 .56209 Mdot
.64751 .56194 Mdot
.64756 .56179 Mdot
.6476 .56164 Mdot
.64765 .56149 Mdot
.6477 .56134 Mdot
.64775 .56119 Mdot
.64779 .56104 Mdot
.64784 .56089 Mdot
.64789 .56074 Mdot
.64794 .56059 Mdot
.64799 .56044 Mdot
.64803 .56029 Mdot
.64808 .56014 Mdot
.64813 .55998 Mdot
.64818 .55983 Mdot
.64822 .55968 Mdot
.64827 .55953 Mdot
.64832 .55937 Mdot
.64837 .55922 Mdot
.64841 .55907 Mdot
.64846 .55891 Mdot
.64851 .55876 Mdot
.64856 .55861 Mdot
.6486 .55845 Mdot
.64865 .5583 Mdot
.6487 .55814 Mdot
.64875 .55799 Mdot
.64879 .55783 Mdot
.64884 .55768 Mdot
.64889 .55752 Mdot
.64894 .55736 Mdot
.64899 .55721 Mdot
.64903 .55705 Mdot
.64908 .55689 Mdot
.64913 .55674 Mdot
.64918 .55658 Mdot
.64922 .55642 Mdot
.64927 .55626 Mdot
.64932 .55611 Mdot
.64937 .55595 Mdot
.64941 .55579 Mdot
.64946 .55563 Mdot
.64951 .55547 Mdot
.64956 .55531 Mdot
.6496 .55515 Mdot
.64965 .55499 Mdot
.6497 .55483 Mdot
.64975 .55467 Mdot
.64979 .55451 Mdot
.64984 .55435 Mdot
.64989 .55419 Mdot
.64994 .55403 Mdot
.64999 .55387 Mdot
.65003 .5537 Mdot
.65008 .55354 Mdot
.65013 .55338 Mdot
.65018 .55322 Mdot
.65022 .55305 Mdot
.65027 .55289 Mdot
.65032 .55273 Mdot
.65037 .55256 Mdot
.65041 .5524 Mdot
.65046 .55224 Mdot
.65051 .55207 Mdot
.65056 .55191 Mdot
.6506 .55174 Mdot
.65065 .55158 Mdot
.6507 .55141 Mdot
.65075 .55125 Mdot
.65079 .55108 Mdot
.65084 .55092 Mdot
.65089 .55075 Mdot
.65094 .55058 Mdot
.65098 .55042 Mdot
.65103 .55025 Mdot
.65108 .55008 Mdot
.65113 .54991 Mdot
.65118 .54975 Mdot
.65122 .54958 Mdot
.65127 .54941 Mdot
.65132 .54924 Mdot
.65137 .54907 Mdot
.65141 .5489 Mdot
.65146 .54874 Mdot
.65151 .54857 Mdot
.65156 .5484 Mdot
.6516 .54823 Mdot
.65165 .54806 Mdot
.6517 .54789 Mdot
.65175 .54772 Mdot
.65179 .54754 Mdot
.65184 .54737 Mdot
.65189 .5472 Mdot
.65194 .54703 Mdot
.65198 .54686 Mdot
.65203 .54669 Mdot
.65208 .54651 Mdot
.65213 .54634 Mdot
.65218 .54617 Mdot
.65222 .546 Mdot
.65227 .54582 Mdot
.65232 .54565 Mdot
.65237 .54548 Mdot
.65241 .5453 Mdot
.65246 .54513 Mdot
.65251 .54495 Mdot
.65256 .54478 Mdot
.6526 .5446 Mdot
.65265 .54443 Mdot
.6527 .54425 Mdot
.65275 .54408 Mdot
.65279 .5439 Mdot
.65284 .54373 Mdot
.65289 .54355 Mdot
.65294 .54337 Mdot
.65298 .5432 Mdot
.65303 .54302 Mdot
.65308 .54284 Mdot
.65313 .54267 Mdot
.65318 .54249 Mdot
.65322 .54231 Mdot
.65327 .54213 Mdot
.65332 .54195 Mdot
.65337 .54178 Mdot
.65341 .5416 Mdot
.65346 .54142 Mdot
.65351 .54124 Mdot
.65356 .54106 Mdot
.6536 .54088 Mdot
.65365 .5407 Mdot
.6537 .54052 Mdot
.65375 .54034 Mdot
.65379 .54016 Mdot
.65384 .53998 Mdot
.65389 .5398 Mdot
.65394 .53961 Mdot
.65398 .53943 Mdot
.65403 .53925 Mdot
.65408 .53907 Mdot
.65413 .53889 Mdot
.65418 .5387 Mdot
.65422 .53852 Mdot
.65427 .53834 Mdot
.65432 .53815 Mdot
.65437 .53797 Mdot
.65441 .53779 Mdot
.65446 .5376 Mdot
.65451 .53742 Mdot
.65456 .53724 Mdot
.6546 .53705 Mdot
.65465 .53687 Mdot
.6547 .53668 Mdot
.65475 .5365 Mdot
.65479 .53631 Mdot
.65484 .53612 Mdot
.65489 .53594 Mdot
.65494 .53575 Mdot
.65498 .53557 Mdot
.65503 .53538 Mdot
.65508 .53519 Mdot
.65513 .535 Mdot
.65517 .53482 Mdot
.65522 .53463 Mdot
.65527 .53444 Mdot
.65532 .53425 Mdot
.65537 .53407 Mdot
.65541 .53388 Mdot
.65546 .53369 Mdot
.65551 .5335 Mdot
.65556 .53331 Mdot
.6556 .53312 Mdot
.65565 .53293 Mdot
.6557 .53274 Mdot
.65575 .53255 Mdot
.65579 .53236 Mdot
.65584 .53217 Mdot
.65589 .53198 Mdot
.65594 .53179 Mdot
.65598 .5316 Mdot
.65603 .53141 Mdot
.65608 .53122 Mdot
.65613 .53102 Mdot
.65617 .53083 Mdot
.65622 .53064 Mdot
.65627 .53045 Mdot
.65632 .53025 Mdot
.65637 .53006 Mdot
.65641 .52987 Mdot
.65646 .52967 Mdot
.65651 .52948 Mdot
.65656 .52929 Mdot
.6566 .52909 Mdot
.65665 .5289 Mdot
.6567 .5287 Mdot
.65675 .52851 Mdot
.65679 .52832 Mdot
.65684 .52812 Mdot
.65689 .52792 Mdot
.65694 .52773 Mdot
.65698 .52753 Mdot
.65703 .52734 Mdot
.65708 .52714 Mdot
.65713 .52694 Mdot
.65717 .52675 Mdot
.65722 .52655 Mdot
.65727 .52635 Mdot
.65732 .52616 Mdot
.65737 .52596 Mdot
.65741 .52576 Mdot
.65746 .52556 Mdot
.65751 .52537 Mdot
.65756 .52517 Mdot
.6576 .52497 Mdot
.65765 .52477 Mdot
.6577 .52457 Mdot
.65775 .52437 Mdot
.65779 .52417 Mdot
.65784 .52397 Mdot
.65789 .52377 Mdot
.65794 .52357 Mdot
.65798 .52337 Mdot
.65803 .52317 Mdot
.65808 .52297 Mdot
.65813 .52277 Mdot
.65817 .52257 Mdot
.65822 .52237 Mdot
.65827 .52216 Mdot
.65832 .52196 Mdot
.65837 .52176 Mdot
.65841 .52156 Mdot
.65846 .52136 Mdot
.65851 .52115 Mdot
.65856 .52095 Mdot
.6586 .52075 Mdot
.65865 .52054 Mdot
.6587 .52034 Mdot
.65875 .52014 Mdot
.65879 .51993 Mdot
.65884 .51973 Mdot
.65889 .51952 Mdot
.65894 .51932 Mdot
.65898 .51911 Mdot
.65903 .51891 Mdot
.65908 .5187 Mdot
.65913 .5185 Mdot
.65917 .51829 Mdot
.65922 .51809 Mdot
.65927 .51788 Mdot
.65932 .51768 Mdot
.65937 .51747 Mdot
.65941 .51726 Mdot
.65946 .51706 Mdot
.65951 .51685 Mdot
.65956 .51664 Mdot
.6596 .51643 Mdot
.65965 .51623 Mdot
.6597 .51602 Mdot
.65975 .51581 Mdot
.65979 .5156 Mdot
.65984 .51539 Mdot
.65989 .51518 Mdot
.65994 .51497 Mdot
.65998 .51477 Mdot
.66003 .51456 Mdot
.66008 .51435 Mdot
.66013 .51414 Mdot
.66017 .51393 Mdot
.66022 .51372 Mdot
.66027 .51351 Mdot
.66032 .5133 Mdot
.66036 .51308 Mdot
.66041 .51287 Mdot
.66046 .51266 Mdot
.66051 .51245 Mdot
.66056 .51224 Mdot
.6606 .51203 Mdot
.66065 .51182 Mdot
.6607 .5116 Mdot
.66075 .51139 Mdot
.66079 .51118 Mdot
.66084 .51097 Mdot
.66089 .51075 Mdot
.66094 .51054 Mdot
.66098 .51033 Mdot
.66103 .51011 Mdot
.66108 .5099 Mdot
.66113 .50968 Mdot
.66117 .50947 Mdot
.66122 .50925 Mdot
.66127 .50904 Mdot
.66132 .50883 Mdot
.66136 .50861 Mdot
.66141 .50839 Mdot
.66146 .50818 Mdot
.66151 .50796 Mdot
.66156 .50775 Mdot
.6616 .50753 Mdot
.66165 .50732 Mdot
.6617 .5071 Mdot
.66175 .50688 Mdot
.66179 .50667 Mdot
.66184 .50645 Mdot
.66189 .50623 Mdot
.66194 .50601 Mdot
.66198 .5058 Mdot
.66203 .50558 Mdot
.66208 .50536 Mdot
.66213 .50514 Mdot
.66217 .50492 Mdot
.66222 .5047 Mdot
.66227 .50449 Mdot
.66232 .50427 Mdot
.66236 .50405 Mdot
.66241 .50383 Mdot
.66246 .50361 Mdot
.66251 .50339 Mdot
.66256 .50317 Mdot
.6626 .50295 Mdot
.66265 .50273 Mdot
.6627 .50251 Mdot
.66275 .50229 Mdot
.66279 .50207 Mdot
.66284 .50184 Mdot
.66289 .50162 Mdot
.66294 .5014 Mdot
.66298 .50118 Mdot
.66303 .50096 Mdot
.66308 .50074 Mdot
.66313 .50051 Mdot
.66317 .50029 Mdot
.66322 .50007 Mdot
.66327 .49985 Mdot
.66332 .49962 Mdot
.66336 .4994 Mdot
.66341 .49918 Mdot
.66346 .49895 Mdot
.66351 .49873 Mdot
.66356 .4985 Mdot
.6636 .49828 Mdot
.66365 .49805 Mdot
.6637 .49783 Mdot
.66375 .49761 Mdot
.66379 .49738 Mdot
.66384 .49716 Mdot
.66389 .49693 Mdot
.66394 .4967 Mdot
.66398 .49648 Mdot
.66403 .49625 Mdot
.66408 .49603 Mdot
.66413 .4958 Mdot
.66417 .49557 Mdot
.66422 .49535 Mdot
.66427 .49512 Mdot
.66432 .49489 Mdot
.66436 .49467 Mdot
.66441 .49444 Mdot
.66446 .49421 Mdot
.66451 .49398 Mdot
.66455 .49375 Mdot
.6646 .49353 Mdot
.66465 .4933 Mdot
.6647 .49307 Mdot
.66475 .49284 Mdot
.66479 .49261 Mdot
.66484 .49238 Mdot
.66489 .49215 Mdot
.66494 .49192 Mdot
.66498 .49169 Mdot
.66503 .49146 Mdot
.66508 .49123 Mdot
.66513 .491 Mdot
.66517 .49077 Mdot
.66522 .49054 Mdot
.66527 .49031 Mdot
.66532 .49008 Mdot
.66536 .48985 Mdot
.66541 .48962 Mdot
.66546 .48939 Mdot
.66551 .48916 Mdot
.66555 .48892 Mdot
.6656 .48869 Mdot
.66565 .48846 Mdot
.6657 .48823 Mdot
.66575 .488 Mdot
.66579 .48776 Mdot
.66584 .48753 Mdot
.66589 .4873 Mdot
.66594 .48706 Mdot
.66598 .48683 Mdot
.66603 .4866 Mdot
.66608 .48636 Mdot
.66613 .48613 Mdot
.66617 .48589 Mdot
.66622 .48566 Mdot
.66627 .48543 Mdot
.66632 .48519 Mdot
.66636 .48496 Mdot
.66641 .48472 Mdot
.66646 .48449 Mdot
.66651 .48425 Mdot
.66655 .48401 Mdot
.6666 .48378 Mdot
.66665 .48354 Mdot
.6667 .48331 Mdot
.66675 .48307 Mdot
.66679 .48283 Mdot
.66684 .4826 Mdot
.66689 .48236 Mdot
.66694 .48212 Mdot
.66698 .48189 Mdot
.66703 .48165 Mdot
.66708 .48141 Mdot
.66713 .48117 Mdot
.66717 .48094 Mdot
.66722 .4807 Mdot
.66727 .48046 Mdot
.66732 .48022 Mdot
.66736 .47998 Mdot
.66741 .47974 Mdot
.66746 .47951 Mdot
.66751 .47927 Mdot
.66755 .47903 Mdot
.6676 .47879 Mdot
.66765 .47855 Mdot
.6677 .47831 Mdot
.66775 .47807 Mdot
.66779 .47783 Mdot
.66784 .47759 Mdot
.66789 .47735 Mdot
.66794 .47711 Mdot
.66798 .47687 Mdot
.66803 .47663 Mdot
.66808 .47638 Mdot
.66813 .47614 Mdot
.66817 .4759 Mdot
.66822 .47566 Mdot
.66827 .47542 Mdot
.66832 .47518 Mdot
.66836 .47493 Mdot
.66841 .47469 Mdot
.66846 .47445 Mdot
.66851 .47421 Mdot
.66855 .47396 Mdot
.6686 .47372 Mdot
.66865 .47348 Mdot
.6687 .47324 Mdot
.66875 .47299 Mdot
.66879 .47275 Mdot
.66884 .4725 Mdot
.66889 .47226 Mdot
.66894 .47202 Mdot
.66898 .47177 Mdot
.66903 .47153 Mdot
.66908 .47128 Mdot
.66913 .47104 Mdot
.66917 .47079 Mdot
.66922 .47055 Mdot
.66927 .4703 Mdot
.66932 .47006 Mdot
.66936 .46981 Mdot
.66941 .46957 Mdot
.66946 .46932 Mdot
.66951 .46907 Mdot
.66955 .46883 Mdot
.6696 .46858 Mdot
.66965 .46834 Mdot
.6697 .46809 Mdot
.66974 .46784 Mdot
.66979 .4676 Mdot
.66984 .46735 Mdot
.66989 .4671 Mdot
.66994 .46685 Mdot
.66998 .46661 Mdot
.67003 .46636 Mdot
.67008 .46611 Mdot
.67013 .46586 Mdot
.67017 .46561 Mdot
.67022 .46537 Mdot
.67027 .46512 Mdot
.67032 .46487 Mdot
.67036 .46462 Mdot
.67041 .46437 Mdot
.67046 .46412 Mdot
.67051 .46387 Mdot
.67055 .46362 Mdot
.6706 .46337 Mdot
.67065 .46312 Mdot
.6707 .46287 Mdot
.67074 .46262 Mdot
.67079 .46237 Mdot
.67084 .46212 Mdot
.67089 .46187 Mdot
.67094 .46162 Mdot
.67098 .46137 Mdot
.67103 .46112 Mdot
.67108 .46087 Mdot
.67113 .46062 Mdot
.67117 .46037 Mdot
.67122 .46011 Mdot
.67127 .45986 Mdot
.67132 .45961 Mdot
.67136 .45936 Mdot
.67141 .45911 Mdot
.67146 .45885 Mdot
.67151 .4586 Mdot
.67155 .45835 Mdot
.6716 .4581 Mdot
.67165 .45784 Mdot
.6717 .45759 Mdot
.67174 .45734 Mdot
.67179 .45708 Mdot
.67184 .45683 Mdot
.67189 .45658 Mdot
.67194 .45632 Mdot
.67198 .45607 Mdot
.67203 .45581 Mdot
.67208 .45556 Mdot
.67213 .4553 Mdot
.67217 .45505 Mdot
.67222 .45479 Mdot
.67227 .45454 Mdot
.67232 .45428 Mdot
.67236 .45403 Mdot
.67241 .45377 Mdot
.67246 .45352 Mdot
.67251 .45326 Mdot
.67255 .45301 Mdot
.6726 .45275 Mdot
.67265 .4525 Mdot
.6727 .45224 Mdot
.67274 .45198 Mdot
.67279 .45173 Mdot
.67284 .45147 Mdot
.67289 .45121 Mdot
.67294 .45096 Mdot
.67298 .4507 Mdot
.67303 .45044 Mdot
.67308 .45018 Mdot
.67313 .44993 Mdot
.67317 .44967 Mdot
.67322 .44941 Mdot
.67327 .44915 Mdot
.67332 .4489 Mdot
.67336 .44864 Mdot
.67341 .44838 Mdot
.67346 .44812 Mdot
.67351 .44786 Mdot
.67355 .4476 Mdot
.6736 .44734 Mdot
.67365 .44709 Mdot
.6737 .44683 Mdot
.67374 .44657 Mdot
.67379 .44631 Mdot
.67384 .44605 Mdot
.67389 .44579 Mdot
.67393 .44553 Mdot
.67398 .44527 Mdot
.67403 .44501 Mdot
.67408 .44475 Mdot
.67413 .44449 Mdot
.67417 .44423 Mdot
.67422 .44397 Mdot
.67427 .44371 Mdot
.67432 .44344 Mdot
.67436 .44318 Mdot
.67441 .44292 Mdot
.67446 .44266 Mdot
.67451 .4424 Mdot
.67455 .44214 Mdot
.6746 .44188 Mdot
.67465 .44161 Mdot
.6747 .44135 Mdot
.67474 .44109 Mdot
.67479 .44083 Mdot
.67484 .44056 Mdot
.67489 .4403 Mdot
.67493 .44004 Mdot
.67498 .43978 Mdot
.67503 .43951 Mdot
.67508 .43925 Mdot
.67513 .43899 Mdot
.67517 .43872 Mdot
.67522 .43846 Mdot
.67527 .4382 Mdot
.67532 .43793 Mdot
.67536 .43767 Mdot
.67541 .43741 Mdot
.67546 .43714 Mdot
.67551 .43688 Mdot
.67555 .43661 Mdot
.6756 .43635 Mdot
.67565 .43608 Mdot
.6757 .43582 Mdot
.67574 .43555 Mdot
.67579 .43529 Mdot
.67584 .43502 Mdot
.67589 .43476 Mdot
.67593 .43449 Mdot
.67598 .43423 Mdot
.67603 .43396 Mdot
.67608 .4337 Mdot
.67613 .43343 Mdot
.67617 .43316 Mdot
.67622 .4329 Mdot
.67627 .43263 Mdot
.67632 .43237 Mdot
.67636 .4321 Mdot
.67641 .43183 Mdot
.67646 .43157 Mdot
.67651 .4313 Mdot
.67655 .43103 Mdot
.6766 .43076 Mdot
.67665 .4305 Mdot
.6767 .43023 Mdot
.67674 .42996 Mdot
.67679 .42969 Mdot
.67684 .42943 Mdot
.67689 .42916 Mdot
.67693 .42889 Mdot
.67698 .42862 Mdot
.67703 .42835 Mdot
.67708 .42809 Mdot
.67713 .42782 Mdot
.67717 .42755 Mdot
.67722 .42728 Mdot
.67727 .42701 Mdot
.67732 .42674 Mdot
.67736 .42647 Mdot
.67741 .4262 Mdot
.67746 .42594 Mdot
.67751 .42567 Mdot
.67755 .4254 Mdot
.6776 .42513 Mdot
.67765 .42486 Mdot
.6777 .42459 Mdot
.67774 .42432 Mdot
.67779 .42405 Mdot
.67784 .42378 Mdot
.67789 .42351 Mdot
.67793 .42324 Mdot
.67798 .42297 Mdot
.67803 .42269 Mdot
.67808 .42242 Mdot
.67813 .42215 Mdot
.67817 .42188 Mdot
.67822 .42161 Mdot
.67827 .42134 Mdot
.67832 .42107 Mdot
.67836 .4208 Mdot
.67841 .42053 Mdot
.67846 .42025 Mdot
.67851 .41998 Mdot
.67855 .41971 Mdot
.6786 .41944 Mdot
.67865 .41917 Mdot
.6787 .41889 Mdot
.67874 .41862 Mdot
.67879 .41835 Mdot
.67884 .41808 Mdot
.67889 .4178 Mdot
.67893 .41753 Mdot
.67898 .41726 Mdot
.67903 .41698 Mdot
.67908 .41671 Mdot
.67912 .41644 Mdot
.67917 .41616 Mdot
.67922 .41589 Mdot
.67927 .41562 Mdot
.67932 .41534 Mdot
.67936 .41507 Mdot
.67941 .4148 Mdot
.67946 .41452 Mdot
.67951 .41425 Mdot
.67955 .41397 Mdot
.6796 .4137 Mdot
.67965 .41343 Mdot
.6797 .41315 Mdot
.67974 .41288 Mdot
.67979 .4126 Mdot
.67984 .41233 Mdot
.67989 .41205 Mdot
.67993 .41178 Mdot
.67998 .4115 Mdot
.68003 .41123 Mdot
.68008 .41095 Mdot
.68012 .41068 Mdot
.68017 .4104 Mdot
.68022 .41012 Mdot
.68027 .40985 Mdot
.68032 .40957 Mdot
.68036 .4093 Mdot
.68041 .40902 Mdot
.68046 .40874 Mdot
.68051 .40847 Mdot
.68055 .40819 Mdot
.6806 .40792 Mdot
.68065 .40764 Mdot
.6807 .40736 Mdot
.68074 .40709 Mdot
.68079 .40681 Mdot
.68084 .40653 Mdot
.68089 .40625 Mdot
.68093 .40598 Mdot
.68098 .4057 Mdot
.68103 .40542 Mdot
.68108 .40515 Mdot
.68112 .40487 Mdot
.68117 .40459 Mdot
.68122 .40431 Mdot
.68127 .40403 Mdot
.68132 .40376 Mdot
.68136 .40348 Mdot
.68141 .4032 Mdot
.68146 .40292 Mdot
.68151 .40264 Mdot
.68155 .40237 Mdot
.6816 .40209 Mdot
.68165 .40181 Mdot
.6817 .40153 Mdot
.68174 .40125 Mdot
.68179 .40097 Mdot
.68184 .40069 Mdot
.68189 .40041 Mdot
.68193 .40014 Mdot
.68198 .39986 Mdot
.68203 .39958 Mdot
.68208 .3993 Mdot
.68212 .39902 Mdot
.68217 .39874 Mdot
.68222 .39846 Mdot
.68227 .39818 Mdot
.68232 .3979 Mdot
.68236 .39762 Mdot
.68241 .39734 Mdot
.68246 .39706 Mdot
.68251 .39678 Mdot
.68255 .3965 Mdot
.6826 .39622 Mdot
.68265 .39594 Mdot
.6827 .39566 Mdot
.68274 .39538 Mdot
.68279 .3951 Mdot
.68284 .39481 Mdot
.68289 .39453 Mdot
.68293 .39425 Mdot
.68298 .39397 Mdot
.68303 .39369 Mdot
.68308 .39341 Mdot
.68312 .39313 Mdot
.68317 .39285 Mdot
.68322 .39256 Mdot
.68327 .39228 Mdot
.68332 .392 Mdot
.68336 .39172 Mdot
.68341 .39144 Mdot
.68346 .39116 Mdot
.68351 .39087 Mdot
.68355 .39059 Mdot
.6836 .39031 Mdot
.68365 .39003 Mdot
.6837 .38974 Mdot
.68374 .38946 Mdot
.68379 .38918 Mdot
.68384 .3889 Mdot
.68389 .38861 Mdot
.68393 .38833 Mdot
.68398 .38805 Mdot
.68403 .38777 Mdot
.68408 .38748 Mdot
.68412 .3872 Mdot
.68417 .38692 Mdot
.68422 .38663 Mdot
.68427 .38635 Mdot
.68431 .38607 Mdot
.68436 .38578 Mdot
.68441 .3855 Mdot
.68446 .38522 Mdot
.68451 .38493 Mdot
.68455 .38465 Mdot
.6846 .38437 Mdot
.68465 .38408 Mdot
.6847 .3838 Mdot
.68474 .38351 Mdot
.68479 .38323 Mdot
.68484 .38294 Mdot
.68489 .38266 Mdot
.68493 .38238 Mdot
.68498 .38209 Mdot
.68503 .38181 Mdot
.68508 .38152 Mdot
.68512 .38124 Mdot
.68517 .38095 Mdot
.68522 .38067 Mdot
.68527 .38038 Mdot
.68531 .3801 Mdot
.68536 .37981 Mdot
.68541 .37953 Mdot
.68546 .37924 Mdot
.68551 .37896 Mdot
.68555 .37867 Mdot
.6856 .37839 Mdot
.68565 .3781 Mdot
.6857 .37782 Mdot
.68574 .37753 Mdot
.68579 .37725 Mdot
.68584 .37696 Mdot
.68589 .37667 Mdot
.68593 .37639 Mdot
.68598 .3761 Mdot
.68603 .37582 Mdot
.68608 .37553 Mdot
.68612 .37524 Mdot
.68617 .37496 Mdot
.68622 .37467 Mdot
.68627 .37439 Mdot
.68631 .3741 Mdot
.68636 .37381 Mdot
.68641 .37353 Mdot
.68646 .37324 Mdot
.68651 .37295 Mdot
.68655 .37267 Mdot
.6866 .37238 Mdot
.68665 .37209 Mdot
.6867 .37181 Mdot
.68674 .37152 Mdot
.68679 .37123 Mdot
.68684 .37094 Mdot
.68689 .37066 Mdot
.68693 .37037 Mdot
.68698 .37008 Mdot
.68703 .3698 Mdot
.68708 .36951 Mdot
.68712 .36922 Mdot
.68717 .36893 Mdot
.68722 .36865 Mdot
.68727 .36836 Mdot
.68731 .36807 Mdot
.68736 .36778 Mdot
.68741 .36749 Mdot
.68746 .36721 Mdot
.68751 .36692 Mdot
.68755 .36663 Mdot
.6876 .36634 Mdot
.68765 .36605 Mdot
.6877 .36577 Mdot
.68774 .36548 Mdot
.68779 .36519 Mdot
.68784 .3649 Mdot
.68789 .36461 Mdot
.68793 .36432 Mdot
.68798 .36404 Mdot
.68803 .36375 Mdot
.68808 .36346 Mdot
.68812 .36317 Mdot
.68817 .36288 Mdot
.68822 .36259 Mdot
.68827 .3623 Mdot
.68831 .36201 Mdot
.68836 .36173 Mdot
.68841 .36144 Mdot
.68846 .36115 Mdot
.6885 .36086 Mdot
.68855 .36057 Mdot
.6886 .36028 Mdot
.68865 .35999 Mdot
.6887 .3597 Mdot
.68874 .35941 Mdot
.68879 .35912 Mdot
.68884 .35883 Mdot
.68889 .35854 Mdot
.68893 .35825 Mdot
.68898 .35796 Mdot
.68903 .35767 Mdot
.68908 .35739 Mdot
.68912 .3571 Mdot
.68917 .35681 Mdot
.68922 .35652 Mdot
.68927 .35623 Mdot
.68931 .35594 Mdot
.68936 .35565 Mdot
.68941 .35536 Mdot
.68946 .35507 Mdot
.6895 .35478 Mdot
.68955 .35449 Mdot
.6896 .3542 Mdot
.68965 .3539 Mdot
.6897 .35361 Mdot
.68974 .35332 Mdot
.68979 .35303 Mdot
.68984 .35274 Mdot
.68989 .35245 Mdot
.68993 .35216 Mdot
.68998 .35187 Mdot
.69003 .35158 Mdot
.69008 .35129 Mdot
.69012 .351 Mdot
.69017 .35071 Mdot
.69022 .35042 Mdot
.69027 .35013 Mdot
.69031 .34984 Mdot
.69036 .34955 Mdot
.69041 .34925 Mdot
.69046 .34896 Mdot
.6905 .34867 Mdot
.69055 .34838 Mdot
.6906 .34809 Mdot
.69065 .3478 Mdot
.6907 .34751 Mdot
.69074 .34722 Mdot
.69079 .34693 Mdot
.69084 .34663 Mdot
.69089 .34634 Mdot
.69093 .34605 Mdot
.69098 .34576 Mdot
.69103 .34547 Mdot
.69108 .34518 Mdot
.69112 .34488 Mdot
.69117 .34459 Mdot
.69122 .3443 Mdot
.69127 .34401 Mdot
.69131 .34372 Mdot
.69136 .34343 Mdot
.69141 .34313 Mdot
.69146 .34284 Mdot
.6915 .34255 Mdot
.69155 .34226 Mdot
.6916 .34197 Mdot
.69165 .34168 Mdot
.6917 .34138 Mdot
.69174 .34109 Mdot
.69179 .3408 Mdot
.69184 .34051 Mdot
.69189 .34022 Mdot
.69193 .33992 Mdot
.69198 .33963 Mdot
.69203 .33934 Mdot
.69208 .33905 Mdot
.69212 .33875 Mdot
.69217 .33846 Mdot
.69222 .33817 Mdot
.69227 .33788 Mdot
.69231 .33758 Mdot
.69236 .33729 Mdot
.69241 .337 Mdot
.69246 .33671 Mdot
.6925 .33642 Mdot
.69255 .33612 Mdot
.6926 .33583 Mdot
.69265 .33554 Mdot
.6927 .33524 Mdot
.69274 .33495 Mdot
.69279 .33466 Mdot
.69284 .33437 Mdot
.69289 .33407 Mdot
.69293 .33378 Mdot
.69298 .33349 Mdot
.69303 .3332 Mdot
.69308 .3329 Mdot
.69312 .33261 Mdot
.69317 .33232 Mdot
.69322 .33202 Mdot
.69327 .33173 Mdot
.69331 .33144 Mdot
.69336 .33115 Mdot
.69341 .33085 Mdot
.69346 .33056 Mdot
.6935 .33027 Mdot
.69355 .32997 Mdot
.6936 .32968 Mdot
.69365 .32939 Mdot
.69369 .32909 Mdot
.69374 .3288 Mdot
.69379 .32851 Mdot
.69384 .32821 Mdot
.69389 .32792 Mdot
.69393 .32763 Mdot
.69398 .32734 Mdot
.69403 .32704 Mdot
.69408 .32675 Mdot
.69412 .32646 Mdot
.69417 .32616 Mdot
.69422 .32587 Mdot
.69427 .32558 Mdot
.69431 .32528 Mdot
.69436 .32499 Mdot
.69441 .3247 Mdot
.69446 .3244 Mdot
.6945 .32411 Mdot
.69455 .32382 Mdot
.6946 .32352 Mdot
.69465 .32323 Mdot
.69469 .32293 Mdot
.69474 .32264 Mdot
.69479 .32235 Mdot
.69484 .32205 Mdot
.69489 .32176 Mdot
.69493 .32147 Mdot
.69498 .32117 Mdot
.69503 .32088 Mdot
.69508 .32059 Mdot
.69512 .32029 Mdot
.69517 .32 Mdot
.69522 .31971 Mdot
.69527 .31941 Mdot
.69531 .31912 Mdot
.69536 .31882 Mdot
.69541 .31853 Mdot
.69546 .31824 Mdot
.6955 .31794 Mdot
.69555 .31765 Mdot
.6956 .31736 Mdot
.69565 .31706 Mdot
.69569 .31677 Mdot
.69574 .31648 Mdot
.69579 .31618 Mdot
.69584 .31589 Mdot
.69589 .31559 Mdot
.69593 .3153 Mdot
.69598 .31501 Mdot
.69603 .31471 Mdot
.69608 .31442 Mdot
.69612 .31413 Mdot
.69617 .31383 Mdot
.69622 .31354 Mdot
.69627 .31324 Mdot
.69631 .31295 Mdot
.69636 .31266 Mdot
.69641 .31236 Mdot
.69646 .31207 Mdot
.6965 .31177 Mdot
.69655 .31148 Mdot
.6966 .31119 Mdot
.69665 .31089 Mdot
.69669 .3106 Mdot
.69674 .31031 Mdot
.69679 .31001 Mdot
.69684 .30972 Mdot
.69689 .30942 Mdot
.69693 .30913 Mdot
.69698 .30884 Mdot
.69703 .30854 Mdot
.69708 .30825 Mdot
.69712 .30795 Mdot
.69717 .30766 Mdot
.69722 .30737 Mdot
.69727 .30707 Mdot
.69731 .30678 Mdot
.69736 .30649 Mdot
.69741 .30619 Mdot
.69746 .3059 Mdot
.6975 .3056 Mdot
.69755 .30531 Mdot
.6976 .30502 Mdot
.69765 .30472 Mdot
.69769 .30443 Mdot
.69774 .30413 Mdot
.69779 .30384 Mdot
.69784 .30355 Mdot
.69788 .30325 Mdot
.69793 .30296 Mdot
.69798 .30267 Mdot
.69803 .30237 Mdot
.69808 .30208 Mdot
.69812 .30178 Mdot
.69817 .30149 Mdot
.69822 .3012 Mdot
.69827 .3009 Mdot
.69831 .30061 Mdot
.69836 .30032 Mdot
.69841 .30002 Mdot
.69846 .29973 Mdot
.6985 .29943 Mdot
.69855 .29914 Mdot
.6986 .29885 Mdot
.69865 .29855 Mdot
.69869 .29826 Mdot
.69874 .29797 Mdot
.69879 .29767 Mdot
.69884 .29738 Mdot
.69888 .29709 Mdot
.69893 .29679 Mdot
.69898 .2965 Mdot
.69903 .2962 Mdot
.69908 .29591 Mdot
.69912 .29562 Mdot
.69917 .29532 Mdot
.69922 .29503 Mdot
.69927 .29474 Mdot
.69931 .29444 Mdot
.69936 .29415 Mdot
.69941 .29386 Mdot
.69946 .29356 Mdot
.6995 .29327 Mdot
.69955 .29298 Mdot
.6996 .29268 Mdot
.69965 .29239 Mdot
.69969 .2921 Mdot
.69974 .2918 Mdot
.69979 .29151 Mdot
.69984 .29122 Mdot
.69988 .29092 Mdot
.69993 .29063 Mdot
.69998 .29034 Mdot
.70003 .29004 Mdot
.70008 .28975 Mdot
.70012 .28946 Mdot
.70017 .28916 Mdot
.70022 .28887 Mdot
.70027 .28858 Mdot
.70031 .28828 Mdot
.70036 .28799 Mdot
.70041 .2877 Mdot
.70046 .2874 Mdot
.7005 .28711 Mdot
.70055 .28682 Mdot
.7006 .28652 Mdot
.70065 .28623 Mdot
.70069 .28594 Mdot
.70074 .28565 Mdot
.70079 .28535 Mdot
.70084 .28506 Mdot
.70088 .28477 Mdot
.70093 .28447 Mdot
.70098 .28418 Mdot
.70103 .28389 Mdot
.70108 .2836 Mdot
.70112 .2833 Mdot
.70117 .28301 Mdot
.70122 .28272 Mdot
.70127 .28242 Mdot
.70131 .28213 Mdot
.70136 .28184 Mdot
.70141 .28155 Mdot
.70146 .28125 Mdot
.7015 .28096 Mdot
.70155 .28067 Mdot
.7016 .28038 Mdot
.70165 .28008 Mdot
.70169 .27979 Mdot
.70174 .2795 Mdot
.70179 .27921 Mdot
.70184 .27891 Mdot
.70188 .27862 Mdot
.70193 .27833 Mdot
.70198 .27804 Mdot
.70203 .27775 Mdot
.70208 .27745 Mdot
.70212 .27716 Mdot
.70217 .27687 Mdot
.70222 .27658 Mdot
.70227 .27628 Mdot
.70231 .27599 Mdot
.70236 .2757 Mdot
.70241 .27541 Mdot
.70246 .27512 Mdot
.7025 .27482 Mdot
.70255 .27453 Mdot
.7026 .27424 Mdot
.70265 .27395 Mdot
.70269 .27366 Mdot
.70274 .27337 Mdot
.70279 .27307 Mdot
.70284 .27278 Mdot
.70288 .27249 Mdot
.70293 .2722 Mdot
.70298 .27191 Mdot
.70303 .27162 Mdot
.70307 .27132 Mdot
.70312 .27103 Mdot
.70317 .27074 Mdot
.70322 .27045 Mdot
.70327 .27016 Mdot
.70331 .26987 Mdot
.70336 .26958 Mdot
.70341 .26929 Mdot
.70346 .26899 Mdot
.7035 .2687 Mdot
.70355 .26841 Mdot
.7036 .26812 Mdot
.70365 .26783 Mdot
.70369 .26754 Mdot
.70374 .26725 Mdot
.70379 .26696 Mdot
.70384 .26667 Mdot
.70388 .26638 Mdot
.70393 .26608 Mdot
.70398 .26579 Mdot
.70403 .2655 Mdot
.70407 .26521 Mdot
.70412 .26492 Mdot
.70417 .26463 Mdot
.70422 .26434 Mdot
.70427 .26405 Mdot
.70431 .26376 Mdot
.70436 .26347 Mdot
.70441 .26318 Mdot
.70446 .26289 Mdot
.7045 .2626 Mdot
.70455 .26231 Mdot
.7046 .26202 Mdot
.70465 .26173 Mdot
.70469 .26144 Mdot
.70474 .26115 Mdot
.70479 .26086 Mdot
.70484 .26057 Mdot
.70488 .26028 Mdot
.70493 .25999 Mdot
.70498 .2597 Mdot
.70503 .25941 Mdot
.70507 .25912 Mdot
.70512 .25883 Mdot
.70517 .25854 Mdot
.70522 .25825 Mdot
.70527 .25796 Mdot
.70531 .25767 Mdot
.70536 .25738 Mdot
.70541 .25709 Mdot
.70546 .2568 Mdot
.7055 .25651 Mdot
.70555 .25622 Mdot
.7056 .25594 Mdot
.70565 .25565 Mdot
.70569 .25536 Mdot
.70574 .25507 Mdot
.70579 .25478 Mdot
.70584 .25449 Mdot
.70588 .2542 Mdot
.70593 .25391 Mdot
.70598 .25362 Mdot
.70603 .25334 Mdot
.70607 .25305 Mdot
.70612 .25276 Mdot
.70617 .25247 Mdot
.70622 .25218 Mdot
.70627 .25189 Mdot
.70631 .25161 Mdot
.70636 .25132 Mdot
.70641 .25103 Mdot
.70646 .25074 Mdot
.7065 .25045 Mdot
.70655 .25016 Mdot
.7066 .24988 Mdot
.70665 .24959 Mdot
.70669 .2493 Mdot
.70674 .24901 Mdot
.70679 .24873 Mdot
.70684 .24844 Mdot
.70688 .24815 Mdot
.70693 .24786 Mdot
.70698 .24757 Mdot
.70703 .24729 Mdot
.70707 .247 Mdot
.70712 .24671 Mdot
.70717 .24643 Mdot
.70722 .24614 Mdot
.70726 .24585 Mdot
.70731 .24556 Mdot
.70736 .24528 Mdot
.70741 .24499 Mdot
.70746 .2447 Mdot
.7075 .24442 Mdot
.70755 .24413 Mdot
.7076 .24384 Mdot
.70765 .24356 Mdot
.70769 .24327 Mdot
.70774 .24298 Mdot
.70779 .2427 Mdot
.70784 .24241 Mdot
.70788 .24212 Mdot
.70793 .24184 Mdot
.70798 .24155 Mdot
.70803 .24127 Mdot
.70807 .24098 Mdot
.70812 .24069 Mdot
.70817 .24041 Mdot
.70822 .24012 Mdot
.70826 .23984 Mdot
.70831 .23955 Mdot
.70836 .23927 Mdot
.70841 .23898 Mdot
.70846 .23869 Mdot
.7085 .23841 Mdot
.70855 .23812 Mdot
.7086 .23784 Mdot
.70865 .23755 Mdot
.70869 .23727 Mdot
.70874 .23698 Mdot
.70879 .2367 Mdot
.70884 .23641 Mdot
.70888 .23613 Mdot
.70893 .23584 Mdot
.70898 .23556 Mdot
.70903 .23527 Mdot
.70907 .23499 Mdot
.70912 .23471 Mdot
.70917 .23442 Mdot
.70922 .23414 Mdot
.70926 .23385 Mdot
.70931 .23357 Mdot
.70936 .23328 Mdot
.70941 .233 Mdot
.70946 .23272 Mdot
.7095 .23243 Mdot
.70955 .23215 Mdot
.7096 .23186 Mdot
.70965 .23158 Mdot
.70969 .2313 Mdot
.70974 .23101 Mdot
.70979 .23073 Mdot
.70984 .23045 Mdot
.70988 .23016 Mdot
.70993 .22988 Mdot
.70998 .2296 Mdot
.71003 .22932 Mdot
.71007 .22903 Mdot
.71012 .22875 Mdot
.71017 .22847 Mdot
.71022 .22818 Mdot
.71026 .2279 Mdot
.71031 .22762 Mdot
.71036 .22734 Mdot
.71041 .22705 Mdot
.71046 .22677 Mdot
.7105 .22649 Mdot
.71055 .22621 Mdot
.7106 .22593 Mdot
.71065 .22564 Mdot
.71069 .22536 Mdot
.71074 .22508 Mdot
.71079 .2248 Mdot
.71084 .22452 Mdot
.71088 .22423 Mdot
.71093 .22395 Mdot
.71098 .22367 Mdot
.71103 .22339 Mdot
.71107 .22311 Mdot
.71112 .22283 Mdot
.71117 .22255 Mdot
.71122 .22227 Mdot
.71126 .22199 Mdot
.71131 .2217 Mdot
.71136 .22142 Mdot
.71141 .22114 Mdot
.71146 .22086 Mdot
.7115 .22058 Mdot
.71155 .2203 Mdot
.7116 .22002 Mdot
.71165 .21974 Mdot
.71169 .21946 Mdot
.71174 .21918 Mdot
.71179 .2189 Mdot
.71184 .21862 Mdot
.71188 .21834 Mdot
.71193 .21806 Mdot
.71198 .21778 Mdot
.71203 .2175 Mdot
.71207 .21722 Mdot
.71212 .21695 Mdot
.71217 .21667 Mdot
.71222 .21639 Mdot
.71226 .21611 Mdot
.71231 .21583 Mdot
.71236 .21555 Mdot
.71241 .21527 Mdot
.71245 .21499 Mdot
.7125 .21471 Mdot
.71255 .21444 Mdot
.7126 .21416 Mdot
.71265 .21388 Mdot
.71269 .2136 Mdot
.71274 .21332 Mdot
.71279 .21305 Mdot
.71284 .21277 Mdot
.71288 .21249 Mdot
.71293 .21221 Mdot
.71298 .21193 Mdot
.71303 .21166 Mdot
.71307 .21138 Mdot
.71312 .2111 Mdot
.71317 .21082 Mdot
.71322 .21055 Mdot
.71326 .21027 Mdot
.71331 .20999 Mdot
.71336 .20972 Mdot
.71341 .20944 Mdot
.71345 .20916 Mdot
.7135 .20889 Mdot
.71355 .20861 Mdot
.7136 .20833 Mdot
.71365 .20806 Mdot
.71369 .20778 Mdot
.71374 .20751 Mdot
.71379 .20723 Mdot
.71384 .20695 Mdot
.71388 .20668 Mdot
.71393 .2064 Mdot
.71398 .20613 Mdot
.71403 .20585 Mdot
.71407 .20558 Mdot
.71412 .2053 Mdot
.71417 .20503 Mdot
.71422 .20475 Mdot
.71426 .20448 Mdot
.71431 .2042 Mdot
.71436 .20393 Mdot
.71441 .20365 Mdot
.71445 .20338 Mdot
.7145 .2031 Mdot
.71455 .20283 Mdot
.7146 .20256 Mdot
.71465 .20228 Mdot
.71469 .20201 Mdot
.71474 .20173 Mdot
.71479 .20146 Mdot
.71484 .20119 Mdot
.71488 .20091 Mdot
.71493 .20064 Mdot
.71498 .20037 Mdot
.71503 .20009 Mdot
.71507 .19982 Mdot
.71512 .19955 Mdot
.71517 .19928 Mdot
.71522 .199 Mdot
.71526 .19873 Mdot
.71531 .19846 Mdot
.71536 .19818 Mdot
.71541 .19791 Mdot
.71545 .19764 Mdot
.7155 .19737 Mdot
.71555 .1971 Mdot
.7156 .19682 Mdot
.71565 .19655 Mdot
.71569 .19628 Mdot
.71574 .19601 Mdot
.71579 .19574 Mdot
.71584 .19547 Mdot
.71588 .1952 Mdot
.71593 .19492 Mdot
.71598 .19465 Mdot
.71603 .19438 Mdot
.71607 .19411 Mdot
.71612 .19384 Mdot
.71617 .19357 Mdot
.71622 .1933 Mdot
.71626 .19303 Mdot
.71631 .19276 Mdot
.71636 .19249 Mdot
.71641 .19222 Mdot
.71645 .19195 Mdot
.7165 .19168 Mdot
.71655 .19141 Mdot
.7166 .19114 Mdot
.71665 .19087 Mdot
.71669 .1906 Mdot
.71674 .19033 Mdot
.71679 .19007 Mdot
.71684 .1898 Mdot
.71688 .18953 Mdot
.71693 .18926 Mdot
.71698 .18899 Mdot
.71703 .18872 Mdot
.71707 .18845 Mdot
.71712 .18819 Mdot
.71717 .18792 Mdot
.71722 .18765 Mdot
.71726 .18738 Mdot
.71731 .18711 Mdot
.71736 .18685 Mdot
.71741 .18658 Mdot
.71745 .18631 Mdot
.7175 .18604 Mdot
.71755 .18578 Mdot
.7176 .18551 Mdot
.71764 .18524 Mdot
.71769 .18498 Mdot
.71774 .18471 Mdot
.71779 .18444 Mdot
.71784 .18418 Mdot
.71788 .18391 Mdot
.71793 .18365 Mdot
.71798 .18338 Mdot
.71803 .18311 Mdot
.71807 .18285 Mdot
.71812 .18258 Mdot
.71817 .18232 Mdot
.71822 .18205 Mdot
.71826 .18179 Mdot
.71831 .18152 Mdot
.71836 .18126 Mdot
.71841 .18099 Mdot
.71845 .18073 Mdot
.7185 .18046 Mdot
.71855 .1802 Mdot
.7186 .17993 Mdot
.71864 .17967 Mdot
.71869 .17941 Mdot
.71874 .17914 Mdot
.71879 .17888 Mdot
.71884 .17861 Mdot
.71888 .17835 Mdot
.71893 .17809 Mdot
.71898 .17782 Mdot
.71903 .17756 Mdot
.71907 .1773 Mdot
.71912 .17704 Mdot
.71917 .17677 Mdot
.71922 .17651 Mdot
.71926 .17625 Mdot
.71931 .17599 Mdot
.71936 .17572 Mdot
.71941 .17546 Mdot
.71945 .1752 Mdot
.7195 .17494 Mdot
.71955 .17468 Mdot
.7196 .17441 Mdot
.71964 .17415 Mdot
.71969 .17389 Mdot
.71974 .17363 Mdot
.71979 .17337 Mdot
.71984 .17311 Mdot
.71988 .17285 Mdot
.71993 .17259 Mdot
.71998 .17233 Mdot
.72003 .17207 Mdot
.72007 .17181 Mdot
.72012 .17155 Mdot
.72017 .17129 Mdot
.72022 .17103 Mdot
.72026 .17077 Mdot
.72031 .17051 Mdot
.72036 .17025 Mdot
.72041 .16999 Mdot
.72045 .16973 Mdot
.7205 .16947 Mdot
.72055 .16921 Mdot
.7206 .16895 Mdot
.72064 .1687 Mdot
.72069 .16844 Mdot
.72074 .16818 Mdot
.72079 .16792 Mdot
.72084 .16766 Mdot
.72088 .1674 Mdot
.72093 .16715 Mdot
.72098 .16689 Mdot
.72103 .16663 Mdot
.72107 .16637 Mdot
.72112 .16612 Mdot
.72117 .16586 Mdot
.72122 .1656 Mdot
.72126 .16535 Mdot
.72131 .16509 Mdot
.72136 .16483 Mdot
.72141 .16458 Mdot
.72145 .16432 Mdot
.7215 .16407 Mdot
.72155 .16381 Mdot
.7216 .16355 Mdot
.72164 .1633 Mdot
.72169 .16304 Mdot
.72174 .16279 Mdot
.72179 .16253 Mdot
.72183 .16228 Mdot
.72188 .16202 Mdot
.72193 .16177 Mdot
.72198 .16151 Mdot
.72203 .16126 Mdot
.72207 .16101 Mdot
.72212 .16075 Mdot
.72217 .1605 Mdot
.72222 .16024 Mdot
.72226 .15999 Mdot
.72231 .15974 Mdot
.72236 .15948 Mdot
.72241 .15923 Mdot
.72245 .15898 Mdot
.7225 .15872 Mdot
.72255 .15847 Mdot
.7226 .15822 Mdot
.72264 .15797 Mdot
.72269 .15771 Mdot
.72274 .15746 Mdot
.72279 .15721 Mdot
.72283 .15696 Mdot
.72288 .15671 Mdot
.72293 .15646 Mdot
.72298 .1562 Mdot
.72303 .15595 Mdot
.72307 .1557 Mdot
.72312 .15545 Mdot
.72317 .1552 Mdot
.72322 .15495 Mdot
.72326 .1547 Mdot
.72331 .15445 Mdot
.72336 .1542 Mdot
.72341 .15395 Mdot
.72345 .1537 Mdot
.7235 .15345 Mdot
.72355 .1532 Mdot
.7236 .15295 Mdot
.72364 .1527 Mdot
.72369 .15245 Mdot
.72374 .1522 Mdot
.72379 .15195 Mdot
.72383 .15171 Mdot
.72388 .15146 Mdot
.72393 .15121 Mdot
.72398 .15096 Mdot
.72403 .15071 Mdot
.72407 .15047 Mdot
.72412 .15022 Mdot
.72417 .14997 Mdot
.72422 .14972 Mdot
.72426 .14948 Mdot
.72431 .14923 Mdot
.72436 .14898 Mdot
.72441 .14874 Mdot
.72445 .14849 Mdot
.7245 .14824 Mdot
.72455 .148 Mdot
.7246 .14775 Mdot
.72464 .1475 Mdot
.72469 .14726 Mdot
.72474 .14701 Mdot
.72479 .14677 Mdot
.72483 .14652 Mdot
.72488 .14628 Mdot
.72493 .14603 Mdot
.72498 .14579 Mdot
.72503 .14554 Mdot
.72507 .1453 Mdot
.72512 .14505 Mdot
.72517 .14481 Mdot
.72522 .14457 Mdot
.72526 .14432 Mdot
.72531 .14408 Mdot
.72536 .14384 Mdot
.72541 .14359 Mdot
.72545 .14335 Mdot
.7255 .14311 Mdot
.72555 .14286 Mdot
.7256 .14262 Mdot
.72564 .14238 Mdot
.72569 .14214 Mdot
.72574 .14189 Mdot
.72579 .14165 Mdot
.72583 .14141 Mdot
.72588 .14117 Mdot
.72593 .14093 Mdot
.72598 .14069 Mdot
.72603 .14044 Mdot
.72607 .1402 Mdot
.72612 .13996 Mdot
.72617 .13972 Mdot
.72622 .13948 Mdot
.72626 .13924 Mdot
.72631 .139 Mdot
.72636 .13876 Mdot
.72641 .13852 Mdot
.72645 .13828 Mdot
.7265 .13804 Mdot
.72655 .1378 Mdot
.7266 .13756 Mdot
.72664 .13733 Mdot
.72669 .13709 Mdot
.72674 .13685 Mdot
.72679 .13661 Mdot
.72683 .13637 Mdot
.72688 .13613 Mdot
.72693 .1359 Mdot
.72698 .13566 Mdot
.72702 .13542 Mdot
.72707 .13518 Mdot
.72712 .13495 Mdot
.72717 .13471 Mdot
.72722 .13447 Mdot
.72726 .13424 Mdot
.72731 .134 Mdot
.72736 .13376 Mdot
.72741 .13353 Mdot
.72745 .13329 Mdot
.7275 .13305 Mdot
.72755 .13282 Mdot
.7276 .13258 Mdot
.72764 .13235 Mdot
.72769 .13211 Mdot
.72774 .13188 Mdot
.72779 .13164 Mdot
.72783 .13141 Mdot
.72788 .13117 Mdot
.72793 .13094 Mdot
.72798 .13071 Mdot
.72802 .13047 Mdot
.72807 .13024 Mdot
.72812 .13001 Mdot
.72817 .12977 Mdot
.72822 .12954 Mdot
.72826 .12931 Mdot
.72831 .12907 Mdot
.72836 .12884 Mdot
.72841 .12861 Mdot
.72845 .12838 Mdot
.7285 .12814 Mdot
.72855 .12791 Mdot
.7286 .12768 Mdot
.72864 .12745 Mdot
.72869 .12722 Mdot
.72874 .12699 Mdot
.72879 .12676 Mdot
.72883 .12652 Mdot
.72888 .12629 Mdot
.72893 .12606 Mdot
.72898 .12583 Mdot
.72902 .1256 Mdot
.72907 .12537 Mdot
.72912 .12514 Mdot
.72917 .12491 Mdot
.72922 .12468 Mdot
.72926 .12446 Mdot
.72931 .12423 Mdot
.72936 .124 Mdot
.72941 .12377 Mdot
.72945 .12354 Mdot
.7295 .12331 Mdot
.72955 .12308 Mdot
.7296 .12286 Mdot
.72964 .12263 Mdot
.72969 .1224 Mdot
.72974 .12217 Mdot
.72979 .12195 Mdot
.72983 .12172 Mdot
.72988 .12149 Mdot
.72993 .12127 Mdot
.72998 .12104 Mdot
.73002 .12081 Mdot
.73007 .12059 Mdot
.73012 .12036 Mdot
.73017 .12014 Mdot
.73022 .11991 Mdot
.73026 .11969 Mdot
.73031 .11946 Mdot
.73036 .11924 Mdot
.73041 .11901 Mdot
.73045 .11879 Mdot
.7305 .11856 Mdot
.73055 .11834 Mdot
.7306 .11812 Mdot
.73064 .11789 Mdot
.73069 .11767 Mdot
.73074 .11744 Mdot
.73079 .11722 Mdot
.73083 .117 Mdot
.73088 .11678 Mdot
.73093 .11655 Mdot
.73098 .11633 Mdot
.73102 .11611 Mdot
.73107 .11589 Mdot
.73112 .11566 Mdot
.73117 .11544 Mdot
.73121 .11522 Mdot
.73126 .115 Mdot
.73131 .11478 Mdot
.73136 .11456 Mdot
.73141 .11434 Mdot
.73145 .11412 Mdot
.7315 .1139 Mdot
.73155 .11368 Mdot
.7316 .11346 Mdot
.73164 .11324 Mdot
.73169 .11302 Mdot
.73174 .1128 Mdot
.73179 .11258 Mdot
.73183 .11236 Mdot
.73188 .11214 Mdot
.73193 .11192 Mdot
.73198 .11171 Mdot
.73202 .11149 Mdot
.73207 .11127 Mdot
.73212 .11105 Mdot
.73217 .11083 Mdot
.73221 .11062 Mdot
.73226 .1104 Mdot
.73231 .11018 Mdot
.73236 .10997 Mdot
.73241 .10975 Mdot
.73245 .10953 Mdot
.7325 .10932 Mdot
.73255 .1091 Mdot
.7326 .10889 Mdot
.73264 .10867 Mdot
.73269 .10846 Mdot
.73274 .10824 Mdot
.73279 .10803 Mdot
.73283 .10781 Mdot
.73288 .1076 Mdot
.73293 .10738 Mdot
.73298 .10717 Mdot
.73302 .10695 Mdot
.73307 .10674 Mdot
.73312 .10653 Mdot
.73317 .10631 Mdot
.73321 .1061 Mdot
.73326 .10589 Mdot
.73331 .10567 Mdot
.73336 .10546 Mdot
.73341 .10525 Mdot
.73345 .10504 Mdot
.7335 .10483 Mdot
.73355 .10461 Mdot
.7336 .1044 Mdot
.73364 .10419 Mdot
.73369 .10398 Mdot
.73374 .10377 Mdot
.73379 .10356 Mdot
.73383 .10335 Mdot
.73388 .10314 Mdot
.73393 .10293 Mdot
.73398 .10272 Mdot
.73402 .10251 Mdot
.73407 .1023 Mdot
.73412 .10209 Mdot
.73417 .10188 Mdot
.73421 .10167 Mdot
.73426 .10146 Mdot
.73431 .10125 Mdot
.73436 .10105 Mdot
.73441 .10084 Mdot
.73445 .10063 Mdot
.7345 .10042 Mdot
.73455 .10022 Mdot
.7346 .10001 Mdot
.73464 .0998 Mdot
.73469 .0996 Mdot
.73474 .09939 Mdot
.73479 .09918 Mdot
.73483 .09898 Mdot
.73488 .09877 Mdot
.73493 .09856 Mdot
.73498 .09836 Mdot
.73502 .09815 Mdot
.73507 .09795 Mdot
.73512 .09774 Mdot
.73517 .09754 Mdot
.73521 .09734 Mdot
.73526 .09713 Mdot
.73531 .09693 Mdot
.73536 .09672 Mdot
.73541 .09652 Mdot
.73545 .09632 Mdot
.7355 .09611 Mdot
.73555 .09591 Mdot
.7356 .09571 Mdot
.73564 .0955 Mdot
.73569 .0953 Mdot
.73574 .0951 Mdot
.73579 .0949 Mdot
.73583 .0947 Mdot
.73588 .0945 Mdot
.73593 .09429 Mdot
.73598 .09409 Mdot
.73602 .09389 Mdot
.73607 .09369 Mdot
.73612 .09349 Mdot
.73617 .09329 Mdot
.73621 .09309 Mdot
.73626 .09289 Mdot
.73631 .09269 Mdot
.73636 .09249 Mdot
.7364 .09229 Mdot
.73645 .09209 Mdot
.7365 .0919 Mdot
.73655 .0917 Mdot
.7366 .0915 Mdot
.73664 .0913 Mdot
.73669 .0911 Mdot
.73674 .09091 Mdot
.73679 .09071 Mdot
.73683 .09051 Mdot
.73688 .09031 Mdot
.73693 .09012 Mdot
.73698 .08992 Mdot
.73702 .08973 Mdot
.73707 .08953 Mdot
.73712 .08933 Mdot
.73717 .08914 Mdot
.73721 .08894 Mdot
.73726 .08875 Mdot
.73731 .08855 Mdot
.73736 .08836 Mdot
.7374 .08816 Mdot
.73745 .08797 Mdot
.7375 .08778 Mdot
.73755 .08758 Mdot
.7376 .08739 Mdot
.73764 .08719 Mdot
.73769 .087 Mdot
.73774 .08681 Mdot
.73779 .08662 Mdot
.73783 .08642 Mdot
.73788 .08623 Mdot
.73793 .08604 Mdot
.73798 .08585 Mdot
.73802 .08566 Mdot
.73807 .08546 Mdot
.73812 .08527 Mdot
.73817 .08508 Mdot
.73821 .08489 Mdot
.73826 .0847 Mdot
.73831 .08451 Mdot
.73836 .08432 Mdot
.7384 .08413 Mdot
.73845 .08394 Mdot
.7385 .08375 Mdot
.73855 .08356 Mdot
.7386 .08337 Mdot
.73864 .08318 Mdot
.73869 .083 Mdot
.73874 .08281 Mdot
.73879 .08262 Mdot
.73883 .08243 Mdot
.73888 .08224 Mdot
.73893 .08206 Mdot
.73898 .08187 Mdot
.73902 .08168 Mdot
.73907 .0815 Mdot
.73912 .08131 Mdot
.73917 .08112 Mdot
.73921 .08094 Mdot
.73926 .08075 Mdot
.73931 .08057 Mdot
.73936 .08038 Mdot
.7394 .0802 Mdot
.73945 .08001 Mdot
.7395 .07983 Mdot
.73955 .07964 Mdot
.7396 .07946 Mdot
.73964 .07927 Mdot
.73969 .07909 Mdot
.73974 .07891 Mdot
.73979 .07872 Mdot
.73983 .07854 Mdot
.73988 .07836 Mdot
.73993 .07818 Mdot
.73998 .07799 Mdot
.74002 .07781 Mdot
.74007 .07763 Mdot
.74012 .07745 Mdot
.74017 .07727 Mdot
.74021 .07709 Mdot
.74026 .0769 Mdot
.74031 .07672 Mdot
.74036 .07654 Mdot
.7404 .07636 Mdot
.74045 .07618 Mdot
.7405 .076 Mdot
.74055 .07582 Mdot
.74059 .07564 Mdot
.74064 .07547 Mdot
.74069 .07529 Mdot
.74074 .07511 Mdot
.74079 .07493 Mdot
.74083 .07475 Mdot
.74088 .07457 Mdot
.74093 .0744 Mdot
.74098 .07422 Mdot
.74102 .07404 Mdot
.74107 .07386 Mdot
.74112 .07369 Mdot
.74117 .07351 Mdot
.74121 .07333 Mdot
.74126 .07316 Mdot
.74131 .07298 Mdot
.74136 .07281 Mdot
.7414 .07263 Mdot
.74145 .07246 Mdot
.7415 .07228 Mdot
.74155 .07211 Mdot
.74159 .07193 Mdot
.74164 .07176 Mdot
.74169 .07159 Mdot
.74174 .07141 Mdot
.74179 .07124 Mdot
.74183 .07106 Mdot
.74188 .07089 Mdot
.74193 .07072 Mdot
.74198 .07055 Mdot
.74202 .07037 Mdot
.74207 .0702 Mdot
.74212 .07003 Mdot
.74217 .06986 Mdot
.74221 .06969 Mdot
.74226 .06952 Mdot
.74231 .06935 Mdot
.74236 .06918 Mdot
.7424 .06901 Mdot
.74245 .06883 Mdot
.7425 .06867 Mdot
.74255 .0685 Mdot
.74259 .06833 Mdot
.74264 .06816 Mdot
.74269 .06799 Mdot
.74274 .06782 Mdot
.74279 .06765 Mdot
.74283 .06748 Mdot
.74288 .06732 Mdot
.74293 .06715 Mdot
.74298 .06698 Mdot
.74302 .06681 Mdot
.74307 .06665 Mdot
.74312 .06648 Mdot
.74317 .06631 Mdot
.74321 .06615 Mdot
.74326 .06598 Mdot
.74331 .06581 Mdot
.74336 .06565 Mdot
.7434 .06548 Mdot
.74345 .06532 Mdot
.7435 .06515 Mdot
.74355 .06499 Mdot
.74359 .06483 Mdot
.74364 .06466 Mdot
.74369 .0645 Mdot
.74374 .06433 Mdot
.74379 .06417 Mdot
.74383 .06401 Mdot
.74388 .06384 Mdot
.74393 .06368 Mdot
.74398 .06352 Mdot
.74402 .06336 Mdot
.74407 .0632 Mdot
.74412 .06303 Mdot
.74417 .06287 Mdot
.74421 .06271 Mdot
.74426 .06255 Mdot
.74431 .06239 Mdot
.74436 .06223 Mdot
.7444 .06207 Mdot
.74445 .06191 Mdot
.7445 .06175 Mdot
.74455 .06159 Mdot
.74459 .06143 Mdot
.74464 .06127 Mdot
.74469 .06111 Mdot
.74474 .06096 Mdot
.74479 .0608 Mdot
.74483 .06064 Mdot
.74488 .06048 Mdot
.74493 .06032 Mdot
.74498 .06017 Mdot
.74502 .06001 Mdot
.74507 .05985 Mdot
.74512 .0597 Mdot
.74517 .05954 Mdot
.74521 .05939 Mdot
.74526 .05923 Mdot
.74531 .05907 Mdot
.74536 .05892 Mdot
.7454 .05876 Mdot
.74545 .05861 Mdot
.7455 .05846 Mdot
.74555 .0583 Mdot
.74559 .05815 Mdot
.74564 .05799 Mdot
.74569 .05784 Mdot
.74574 .05769 Mdot
.74578 .05753 Mdot
.74583 .05738 Mdot
.74588 .05723 Mdot
.74593 .05708 Mdot
.74598 .05693 Mdot
.74602 .05677 Mdot
.74607 .05662 Mdot
.74612 .05647 Mdot
.74617 .05632 Mdot
.74621 .05617 Mdot
.74626 .05602 Mdot
.74631 .05587 Mdot
.74636 .05572 Mdot
.7464 .05557 Mdot
.74645 .05542 Mdot
.7465 .05527 Mdot
.74655 .05512 Mdot
.74659 .05497 Mdot
.74664 .05483 Mdot
.74669 .05468 Mdot
.74674 .05453 Mdot
.74678 .05438 Mdot
.74683 .05423 Mdot
.74688 .05409 Mdot
.74693 .05394 Mdot
.74698 .05379 Mdot
.74702 .05365 Mdot
.74707 .0535 Mdot
.74712 .05336 Mdot
.74717 .05321 Mdot
.74721 .05306 Mdot
.74726 .05292 Mdot
.74731 .05277 Mdot
.74736 .05263 Mdot
.7474 .05249 Mdot
.74745 .05234 Mdot
.7475 .0522 Mdot
.74755 .05205 Mdot
.74759 .05191 Mdot
.74764 .05177 Mdot
.74769 .05163 Mdot
.74774 .05148 Mdot
.74778 .05134 Mdot
.74783 .0512 Mdot
.74788 .05106 Mdot
.74793 .05092 Mdot
.74798 .05077 Mdot
.74802 .05063 Mdot
.74807 .05049 Mdot
.74812 .05035 Mdot
.74817 .05021 Mdot
.74821 .05007 Mdot
.74826 .04993 Mdot
.74831 .04979 Mdot
.74836 .04965 Mdot
.7484 .04952 Mdot
.74845 .04938 Mdot
.7485 .04924 Mdot
.74855 .0491 Mdot
.74859 .04896 Mdot
.74864 .04882 Mdot
.74869 .04869 Mdot
.74874 .04855 Mdot
.74878 .04841 Mdot
.74883 .04828 Mdot
.74888 .04814 Mdot
.74893 .048 Mdot
.74898 .04787 Mdot
.74902 .04773 Mdot
.74907 .0476 Mdot
.74912 .04746 Mdot
.74917 .04733 Mdot
.74921 .04719 Mdot
.74926 .04706 Mdot
.74931 .04693 Mdot
.74936 .04679 Mdot
.7494 .04666 Mdot
.74945 .04653 Mdot
.7495 .04639 Mdot
.74955 .04626 Mdot
.74959 .04613 Mdot
.74964 .046 Mdot
.74969 .04586 Mdot
.74974 .04573 Mdot
.74978 .0456 Mdot
.74983 .04547 Mdot
.74988 .04534 Mdot
.74993 .04521 Mdot
.74998 .04508 Mdot
.75002 .04495 Mdot
.75007 .04482 Mdot
.75012 .04469 Mdot
.75017 .04456 Mdot
.75021 .04443 Mdot
.75026 .0443 Mdot
.75031 .04417 Mdot
.75036 .04405 Mdot
.7504 .04392 Mdot
.75045 .04379 Mdot
.7505 .04366 Mdot
.75055 .04354 Mdot
.75059 .04341 Mdot
.75064 .04328 Mdot
.75069 .04316 Mdot
.75074 .04303 Mdot
.75078 .0429 Mdot
.75083 .04278 Mdot
.75088 .04265 Mdot
.75093 .04253 Mdot
.75097 .0424 Mdot
.75102 .04228 Mdot
.75107 .04216 Mdot
.75112 .04203 Mdot
.75117 .04191 Mdot
.75121 .04179 Mdot
.75126 .04166 Mdot
.75131 .04154 Mdot
.75136 .04142 Mdot
.7514 .04129 Mdot
.75145 .04117 Mdot
.7515 .04105 Mdot
.75155 .04093 Mdot
.75159 .04081 Mdot
.75164 .04069 Mdot
.75169 .04057 Mdot
.75174 .04045 Mdot
.75178 .04033 Mdot
.75183 .04021 Mdot
.75188 .04009 Mdot
.75193 .03997 Mdot
.75197 .03985 Mdot
.75202 .03973 Mdot
.75207 .03961 Mdot
.75212 .03949 Mdot
.75217 .03937 Mdot
.75221 .03926 Mdot
.75226 .03914 Mdot
.75231 .03902 Mdot
.75236 .0389 Mdot
.7524 .03879 Mdot
.75245 .03867 Mdot
.7525 .03856 Mdot
.75255 .03844 Mdot
.75259 .03832 Mdot
.75264 .03821 Mdot
.75269 .03809 Mdot
.75274 .03798 Mdot
.75278 .03786 Mdot
.75283 .03775 Mdot
.75288 .03764 Mdot
.75293 .03752 Mdot
.75297 .03741 Mdot
.75302 .0373 Mdot
.75307 .03718 Mdot
.75312 .03707 Mdot
.75317 .03696 Mdot
.75321 .03685 Mdot
.75326 .03673 Mdot
.75331 .03662 Mdot
.75336 .03651 Mdot
.7534 .0364 Mdot
.75345 .03629 Mdot
.7535 .03618 Mdot
.75355 .03607 Mdot
.75359 .03596 Mdot
.75364 .03585 Mdot
.75369 .03574 Mdot
.75374 .03563 Mdot
.75378 .03552 Mdot
.75383 .03541 Mdot
.75388 .03531 Mdot
.75393 .0352 Mdot
.75397 .03509 Mdot
.75402 .03498 Mdot
.75407 .03488 Mdot
.75412 .03477 Mdot
.75417 .03466 Mdot
.75421 .03456 Mdot
.75426 .03445 Mdot
.75431 .03434 Mdot
.75436 .03424 Mdot
.7544 .03413 Mdot
.75445 .03403 Mdot
.7545 .03392 Mdot
.75455 .03382 Mdot
.75459 .03372 Mdot
.75464 .03361 Mdot
.75469 .03351 Mdot
.75474 .03341 Mdot
.75478 .0333 Mdot
.75483 .0332 Mdot
.75488 .0331 Mdot
.75493 .03299 Mdot
.75497 .03289 Mdot
.75502 .03279 Mdot
.75507 .03269 Mdot
.75512 .03259 Mdot
.75516 .03249 Mdot
.75521 .03239 Mdot
.75526 .03229 Mdot
.75531 .03219 Mdot
.75536 .03209 Mdot
.7554 .03199 Mdot
.75545 .03189 Mdot
.7555 .03179 Mdot
.75555 .03169 Mdot
.75559 .03159 Mdot
.75564 .0315 Mdot
.75569 .0314 Mdot
.75574 .0313 Mdot
.75578 .0312 Mdot
.75583 .03111 Mdot
.75588 .03101 Mdot
.75593 .03091 Mdot
.75597 .03082 Mdot
.75602 .03072 Mdot
.75607 .03063 Mdot
.75612 .03053 Mdot
.75616 .03044 Mdot
.75621 .03034 Mdot
.75626 .03025 Mdot
.75631 .03015 Mdot
.75636 .03006 Mdot
.7564 .02996 Mdot
.75645 .02987 Mdot
.7565 .02978 Mdot
.75655 .02969 Mdot
.75659 .02959 Mdot
.75664 .0295 Mdot
.75669 .02941 Mdot
.75674 .02932 Mdot
.75678 .02923 Mdot
.75683 .02913 Mdot
.75688 .02904 Mdot
.75693 .02895 Mdot
.75697 .02886 Mdot
.75702 .02877 Mdot
.75707 .02868 Mdot
.75712 .02859 Mdot
.75716 .0285 Mdot
.75721 .02842 Mdot
.75726 .02833 Mdot
.75731 .02824 Mdot
.75736 .02815 Mdot
.7574 .02806 Mdot
.75745 .02798 Mdot
.7575 .02789 Mdot
.75755 .0278 Mdot
.75759 .02772 Mdot
.75764 .02763 Mdot
.75769 .02754 Mdot
.75774 .02746 Mdot
.75778 .02737 Mdot
.75783 .02729 Mdot
.75788 .0272 Mdot
.75793 .02712 Mdot
.75797 .02703 Mdot
.75802 .02695 Mdot
.75807 .02686 Mdot
.75812 .02678 Mdot
.75816 .0267 Mdot
.75821 .02662 Mdot
.75826 .02653 Mdot
.75831 .02645 Mdot
.75836 .02637 Mdot
.7584 .02629 Mdot
.75845 .0262 Mdot
.7585 .02612 Mdot
.75855 .02604 Mdot
.75859 .02596 Mdot
.75864 .02588 Mdot
.75869 .0258 Mdot
.75874 .02572 Mdot
.75878 .02564 Mdot
.75883 .02556 Mdot
.75888 .02548 Mdot
.75893 .0254 Mdot
.75897 .02533 Mdot
.75902 .02525 Mdot
.75907 .02517 Mdot
.75912 .02509 Mdot
.75916 .02502 Mdot
.75921 .02494 Mdot
.75926 .02486 Mdot
.75931 .02479 Mdot
.75936 .02471 Mdot
.7594 .02463 Mdot
.75945 .02456 Mdot
.7595 .02448 Mdot
.75955 .02441 Mdot
.75959 .02433 Mdot
.75964 .02426 Mdot
.75969 .02418 Mdot
.75974 .02411 Mdot
.75978 .02404 Mdot
.75983 .02396 Mdot
.75988 .02389 Mdot
.75993 .02382 Mdot
.75997 .02375 Mdot
.76002 .02367 Mdot
.76007 .0236 Mdot
.76012 .02353 Mdot
.76016 .02346 Mdot
.76021 .02339 Mdot
.76026 .02332 Mdot
.76031 .02325 Mdot
.76035 .02318 Mdot
.7604 .02311 Mdot
.76045 .02304 Mdot
.7605 .02297 Mdot
.76055 .0229 Mdot
.76059 .02283 Mdot
.76064 .02276 Mdot
.76069 .02269 Mdot
.76074 .02262 Mdot
.76078 .02256 Mdot
.76083 .02249 Mdot
.76088 .02242 Mdot
.76093 .02236 Mdot
.76097 .02229 Mdot
.76102 .02222 Mdot
.76107 .02216 Mdot
.76112 .02209 Mdot
.76116 .02203 Mdot
.76121 .02196 Mdot
.76126 .0219 Mdot
.76131 .02183 Mdot
.76135 .02177 Mdot
.7614 .0217 Mdot
.76145 .02164 Mdot
.7615 .02158 Mdot
.76155 .02151 Mdot
.76159 .02145 Mdot
.76164 .02139 Mdot
.76169 .02133 Mdot
.76174 .02127 Mdot
.76178 .0212 Mdot
.76183 .02114 Mdot
.76188 .02108 Mdot
.76193 .02102 Mdot
.76197 .02096 Mdot
.76202 .0209 Mdot
.76207 .02084 Mdot
.76212 .02078 Mdot
.76216 .02072 Mdot
.76221 .02066 Mdot
.76226 .0206 Mdot
.76231 .02055 Mdot
.76235 .02049 Mdot
.7624 .02043 Mdot
.76245 .02037 Mdot
.7625 .02031 Mdot
.76255 .02026 Mdot
.76259 .0202 Mdot
.76264 .02014 Mdot
.76269 .02009 Mdot
.76274 .02003 Mdot
.76278 .01998 Mdot
.76283 .01992 Mdot
.76288 .01987 Mdot
.76293 .01981 Mdot
.76297 .01976 Mdot
.76302 .0197 Mdot
.76307 .01965 Mdot
.76312 .0196 Mdot
.76316 .01954 Mdot
.76321 .01949 Mdot
.76326 .01944 Mdot
.76331 .01939 Mdot
.76335 .01933 Mdot
.7634 .01928 Mdot
.76345 .01923 Mdot
.7635 .01918 Mdot
.76355 .01913 Mdot
.76359 .01908 Mdot
.76364 .01903 Mdot
.76369 .01898 Mdot
.76374 .01893 Mdot
.76378 .01888 Mdot
.76383 .01883 Mdot
.76388 .01878 Mdot
.76393 .01873 Mdot
.76397 .01868 Mdot
.76402 .01864 Mdot
.76407 .01859 Mdot
.76412 .01854 Mdot
.76416 .01849 Mdot
.76421 .01845 Mdot
.76426 .0184 Mdot
.76431 .01835 Mdot
.76435 .01831 Mdot
.7644 .01826 Mdot
.76445 .01822 Mdot
.7645 .01817 Mdot
.76454 .01813 Mdot
.76459 .01808 Mdot
.76464 .01804 Mdot
.76469 .01799 Mdot
.76474 .01795 Mdot
.76478 .01791 Mdot
.76483 .01786 Mdot
.76488 .01782 Mdot
.76493 .01778 Mdot
.76497 .01774 Mdot
.76502 .01769 Mdot
.76507 .01765 Mdot
.76512 .01761 Mdot
.76516 .01757 Mdot
.76521 .01753 Mdot
.76526 .01749 Mdot
.76531 .01745 Mdot
.76535 .01741 Mdot
.7654 .01737 Mdot
.76545 .01733 Mdot
.7655 .01729 Mdot
.76554 .01725 Mdot
.76559 .01721 Mdot
.76564 .01718 Mdot
.76569 .01714 Mdot
.76574 .0171 Mdot
.76578 .01706 Mdot
.76583 .01703 Mdot
.76588 .01699 Mdot
.76593 .01695 Mdot
.76597 .01692 Mdot
.76602 .01688 Mdot
.76607 .01685 Mdot
.76612 .01681 Mdot
.76616 .01678 Mdot
.76621 .01674 Mdot
.76626 .01671 Mdot
.76631 .01667 Mdot
.76635 .01664 Mdot
.7664 .01661 Mdot
.76645 .01657 Mdot
.7665 .01654 Mdot
.76654 .01651 Mdot
.76659 .01648 Mdot
.76664 .01644 Mdot
.76669 .01641 Mdot
.76674 .01638 Mdot
.76678 .01635 Mdot
.76683 .01632 Mdot
.76688 .01629 Mdot
.76693 .01626 Mdot
.76697 .01623 Mdot
.76702 .0162 Mdot
.76707 .01617 Mdot
.76712 .01614 Mdot
.76716 .01611 Mdot
.76721 .01608 Mdot
.76726 .01605 Mdot
.76731 .01603 Mdot
.76735 .016 Mdot
.7674 .01597 Mdot
.76745 .01594 Mdot
.7675 .01592 Mdot
.76754 .01589 Mdot
.76759 .01587 Mdot
.76764 .01584 Mdot
.76769 .01581 Mdot
.76774 .01579 Mdot
.76778 .01576 Mdot
.76783 .01574 Mdot
.76788 .01571 Mdot
.76793 .01569 Mdot
.76797 .01567 Mdot
.76802 .01564 Mdot
.76807 .01562 Mdot
.76812 .0156 Mdot
.76816 .01557 Mdot
.76821 .01555 Mdot
.76826 .01553 Mdot
.76831 .01551 Mdot
.76835 .01549 Mdot
.7684 .01547 Mdot
.76845 .01544 Mdot
.7685 .01542 Mdot
.76854 .0154 Mdot
.76859 .01538 Mdot
.76864 .01536 Mdot
.76869 .01535 Mdot
.76874 .01533 Mdot
.76878 .01531 Mdot
.76883 .01529 Mdot
.76888 .01527 Mdot
.76893 .01525 Mdot
.76897 .01523 Mdot
.76902 .01522 Mdot
.76907 .0152 Mdot
.76912 .01518 Mdot
.76916 .01517 Mdot
.76921 .01515 Mdot
.76926 .01514 Mdot
.76931 .01512 Mdot
.76935 .0151 Mdot
.7694 .01509 Mdot
.76945 .01507 Mdot
.7695 .01506 Mdot
.76954 .01505 Mdot
.76959 .01503 Mdot
.76964 .01502 Mdot
.76969 .01501 Mdot
.76973 .01499 Mdot
.76978 .01498 Mdot
.76983 .01497 Mdot
.76988 .01496 Mdot
.76993 .01494 Mdot
.76997 .01493 Mdot
.77002 .01492 Mdot
.77007 .01491 Mdot
.77012 .0149 Mdot
.77016 .01489 Mdot
.77021 .01488 Mdot
.77026 .01487 Mdot
.77031 .01486 Mdot
.77035 .01485 Mdot
.7704 .01484 Mdot
.77045 .01483 Mdot
.7705 .01483 Mdot
.77054 .01482 Mdot
.77059 .01481 Mdot
.77064 .0148 Mdot
.77069 .0148 Mdot
.77073 .01479 Mdot
.77078 .01478 Mdot
.77083 .01478 Mdot
.77088 .01477 Mdot
.77093 .01477 Mdot
.77097 .01476 Mdot
.77102 .01475 Mdot
.77107 .01475 Mdot
.77112 .01475 Mdot
.77116 .01474 Mdot
.77121 .01474 Mdot
.77126 .01473 Mdot
.77131 .01473 Mdot
.77135 .01473 Mdot
.7714 .01473 Mdot
.77145 .01472 Mdot
.7715 .01472 Mdot
.77154 .01472 Mdot
.77159 .01472 Mdot
.77164 .01472 Mdot
.77169 .01472 Mdot
.77173 .01472 Mdot
.77178 .01472 Mdot
.77183 .01472 Mdot
.77188 .01472 Mdot
.77193 .01472 Mdot
.77197 .01472 Mdot
.77202 .01472 Mdot
.77207 .01472 Mdot
.77212 .01472 Mdot
.77216 .01472 Mdot
.77221 .01473 Mdot
.77226 .01473 Mdot
.77231 .01473 Mdot
.77235 .01473 Mdot
.7724 .01474 Mdot
.77245 .01474 Mdot
.7725 .01475 Mdot
.77254 .01475 Mdot
.77259 .01476 Mdot
.77264 .01476 Mdot
.77269 .01477 Mdot
.77273 .01477 Mdot
.77278 .01478 Mdot
.77283 .01478 Mdot
.77288 .01479 Mdot
.77293 .0148 Mdot
.77297 .0148 Mdot
.77302 .01481 Mdot
.77307 .01482 Mdot
.77312 .01483 Mdot
.77316 .01483 Mdot
.77321 .01484 Mdot
.77326 .01485 Mdot
.77331 .01486 Mdot
.77335 .01487 Mdot
.7734 .01488 Mdot
.77345 .01489 Mdot
.7735 .0149 Mdot
.77354 .01491 Mdot
.77359 .01492 Mdot
.77364 .01493 Mdot
.77369 .01494 Mdot
.77373 .01496 Mdot
.77378 .01497 Mdot
.77383 .01498 Mdot
.77388 .01499 Mdot
.77392 .01501 Mdot
.77397 .01502 Mdot
.77402 .01503 Mdot
.77407 .01505 Mdot
.77412 .01506 Mdot
.77416 .01508 Mdot
.77421 .01509 Mdot
.77426 .01511 Mdot
.77431 .01512 Mdot
.77435 .01514 Mdot
.7744 .01515 Mdot
.77445 .01517 Mdot
.7745 .01518 Mdot
.77454 .0152 Mdot
.77459 .01522 Mdot
.77464 .01524 Mdot
.77469 .01525 Mdot
.77473 .01527 Mdot
.77478 .01529 Mdot
.77483 .01531 Mdot
.77488 .01533 Mdot
.77492 .01535 Mdot
.77497 .01537 Mdot
.77502 .01539 Mdot
.77507 .01541 Mdot
.77512 .01543 Mdot
.77516 .01545 Mdot
.77521 .01547 Mdot
.77526 .01549 Mdot
.77531 .01551 Mdot
.77535 .01553 Mdot
.7754 .01555 Mdot
.77545 .01558 Mdot
.7755 .0156 Mdot
.77554 .01562 Mdot
.77559 .01564 Mdot
.77564 .01567 Mdot
.77569 .01569 Mdot
.77573 .01572 Mdot
.77578 .01574 Mdot
.77583 .01577 Mdot
.77588 .01579 Mdot
.77592 .01582 Mdot
.77597 .01584 Mdot
.77602 .01587 Mdot
.77607 .01589 Mdot
.77612 .01592 Mdot
.77616 .01595 Mdot
.77621 .01597 Mdot
.77626 .016 Mdot
.77631 .01603 Mdot
.77635 .01606 Mdot
.7764 .01608 Mdot
.77645 .01611 Mdot
.7765 .01614 Mdot
.77654 .01617 Mdot
.77659 .0162 Mdot
.77664 .01623 Mdot
.77669 .01626 Mdot
.77673 .01629 Mdot
.77678 .01632 Mdot
.77683 .01635 Mdot
.77688 .01638 Mdot
.77692 .01641 Mdot
.77697 .01645 Mdot
.77702 .01648 Mdot
.77707 .01651 Mdot
.77712 .01654 Mdot
.77716 .01658 Mdot
.77721 .01661 Mdot
.77726 .01664 Mdot
.77731 .01668 Mdot
.77735 .01671 Mdot
.7774 .01674 Mdot
.77745 .01678 Mdot
.7775 .01681 Mdot
.77754 .01685 Mdot
.77759 .01688 Mdot
.77764 .01692 Mdot
.77769 .01696 Mdot
.77773 .01699 Mdot
.77778 .01703 Mdot
.77783 .01707 Mdot
.77788 .0171 Mdot
.77792 .01714 Mdot
.77797 .01718 Mdot
.77802 .01722 Mdot
.77807 .01726 Mdot
.77812 .01729 Mdot
.77816 .01733 Mdot
.77821 .01737 Mdot
.77826 .01741 Mdot
.77831 .01745 Mdot
.77835 .01749 Mdot
.7784 .01753 Mdot
.77845 .01757 Mdot
.7785 .01761 Mdot
.77854 .01766 Mdot
.77859 .0177 Mdot
.77864 .01774 Mdot
.77869 .01778 Mdot
.77873 .01782 Mdot
.77878 .01787 Mdot
.77883 .01791 Mdot
.77888 .01795 Mdot
.77892 .018 Mdot
.77897 .01804 Mdot
.77902 .01808 Mdot
.77907 .01813 Mdot
.77911 .01817 Mdot
.77916 .01822 Mdot
.77921 .01826 Mdot
.77926 .01831 Mdot
.77931 .01836 Mdot
.77935 .0184 Mdot
.7794 .01845 Mdot
.77945 .0185 Mdot
.7795 .01854 Mdot
.77954 .01859 Mdot
.77959 .01864 Mdot
.77964 .01869 Mdot
.77969 .01873 Mdot
.77973 .01878 Mdot
.77978 .01883 Mdot
.77983 .01888 Mdot
.77988 .01893 Mdot
.77992 .01898 Mdot
.77997 .01903 Mdot
.78002 .01908 Mdot
.78007 .01913 Mdot
.78011 .01918 Mdot
.78016 .01923 Mdot
.78021 .01929 Mdot
.78026 .01934 Mdot
.78031 .01939 Mdot
.78035 .01944 Mdot
.7804 .01949 Mdot
.78045 .01955 Mdot
.7805 .0196 Mdot
.78054 .01965 Mdot
.78059 .01971 Mdot
.78064 .01976 Mdot
.78069 .01982 Mdot
.78073 .01987 Mdot
.78078 .01993 Mdot
.78083 .01998 Mdot
.78088 .02004 Mdot
.78092 .02009 Mdot
.78097 .02015 Mdot
.78102 .02021 Mdot
.78107 .02026 Mdot
.78111 .02032 Mdot
.78116 .02038 Mdot
.78121 .02043 Mdot
.78126 .02049 Mdot
.78131 .02055 Mdot
.78135 .02061 Mdot
.7814 .02067 Mdot
.78145 .02073 Mdot
.7815 .02079 Mdot
.78154 .02085 Mdot
.78159 .0209 Mdot
.78164 .02097 Mdot
.78169 .02103 Mdot
.78173 .02109 Mdot
.78178 .02115 Mdot
.78183 .02121 Mdot
.78188 .02127 Mdot
.78192 .02133 Mdot
.78197 .02139 Mdot
.78202 .02146 Mdot
.78207 .02152 Mdot
.78211 .02158 Mdot
.78216 .02165 Mdot
.78221 .02171 Mdot
.78226 .02177 Mdot
.78231 .02184 Mdot
.78235 .0219 Mdot
.7824 .02197 Mdot
.78245 .02203 Mdot
.7825 .0221 Mdot
.78254 .02216 Mdot
.78259 .02223 Mdot
.78264 .02229 Mdot
.78269 .02236 Mdot
.78273 .02243 Mdot
.78278 .0225 Mdot
.78283 .02256 Mdot
.78288 .02263 Mdot
.78292 .0227 Mdot
.78297 .02277 Mdot
.78302 .02283 Mdot
.78307 .0229 Mdot
.78311 .02297 Mdot
.78316 .02304 Mdot
.78321 .02311 Mdot
.78326 .02318 Mdot
.78331 .02325 Mdot
.78335 .02332 Mdot
.7834 .02339 Mdot
.78345 .02346 Mdot
.7835 .02354 Mdot
.78354 .02361 Mdot
.78359 .02368 Mdot
.78364 .02375 Mdot
.78369 .02382 Mdot
.78373 .0239 Mdot
.78378 .02397 Mdot
.78383 .02404 Mdot
.78388 .02412 Mdot
.78392 .02419 Mdot
.78397 .02426 Mdot
.78402 .02434 Mdot
.78407 .02441 Mdot
.78411 .02449 Mdot
.78416 .02456 Mdot
.78421 .02464 Mdot
.78426 .02472 Mdot
.7843 .02479 Mdot
.78435 .02487 Mdot
.7844 .02495 Mdot
.78445 .02502 Mdot
.7845 .0251 Mdot
.78454 .02518 Mdot
.78459 .02526 Mdot
.78464 .02533 Mdot
.78469 .02541 Mdot
.78473 .02549 Mdot
.78478 .02557 Mdot
.78483 .02565 Mdot
.78488 .02573 Mdot
.78492 .02581 Mdot
.78497 .02589 Mdot
.78502 .02597 Mdot
.78507 .02605 Mdot
.78511 .02613 Mdot
.78516 .02621 Mdot
.78521 .02629 Mdot
.78526 .02638 Mdot
.7853 .02646 Mdot
.78535 .02654 Mdot
.7854 .02662 Mdot
.78545 .02671 Mdot
.7855 .02679 Mdot
.78554 .02687 Mdot
.78559 .02696 Mdot
.78564 .02704 Mdot
.78569 .02712 Mdot
.78573 .02721 Mdot
.78578 .02729 Mdot
.78583 .02738 Mdot
.78588 .02747 Mdot
.78592 .02755 Mdot
.78597 .02764 Mdot
.78602 .02772 Mdot
.78607 .02781 Mdot
.78611 .0279 Mdot
.78616 .02798 Mdot
.78621 .02807 Mdot
.78626 .02816 Mdot
.7863 .02825 Mdot
.78635 .02834 Mdot
.7864 .02842 Mdot
.78645 .02851 Mdot
.7865 .0286 Mdot
.78654 .02869 Mdot
.78659 .02878 Mdot
.78664 .02887 Mdot
.78669 .02896 Mdot
.78673 .02905 Mdot
.78678 .02914 Mdot
.78683 .02923 Mdot
.78688 .02933 Mdot
.78692 .02942 Mdot
.78697 .02951 Mdot
.78702 .0296 Mdot
.78707 .02969 Mdot
.78711 .02979 Mdot
.78716 .02988 Mdot
.78721 .02997 Mdot
.78726 .03007 Mdot
.7873 .03016 Mdot
.78735 .03026 Mdot
.7874 .03035 Mdot
.78745 .03044 Mdot
.7875 .03054 Mdot
.78754 .03063 Mdot
.78759 .03073 Mdot
.78764 .03083 Mdot
.78769 .03092 Mdot
.78773 .03102 Mdot
.78778 .03112 Mdot
.78783 .03121 Mdot
.78788 .03131 Mdot
.78792 .03141 Mdot
.78797 .03151 Mdot
.78802 .0316 Mdot
.78807 .0317 Mdot
.78811 .0318 Mdot
.78816 .0319 Mdot
.78821 .032 Mdot
.78826 .0321 Mdot
.7883 .0322 Mdot
.78835 .0323 Mdot
.7884 .0324 Mdot
.78845 .0325 Mdot
.78849 .0326 Mdot
.78854 .0327 Mdot
.78859 .0328 Mdot
.78864 .0329 Mdot
.78869 .03301 Mdot
.78873 .03311 Mdot
.78878 .03321 Mdot
.78883 .03331 Mdot
.78888 .03342 Mdot
.78892 .03352 Mdot
.78897 .03362 Mdot
.78902 .03373 Mdot
.78907 .03383 Mdot
.78911 .03394 Mdot
.78916 .03404 Mdot
.78921 .03415 Mdot
.78926 .03425 Mdot
.7893 .03436 Mdot
.78935 .03446 Mdot
.7894 .03457 Mdot
.78945 .03467 Mdot
.78949 .03478 Mdot
.78954 .03489 Mdot
.78959 .035 Mdot
.78964 .0351 Mdot
.78969 .03521 Mdot
.78973 .03532 Mdot
.78978 .03543 Mdot
.78983 .03554 Mdot
.78988 .03564 Mdot
.78992 .03575 Mdot
.78997 .03586 Mdot
.79002 .03597 Mdot
.79007 .03608 Mdot
.79011 .03619 Mdot
.79016 .0363 Mdot
.79021 .03641 Mdot
.79026 .03652 Mdot
.7903 .03664 Mdot
.79035 .03675 Mdot
.7904 .03686 Mdot
.79045 .03697 Mdot
.79049 .03708 Mdot
.79054 .0372 Mdot
.79059 .03731 Mdot
.79064 .03742 Mdot
.79069 .03754 Mdot
.79073 .03765 Mdot
.79078 .03776 Mdot
.79083 .03788 Mdot
.79088 .03799 Mdot
.79092 .03811 Mdot
.79097 .03822 Mdot
.79102 .03834 Mdot
.79107 .03845 Mdot
.79111 .03857 Mdot
.79116 .03869 Mdot
.79121 .0388 Mdot
.79126 .03892 Mdot
.7913 .03904 Mdot
.79135 .03915 Mdot
.7914 .03927 Mdot
.79145 .03939 Mdot
.79149 .03951 Mdot
.79154 .03962 Mdot
.79159 .03974 Mdot
.79164 .03986 Mdot
.79169 .03998 Mdot
.79173 .0401 Mdot
.79178 .04022 Mdot
.79183 .04034 Mdot
.79188 .04046 Mdot
.79192 .04058 Mdot
.79197 .0407 Mdot
.79202 .04082 Mdot
.79207 .04094 Mdot
.79211 .04107 Mdot
.79216 .04119 Mdot
.79221 .04131 Mdot
.79226 .04143 Mdot
.7923 .04155 Mdot
.79235 .04168 Mdot
.7924 .0418 Mdot
.79245 .04192 Mdot
.79249 .04205 Mdot
.79254 .04217 Mdot
.79259 .0423 Mdot
.79264 .04242 Mdot
.79269 .04255 Mdot
.79273 .04267 Mdot
.79278 .0428 Mdot
.79283 .04292 Mdot
.79288 .04305 Mdot
.79292 .04317 Mdot
.79297 .0433 Mdot
.79302 .04343 Mdot
.79307 .04355 Mdot
.79311 .04368 Mdot
.79316 .04381 Mdot
.79321 .04394 Mdot
.79326 .04406 Mdot
.7933 .04419 Mdot
.79335 .04432 Mdot
.7934 .04445 Mdot
.79345 .04458 Mdot
.79349 .04471 Mdot
.79354 .04484 Mdot
.79359 .04497 Mdot
.79364 .0451 Mdot
.79368 .04523 Mdot
.79373 .04536 Mdot
.79378 .04549 Mdot
.79383 .04562 Mdot
.79388 .04575 Mdot
.79392 .04588 Mdot
.79397 .04601 Mdot
.79402 .04615 Mdot
.79407 .04628 Mdot
.79411 .04641 Mdot
.79416 .04654 Mdot
.79421 .04668 Mdot
.79426 .04681 Mdot
.7943 .04694 Mdot
.79435 .04708 Mdot
.7944 .04721 Mdot
.79445 .04735 Mdot
.79449 .04748 Mdot
.79454 .04762 Mdot
.79459 .04775 Mdot
.79464 .04789 Mdot
.79468 .04802 Mdot
.79473 .04816 Mdot
.79478 .0483 Mdot
.79483 .04843 Mdot
.79488 .04857 Mdot
.79492 .04871 Mdot
.79497 .04884 Mdot
.79502 .04898 Mdot
.79507 .04912 Mdot
.79511 .04926 Mdot
.79516 .0494 Mdot
.79521 .04954 Mdot
.79526 .04967 Mdot
.7953 .04981 Mdot
.79535 .04995 Mdot
.7954 .05009 Mdot
.79545 .05023 Mdot
.79549 .05037 Mdot
.79554 .05051 Mdot
.79559 .05065 Mdot
.79564 .0508 Mdot
.79568 .05094 Mdot
.79573 .05108 Mdot
.79578 .05122 Mdot
.79583 .05136 Mdot
.79588 .0515 Mdot
.79592 .05165 Mdot
.79597 .05179 Mdot
.79602 .05193 Mdot
.79607 .05208 Mdot
.79611 .05222 Mdot
.79616 .05236 Mdot
.79621 .05251 Mdot
.79626 .05265 Mdot
.7963 .0528 Mdot
.79635 .05294 Mdot
.7964 .05309 Mdot
.79645 .05323 Mdot
.79649 .05338 Mdot
.79654 .05352 Mdot
.79659 .05367 Mdot
.79664 .05382 Mdot
.79668 .05396 Mdot
.79673 .05411 Mdot
.79678 .05426 Mdot
.79683 .0544 Mdot
.79688 .05455 Mdot
.79692 .0547 Mdot
.79697 .05485 Mdot
.79702 .055 Mdot
.79707 .05515 Mdot
.79711 .05529 Mdot
.79716 .05544 Mdot
.79721 .05559 Mdot
.79726 .05574 Mdot
.7973 .05589 Mdot
.79735 .05604 Mdot
.7974 .05619 Mdot
.79745 .05634 Mdot
.79749 .0565 Mdot
.79754 .05665 Mdot
.79759 .0568 Mdot
.79764 .05695 Mdot
.79768 .0571 Mdot
.79773 .05725 Mdot
.79778 .05741 Mdot
.79783 .05756 Mdot
.79787 .05771 Mdot
.79792 .05787 Mdot
.79797 .05802 Mdot
.79802 .05817 Mdot
.79807 .05833 Mdot
.79811 .05848 Mdot
.79816 .05864 Mdot
.79821 .05879 Mdot
.79826 .05895 Mdot
.7983 .0591 Mdot
.79835 .05926 Mdot
.7984 .05941 Mdot
.79845 .05957 Mdot
.79849 .05972 Mdot
.79854 .05988 Mdot
.79859 .06004 Mdot
.79864 .06019 Mdot
.79868 .06035 Mdot
.79873 .06051 Mdot
.79878 .06067 Mdot
.79883 .06083 Mdot
.79887 .06098 Mdot
.79892 .06114 Mdot
.79897 .0613 Mdot
.79902 .06146 Mdot
.79907 .06162 Mdot
.79911 .06178 Mdot
.79916 .06194 Mdot
.79921 .0621 Mdot
.79926 .06226 Mdot
.7993 .06242 Mdot
.79935 .06258 Mdot
.7994 .06274 Mdot
.79945 .0629 Mdot
.79949 .06306 Mdot
.79954 .06322 Mdot
.79959 .06339 Mdot
.79964 .06355 Mdot
.79968 .06371 Mdot
.79973 .06387 Mdot
.79978 .06404 Mdot
.79983 .0642 Mdot
.79987 .06436 Mdot
.79992 .06453 Mdot
.79997 .06469 Mdot
.80002 .06486 Mdot
.80007 .06502 Mdot
.80011 .06518 Mdot
.80016 .06535 Mdot
.80021 .06551 Mdot
.80026 .06568 Mdot
.8003 .06585 Mdot
.80035 .06601 Mdot
.8004 .06618 Mdot
.80045 .06634 Mdot
.80049 .06651 Mdot
.80054 .06668 Mdot
.80059 .06684 Mdot
.80064 .06701 Mdot
.80068 .06718 Mdot
.80073 .06735 Mdot
.80078 .06751 Mdot
.80083 .06768 Mdot
.80087 .06785 Mdot
.80092 .06802 Mdot
.80097 .06819 Mdot
.80102 .06836 Mdot
.80107 .06853 Mdot
.80111 .0687 Mdot
.80116 .06887 Mdot
.80121 .06904 Mdot
.80126 .06921 Mdot
.8013 .06938 Mdot
.80135 .06955 Mdot
.8014 .06972 Mdot
.80145 .06989 Mdot
.80149 .07006 Mdot
.80154 .07024 Mdot
.80159 .07041 Mdot
.80164 .07058 Mdot
.80168 .07075 Mdot
.80173 .07093 Mdot
.80178 .0711 Mdot
.80183 .07127 Mdot
.80187 .07145 Mdot
.80192 .07162 Mdot
.80197 .07179 Mdot
.80202 .07197 Mdot
.80207 .07214 Mdot
.80211 .07232 Mdot
.80216 .07249 Mdot
.80221 .07267 Mdot
.80226 .07284 Mdot
.8023 .07302 Mdot
.80235 .07319 Mdot
.8024 .07337 Mdot
.80245 .07355 Mdot
.80249 .07372 Mdot
.80254 .0739 Mdot
.80259 .07408 Mdot
.80264 .07425 Mdot
.80268 .07443 Mdot
.80273 .07461 Mdot
.80278 .07479 Mdot
.80283 .07497 Mdot
.80287 .07515 Mdot
.80292 .07532 Mdot
.80297 .0755 Mdot
.80302 .07568 Mdot
.80306 .07586 Mdot
.80311 .07604 Mdot
.80316 .07622 Mdot
.80321 .0764 Mdot
.80326 .07658 Mdot
.8033 .07676 Mdot
.80335 .07694 Mdot
.8034 .07712 Mdot
.80345 .07731 Mdot
.80349 .07749 Mdot
.80354 .07767 Mdot
.80359 .07785 Mdot
.80364 .07803 Mdot
.80368 .07822 Mdot
.80373 .0784 Mdot
.80378 .07858 Mdot
.80383 .07876 Mdot
.80387 .07895 Mdot
.80392 .07913 Mdot
.80397 .07931 Mdot
.80402 .0795 Mdot
.80406 .07968 Mdot
.80411 .07987 Mdot
.80416 .08005 Mdot
.80421 .08024 Mdot
.80426 .08042 Mdot
.8043 .08061 Mdot
.80435 .08079 Mdot
.8044 .08098 Mdot
.80445 .08117 Mdot
.80449 .08135 Mdot
.80454 .08154 Mdot
.80459 .08173 Mdot
.80464 .08191 Mdot
.80468 .0821 Mdot
.80473 .08229 Mdot
.80478 .08247 Mdot
.80483 .08266 Mdot
.80487 .08285 Mdot
.80492 .08304 Mdot
.80497 .08323 Mdot
.80502 .08342 Mdot
.80506 .08361 Mdot
.80511 .0838 Mdot
.80516 .08398 Mdot
.80521 .08417 Mdot
.80526 .08436 Mdot
.8053 .08455 Mdot
.80535 .08475 Mdot
.8054 .08494 Mdot
.80545 .08513 Mdot
.80549 .08532 Mdot
.80554 .08551 Mdot
.80559 .0857 Mdot
.80564 .08589 Mdot
.80568 .08608 Mdot
.80573 .08628 Mdot
.80578 .08647 Mdot
.80583 .08666 Mdot
.80587 .08685 Mdot
.80592 .08705 Mdot
.80597 .08724 Mdot
.80602 .08743 Mdot
.80606 .08763 Mdot
.80611 .08782 Mdot
.80616 .08802 Mdot
.80621 .08821 Mdot
.80626 .08841 Mdot
.8063 .0886 Mdot
.80635 .0888 Mdot
.8064 .08899 Mdot
.80645 .08919 Mdot
.80649 .08938 Mdot
.80654 .08958 Mdot
.80659 .08977 Mdot
.80664 .08997 Mdot
.80668 .09017 Mdot
.80673 .09036 Mdot
.80678 .09056 Mdot
.80683 .09076 Mdot
.80687 .09096 Mdot
.80692 .09115 Mdot
.80697 .09135 Mdot
.80702 .09155 Mdot
.80706 .09175 Mdot
.80711 .09195 Mdot
.80716 .09215 Mdot
.80721 .09234 Mdot
.80725 .09254 Mdot
.8073 .09274 Mdot
.80735 .09294 Mdot
.8074 .09314 Mdot
.80745 .09334 Mdot
.80749 .09354 Mdot
.80754 .09374 Mdot
.80759 .09394 Mdot
.80764 .09415 Mdot
.80768 .09435 Mdot
.80773 .09455 Mdot
.80778 .09475 Mdot
.80783 .09495 Mdot
.80787 .09515 Mdot
.80792 .09536 Mdot
.80797 .09556 Mdot
.80802 .09576 Mdot
.80806 .09596 Mdot
.80811 .09617 Mdot
.80816 .09637 Mdot
.80821 .09657 Mdot
.80825 .09678 Mdot
.8083 .09698 Mdot
.80835 .09719 Mdot
.8084 .09739 Mdot
.80845 .09759 Mdot
.80849 .0978 Mdot
.80854 .098 Mdot
.80859 .09821 Mdot
.80864 .09841 Mdot
.80868 .09862 Mdot
.80873 .09883 Mdot
.80878 .09903 Mdot
.80883 .09924 Mdot
.80887 .09945 Mdot
.80892 .09965 Mdot
.80897 .09986 Mdot
.80902 .10007 Mdot
.80906 .10027 Mdot
.80911 .10048 Mdot
.80916 .10069 Mdot
.80921 .1009 Mdot
.80925 .1011 Mdot
.8093 .10131 Mdot
.80935 .10152 Mdot
.8094 .10173 Mdot
.80945 .10194 Mdot
.80949 .10215 Mdot
.80954 .10236 Mdot
.80959 .10257 Mdot
.80964 .10278 Mdot
.80968 .10299 Mdot
.80973 .1032 Mdot
.80978 .10341 Mdot
.80983 .10362 Mdot
.80987 .10383 Mdot
.80992 .10404 Mdot
.80997 .10425 Mdot
.81002 .10446 Mdot
.81006 .10467 Mdot
.81011 .10489 Mdot
.81016 .1051 Mdot
.81021 .10531 Mdot
.81025 .10552 Mdot
.8103 .10574 Mdot
.81035 .10595 Mdot
.8104 .10616 Mdot
.81045 .10638 Mdot
.81049 .10659 Mdot
.81054 .1068 Mdot
.81059 .10702 Mdot
.81064 .10723 Mdot
.81068 .10744 Mdot
.81073 .10766 Mdot
.81078 .10787 Mdot
.81083 .10809 Mdot
.81087 .1083 Mdot
.81092 .10852 Mdot
.81097 .10873 Mdot
.81102 .10895 Mdot
.81106 .10917 Mdot
.81111 .10938 Mdot
.81116 .1096 Mdot
.81121 .10982 Mdot
.81125 .11003 Mdot
.8113 .11025 Mdot
.81135 .11047 Mdot
.8114 .11068 Mdot
.81145 .1109 Mdot
.81149 .11112 Mdot
.81154 .11134 Mdot
.81159 .11155 Mdot
.81164 .11177 Mdot
.81168 .11199 Mdot
.81173 .11221 Mdot
.81178 .11243 Mdot
.81183 .11265 Mdot
.81187 .11287 Mdot
.81192 .11309 Mdot
.81197 .11331 Mdot
.81202 .11353 Mdot
.81206 .11375 Mdot
.81211 .11397 Mdot
.81216 .11419 Mdot
.81221 .11441 Mdot
.81225 .11463 Mdot
.8123 .11485 Mdot
.81235 .11507 Mdot
.8124 .11529 Mdot
.81244 .11551 Mdot
.81249 .11574 Mdot
.81254 .11596 Mdot
.81259 .11618 Mdot
.81264 .1164 Mdot
.81268 .11662 Mdot
.81273 .11685 Mdot
.81278 .11707 Mdot
.81283 .11729 Mdot
.81287 .11752 Mdot
.81292 .11774 Mdot
.81297 .11796 Mdot
.81302 .11819 Mdot
.81306 .11841 Mdot
.81311 .11864 Mdot
.81316 .11886 Mdot
.81321 .11909 Mdot
.81325 .11931 Mdot
.8133 .11954 Mdot
.81335 .11976 Mdot
.8134 .11999 Mdot
.81344 .12021 Mdot
.81349 .12044 Mdot
.81354 .12066 Mdot
.81359 .12089 Mdot
.81364 .12112 Mdot
.81368 .12134 Mdot
.81373 .12157 Mdot
.81378 .1218 Mdot
.81383 .12202 Mdot
.81387 .12225 Mdot
.81392 .12248 Mdot
.81397 .12271 Mdot
.81402 .12293 Mdot
.81406 .12316 Mdot
.81411 .12339 Mdot
.81416 .12362 Mdot
.81421 .12385 Mdot
.81425 .12408 Mdot
.8143 .12431 Mdot
.81435 .12453 Mdot
.8144 .12476 Mdot
.81444 .12499 Mdot
.81449 .12522 Mdot
.81454 .12545 Mdot
.81459 .12568 Mdot
.81464 .12591 Mdot
.81468 .12614 Mdot
.81473 .12637 Mdot
.81478 .12661 Mdot
.81483 .12684 Mdot
.81487 .12707 Mdot
.81492 .1273 Mdot
.81497 .12753 Mdot
.81502 .12776 Mdot
.81506 .12799 Mdot
.81511 .12823 Mdot
.81516 .12846 Mdot
.81521 .12869 Mdot
.81525 .12892 Mdot
.8153 .12916 Mdot
.81535 .12939 Mdot
.8154 .12962 Mdot
.81544 .12986 Mdot
.81549 .13009 Mdot
.81554 .13032 Mdot
.81559 .13056 Mdot
.81564 .13079 Mdot
.81568 .13103 Mdot
.81573 .13126 Mdot
.81578 .13149 Mdot
.81583 .13173 Mdot
.81587 .13196 Mdot
.81592 .1322 Mdot
.81597 .13243 Mdot
.81602 .13267 Mdot
.81606 .13291 Mdot
.81611 .13314 Mdot
.81616 .13338 Mdot
.81621 .13361 Mdot
.81625 .13385 Mdot
.8163 .13409 Mdot
.81635 .13432 Mdot
.8164 .13456 Mdot
.81644 .1348 Mdot
.81649 .13503 Mdot
.81654 .13527 Mdot
.81659 .13551 Mdot
.81664 .13575 Mdot
.81668 .13599 Mdot
.81673 .13622 Mdot
.81678 .13646 Mdot
.81683 .1367 Mdot
.81687 .13694 Mdot
.81692 .13718 Mdot
.81697 .13742 Mdot
.81702 .13766 Mdot
.81706 .1379 Mdot
.81711 .13813 Mdot
.81716 .13837 Mdot
.81721 .13861 Mdot
.81725 .13885 Mdot
.8173 .13909 Mdot
.81735 .13933 Mdot
.8174 .13958 Mdot
.81744 .13982 Mdot
.81749 .14006 Mdot
.81754 .1403 Mdot
.81759 .14054 Mdot
.81763 .14078 Mdot
.81768 .14102 Mdot
.81773 .14126 Mdot
.81778 .14151 Mdot
.81783 .14175 Mdot
.81787 .14199 Mdot
.81792 .14223 Mdot
.81797 .14247 Mdot
.81802 .14272 Mdot
.81806 .14296 Mdot
.81811 .1432 Mdot
.81816 .14345 Mdot
.81821 .14369 Mdot
.81825 .14393 Mdot
.8183 .14418 Mdot
.81835 .14442 Mdot
.8184 .14466 Mdot
.81844 .14491 Mdot
.81849 .14515 Mdot
.81854 .1454 Mdot
.81859 .14564 Mdot
.81863 .14589 Mdot
.81868 .14613 Mdot
.81873 .14638 Mdot
.81878 .14662 Mdot
.81883 .14687 Mdot
.81887 .14711 Mdot
.81892 .14736 Mdot
.81897 .14761 Mdot
.81902 .14785 Mdot
.81906 .1481 Mdot
.81911 .14834 Mdot
.81916 .14859 Mdot
.81921 .14884 Mdot
.81925 .14909 Mdot
.8193 .14933 Mdot
.81935 .14958 Mdot
.8194 .14983 Mdot
.81944 .15007 Mdot
.81949 .15032 Mdot
.81954 .15057 Mdot
.81959 .15082 Mdot
.81963 .15107 Mdot
.81968 .15131 Mdot
.81973 .15156 Mdot
.81978 .15181 Mdot
.81983 .15206 Mdot
.81987 .15231 Mdot
.81992 .15256 Mdot
.81997 .15281 Mdot
.82002 .15306 Mdot
.82006 .15331 Mdot
.82011 .15356 Mdot
.82016 .15381 Mdot
.82021 .15406 Mdot
.82025 .15431 Mdot
.8203 .15456 Mdot
.82035 .15481 Mdot
.8204 .15506 Mdot
.82044 .15531 Mdot
.82049 .15556 Mdot
.82054 .15581 Mdot
.82059 .15606 Mdot
.82063 .15632 Mdot
.82068 .15657 Mdot
.82073 .15682 Mdot
.82078 .15707 Mdot
.82083 .15732 Mdot
.82087 .15757 Mdot
.82092 .15783 Mdot
.82097 .15808 Mdot
.82102 .15833 Mdot
.82106 .15859 Mdot
.82111 .15884 Mdot
.82116 .15909 Mdot
.82121 .15934 Mdot
.82125 .1596 Mdot
.8213 .15985 Mdot
.82135 .16011 Mdot
.8214 .16036 Mdot
.82144 .16061 Mdot
.82149 .16087 Mdot
.82154 .16112 Mdot
.82159 .16138 Mdot
.82163 .16163 Mdot
.82168 .16189 Mdot
.82173 .16214 Mdot
.82178 .1624 Mdot
.82182 .16265 Mdot
.82187 .16291 Mdot
.82192 .16316 Mdot
.82197 .16342 Mdot
.82202 .16367 Mdot
.82206 .16393 Mdot
.82211 .16419 Mdot
.82216 .16444 Mdot
.82221 .1647 Mdot
.82225 .16495 Mdot
.8223 .16521 Mdot
.82235 .16547 Mdot
.8224 .16573 Mdot
.82244 .16598 Mdot
.82249 .16624 Mdot
.82254 .1665 Mdot
.82259 .16675 Mdot
.82263 .16701 Mdot
.82268 .16727 Mdot
.82273 .16753 Mdot
.82278 .16779 Mdot
.82282 .16804 Mdot
.82287 .1683 Mdot
.82292 .16856 Mdot
.82297 .16882 Mdot
.82302 .16908 Mdot
.82306 .16934 Mdot
.82311 .1696 Mdot
.82316 .16986 Mdot
.82321 .17012 Mdot
.82325 .17037 Mdot
.8233 .17063 Mdot
.82335 .17089 Mdot
.8234 .17115 Mdot
.82344 .17141 Mdot
.82349 .17167 Mdot
.82354 .17193 Mdot
.82359 .1722 Mdot
.82363 .17246 Mdot
.82368 .17272 Mdot
.82373 .17298 Mdot
.82378 .17324 Mdot
.82382 .1735 Mdot
.82387 .17376 Mdot
.82392 .17402 Mdot
.82397 .17428 Mdot
.82402 .17455 Mdot
.82406 .17481 Mdot
.82411 .17507 Mdot
.82416 .17533 Mdot
.82421 .17559 Mdot
.82425 .17586 Mdot
.8243 .17612 Mdot
.82435 .17638 Mdot
.8244 .17664 Mdot
.82444 .17691 Mdot
.82449 .17717 Mdot
.82454 .17743 Mdot
.82459 .1777 Mdot
.82463 .17796 Mdot
.82468 .17822 Mdot
.82473 .17849 Mdot
.82478 .17875 Mdot
.82482 .17901 Mdot
.82487 .17928 Mdot
.82492 .17954 Mdot
.82497 .17981 Mdot
.82502 .18007 Mdot
.82506 .18034 Mdot
.82511 .1806 Mdot
.82516 .18087 Mdot
.82521 .18113 Mdot
.82525 .1814 Mdot
.8253 .18166 Mdot
.82535 .18193 Mdot
.8254 .18219 Mdot
.82544 .18246 Mdot
.82549 .18272 Mdot
.82554 .18299 Mdot
.82559 .18326 Mdot
.82563 .18352 Mdot
.82568 .18379 Mdot
.82573 .18405 Mdot
.82578 .18432 Mdot
.82582 .18459 Mdot
.82587 .18485 Mdot
.82592 .18512 Mdot
.82597 .18539 Mdot
.82602 .18565 Mdot
.82606 .18592 Mdot
.82611 .18619 Mdot
.82616 .18646 Mdot
.82621 .18672 Mdot
.82625 .18699 Mdot
.8263 .18726 Mdot
.82635 .18753 Mdot
.8264 .1878 Mdot
.82644 .18806 Mdot
.82649 .18833 Mdot
.82654 .1886 Mdot
.82659 .18887 Mdot
.82663 .18914 Mdot
.82668 .18941 Mdot
.82673 .18968 Mdot
.82678 .18994 Mdot
.82682 .19021 Mdot
.82687 .19048 Mdot
.82692 .19075 Mdot
.82697 .19102 Mdot
.82701 .19129 Mdot
.82706 .19156 Mdot
.82711 .19183 Mdot
.82716 .1921 Mdot
.82721 .19237 Mdot
.82725 .19264 Mdot
.8273 .19291 Mdot
.82735 .19318 Mdot
.8274 .19345 Mdot
.82744 .19372 Mdot
.82749 .19399 Mdot
.82754 .19427 Mdot
.82759 .19454 Mdot
.82763 .19481 Mdot
.82768 .19508 Mdot
.82773 .19535 Mdot
.82778 .19562 Mdot
.82782 .19589 Mdot
.82787 .19617 Mdot
.82792 .19644 Mdot
.82797 .19671 Mdot
.82801 .19698 Mdot
.82806 .19725 Mdot
.82811 .19753 Mdot
.82816 .1978 Mdot
.82821 .19807 Mdot
.82825 .19834 Mdot
.8283 .19862 Mdot
.82835 .19889 Mdot
.8284 .19916 Mdot
.82844 .19943 Mdot
.82849 .19971 Mdot
.82854 .19998 Mdot
.82859 .20025 Mdot
.82863 .20053 Mdot
.82868 .2008 Mdot
.82873 .20108 Mdot
.82878 .20135 Mdot
.82882 .20162 Mdot
.82887 .2019 Mdot
.82892 .20217 Mdot
.82897 .20245 Mdot
.82901 .20272 Mdot
.82906 .20299 Mdot
.82911 .20327 Mdot
.82916 .20354 Mdot
.82921 .20382 Mdot
.82925 .20409 Mdot
.8293 .20437 Mdot
.82935 .20464 Mdot
.8294 .20492 Mdot
.82944 .20519 Mdot
.82949 .20547 Mdot
.82954 .20575 Mdot
.82959 .20602 Mdot
.82963 .2063 Mdot
.82968 .20657 Mdot
.82973 .20685 Mdot
.82978 .20712 Mdot
.82982 .2074 Mdot
.82987 .20768 Mdot
.82992 .20795 Mdot
.82997 .20823 Mdot
.83001 .20851 Mdot
.83006 .20878 Mdot
.83011 .20906 Mdot
.83016 .20934 Mdot
.83021 .20961 Mdot
.83025 .20989 Mdot
.8303 .21017 Mdot
.83035 .21044 Mdot
.8304 .21072 Mdot
.83044 .211 Mdot
.83049 .21128 Mdot
.83054 .21155 Mdot
.83059 .21183 Mdot
.83063 .21211 Mdot
.83068 .21239 Mdot
.83073 .21267 Mdot
.83078 .21294 Mdot
.83082 .21322 Mdot
.83087 .2135 Mdot
.83092 .21378 Mdot
.83097 .21406 Mdot
.83101 .21434 Mdot
.83106 .21461 Mdot
.83111 .21489 Mdot
.83116 .21517 Mdot
.8312 .21545 Mdot
.83125 .21573 Mdot
.8313 .21601 Mdot
.83135 .21629 Mdot
.8314 .21657 Mdot
.83144 .21685 Mdot
.83149 .21713 Mdot
.83154 .21741 Mdot
.83159 .21769 Mdot
.83163 .21797 Mdot
.83168 .21825 Mdot
.83173 .21853 Mdot
.83178 .21881 Mdot
.83182 .21909 Mdot
.83187 .21937 Mdot
.83192 .21965 Mdot
.83197 .21993 Mdot
.83201 .22021 Mdot
.83206 .22049 Mdot
.83211 .22077 Mdot
.83216 .22105 Mdot
.8322 .22133 Mdot
.83225 .22161 Mdot
.8323 .22189 Mdot
.83235 .22217 Mdot
.8324 .22246 Mdot
.83244 .22274 Mdot
.83249 .22302 Mdot
.83254 .2233 Mdot
.83259 .22358 Mdot
.83263 .22386 Mdot
.83268 .22414 Mdot
.83273 .22443 Mdot
.83278 .22471 Mdot
.83282 .22499 Mdot
.83287 .22527 Mdot
.83292 .22555 Mdot
.83297 .22584 Mdot
.83301 .22612 Mdot
.83306 .2264 Mdot
.83311 .22668 Mdot
.83316 .22697 Mdot
.8332 .22725 Mdot
.83325 .22753 Mdot
.8333 .22781 Mdot
.83335 .2281 Mdot
.8334 .22838 Mdot
.83344 .22866 Mdot
.83349 .22895 Mdot
.83354 .22923 Mdot
.83359 .22951 Mdot
.83363 .2298 Mdot
.83368 .23008 Mdot
.83373 .23036 Mdot
.83378 .23065 Mdot
.83382 .23093 Mdot
.83387 .23121 Mdot
.83392 .2315 Mdot
.83397 .23178 Mdot
.83401 .23207 Mdot
.83406 .23235 Mdot
.83411 .23263 Mdot
.83416 .23292 Mdot
.8342 .2332 Mdot
.83425 .23349 Mdot
.8343 .23377 Mdot
.83435 .23406 Mdot
.8344 .23434 Mdot
.83444 .23463 Mdot
.83449 .23491 Mdot
.83454 .2352 Mdot
.83459 .23548 Mdot
.83463 .23577 Mdot
.83468 .23605 Mdot
.83473 .23634 Mdot
.83478 .23662 Mdot
.83482 .23691 Mdot
.83487 .23719 Mdot
.83492 .23748 Mdot
.83497 .23776 Mdot
.83501 .23805 Mdot
.83506 .23833 Mdot
.83511 .23862 Mdot
.83516 .23891 Mdot
.8352 .23919 Mdot
.83525 .23948 Mdot
.8353 .23976 Mdot
.83535 .24005 Mdot
.8354 .24033 Mdot
.83544 .24062 Mdot
.83549 .24091 Mdot
.83554 .24119 Mdot
.83559 .24148 Mdot
.83563 .24177 Mdot
.83568 .24205 Mdot
.83573 .24234 Mdot
.83578 .24263 Mdot
.83582 .24291 Mdot
.83587 .2432 Mdot
.83592 .24349 Mdot
.83597 .24377 Mdot
.83601 .24406 Mdot
.83606 .24435 Mdot
.83611 .24463 Mdot
.83616 .24492 Mdot
.8362 .24521 Mdot
.83625 .2455 Mdot
.8363 .24578 Mdot
.83635 .24607 Mdot
.83639 .24636 Mdot
.83644 .24665 Mdot
.83649 .24693 Mdot
.83654 .24722 Mdot
.83659 .24751 Mdot
.83663 .2478 Mdot
.83668 .24809 Mdot
.83673 .24837 Mdot
.83678 .24866 Mdot
.83682 .24895 Mdot
.83687 .24924 Mdot
.83692 .24953 Mdot
.83697 .24981 Mdot
.83701 .2501 Mdot
.83706 .25039 Mdot
.83711 .25068 Mdot
.83716 .25097 Mdot
.8372 .25126 Mdot
.83725 .25154 Mdot
.8373 .25183 Mdot
.83735 .25212 Mdot
.83739 .25241 Mdot
.83744 .2527 Mdot
.83749 .25299 Mdot
.83754 .25328 Mdot
.83759 .25357 Mdot
.83763 .25386 Mdot
.83768 .25414 Mdot
.83773 .25443 Mdot
.83778 .25472 Mdot
.83782 .25501 Mdot
.83787 .2553 Mdot
.83792 .25559 Mdot
.83797 .25588 Mdot
.83801 .25617 Mdot
.83806 .25646 Mdot
.83811 .25675 Mdot
.83816 .25704 Mdot
.8382 .25733 Mdot
.83825 .25762 Mdot
.8383 .25791 Mdot
.83835 .2582 Mdot
.83839 .25849 Mdot
.83844 .25878 Mdot
.83849 .25907 Mdot
.83854 .25936 Mdot
.83859 .25965 Mdot
.83863 .25994 Mdot
.83868 .26023 Mdot
.83873 .26052 Mdot
.83878 .26081 Mdot
.83882 .2611 Mdot
.83887 .26139 Mdot
.83892 .26168 Mdot
.83897 .26197 Mdot
.83901 .26226 Mdot
.83906 .26255 Mdot
.83911 .26284 Mdot
.83916 .26313 Mdot
.8392 .26342 Mdot
.83925 .26371 Mdot
.8393 .264 Mdot
.83935 .2643 Mdot
.83939 .26459 Mdot
.83944 .26488 Mdot
.83949 .26517 Mdot
.83954 .26546 Mdot
.83959 .26575 Mdot
.83963 .26604 Mdot
.83968 .26633 Mdot
.83973 .26662 Mdot
.83978 .26692 Mdot
.83982 .26721 Mdot
.83987 .2675 Mdot
.83992 .26779 Mdot
.83997 .26808 Mdot
.84001 .26837 Mdot
.84006 .26866 Mdot
.84011 .26896 Mdot
.84016 .26925 Mdot
.8402 .26954 Mdot
.84025 .26983 Mdot
.8403 .27012 Mdot
.84035 .27041 Mdot
.84039 .27071 Mdot
.84044 .271 Mdot
.84049 .27129 Mdot
.84054 .27158 Mdot
.84058 .27187 Mdot
.84063 .27216 Mdot
.84068 .27246 Mdot
.84073 .27275 Mdot
.84078 .27304 Mdot
.84082 .27333 Mdot
.84087 .27362 Mdot
.84092 .27392 Mdot
.84097 .27421 Mdot
.84101 .2745 Mdot
.84106 .27479 Mdot
.84111 .27509 Mdot
.84116 .27538 Mdot
.8412 .27567 Mdot
.84125 .27596 Mdot
.8413 .27626 Mdot
.84135 .27655 Mdot
.84139 .27684 Mdot
.84144 .27713 Mdot
.84149 .27743 Mdot
.84154 .27772 Mdot
.84158 .27801 Mdot
.84163 .2783 Mdot
.84168 .2786 Mdot
.84173 .27889 Mdot
.84178 .27918 Mdot
.84182 .27947 Mdot
.84187 .27977 Mdot
.84192 .28006 Mdot
.84197 .28035 Mdot
.84201 .28065 Mdot
.84206 .28094 Mdot
.84211 .28123 Mdot
.84216 .28153 Mdot
.8422 .28182 Mdot
.84225 .28211 Mdot
.8423 .2824 Mdot
.84235 .2827 Mdot
.84239 .28299 Mdot
.84244 .28328 Mdot
.84249 .28358 Mdot
.84254 .28387 Mdot
.84258 .28416 Mdot
.84263 .28446 Mdot
.84268 .28475 Mdot
.84273 .28504 Mdot
.84278 .28534 Mdot
.84282 .28563 Mdot
.84287 .28592 Mdot
.84292 .28622 Mdot
.84297 .28651 Mdot
.84301 .2868 Mdot
.84306 .2871 Mdot
.84311 .28739 Mdot
.84316 .28768 Mdot
.8432 .28798 Mdot
.84325 .28827 Mdot
.8433 .28856 Mdot
.84335 .28886 Mdot
.84339 .28915 Mdot
.84344 .28945 Mdot
.84349 .28974 Mdot
.84354 .29003 Mdot
.84358 .29033 Mdot
.84363 .29062 Mdot
.84368 .29091 Mdot
.84373 .29121 Mdot
.84378 .2915 Mdot
.84382 .2918 Mdot
.84387 .29209 Mdot
.84392 .29238 Mdot
.84397 .29268 Mdot
.84401 .29297 Mdot
.84406 .29326 Mdot
.84411 .29356 Mdot
.84416 .29385 Mdot
.8442 .29415 Mdot
.84425 .29444 Mdot
.8443 .29473 Mdot
.84435 .29503 Mdot
.84439 .29532 Mdot
.84444 .29562 Mdot
.84449 .29591 Mdot
.84454 .2962 Mdot
.84458 .2965 Mdot
.84463 .29679 Mdot
.84468 .29709 Mdot
.84473 .29738 Mdot
.84478 .29767 Mdot
.84482 .29797 Mdot
.84487 .29826 Mdot
.84492 .29856 Mdot
.84497 .29885 Mdot
.84501 .29914 Mdot
.84506 .29944 Mdot
.84511 .29973 Mdot
.84516 .30003 Mdot
.8452 .30032 Mdot
.84525 .30062 Mdot
.8453 .30091 Mdot
.84535 .3012 Mdot
.84539 .3015 Mdot
.84544 .30179 Mdot
.84549 .30209 Mdot
.84554 .30238 Mdot
.84558 .30268 Mdot
.84563 .30297 Mdot
.84568 .30326 Mdot
.84573 .30356 Mdot
.84577 .30385 Mdot
.84582 .30415 Mdot
.84587 .30444 Mdot
.84592 .30473 Mdot
.84597 .30503 Mdot
.84601 .30532 Mdot
.84606 .30562 Mdot
.84611 .30591 Mdot
.84616 .30621 Mdot
.8462 .3065 Mdot
.84625 .30679 Mdot
.8463 .30709 Mdot
.84635 .30738 Mdot
.84639 .30768 Mdot
.84644 .30797 Mdot
.84649 .30827 Mdot
.84654 .30856 Mdot
.84658 .30885 Mdot
.84663 .30915 Mdot
.84668 .30944 Mdot
.84673 .30974 Mdot
.84677 .31003 Mdot
.84682 .31033 Mdot
.84687 .31062 Mdot
.84692 .31091 Mdot
.84697 .31121 Mdot
.84701 .3115 Mdot
.84706 .3118 Mdot
.84711 .31209 Mdot
.84716 .31239 Mdot
.8472 .31268 Mdot
.84725 .31298 Mdot
.8473 .31327 Mdot
.84735 .31356 Mdot
.84739 .31386 Mdot
.84744 .31415 Mdot
.84749 .31445 Mdot
.84754 .31474 Mdot
.84758 .31503 Mdot
.84763 .31533 Mdot
.84768 .31562 Mdot
.84773 .31592 Mdot
.84777 .31621 Mdot
.84782 .31651 Mdot
.84787 .3168 Mdot
.84792 .31709 Mdot
.84797 .31739 Mdot
.84801 .31768 Mdot
.84806 .31798 Mdot
.84811 .31827 Mdot
.84816 .31857 Mdot
.8482 .31886 Mdot
.84825 .31915 Mdot
.8483 .31945 Mdot
.84835 .31974 Mdot
.84839 .32004 Mdot
.84844 .32033 Mdot
.84849 .32062 Mdot
.84854 .32092 Mdot
.84858 .32121 Mdot
.84863 .32151 Mdot
.84868 .3218 Mdot
.84873 .32209 Mdot
.84877 .32239 Mdot
.84882 .32268 Mdot
.84887 .32298 Mdot
.84892 .32327 Mdot
.84897 .32356 Mdot
.84901 .32386 Mdot
.84906 .32415 Mdot
.84911 .32445 Mdot
.84916 .32474 Mdot
.8492 .32503 Mdot
.84925 .32533 Mdot
.8493 .32562 Mdot
.84935 .32592 Mdot
.84939 .32621 Mdot
.84944 .3265 Mdot
.84949 .3268 Mdot
.84954 .32709 Mdot
.84958 .32738 Mdot
.84963 .32768 Mdot
.84968 .32797 Mdot
.84973 .32827 Mdot
.84977 .32856 Mdot
.84982 .32885 Mdot
.84987 .32915 Mdot
.84992 .32944 Mdot
.84997 .32973 Mdot
.85001 .33003 Mdot
.85006 .33032 Mdot
.85011 .33061 Mdot
.85016 .33091 Mdot
.8502 .3312 Mdot
.85025 .33149 Mdot
.8503 .33179 Mdot
.85035 .33208 Mdot
.85039 .33237 Mdot
.85044 .33267 Mdot
.85049 .33296 Mdot
.85054 .33325 Mdot
.85058 .33355 Mdot
.85063 .33384 Mdot
.85068 .33413 Mdot
.85073 .33443 Mdot
.85077 .33472 Mdot
.85082 .33501 Mdot
.85087 .33531 Mdot
.85092 .3356 Mdot
.85096 .33589 Mdot
.85101 .33619 Mdot
.85106 .33648 Mdot
.85111 .33677 Mdot
.85116 .33707 Mdot
.8512 .33736 Mdot
.85125 .33765 Mdot
.8513 .33794 Mdot
.85135 .33824 Mdot
.85139 .33853 Mdot
.85144 .33882 Mdot
.85149 .33912 Mdot
.85154 .33941 Mdot
.85158 .3397 Mdot
.85163 .33999 Mdot
.85168 .34029 Mdot
.85173 .34058 Mdot
.85177 .34087 Mdot
.85182 .34116 Mdot
.85187 .34146 Mdot
.85192 .34175 Mdot
.85196 .34204 Mdot
.85201 .34233 Mdot
.85206 .34263 Mdot
.85211 .34292 Mdot
.85216 .34321 Mdot
.8522 .3435 Mdot
.85225 .3438 Mdot
.8523 .34409 Mdot
.85235 .34438 Mdot
.85239 .34467 Mdot
.85244 .34496 Mdot
.85249 .34526 Mdot
.85254 .34555 Mdot
.85258 .34584 Mdot
.85263 .34613 Mdot
.85268 .34642 Mdot
.85273 .34672 Mdot
.85277 .34701 Mdot
.85282 .3473 Mdot
.85287 .34759 Mdot
.85292 .34788 Mdot
.85296 .34818 Mdot
.85301 .34847 Mdot
.85306 .34876 Mdot
.85311 .34905 Mdot
.85316 .34934 Mdot
.8532 .34963 Mdot
.85325 .34992 Mdot
.8533 .35022 Mdot
.85335 .35051 Mdot
.85339 .3508 Mdot
.85344 .35109 Mdot
.85349 .35138 Mdot
.85354 .35167 Mdot
.85358 .35196 Mdot
.85363 .35226 Mdot
.85368 .35255 Mdot
.85373 .35284 Mdot
.85377 .35313 Mdot
.85382 .35342 Mdot
.85387 .35371 Mdot
.85392 .354 Mdot
.85396 .35429 Mdot
.85401 .35458 Mdot
.85406 .35487 Mdot
.85411 .35516 Mdot
.85416 .35545 Mdot
.8542 .35575 Mdot
.85425 .35604 Mdot
.8543 .35633 Mdot
.85435 .35662 Mdot
.85439 .35691 Mdot
.85444 .3572 Mdot
.85449 .35749 Mdot
.85454 .35778 Mdot
.85458 .35807 Mdot
.85463 .35836 Mdot
.85468 .35865 Mdot
.85473 .35894 Mdot
.85477 .35923 Mdot
.85482 .35952 Mdot
.85487 .35981 Mdot
.85492 .3601 Mdot
.85496 .36039 Mdot
.85501 .36068 Mdot
.85506 .36097 Mdot
.85511 .36126 Mdot
.85515 .36155 Mdot
.8552 .36184 Mdot
.85525 .36213 Mdot
.8553 .36242 Mdot
.85535 .36271 Mdot
.85539 .36299 Mdot
.85544 .36328 Mdot
.85549 .36357 Mdot
.85554 .36386 Mdot
.85558 .36415 Mdot
.85563 .36444 Mdot
.85568 .36473 Mdot
.85573 .36502 Mdot
.85577 .36531 Mdot
.85582 .3656 Mdot
.85587 .36588 Mdot
.85592 .36617 Mdot
.85596 .36646 Mdot
.85601 .36675 Mdot
.85606 .36704 Mdot
.85611 .36733 Mdot
.85615 .36762 Mdot
.8562 .3679 Mdot
.85625 .36819 Mdot
.8563 .36848 Mdot
.85635 .36877 Mdot
.85639 .36906 Mdot
.85644 .36935 Mdot
.85649 .36963 Mdot
.85654 .36992 Mdot
.85658 .37021 Mdot
.85663 .3705 Mdot
.85668 .37079 Mdot
.85673 .37107 Mdot
.85677 .37136 Mdot
.85682 .37165 Mdot
.85687 .37194 Mdot
.85692 .37222 Mdot
.85696 .37251 Mdot
.85701 .3728 Mdot
.85706 .37309 Mdot
.85711 .37337 Mdot
.85715 .37366 Mdot
.8572 .37395 Mdot
.85725 .37423 Mdot
.8573 .37452 Mdot
.85735 .37481 Mdot
.85739 .37509 Mdot
.85744 .37538 Mdot
.85749 .37567 Mdot
.85754 .37595 Mdot
.85758 .37624 Mdot
.85763 .37653 Mdot
.85768 .37681 Mdot
.85773 .3771 Mdot
.85777 .37739 Mdot
.85782 .37767 Mdot
.85787 .37796 Mdot
.85792 .37825 Mdot
.85796 .37853 Mdot
.85801 .37882 Mdot
.85806 .3791 Mdot
.85811 .37939 Mdot
.85815 .37968 Mdot
.8582 .37996 Mdot
.85825 .38025 Mdot
.8583 .38053 Mdot
.85835 .38082 Mdot
.85839 .3811 Mdot
.85844 .38139 Mdot
.85849 .38167 Mdot
.85854 .38196 Mdot
.85858 .38224 Mdot
.85863 .38253 Mdot
.85868 .38281 Mdot
.85873 .3831 Mdot
.85877 .38338 Mdot
.85882 .38367 Mdot
.85887 .38395 Mdot
.85892 .38424 Mdot
.85896 .38452 Mdot
.85901 .38481 Mdot
.85906 .38509 Mdot
.85911 .38537 Mdot
.85915 .38566 Mdot
.8592 .38594 Mdot
.85925 .38623 Mdot
.8593 .38651 Mdot
.85935 .38679 Mdot
.85939 .38708 Mdot
.85944 .38736 Mdot
.85949 .38765 Mdot
.85954 .38793 Mdot
.85958 .38821 Mdot
.85963 .3885 Mdot
.85968 .38878 Mdot
.85973 .38906 Mdot
.85977 .38935 Mdot
.85982 .38963 Mdot
.85987 .38991 Mdot
.85992 .3902 Mdot
.85996 .39048 Mdot
.86001 .39076 Mdot
.86006 .39104 Mdot
.86011 .39133 Mdot
.86015 .39161 Mdot
.8602 .39189 Mdot
.86025 .39217 Mdot
.8603 .39246 Mdot
.86034 .39274 Mdot
.86039 .39302 Mdot
.86044 .3933 Mdot
.86049 .39358 Mdot
.86054 .39387 Mdot
.86058 .39415 Mdot
.86063 .39443 Mdot
.86068 .39471 Mdot
.86073 .39499 Mdot
.86077 .39527 Mdot
.86082 .39556 Mdot
.86087 .39584 Mdot
.86092 .39612 Mdot
.86096 .3964 Mdot
.86101 .39668 Mdot
.86106 .39696 Mdot
.86111 .39724 Mdot
.86115 .39752 Mdot
.8612 .3978 Mdot
.86125 .39808 Mdot
.8613 .39836 Mdot
.86134 .39864 Mdot
.86139 .39893 Mdot
.86144 .39921 Mdot
.86149 .39949 Mdot
.86154 .39977 Mdot
.86158 .40005 Mdot
.86163 .40033 Mdot
.86168 .4006 Mdot
.86173 .40088 Mdot
.86177 .40116 Mdot
.86182 .40144 Mdot
.86187 .40172 Mdot
.86192 .402 Mdot
.86196 .40228 Mdot
.86201 .40256 Mdot
.86206 .40284 Mdot
.86211 .40312 Mdot
.86215 .4034 Mdot
.8622 .40368 Mdot
.86225 .40395 Mdot
.8623 .40423 Mdot
.86234 .40451 Mdot
.86239 .40479 Mdot
.86244 .40507 Mdot
.86249 .40535 Mdot
.86254 .40562 Mdot
.86258 .4059 Mdot
.86263 .40618 Mdot
.86268 .40646 Mdot
.86273 .40674 Mdot
.86277 .40701 Mdot
.86282 .40729 Mdot
.86287 .40757 Mdot
.86292 .40785 Mdot
.86296 .40812 Mdot
.86301 .4084 Mdot
.86306 .40868 Mdot
.86311 .40895 Mdot
.86315 .40923 Mdot
.8632 .40951 Mdot
.86325 .40978 Mdot
.8633 .41006 Mdot
.86334 .41034 Mdot
.86339 .41061 Mdot
.86344 .41089 Mdot
.86349 .41117 Mdot
.86354 .41144 Mdot
.86358 .41172 Mdot
.86363 .41199 Mdot
.86368 .41227 Mdot
.86373 .41254 Mdot
.86377 .41282 Mdot
.86382 .41309 Mdot
.86387 .41337 Mdot
.86392 .41365 Mdot
.86396 .41392 Mdot
.86401 .4142 Mdot
.86406 .41447 Mdot
.86411 .41474 Mdot
.86415 .41502 Mdot
.8642 .41529 Mdot
.86425 .41557 Mdot
.8643 .41584 Mdot
.86434 .41612 Mdot
.86439 .41639 Mdot
.86444 .41666 Mdot
.86449 .41694 Mdot
.86453 .41721 Mdot
.86458 .41749 Mdot
.86463 .41776 Mdot
.86468 .41803 Mdot
.86473 .41831 Mdot
.86477 .41858 Mdot
.86482 .41885 Mdot
.86487 .41913 Mdot
.86492 .4194 Mdot
.86496 .41967 Mdot
.86501 .41994 Mdot
.86506 .42022 Mdot
.86511 .42049 Mdot
.86515 .42076 Mdot
.8652 .42103 Mdot
.86525 .42131 Mdot
.8653 .42158 Mdot
.86534 .42185 Mdot
.86539 .42212 Mdot
.86544 .42239 Mdot
.86549 .42266 Mdot
.86553 .42294 Mdot
.86558 .42321 Mdot
.86563 .42348 Mdot
.86568 .42375 Mdot
.86573 .42402 Mdot
.86577 .42429 Mdot
.86582 .42456 Mdot
.86587 .42483 Mdot
.86592 .4251 Mdot
.86596 .42537 Mdot
.86601 .42564 Mdot
.86606 .42591 Mdot
.86611 .42618 Mdot
.86615 .42645 Mdot
.8662 .42672 Mdot
.86625 .42699 Mdot
.8663 .42726 Mdot
.86634 .42753 Mdot
.86639 .4278 Mdot
.86644 .42807 Mdot
.86649 .42834 Mdot
.86653 .42861 Mdot
.86658 .42888 Mdot
.86663 .42915 Mdot
.86668 .42942 Mdot
.86673 .42968 Mdot
.86677 .42995 Mdot
.86682 .43022 Mdot
.86687 .43049 Mdot
.86692 .43076 Mdot
.86696 .43103 Mdot
.86701 .43129 Mdot
.86706 .43156 Mdot
.86711 .43183 Mdot
.86715 .4321 Mdot
.8672 .43236 Mdot
.86725 .43263 Mdot
.8673 .4329 Mdot
.86734 .43316 Mdot
.86739 .43343 Mdot
.86744 .4337 Mdot
.86749 .43396 Mdot
.86753 .43423 Mdot
.86758 .4345 Mdot
.86763 .43476 Mdot
.86768 .43503 Mdot
.86773 .4353 Mdot
.86777 .43556 Mdot
.86782 .43583 Mdot
.86787 .43609 Mdot
.86792 .43636 Mdot
.86796 .43662 Mdot
.86801 .43689 Mdot
.86806 .43715 Mdot
.86811 .43742 Mdot
.86815 .43768 Mdot
.8682 .43795 Mdot
.86825 .43821 Mdot
.8683 .43848 Mdot
.86834 .43874 Mdot
.86839 .439 Mdot
.86844 .43927 Mdot
.86849 .43953 Mdot
.86853 .4398 Mdot
.86858 .44006 Mdot
.86863 .44032 Mdot
.86868 .44059 Mdot
.86873 .44085 Mdot
.86877 .44111 Mdot
.86882 .44138 Mdot
.86887 .44164 Mdot
.86892 .4419 Mdot
.86896 .44216 Mdot
.86901 .44243 Mdot
.86906 .44269 Mdot
.86911 .44295 Mdot
.86915 .44321 Mdot
.8692 .44347 Mdot
.86925 .44374 Mdot
.8693 .444 Mdot
.86934 .44426 Mdot
.86939 .44452 Mdot
.86944 .44478 Mdot
.86949 .44504 Mdot
.86953 .4453 Mdot
.86958 .44556 Mdot
.86963 .44583 Mdot
.86968 .44609 Mdot
.86972 .44635 Mdot
.86977 .44661 Mdot
.86982 .44687 Mdot
.86987 .44713 Mdot
.86992 .44739 Mdot
.86996 .44765 Mdot
.87001 .44791 Mdot
.87006 .44817 Mdot
.87011 .44842 Mdot
.87015 .44868 Mdot
.8702 .44894 Mdot
.87025 .4492 Mdot
.8703 .44946 Mdot
.87034 .44972 Mdot
.87039 .44998 Mdot
.87044 .45024 Mdot
.87049 .45049 Mdot
.87053 .45075 Mdot
.87058 .45101 Mdot
.87063 .45127 Mdot
.87068 .45153 Mdot
.87072 .45178 Mdot
.87077 .45204 Mdot
.87082 .4523 Mdot
.87087 .45255 Mdot
.87092 .45281 Mdot
.87096 .45307 Mdot
.87101 .45332 Mdot
.87106 .45358 Mdot
.87111 .45384 Mdot
.87115 .45409 Mdot
.8712 .45435 Mdot
.87125 .45461 Mdot
.8713 .45486 Mdot
.87134 .45512 Mdot
.87139 .45537 Mdot
.87144 .45563 Mdot
.87149 .45588 Mdot
.87153 .45614 Mdot
.87158 .45639 Mdot
.87163 .45665 Mdot
.87168 .4569 Mdot
.87172 .45716 Mdot
.87177 .45741 Mdot
.87182 .45766 Mdot
.87187 .45792 Mdot
.87192 .45817 Mdot
.87196 .45843 Mdot
.87201 .45868 Mdot
.87206 .45893 Mdot
.87211 .45919 Mdot
.87215 .45944 Mdot
.8722 .45969 Mdot
.87225 .45994 Mdot
.8723 .4602 Mdot
.87234 .46045 Mdot
.87239 .4607 Mdot
.87244 .46095 Mdot
.87249 .46121 Mdot
.87253 .46146 Mdot
.87258 .46171 Mdot
.87263 .46196 Mdot
.87268 .46221 Mdot
.87272 .46246 Mdot
.87277 .46271 Mdot
.87282 .46297 Mdot
.87287 .46322 Mdot
.87292 .46347 Mdot
.87296 .46372 Mdot
.87301 .46397 Mdot
.87306 .46422 Mdot
.87311 .46447 Mdot
.87315 .46472 Mdot
.8732 .46497 Mdot
.87325 .46522 Mdot
.8733 .46547 Mdot
.87334 .46572 Mdot
.87339 .46596 Mdot
.87344 .46621 Mdot
.87349 .46646 Mdot
.87353 .46671 Mdot
.87358 .46696 Mdot
.87363 .46721 Mdot
.87368 .46746 Mdot
.87372 .4677 Mdot
.87377 .46795 Mdot
.87382 .4682 Mdot
.87387 .46845 Mdot
.87391 .46869 Mdot
.87396 .46894 Mdot
.87401 .46919 Mdot
.87406 .46944 Mdot
.87411 .46968 Mdot
.87415 .46993 Mdot
.8742 .47017 Mdot
.87425 .47042 Mdot
.8743 .47067 Mdot
.87434 .47091 Mdot
.87439 .47116 Mdot
.87444 .4714 Mdot
.87449 .47165 Mdot
.87453 .47189 Mdot
.87458 .47214 Mdot
.87463 .47238 Mdot
.87468 .47263 Mdot
.87472 .47287 Mdot
.87477 .47312 Mdot
.87482 .47336 Mdot
.87487 .47361 Mdot
.87491 .47385 Mdot
.87496 .47409 Mdot
.87501 .47434 Mdot
.87506 .47458 Mdot
.87511 .47482 Mdot
.87515 .47507 Mdot
.8752 .47531 Mdot
.87525 .47555 Mdot
.8753 .4758 Mdot
.87534 .47604 Mdot
.87539 .47628 Mdot
.87544 .47652 Mdot
.87549 .47676 Mdot
.87553 .47701 Mdot
.87558 .47725 Mdot
.87563 .47749 Mdot
.87568 .47773 Mdot
.87572 .47797 Mdot
.87577 .47821 Mdot
.87582 .47845 Mdot
.87587 .47869 Mdot
.87591 .47893 Mdot
.87596 .47918 Mdot
.87601 .47942 Mdot
.87606 .47965 Mdot
.87611 .47989 Mdot
.87615 .48013 Mdot
.8762 .48037 Mdot
.87625 .48061 Mdot
.8763 .48085 Mdot
.87634 .48109 Mdot
.87639 .48133 Mdot
.87644 .48157 Mdot
.87649 .48181 Mdot
.87653 .48204 Mdot
.87658 .48228 Mdot
.87663 .48252 Mdot
.87668 .48276 Mdot
.87672 .483 Mdot
.87677 .48323 Mdot
.87682 .48347 Mdot
.87687 .48371 Mdot
.87691 .48394 Mdot
.87696 .48418 Mdot
.87701 .48442 Mdot
.87706 .48465 Mdot
.87711 .48489 Mdot
.87715 .48513 Mdot
.8772 .48536 Mdot
.87725 .4856 Mdot
.8773 .48583 Mdot
.87734 .48607 Mdot
.87739 .4863 Mdot
.87744 .48654 Mdot
.87749 .48677 Mdot
.87753 .48701 Mdot
.87758 .48724 Mdot
.87763 .48747 Mdot
.87768 .48771 Mdot
.87772 .48794 Mdot
.87777 .48818 Mdot
.87782 .48841 Mdot
.87787 .48864 Mdot
.87791 .48888 Mdot
.87796 .48911 Mdot
.87801 .48934 Mdot
.87806 .48957 Mdot
.87811 .48981 Mdot
.87815 .49004 Mdot
.8782 .49027 Mdot
.87825 .4905 Mdot
.8783 .49073 Mdot
.87834 .49097 Mdot
.87839 .4912 Mdot
.87844 .49143 Mdot
.87849 .49166 Mdot
.87853 .49189 Mdot
.87858 .49212 Mdot
.87863 .49235 Mdot
.87868 .49258 Mdot
.87872 .49281 Mdot
.87877 .49304 Mdot
.87882 .49327 Mdot
.87887 .4935 Mdot
.87891 .49373 Mdot
.87896 .49396 Mdot
.87901 .49419 Mdot
.87906 .49441 Mdot
.8791 .49464 Mdot
.87915 .49487 Mdot
.8792 .4951 Mdot
.87925 .49533 Mdot
.8793 .49556 Mdot
.87934 .49578 Mdot
.87939 .49601 Mdot
.87944 .49624 Mdot
.87949 .49646 Mdot
.87953 .49669 Mdot
.87958 .49692 Mdot
.87963 .49714 Mdot
.87968 .49737 Mdot
.87972 .4976 Mdot
.87977 .49782 Mdot
.87982 .49805 Mdot
.87987 .49827 Mdot
.87991 .4985 Mdot
.87996 .49872 Mdot
.88001 .49895 Mdot
.88006 .49917 Mdot
.8801 .4994 Mdot
.88015 .49962 Mdot
.8802 .49985 Mdot
.88025 .50007 Mdot
.8803 .5003 Mdot
.88034 .50052 Mdot
.88039 .50074 Mdot
.88044 .50097 Mdot
.88049 .50119 Mdot
.88053 .50141 Mdot
.88058 .50163 Mdot
.88063 .50186 Mdot
.88068 .50208 Mdot
.88072 .5023 Mdot
.88077 .50252 Mdot
.88082 .50274 Mdot
.88087 .50297 Mdot
.88091 .50319 Mdot
.88096 .50341 Mdot
.88101 .50363 Mdot
.88106 .50385 Mdot
.8811 .50407 Mdot
.88115 .50429 Mdot
.8812 .50451 Mdot
.88125 .50473 Mdot
.8813 .50495 Mdot
.88134 .50517 Mdot
.88139 .50539 Mdot
.88144 .50561 Mdot
.88149 .50583 Mdot
.88153 .50605 Mdot
.88158 .50626 Mdot
.88163 .50648 Mdot
.88168 .5067 Mdot
.88172 .50692 Mdot
.88177 .50714 Mdot
.88182 .50735 Mdot
.88187 .50757 Mdot
.88191 .50779 Mdot
.88196 .50801 Mdot
.88201 .50822 Mdot
.88206 .50844 Mdot
.8821 .50866 Mdot
.88215 .50887 Mdot
.8822 .50909 Mdot
.88225 .5093 Mdot
.8823 .50952 Mdot
.88234 .50973 Mdot
.88239 .50995 Mdot
.88244 .51016 Mdot
.88249 .51038 Mdot
.88253 .51059 Mdot
.88258 .51081 Mdot
.88263 .51102 Mdot
.88268 .51124 Mdot
.88272 .51145 Mdot
.88277 .51166 Mdot
.88282 .51188 Mdot
.88287 .51209 Mdot
.88291 .5123 Mdot
.88296 .51252 Mdot
.88301 .51273 Mdot
.88306 .51294 Mdot
.8831 .51315 Mdot
.88315 .51336 Mdot
.8832 .51358 Mdot
.88325 .51379 Mdot
.8833 .514 Mdot
.88334 .51421 Mdot
.88339 .51442 Mdot
.88344 .51463 Mdot
.88349 .51484 Mdot
.88353 .51505 Mdot
.88358 .51526 Mdot
.88363 .51547 Mdot
.88368 .51568 Mdot
.88372 .51589 Mdot
.88377 .5161 Mdot
.88382 .51631 Mdot
.88387 .51652 Mdot
.88391 .51673 Mdot
.88396 .51694 Mdot
.88401 .51714 Mdot
.88406 .51735 Mdot
.8841 .51756 Mdot
.88415 .51777 Mdot
.8842 .51798 Mdot
.88425 .51818 Mdot
.88429 .51839 Mdot
.88434 .5186 Mdot
.88439 .5188 Mdot
.88444 .51901 Mdot
.88449 .51922 Mdot
.88453 .51942 Mdot
.88458 .51963 Mdot
.88463 .51983 Mdot
.88468 .52004 Mdot
.88472 .52024 Mdot
.88477 .52045 Mdot
.88482 .52065 Mdot
.88487 .52086 Mdot
.88491 .52106 Mdot
.88496 .52126 Mdot
.88501 .52147 Mdot
.88506 .52167 Mdot
.8851 .52188 Mdot
.88515 .52208 Mdot
.8852 .52228 Mdot
.88525 .52248 Mdot
.88529 .52269 Mdot
.88534 .52289 Mdot
.88539 .52309 Mdot
.88544 .52329 Mdot
.88549 .52349 Mdot
.88553 .5237 Mdot
.88558 .5239 Mdot
.88563 .5241 Mdot
.88568 .5243 Mdot
.88572 .5245 Mdot
.88577 .5247 Mdot
.88582 .5249 Mdot
.88587 .5251 Mdot
.88591 .5253 Mdot
.88596 .5255 Mdot
.88601 .5257 Mdot
.88606 .5259 Mdot
.8861 .5261 Mdot
.88615 .5263 Mdot
.8862 .52649 Mdot
.88625 .52669 Mdot
.88629 .52689 Mdot
.88634 .52709 Mdot
.88639 .52729 Mdot
.88644 .52748 Mdot
.88649 .52768 Mdot
.88653 .52788 Mdot
.88658 .52807 Mdot
.88663 .52827 Mdot
.88668 .52847 Mdot
.88672 .52866 Mdot
.88677 .52886 Mdot
.88682 .52905 Mdot
.88687 .52925 Mdot
.88691 .52944 Mdot
.88696 .52964 Mdot
.88701 .52983 Mdot
.88706 .53003 Mdot
.8871 .53022 Mdot
.88715 .53042 Mdot
.8872 .53061 Mdot
.88725 .5308 Mdot
.88729 .531 Mdot
.88734 .53119 Mdot
.88739 .53138 Mdot
.88744 .53158 Mdot
.88749 .53177 Mdot
.88753 .53196 Mdot
.88758 .53215 Mdot
.88763 .53235 Mdot
.88768 .53254 Mdot
.88772 .53273 Mdot
.88777 .53292 Mdot
.88782 .53311 Mdot
.88787 .5333 Mdot
.88791 .53349 Mdot
.88796 .53368 Mdot
.88801 .53387 Mdot
.88806 .53406 Mdot
.8881 .53425 Mdot
.88815 .53444 Mdot
.8882 .53463 Mdot
.88825 .53482 Mdot
.88829 .53501 Mdot
.88834 .5352 Mdot
.88839 .53538 Mdot
.88844 .53557 Mdot
.88848 .53576 Mdot
.88853 .53595 Mdot
.88858 .53613 Mdot
.88863 .53632 Mdot
.88868 .53651 Mdot
.88872 .53669 Mdot
.88877 .53688 Mdot
.88882 .53707 Mdot
.88887 .53725 Mdot
.88891 .53744 Mdot
.88896 .53762 Mdot
.88901 .53781 Mdot
.88906 .53799 Mdot
.8891 .53818 Mdot
.88915 .53836 Mdot
.8892 .53855 Mdot
.88925 .53873 Mdot
.88929 .53892 Mdot
.88934 .5391 Mdot
.88939 .53928 Mdot
.88944 .53947 Mdot
.88948 .53965 Mdot
.88953 .53983 Mdot
.88958 .54002 Mdot
.88963 .5402 Mdot
.88968 .54038 Mdot
.88972 .54056 Mdot
.88977 .54074 Mdot
.88982 .54092 Mdot
.88987 .54111 Mdot
.88991 .54129 Mdot
.88996 .54147 Mdot
.89001 .54165 Mdot
.89006 .54183 Mdot
.8901 .54201 Mdot
.89015 .54219 Mdot
.8902 .54237 Mdot
.89025 .54255 Mdot
.89029 .54273 Mdot
.89034 .5429 Mdot
.89039 .54308 Mdot
.89044 .54326 Mdot
.89048 .54344 Mdot
.89053 .54362 Mdot
.89058 .54379 Mdot
.89063 .54397 Mdot
.89068 .54415 Mdot
.89072 .54433 Mdot
.89077 .5445 Mdot
.89082 .54468 Mdot
.89087 .54486 Mdot
.89091 .54503 Mdot
.89096 .54521 Mdot
.89101 .54538 Mdot
.89106 .54556 Mdot
.8911 .54573 Mdot
.89115 .54591 Mdot
.8912 .54608 Mdot
.89125 .54626 Mdot
.89129 .54643 Mdot
.89134 .5466 Mdot
.89139 .54678 Mdot
.89144 .54695 Mdot
.89148 .54712 Mdot
.89153 .5473 Mdot
.89158 .54747 Mdot
.89163 .54764 Mdot
.89168 .54781 Mdot
.89172 .54799 Mdot
.89177 .54816 Mdot
.89182 .54833 Mdot
.89187 .5485 Mdot
.89191 .54867 Mdot
.89196 .54884 Mdot
.89201 .54901 Mdot
.89206 .54918 Mdot
.8921 .54935 Mdot
.89215 .54952 Mdot
.8922 .54969 Mdot
.89225 .54986 Mdot
.89229 .55003 Mdot
.89234 .5502 Mdot
.89239 .55037 Mdot
.89244 .55054 Mdot
.89248 .5507 Mdot
.89253 .55087 Mdot
.89258 .55104 Mdot
.89263 .55121 Mdot
.89268 .55137 Mdot
.89272 .55154 Mdot
.89277 .55171 Mdot
.89282 .55187 Mdot
.89287 .55204 Mdot
.89291 .55221 Mdot
.89296 .55237 Mdot
.89301 .55254 Mdot
.89306 .5527 Mdot
.8931 .55287 Mdot
.89315 .55303 Mdot
.8932 .5532 Mdot
.89325 .55336 Mdot
.89329 .55352 Mdot
.89334 .55369 Mdot
.89339 .55385 Mdot
.89344 .55402 Mdot
.89348 .55418 Mdot
.89353 .55434 Mdot
.89358 .5545 Mdot
.89363 .55467 Mdot
.89367 .55483 Mdot
.89372 .55499 Mdot
.89377 .55515 Mdot
.89382 .55531 Mdot
.89387 .55547 Mdot
.89391 .55563 Mdot
.89396 .55579 Mdot
.89401 .55595 Mdot
.89406 .55611 Mdot
.8941 .55627 Mdot
.89415 .55643 Mdot
.8942 .55659 Mdot
.89425 .55675 Mdot
.89429 .55691 Mdot
.89434 .55707 Mdot
.89439 .55723 Mdot
.89444 .55739 Mdot
.89448 .55754 Mdot
.89453 .5577 Mdot
.89458 .55786 Mdot
.89463 .55802 Mdot
.89467 .55817 Mdot
.89472 .55833 Mdot
.89477 .55849 Mdot
.89482 .55864 Mdot
.89487 .5588 Mdot
.89491 .55895 Mdot
.89496 .55911 Mdot
.89501 .55926 Mdot
.89506 .55942 Mdot
.8951 .55957 Mdot
.89515 .55973 Mdot
.8952 .55988 Mdot
.89525 .56003 Mdot
.89529 .56019 Mdot
.89534 .56034 Mdot
.89539 .56049 Mdot
.89544 .56065 Mdot
.89548 .5608 Mdot
.89553 .56095 Mdot
.89558 .5611 Mdot
.89563 .56126 Mdot
.89567 .56141 Mdot
.89572 .56156 Mdot
.89577 .56171 Mdot
.89582 .56186 Mdot
.89587 .56201 Mdot
.89591 .56216 Mdot
.89596 .56231 Mdot
.89601 .56246 Mdot
.89606 .56261 Mdot
.8961 .56276 Mdot
.89615 .56291 Mdot
.8962 .56306 Mdot
.89625 .56321 Mdot
.89629 .56335 Mdot
.89634 .5635 Mdot
.89639 .56365 Mdot
.89644 .5638 Mdot
.89648 .56394 Mdot
.89653 .56409 Mdot
.89658 .56424 Mdot
.89663 .56438 Mdot
.89667 .56453 Mdot
.89672 .56468 Mdot
.89677 .56482 Mdot
.89682 .56497 Mdot
.89687 .56511 Mdot
.89691 .56526 Mdot
.89696 .5654 Mdot
.89701 .56555 Mdot
.89706 .56569 Mdot
.8971 .56584 Mdot
.89715 .56598 Mdot
.8972 .56612 Mdot
.89725 .56627 Mdot
.89729 .56641 Mdot
.89734 .56655 Mdot
.89739 .56669 Mdot
.89744 .56684 Mdot
.89748 .56698 Mdot
.89753 .56712 Mdot
.89758 .56726 Mdot
.89763 .5674 Mdot
.89767 .56754 Mdot
.89772 .56768 Mdot
.89777 .56782 Mdot
.89782 .56796 Mdot
.89786 .5681 Mdot
.89791 .56824 Mdot
.89796 .56838 Mdot
.89801 .56852 Mdot
.89806 .56866 Mdot
.8981 .5688 Mdot
.89815 .56894 Mdot
.8982 .56907 Mdot
.89825 .56921 Mdot
.89829 .56935 Mdot
.89834 .56949 Mdot
.89839 .56962 Mdot
.89844 .56976 Mdot
.89848 .5699 Mdot
.89853 .57003 Mdot
.89858 .57017 Mdot
.89863 .5703 Mdot
.89867 .57044 Mdot
.89872 .57057 Mdot
.89877 .57071 Mdot
.89882 .57084 Mdot
.89886 .57098 Mdot
.89891 .57111 Mdot
.89896 .57125 Mdot
.89901 .57138 Mdot
.89906 .57151 Mdot
.8991 .57165 Mdot
.89915 .57178 Mdot
.8992 .57191 Mdot
.89925 .57204 Mdot
.89929 .57217 Mdot
.89934 .57231 Mdot
.89939 .57244 Mdot
.89944 .57257 Mdot
.89948 .5727 Mdot
.89953 .57283 Mdot
.89958 .57296 Mdot
.89963 .57309 Mdot
.89967 .57322 Mdot
.89972 .57335 Mdot
.89977 .57348 Mdot
.89982 .57361 Mdot
.89986 .57374 Mdot
.89991 .57387 Mdot
.89996 .57399 Mdot
.90001 .57412 Mdot
.90006 .57425 Mdot
.9001 .57438 Mdot
.90015 .5745 Mdot
.9002 .57463 Mdot
.90025 .57476 Mdot
.90029 .57488 Mdot
.90034 .57501 Mdot
.90039 .57514 Mdot
.90044 .57526 Mdot
.90048 .57539 Mdot
.90053 .57551 Mdot
.90058 .57564 Mdot
.90063 .57576 Mdot
.90067 .57589 Mdot
.90072 .57601 Mdot
.90077 .57613 Mdot
.90082 .57626 Mdot
.90086 .57638 Mdot
.90091 .5765 Mdot
.90096 .57663 Mdot
.90101 .57675 Mdot
.90106 .57687 Mdot
.9011 .57699 Mdot
.90115 .57711 Mdot
.9012 .57723 Mdot
.90125 .57736 Mdot
.90129 .57748 Mdot
.90134 .5776 Mdot
.90139 .57772 Mdot
.90144 .57784 Mdot
.90148 .57796 Mdot
.90153 .57808 Mdot
.90158 .5782 Mdot
.90163 .57831 Mdot
.90167 .57843 Mdot
.90172 .57855 Mdot
.90177 .57867 Mdot
.90182 .57879 Mdot
.90186 .5789 Mdot
.90191 .57902 Mdot
.90196 .57914 Mdot
.90201 .57926 Mdot
.90206 .57937 Mdot
.9021 .57949 Mdot
.90215 .5796 Mdot
.9022 .57972 Mdot
.90225 .57983 Mdot
.90229 .57995 Mdot
.90234 .58006 Mdot
.90239 .58018 Mdot
.90244 .58029 Mdot
.90248 .58041 Mdot
.90253 .58052 Mdot
.90258 .58063 Mdot
.90263 .58075 Mdot
.90267 .58086 Mdot
.90272 .58097 Mdot
.90277 .58109 Mdot
.90282 .5812 Mdot
.90286 .58131 Mdot
.90291 .58142 Mdot
.90296 .58153 Mdot
.90301 .58164 Mdot
.90305 .58175 Mdot
.9031 .58186 Mdot
.90315 .58198 Mdot
.9032 .58209 Mdot
.90325 .58219 Mdot
.90329 .5823 Mdot
.90334 .58241 Mdot
.90339 .58252 Mdot
.90344 .58263 Mdot
.90348 .58274 Mdot
.90353 .58285 Mdot
.90358 .58295 Mdot
.90363 .58306 Mdot
.90367 .58317 Mdot
.90372 .58328 Mdot
.90377 .58338 Mdot
.90382 .58349 Mdot
.90386 .5836 Mdot
.90391 .5837 Mdot
.90396 .58381 Mdot
.90401 .58391 Mdot
.90405 .58402 Mdot
.9041 .58412 Mdot
.90415 .58423 Mdot
.9042 .58433 Mdot
.90425 .58443 Mdot
.90429 .58454 Mdot
.90434 .58464 Mdot
.90439 .58474 Mdot
.90444 .58485 Mdot
.90448 .58495 Mdot
.90453 .58505 Mdot
.90458 .58515 Mdot
.90463 .58526 Mdot
.90467 .58536 Mdot
.90472 .58546 Mdot
.90477 .58556 Mdot
.90482 .58566 Mdot
.90486 .58576 Mdot
.90491 .58586 Mdot
.90496 .58596 Mdot
.90501 .58606 Mdot
.90505 .58616 Mdot
.9051 .58626 Mdot
.90515 .58636 Mdot
.9052 .58645 Mdot
.90525 .58655 Mdot
.90529 .58665 Mdot
.90534 .58675 Mdot
.90539 .58684 Mdot
.90544 .58694 Mdot
.90548 .58704 Mdot
.90553 .58713 Mdot
.90558 .58723 Mdot
.90563 .58733 Mdot
.90567 .58742 Mdot
.90572 .58752 Mdot
.90577 .58761 Mdot
.90582 .58771 Mdot
.90586 .5878 Mdot
.90591 .5879 Mdot
.90596 .58799 Mdot
.90601 .58808 Mdot
.90605 .58818 Mdot
.9061 .58827 Mdot
.90615 .58836 Mdot
.9062 .58846 Mdot
.90625 .58855 Mdot
.90629 .58864 Mdot
.90634 .58873 Mdot
.90639 .58882 Mdot
.90644 .58891 Mdot
.90648 .589 Mdot
.90653 .5891 Mdot
.90658 .58919 Mdot
.90663 .58928 Mdot
.90667 .58937 Mdot
.90672 .58945 Mdot
.90677 .58954 Mdot
.90682 .58963 Mdot
.90686 .58972 Mdot
.90691 .58981 Mdot
.90696 .5899 Mdot
.90701 .58999 Mdot
.90705 .59007 Mdot
.9071 .59016 Mdot
.90715 .59025 Mdot
.9072 .59033 Mdot
.90724 .59042 Mdot
.90729 .59051 Mdot
.90734 .59059 Mdot
.90739 .59068 Mdot
.90744 .59076 Mdot
.90748 .59085 Mdot
.90753 .59093 Mdot
.90758 .59102 Mdot
.90763 .5911 Mdot
.90767 .59118 Mdot
.90772 .59127 Mdot
.90777 .59135 Mdot
.90782 .59143 Mdot
.90786 .59152 Mdot
.90791 .5916 Mdot
.90796 .59168 Mdot
.90801 .59176 Mdot
.90805 .59184 Mdot
.9081 .59193 Mdot
.90815 .59201 Mdot
.9082 .59209 Mdot
.90824 .59217 Mdot
.90829 .59225 Mdot
.90834 .59233 Mdot
.90839 .59241 Mdot
.90844 .59249 Mdot
.90848 .59257 Mdot
.90853 .59264 Mdot
.90858 .59272 Mdot
.90863 .5928 Mdot
.90867 .59288 Mdot
.90872 .59296 Mdot
.90877 .59303 Mdot
.90882 .59311 Mdot
.90886 .59319 Mdot
.90891 .59326 Mdot
.90896 .59334 Mdot
.90901 .59342 Mdot
.90905 .59349 Mdot
.9091 .59357 Mdot
.90915 .59364 Mdot
.9092 .59372 Mdot
.90924 .59379 Mdot
.90929 .59387 Mdot
.90934 .59394 Mdot
.90939 .59401 Mdot
.90944 .59409 Mdot
.90948 .59416 Mdot
.90953 .59423 Mdot
.90958 .5943 Mdot
.90963 .59438 Mdot
.90967 .59445 Mdot
.90972 .59452 Mdot
.90977 .59459 Mdot
.90982 .59466 Mdot
.90986 .59473 Mdot
.90991 .5948 Mdot
.90996 .59487 Mdot
.91001 .59494 Mdot
.91005 .59501 Mdot
.9101 .59508 Mdot
.91015 .59515 Mdot
.9102 .59522 Mdot
.91024 .59529 Mdot
.91029 .59536 Mdot
.91034 .59542 Mdot
.91039 .59549 Mdot
.91044 .59556 Mdot
.91048 .59563 Mdot
.91053 .59569 Mdot
.91058 .59576 Mdot
.91063 .59583 Mdot
.91067 .59589 Mdot
.91072 .59596 Mdot
.91077 .59602 Mdot
.91082 .59609 Mdot
.91086 .59615 Mdot
.91091 .59622 Mdot
.91096 .59628 Mdot
.91101 .59634 Mdot
.91105 .59641 Mdot
.9111 .59647 Mdot
.91115 .59653 Mdot
.9112 .5966 Mdot
.91124 .59666 Mdot
.91129 .59672 Mdot
.91134 .59678 Mdot
.91139 .59684 Mdot
.91144 .59691 Mdot
.91148 .59697 Mdot
.91153 .59703 Mdot
.91158 .59709 Mdot
.91163 .59715 Mdot
.91167 .59721 Mdot
.91172 .59727 Mdot
.91177 .59733 Mdot
.91182 .59739 Mdot
.91186 .59744 Mdot
.91191 .5975 Mdot
.91196 .59756 Mdot
.91201 .59762 Mdot
.91205 .59768 Mdot
.9121 .59773 Mdot
.91215 .59779 Mdot
.9122 .59785 Mdot
.91224 .5979 Mdot
.91229 .59796 Mdot
.91234 .59802 Mdot
.91239 .59807 Mdot
.91243 .59813 Mdot
.91248 .59818 Mdot
.91253 .59824 Mdot
.91258 .59829 Mdot
.91263 .59834 Mdot
.91267 .5984 Mdot
.91272 .59845 Mdot
.91277 .5985 Mdot
.91282 .59856 Mdot
.91286 .59861 Mdot
.91291 .59866 Mdot
.91296 .59871 Mdot
.91301 .59877 Mdot
.91305 .59882 Mdot
.9131 .59887 Mdot
.91315 .59892 Mdot
.9132 .59897 Mdot
.91324 .59902 Mdot
.91329 .59907 Mdot
.91334 .59912 Mdot
.91339 .59917 Mdot
.91343 .59922 Mdot
.91348 .59927 Mdot
.91353 .59932 Mdot
.91358 .59936 Mdot
.91363 .59941 Mdot
.91367 .59946 Mdot
.91372 .59951 Mdot
.91377 .59955 Mdot
.91382 .5996 Mdot
.91386 .59965 Mdot
.91391 .59969 Mdot
.91396 .59974 Mdot
.91401 .59979 Mdot
.91405 .59983 Mdot
.9141 .59988 Mdot
.91415 .59992 Mdot
.9142 .59996 Mdot
.91424 .60001 Mdot
.91429 .60005 Mdot
.91434 .6001 Mdot
.91439 .60014 Mdot
.91443 .60018 Mdot
.91448 .60023 Mdot
.91453 .60027 Mdot
.91458 .60031 Mdot
.91463 .60035 Mdot
.91467 .60039 Mdot
.91472 .60043 Mdot
.91477 .60048 Mdot
.91482 .60052 Mdot
.91486 .60056 Mdot
.91491 .6006 Mdot
.91496 .60064 Mdot
.91501 .60068 Mdot
.91505 .60072 Mdot
.9151 .60075 Mdot
.91515 .60079 Mdot
.9152 .60083 Mdot
.91524 .60087 Mdot
.91529 .60091 Mdot
.91534 .60094 Mdot
.91539 .60098 Mdot
.91543 .60102 Mdot
.91548 .60106 Mdot
.91553 .60109 Mdot
.91558 .60113 Mdot
.91563 .60116 Mdot
.91567 .6012 Mdot
.91572 .60123 Mdot
.91577 .60127 Mdot
.91582 .6013 Mdot
.91586 .60134 Mdot
.91591 .60137 Mdot
.91596 .60141 Mdot
.91601 .60144 Mdot
.91605 .60147 Mdot
.9161 .6015 Mdot
.91615 .60154 Mdot
.9162 .60157 Mdot
.91624 .6016 Mdot
.91629 .60163 Mdot
.91634 .60166 Mdot
.91639 .60169 Mdot
.91643 .60173 Mdot
.91648 .60176 Mdot
.91653 .60179 Mdot
.91658 .60182 Mdot
.91663 .60185 Mdot
.91667 .60187 Mdot
.91672 .6019 Mdot
.91677 .60193 Mdot
.91682 .60196 Mdot
.91686 .60199 Mdot
.91691 .60202 Mdot
.91696 .60204 Mdot
.91701 .60207 Mdot
.91705 .6021 Mdot
.9171 .60213 Mdot
.91715 .60215 Mdot
.9172 .60218 Mdot
.91724 .6022 Mdot
.91729 .60223 Mdot
.91734 .60225 Mdot
.91739 .60228 Mdot
.91743 .6023 Mdot
.91748 .60233 Mdot
.91753 .60235 Mdot
.91758 .60238 Mdot
.91762 .6024 Mdot
.91767 .60242 Mdot
.91772 .60244 Mdot
.91777 .60247 Mdot
.91782 .60249 Mdot
.91786 .60251 Mdot
.91791 .60253 Mdot
.91796 .60255 Mdot
.91801 .60258 Mdot
.91805 .6026 Mdot
.9181 .60262 Mdot
.91815 .60264 Mdot
.9182 .60266 Mdot
.91824 .60268 Mdot
.91829 .6027 Mdot
.91834 .60271 Mdot
.91839 .60273 Mdot
.91843 .60275 Mdot
.91848 .60277 Mdot
.91853 .60279 Mdot
.91858 .60281 Mdot
.91862 .60282 Mdot
.91867 .60284 Mdot
.91872 .60286 Mdot
.91877 .60287 Mdot
.91882 .60289 Mdot
.91886 .6029 Mdot
.91891 .60292 Mdot
.91896 .60294 Mdot
.91901 .60295 Mdot
.91905 .60296 Mdot
.9191 .60298 Mdot
.91915 .60299 Mdot
.9192 .60301 Mdot
.91924 .60302 Mdot
.91929 .60303 Mdot
.91934 .60305 Mdot
.91939 .60306 Mdot
.91943 .60307 Mdot
.91948 .60308 Mdot
.91953 .60309 Mdot
.91958 .60311 Mdot
.91962 .60312 Mdot
.91967 .60313 Mdot
.91972 .60314 Mdot
.91977 .60315 Mdot
.91982 .60316 Mdot
.91986 .60317 Mdot
.91991 .60318 Mdot
.91996 .60319 Mdot
.92001 .60319 Mdot
.92005 .6032 Mdot
.9201 .60321 Mdot
.92015 .60322 Mdot
.9202 .60323 Mdot
.92024 .60323 Mdot
.92029 .60324 Mdot
.92034 .60325 Mdot
.92039 .60325 Mdot
.92043 .60326 Mdot
.92048 .60327 Mdot
.92053 .60327 Mdot
.92058 .60328 Mdot
.92062 .60328 Mdot
.92067 .60329 Mdot
.92072 .60329 Mdot
.92077 .60329 Mdot
.92082 .6033 Mdot
.92086 .6033 Mdot
.92091 .6033 Mdot
.92096 .60331 Mdot
.92101 .60331 Mdot
.92105 .60331 Mdot
.9211 .60331 Mdot
.92115 .60332 Mdot
.9212 .60332 Mdot
.92124 .60332 Mdot
.92129 .60332 Mdot
.92134 .60332 Mdot
.92139 .60332 Mdot
.92143 .60332 Mdot
.92148 .60332 Mdot
.92153 .60332 Mdot
.92158 .60332 Mdot
.92162 .60332 Mdot
.92167 .60331 Mdot
.92172 .60331 Mdot
.92177 .60331 Mdot
.92181 .60331 Mdot
.92186 .6033 Mdot
.92191 .6033 Mdot
.92196 .6033 Mdot
.92201 .60329 Mdot
.92205 .60329 Mdot
.9221 .60329 Mdot
.92215 .60328 Mdot
.9222 .60328 Mdot
.92224 .60327 Mdot
.92229 .60327 Mdot
.92234 .60326 Mdot
.92239 .60325 Mdot
.92243 .60325 Mdot
.92248 .60324 Mdot
.92253 .60323 Mdot
.92258 .60323 Mdot
.92262 .60322 Mdot
.92267 .60321 Mdot
.92272 .6032 Mdot
.92277 .6032 Mdot
.92281 .60319 Mdot
.92286 .60318 Mdot
.92291 .60317 Mdot
.92296 .60316 Mdot
.92301 .60315 Mdot
.92305 .60314 Mdot
.9231 .60313 Mdot
.92315 .60312 Mdot
.9232 .60311 Mdot
.92324 .6031 Mdot
.92329 .60308 Mdot
.92334 .60307 Mdot
.92339 .60306 Mdot
.92343 .60305 Mdot
.92348 .60303 Mdot
.92353 .60302 Mdot
.92358 .60301 Mdot
.92362 .60299 Mdot
.92367 .60298 Mdot
.92372 .60297 Mdot
.92377 .60295 Mdot
.92381 .60294 Mdot
.92386 .60292 Mdot
.92391 .60291 Mdot
.92396 .60289 Mdot
.92401 .60287 Mdot
.92405 .60286 Mdot
.9241 .60284 Mdot
.92415 .60282 Mdot
.9242 .60281 Mdot
.92424 .60279 Mdot
.92429 .60277 Mdot
.92434 .60275 Mdot
.92439 .60274 Mdot
.92443 .60272 Mdot
.92448 .6027 Mdot
.92453 .60268 Mdot
.92458 .60266 Mdot
.92462 .60264 Mdot
.92467 .60262 Mdot
.92472 .6026 Mdot
.92477 .60258 Mdot
.92481 .60256 Mdot
.92486 .60254 Mdot
.92491 .60251 Mdot
.92496 .60249 Mdot
.92501 .60247 Mdot
.92505 .60245 Mdot
.9251 .60242 Mdot
.92515 .6024 Mdot
.9252 .60238 Mdot
.92524 .60235 Mdot
.92529 .60233 Mdot
.92534 .60231 Mdot
.92539 .60228 Mdot
.92543 .60226 Mdot
.92548 .60223 Mdot
.92553 .60221 Mdot
.92558 .60218 Mdot
.92562 .60215 Mdot
.92567 .60213 Mdot
.92572 .6021 Mdot
.92577 .60207 Mdot
.92581 .60205 Mdot
.92586 .60202 Mdot
.92591 .60199 Mdot
.92596 .60196 Mdot
.92601 .60194 Mdot
.92605 .60191 Mdot
.9261 .60188 Mdot
.92615 .60185 Mdot
.9262 .60182 Mdot
.92624 .60179 Mdot
.92629 .60176 Mdot
.92634 .60173 Mdot
.92639 .6017 Mdot
.92643 .60167 Mdot
.92648 .60164 Mdot
.92653 .6016 Mdot
.92658 .60157 Mdot
.92662 .60154 Mdot
.92667 .60151 Mdot
.92672 .60148 Mdot
.92677 .60144 Mdot
.92681 .60141 Mdot
.92686 .60138 Mdot
.92691 .60134 Mdot
.92696 .60131 Mdot
.927 .60127 Mdot
.92705 .60124 Mdot
.9271 .6012 Mdot
.92715 .60117 Mdot
.9272 .60113 Mdot
.92724 .6011 Mdot
.92729 .60106 Mdot
.92734 .60102 Mdot
.92739 .60099 Mdot
.92743 .60095 Mdot
.92748 .60091 Mdot
.92753 .60087 Mdot
.92758 .60084 Mdot
.92762 .6008 Mdot
.92767 .60076 Mdot
.92772 .60072 Mdot
.92777 .60068 Mdot
.92781 .60064 Mdot
.92786 .6006 Mdot
.92791 .60056 Mdot
.92796 .60052 Mdot
.928 .60048 Mdot
.92805 .60044 Mdot
.9281 .6004 Mdot
.92815 .60036 Mdot
.9282 .60032 Mdot
.92824 .60027 Mdot
.92829 .60023 Mdot
.92834 .60019 Mdot
.92839 .60014 Mdot
.92843 .6001 Mdot
.92848 .60006 Mdot
.92853 .60001 Mdot
.92858 .59997 Mdot
.92862 .59993 Mdot
.92867 .59988 Mdot
.92872 .59984 Mdot
.92877 .59979 Mdot
.92881 .59974 Mdot
.92886 .5997 Mdot
.92891 .59965 Mdot
.92896 .59961 Mdot
.929 .59956 Mdot
.92905 .59951 Mdot
.9291 .59947 Mdot
.92915 .59942 Mdot
.9292 .59937 Mdot
.92924 .59932 Mdot
.92929 .59927 Mdot
.92934 .59922 Mdot
.92939 .59918 Mdot
.92943 .59913 Mdot
.92948 .59908 Mdot
.92953 .59903 Mdot
.92958 .59898 Mdot
.92962 .59893 Mdot
.92967 .59887 Mdot
.92972 .59882 Mdot
.92977 .59877 Mdot
.92981 .59872 Mdot
.92986 .59867 Mdot
.92991 .59862 Mdot
.92996 .59856 Mdot
.93 .59851 Mdot
.93005 .59846 Mdot
.9301 .5984 Mdot
.93015 .59835 Mdot
.9302 .5983 Mdot
.93024 .59824 Mdot
.93029 .59819 Mdot
.93034 .59813 Mdot
.93039 .59808 Mdot
.93043 .59802 Mdot
.93048 .59797 Mdot
.93053 .59791 Mdot
.93058 .59785 Mdot
.93062 .5978 Mdot
.93067 .59774 Mdot
.93072 .59768 Mdot
.93077 .59763 Mdot
.93081 .59757 Mdot
.93086 .59751 Mdot
.93091 .59745 Mdot
.93096 .59739 Mdot
.931 .59733 Mdot
.93105 .59727 Mdot
.9311 .59721 Mdot
.93115 .59715 Mdot
.93119 .59709 Mdot
.93124 .59703 Mdot
.93129 .59697 Mdot
.93134 .59691 Mdot
.93139 .59685 Mdot
.93143 .59679 Mdot
.93148 .59673 Mdot
.93153 .59667 Mdot
.93158 .5966 Mdot
.93162 .59654 Mdot
.93167 .59648 Mdot
.93172 .59641 Mdot
.93177 .59635 Mdot
.93181 .59629 Mdot
.93186 .59622 Mdot
.93191 .59616 Mdot
.93196 .59609 Mdot
.932 .59603 Mdot
.93205 .59596 Mdot
.9321 .5959 Mdot
.93215 .59583 Mdot
.93219 .59577 Mdot
.93224 .5957 Mdot
.93229 .59563 Mdot
.93234 .59557 Mdot
.93239 .5955 Mdot
.93243 .59543 Mdot
.93248 .59536 Mdot
.93253 .5953 Mdot
.93258 .59523 Mdot
.93262 .59516 Mdot
.93267 .59509 Mdot
.93272 .59502 Mdot
.93277 .59495 Mdot
.93281 .59488 Mdot
.93286 .59481 Mdot
.93291 .59474 Mdot
.93296 .59467 Mdot
.933 .5946 Mdot
.93305 .59453 Mdot
.9331 .59446 Mdot
.93315 .59438 Mdot
.93319 .59431 Mdot
.93324 .59424 Mdot
.93329 .59417 Mdot
.93334 .59409 Mdot
.93339 .59402 Mdot
.93343 .59395 Mdot
.93348 .59387 Mdot
.93353 .5938 Mdot
.93358 .59372 Mdot
.93362 .59365 Mdot
.93367 .59357 Mdot
.93372 .5935 Mdot
.93377 .59342 Mdot
.93381 .59335 Mdot
.93386 .59327 Mdot
.93391 .5932 Mdot
.93396 .59312 Mdot
.934 .59304 Mdot
.93405 .59296 Mdot
.9341 .59289 Mdot
.93415 .59281 Mdot
.93419 .59273 Mdot
.93424 .59265 Mdot
.93429 .59257 Mdot
.93434 .59249 Mdot
.93439 .59242 Mdot
.93443 .59234 Mdot
.93448 .59226 Mdot
.93453 .59218 Mdot
.93458 .5921 Mdot
.93462 .59201 Mdot
.93467 .59193 Mdot
.93472 .59185 Mdot
.93477 .59177 Mdot
.93481 .59169 Mdot
.93486 .59161 Mdot
.93491 .59152 Mdot
.93496 .59144 Mdot
.935 .59136 Mdot
.93505 .59128 Mdot
.9351 .59119 Mdot
.93515 .59111 Mdot
.93519 .59102 Mdot
.93524 .59094 Mdot
.93529 .59086 Mdot
.93534 .59077 Mdot
.93539 .59069 Mdot
.93543 .5906 Mdot
.93548 .59051 Mdot
.93553 .59043 Mdot
.93558 .59034 Mdot
.93562 .59026 Mdot
.93567 .59017 Mdot
.93572 .59008 Mdot
.93577 .58999 Mdot
.93581 .58991 Mdot
.93586 .58982 Mdot
.93591 .58973 Mdot
.93596 .58964 Mdot
.936 .58955 Mdot
.93605 .58946 Mdot
.9361 .58937 Mdot
.93615 .58928 Mdot
.93619 .58919 Mdot
.93624 .5891 Mdot
.93629 .58901 Mdot
.93634 .58892 Mdot
.93638 .58883 Mdot
.93643 .58874 Mdot
.93648 .58865 Mdot
.93653 .58856 Mdot
.93658 .58846 Mdot
.93662 .58837 Mdot
.93667 .58828 Mdot
.93672 .58819 Mdot
.93677 .58809 Mdot
.93681 .588 Mdot
.93686 .5879 Mdot
.93691 .58781 Mdot
.93696 .58772 Mdot
.937 .58762 Mdot
.93705 .58753 Mdot
.9371 .58743 Mdot
.93715 .58734 Mdot
.93719 .58724 Mdot
.93724 .58714 Mdot
.93729 .58705 Mdot
.93734 .58695 Mdot
.93738 .58685 Mdot
.93743 .58676 Mdot
.93748 .58666 Mdot
.93753 .58656 Mdot
.93758 .58646 Mdot
.93762 .58636 Mdot
.93767 .58627 Mdot
.93772 .58617 Mdot
.93777 .58607 Mdot
.93781 .58597 Mdot
.93786 .58587 Mdot
.93791 .58577 Mdot
.93796 .58567 Mdot
.938 .58557 Mdot
.93805 .58547 Mdot
.9381 .58537 Mdot
.93815 .58526 Mdot
.93819 .58516 Mdot
.93824 .58506 Mdot
.93829 .58496 Mdot
.93834 .58486 Mdot
.93838 .58475 Mdot
.93843 .58465 Mdot
.93848 .58455 Mdot
.93853 .58444 Mdot
.93858 .58434 Mdot
.93862 .58423 Mdot
.93867 .58413 Mdot
.93872 .58403 Mdot
.93877 .58392 Mdot
.93881 .58382 Mdot
.93886 .58371 Mdot
.93891 .5836 Mdot
.93896 .5835 Mdot
.939 .58339 Mdot
.93905 .58328 Mdot
.9391 .58318 Mdot
.93915 .58307 Mdot
.93919 .58296 Mdot
.93924 .58286 Mdot
.93929 .58275 Mdot
.93934 .58264 Mdot
.93938 .58253 Mdot
.93943 .58242 Mdot
.93948 .58231 Mdot
.93953 .5822 Mdot
.93958 .58209 Mdot
.93962 .58198 Mdot
.93967 .58187 Mdot
.93972 .58176 Mdot
.93977 .58165 Mdot
.93981 .58154 Mdot
.93986 .58143 Mdot
.93991 .58132 Mdot
.93996 .58121 Mdot
.94 .58109 Mdot
.94005 .58098 Mdot
.9401 .58087 Mdot
.94015 .58076 Mdot
.94019 .58064 Mdot
.94024 .58053 Mdot
.94029 .58042 Mdot
.94034 .5803 Mdot
.94038 .58019 Mdot
.94043 .58007 Mdot
.94048 .57996 Mdot
.94053 .57984 Mdot
.94057 .57973 Mdot
.94062 .57961 Mdot
.94067 .5795 Mdot
.94072 .57938 Mdot
.94077 .57926 Mdot
.94081 .57915 Mdot
.94086 .57903 Mdot
.94091 .57891 Mdot
.94096 .57879 Mdot
.941 .57868 Mdot
.94105 .57856 Mdot
.9411 .57844 Mdot
.94115 .57832 Mdot
.94119 .5782 Mdot
.94124 .57808 Mdot
.94129 .57796 Mdot
.94134 .57784 Mdot
.94138 .57772 Mdot
.94143 .5776 Mdot
.94148 .57748 Mdot
.94153 .57736 Mdot
.94157 .57724 Mdot
.94162 .57712 Mdot
.94167 .577 Mdot
.94172 .57688 Mdot
.94177 .57676 Mdot
.94181 .57663 Mdot
.94186 .57651 Mdot
.94191 .57639 Mdot
.94196 .57626 Mdot
.942 .57614 Mdot
.94205 .57602 Mdot
.9421 .57589 Mdot
.94215 .57577 Mdot
.94219 .57564 Mdot
.94224 .57552 Mdot
.94229 .57539 Mdot
.94234 .57527 Mdot
.94238 .57514 Mdot
.94243 .57502 Mdot
.94248 .57489 Mdot
.94253 .57476 Mdot
.94257 .57464 Mdot
.94262 .57451 Mdot
.94267 .57438 Mdot
.94272 .57426 Mdot
.94277 .57413 Mdot
.94281 .574 Mdot
.94286 .57387 Mdot
.94291 .57374 Mdot
.94296 .57362 Mdot
.943 .57349 Mdot
.94305 .57336 Mdot
.9431 .57323 Mdot
.94315 .5731 Mdot
.94319 .57297 Mdot
.94324 .57284 Mdot
.94329 .57271 Mdot
.94334 .57258 Mdot
.94338 .57244 Mdot
.94343 .57231 Mdot
.94348 .57218 Mdot
.94353 .57205 Mdot
.94357 .57192 Mdot
.94362 .57178 Mdot
.94367 .57165 Mdot
.94372 .57152 Mdot
.94377 .57139 Mdot
.94381 .57125 Mdot
.94386 .57112 Mdot
.94391 .57098 Mdot
.94396 .57085 Mdot
.944 .57072 Mdot
.94405 .57058 Mdot
.9441 .57045 Mdot
.94415 .57031 Mdot
.94419 .57017 Mdot
.94424 .57004 Mdot
.94429 .5699 Mdot
.94434 .56977 Mdot
.94438 .56963 Mdot
.94443 .56949 Mdot
.94448 .56935 Mdot
.94453 .56922 Mdot
.94457 .56908 Mdot
.94462 .56894 Mdot
.94467 .5688 Mdot
.94472 .56867 Mdot
.94477 .56853 Mdot
.94481 .56839 Mdot
.94486 .56825 Mdot
.94491 .56811 Mdot
.94496 .56797 Mdot
.945 .56783 Mdot
.94505 .56769 Mdot
.9451 .56755 Mdot
.94515 .56741 Mdot
.94519 .56727 Mdot
.94524 .56712 Mdot
.94529 .56698 Mdot
.94534 .56684 Mdot
.94538 .5667 Mdot
.94543 .56656 Mdot
.94548 .56641 Mdot
.94553 .56627 Mdot
.94557 .56613 Mdot
.94562 .56598 Mdot
.94567 .56584 Mdot
.94572 .5657 Mdot
.94576 .56555 Mdot
.94581 .56541 Mdot
.94586 .56526 Mdot
.94591 .56512 Mdot
.94596 .56497 Mdot
.946 .56483 Mdot
.94605 .56468 Mdot
.9461 .56454 Mdot
.94615 .56439 Mdot
.94619 .56424 Mdot
.94624 .5641 Mdot
.94629 .56395 Mdot
.94634 .5638 Mdot
.94638 .56365 Mdot
.94643 .56351 Mdot
.94648 .56336 Mdot
.94653 .56321 Mdot
.94657 .56306 Mdot
.94662 .56291 Mdot
.94667 .56276 Mdot
.94672 .56261 Mdot
.94676 .56247 Mdot
.94681 .56232 Mdot
.94686 .56217 Mdot
.94691 .56202 Mdot
.94696 .56186 Mdot
.947 .56171 Mdot
.94705 .56156 Mdot
.9471 .56141 Mdot
.94715 .56126 Mdot
.94719 .56111 Mdot
.94724 .56096 Mdot
.94729 .5608 Mdot
.94734 .56065 Mdot
.94738 .5605 Mdot
.94743 .56034 Mdot
.94748 .56019 Mdot
.94753 .56004 Mdot
.94757 .55988 Mdot
.94762 .55973 Mdot
.94767 .55958 Mdot
.94772 .55942 Mdot
.94776 .55927 Mdot
.94781 .55911 Mdot
.94786 .55896 Mdot
.94791 .5588 Mdot
.94796 .55864 Mdot
.948 .55849 Mdot
.94805 .55833 Mdot
.9481 .55818 Mdot
.94815 .55802 Mdot
.94819 .55786 Mdot
.94824 .5577 Mdot
.94829 .55755 Mdot
.94834 .55739 Mdot
.94838 .55723 Mdot
.94843 .55707 Mdot
.94848 .55691 Mdot
.94853 .55675 Mdot
.94857 .5566 Mdot
.94862 .55644 Mdot
.94867 .55628 Mdot
.94872 .55612 Mdot
.94876 .55596 Mdot
.94881 .5558 Mdot
.94886 .55564 Mdot
.94891 .55547 Mdot
.94896 .55531 Mdot
.949 .55515 Mdot
.94905 .55499 Mdot
.9491 .55483 Mdot
.94915 .55467 Mdot
.94919 .5545 Mdot
.94924 .55434 Mdot
.94929 .55418 Mdot
.94934 .55402 Mdot
.94938 .55385 Mdot
.94943 .55369 Mdot
.94948 .55353 Mdot
.94953 .55336 Mdot
.94957 .5532 Mdot
.94962 .55303 Mdot
.94967 .55287 Mdot
.94972 .5527 Mdot
.94976 .55254 Mdot
.94981 .55237 Mdot
.94986 .55221 Mdot
.94991 .55204 Mdot
.94996 .55187 Mdot
.95 .55171 Mdot
.95005 .55154 Mdot
.9501 .55137 Mdot
.95015 .55121 Mdot
.95019 .55104 Mdot
.95024 .55087 Mdot
.95029 .5507 Mdot
.95034 .55054 Mdot
.95038 .55037 Mdot
.95043 .5502 Mdot
.95048 .55003 Mdot
.95053 .54986 Mdot
.95057 .54969 Mdot
.95062 .54952 Mdot
.95067 .54935 Mdot
.95072 .54918 Mdot
.95076 .54901 Mdot
.95081 .54884 Mdot
.95086 .54867 Mdot
.95091 .5485 Mdot
.95095 .54833 Mdot
.951 .54816 Mdot
.95105 .54798 Mdot
.9511 .54781 Mdot
.95115 .54764 Mdot
.95119 .54747 Mdot
.95124 .5473 Mdot
.95129 .54712 Mdot
.95134 .54695 Mdot
.95138 .54678 Mdot
.95143 .5466 Mdot
.95148 .54643 Mdot
.95153 .54625 Mdot
.95157 .54608 Mdot
.95162 .5459 Mdot
.95167 .54573 Mdot
.95172 .54555 Mdot
.95176 .54538 Mdot
.95181 .5452 Mdot
.95186 .54503 Mdot
.95191 .54485 Mdot
.95195 .54468 Mdot
.952 .5445 Mdot
.95205 .54432 Mdot
.9521 .54415 Mdot
.95215 .54397 Mdot
.95219 .54379 Mdot
.95224 .54361 Mdot
.95229 .54344 Mdot
.95234 .54326 Mdot
.95238 .54308 Mdot
.95243 .5429 Mdot
.95248 .54272 Mdot
.95253 .54254 Mdot
.95257 .54236 Mdot
.95262 .54218 Mdot
.95267 .542 Mdot
.95272 .54182 Mdot
.95276 .54164 Mdot
.95281 .54146 Mdot
.95286 .54128 Mdot
.95291 .5411 Mdot
.95295 .54092 Mdot
.953 .54074 Mdot
.95305 .54056 Mdot
.9531 .54037 Mdot
.95315 .54019 Mdot
.95319 .54001 Mdot
.95324 .53983 Mdot
.95329 .53964 Mdot
.95334 .53946 Mdot
.95338 .53928 Mdot
.95343 .53909 Mdot
.95348 .53891 Mdot
.95353 .53873 Mdot
.95357 .53854 Mdot
.95362 .53836 Mdot
.95367 .53817 Mdot
.95372 .53799 Mdot
.95376 .5378 Mdot
.95381 .53762 Mdot
.95386 .53743 Mdot
.95391 .53725 Mdot
.95395 .53706 Mdot
.954 .53687 Mdot
.95405 .53669 Mdot
.9541 .5365 Mdot
.95415 .53631 Mdot
.95419 .53613 Mdot
.95424 .53594 Mdot
.95429 .53575 Mdot
.95434 .53556 Mdot
.95438 .53538 Mdot
.95443 .53519 Mdot
.95448 .535 Mdot
.95453 .53481 Mdot
.95457 .53462 Mdot
.95462 .53443 Mdot
.95467 .53424 Mdot
.95472 .53405 Mdot
.95476 .53386 Mdot
.95481 .53367 Mdot
.95486 .53348 Mdot
.95491 .53329 Mdot
.95495 .5331 Mdot
.955 .53291 Mdot
.95505 .53272 Mdot
.9551 .53253 Mdot
.95514 .53234 Mdot
.95519 .53214 Mdot
.95524 .53195 Mdot
.95529 .53176 Mdot
.95534 .53157 Mdot
.95538 .53137 Mdot
.95543 .53118 Mdot
.95548 .53099 Mdot
.95553 .53079 Mdot
.95557 .5306 Mdot
.95562 .53041 Mdot
.95567 .53021 Mdot
.95572 .53002 Mdot
.95576 .52982 Mdot
.95581 .52963 Mdot
.95586 .52943 Mdot
.95591 .52924 Mdot
.95595 .52904 Mdot
.956 .52885 Mdot
.95605 .52865 Mdot
.9561 .52845 Mdot
.95614 .52826 Mdot
.95619 .52806 Mdot
.95624 .52787 Mdot
.95629 .52767 Mdot
.95634 .52747 Mdot
.95638 .52727 Mdot
.95643 .52708 Mdot
.95648 .52688 Mdot
.95653 .52668 Mdot
.95657 .52648 Mdot
.95662 .52628 Mdot
.95667 .52608 Mdot
.95672 .52589 Mdot
.95676 .52569 Mdot
.95681 .52549 Mdot
.95686 .52529 Mdot
.95691 .52509 Mdot
.95695 .52489 Mdot
.957 .52469 Mdot
.95705 .52449 Mdot
.9571 .52429 Mdot
.95714 .52408 Mdot
.95719 .52388 Mdot
.95724 .52368 Mdot
.95729 .52348 Mdot
.95734 .52328 Mdot
.95738 .52308 Mdot
.95743 .52287 Mdot
.95748 .52267 Mdot
.95753 .52247 Mdot
.95757 .52227 Mdot
.95762 .52206 Mdot
.95767 .52186 Mdot
.95772 .52166 Mdot
.95776 .52145 Mdot
.95781 .52125 Mdot
.95786 .52104 Mdot
.95791 .52084 Mdot
.95795 .52064 Mdot
.958 .52043 Mdot
.95805 .52023 Mdot
.9581 .52002 Mdot
.95814 .51982 Mdot
.95819 .51961 Mdot
.95824 .5194 Mdot
.95829 .5192 Mdot
.95834 .51899 Mdot
.95838 .51879 Mdot
.95843 .51858 Mdot
.95848 .51837 Mdot
.95853 .51816 Mdot
.95857 .51796 Mdot
.95862 .51775 Mdot
.95867 .51754 Mdot
.95872 .51733 Mdot
.95876 .51713 Mdot
.95881 .51692 Mdot
.95886 .51671 Mdot
.95891 .5165 Mdot
.95895 .51629 Mdot
.959 .51608 Mdot
.95905 .51587 Mdot
.9591 .51566 Mdot
.95914 .51545 Mdot
.95919 .51524 Mdot
.95924 .51503 Mdot
.95929 .51482 Mdot
.95934 .51461 Mdot
.95938 .5144 Mdot
.95943 .51419 Mdot
.95948 .51398 Mdot
.95953 .51377 Mdot
.95957 .51356 Mdot
.95962 .51334 Mdot
.95967 .51313 Mdot
.95972 .51292 Mdot
.95976 .51271 Mdot
.95981 .51249 Mdot
.95986 .51228 Mdot
.95991 .51207 Mdot
.95995 .51185 Mdot
.96 .51164 Mdot
.96005 .51143 Mdot
.9601 .51121 Mdot
.96014 .511 Mdot
.96019 .51079 Mdot
.96024 .51057 Mdot
.96029 .51036 Mdot
.96033 .51014 Mdot
.96038 .50993 Mdot
.96043 .50971 Mdot
.96048 .5095 Mdot
.96053 .50928 Mdot
.96057 .50906 Mdot
.96062 .50885 Mdot
.96067 .50863 Mdot
.96072 .50841 Mdot
.96076 .5082 Mdot
.96081 .50798 Mdot
.96086 .50776 Mdot
.96091 .50755 Mdot
.96095 .50733 Mdot
.961 .50711 Mdot
.96105 .50689 Mdot
.9611 .50668 Mdot
.96114 .50646 Mdot
.96119 .50624 Mdot
.96124 .50602 Mdot
.96129 .5058 Mdot
.96133 .50558 Mdot
.96138 .50536 Mdot
.96143 .50514 Mdot
.96148 .50492 Mdot
.96153 .5047 Mdot
.96157 .50448 Mdot
.96162 .50426 Mdot
.96167 .50404 Mdot
.96172 .50382 Mdot
.96176 .5036 Mdot
.96181 .50338 Mdot
.96186 .50316 Mdot
.96191 .50294 Mdot
.96195 .50272 Mdot
.962 .50249 Mdot
.96205 .50227 Mdot
.9621 .50205 Mdot
.96214 .50183 Mdot
.96219 .5016 Mdot
.96224 .50138 Mdot
.96229 .50116 Mdot
.96233 .50094 Mdot
.96238 .50071 Mdot
.96243 .50049 Mdot
.96248 .50026 Mdot
.96253 .50004 Mdot
.96257 .49982 Mdot
.96262 .49959 Mdot
.96267 .49937 Mdot
.96272 .49914 Mdot
.96276 .49892 Mdot
.96281 .49869 Mdot
.96286 .49847 Mdot
.96291 .49824 Mdot
.96295 .49802 Mdot
.963 .49779 Mdot
.96305 .49756 Mdot
.9631 .49734 Mdot
.96314 .49711 Mdot
.96319 .49688 Mdot
.96324 .49666 Mdot
.96329 .49643 Mdot
.96333 .4962 Mdot
.96338 .49598 Mdot
.96343 .49575 Mdot
.96348 .49552 Mdot
.96353 .49529 Mdot
.96357 .49507 Mdot
.96362 .49484 Mdot
.96367 .49461 Mdot
.96372 .49438 Mdot
.96376 .49415 Mdot
.96381 .49392 Mdot
.96386 .49369 Mdot
.96391 .49346 Mdot
.96395 .49323 Mdot
.964 .493 Mdot
.96405 .49277 Mdot
.9641 .49254 Mdot
.96414 .49231 Mdot
.96419 .49208 Mdot
.96424 .49185 Mdot
.96429 .49162 Mdot
.96433 .49139 Mdot
.96438 .49116 Mdot
.96443 .49093 Mdot
.96448 .4907 Mdot
.96452 .49046 Mdot
.96457 .49023 Mdot
.96462 .49 Mdot
.96467 .48977 Mdot
.96472 .48953 Mdot
.96476 .4893 Mdot
.96481 .48907 Mdot
.96486 .48884 Mdot
.96491 .4886 Mdot
.96495 .48837 Mdot
.965 .48814 Mdot
.96505 .4879 Mdot
.9651 .48767 Mdot
.96514 .48743 Mdot
.96519 .4872 Mdot
.96524 .48696 Mdot
.96529 .48673 Mdot
.96533 .4865 Mdot
.96538 .48626 Mdot
.96543 .48603 Mdot
.96548 .48579 Mdot
.96552 .48555 Mdot
.96557 .48532 Mdot
.96562 .48508 Mdot
.96567 .48485 Mdot
.96572 .48461 Mdot
.96576 .48437 Mdot
.96581 .48414 Mdot
.96586 .4839 Mdot
.96591 .48366 Mdot
.96595 .48343 Mdot
.966 .48319 Mdot
.96605 .48295 Mdot
.9661 .48271 Mdot
.96614 .48248 Mdot
.96619 .48224 Mdot
.96624 .482 Mdot
.96629 .48176 Mdot
.96633 .48152 Mdot
.96638 .48128 Mdot
.96643 .48104 Mdot
.96648 .48081 Mdot
.96652 .48057 Mdot
.96657 .48033 Mdot
.96662 .48009 Mdot
.96667 .47985 Mdot
.96672 .47961 Mdot
.96676 .47937 Mdot
.96681 .47913 Mdot
.96686 .47889 Mdot
.96691 .47865 Mdot
.96695 .47841 Mdot
.967 .47816 Mdot
.96705 .47792 Mdot
.9671 .47768 Mdot
.96714 .47744 Mdot
.96719 .4772 Mdot
.96724 .47696 Mdot
.96729 .47672 Mdot
.96733 .47647 Mdot
.96738 .47623 Mdot
.96743 .47599 Mdot
.96748 .47575 Mdot
.96752 .4755 Mdot
.96757 .47526 Mdot
.96762 .47502 Mdot
.96767 .47477 Mdot
.96772 .47453 Mdot
.96776 .47429 Mdot
.96781 .47404 Mdot
.96786 .4738 Mdot
.96791 .47355 Mdot
.96795 .47331 Mdot
.968 .47307 Mdot
.96805 .47282 Mdot
.9681 .47258 Mdot
.96814 .47233 Mdot
.96819 .47209 Mdot
.96824 .47184 Mdot
.96829 .4716 Mdot
.96833 .47135 Mdot
.96838 .4711 Mdot
.96843 .47086 Mdot
.96848 .47061 Mdot
.96852 .47037 Mdot
.96857 .47012 Mdot
.96862 .46987 Mdot
.96867 .46963 Mdot
.96872 .46938 Mdot
.96876 .46913 Mdot
.96881 .46888 Mdot
.96886 .46864 Mdot
.96891 .46839 Mdot
.96895 .46814 Mdot
.969 .46789 Mdot
.96905 .46765 Mdot
.9691 .4674 Mdot
.96914 .46715 Mdot
.96919 .4669 Mdot
.96924 .46665 Mdot
.96929 .4664 Mdot
.96933 .46615 Mdot
.96938 .46591 Mdot
.96943 .46566 Mdot
.96948 .46541 Mdot
.96952 .46516 Mdot
.96957 .46491 Mdot
.96962 .46466 Mdot
.96967 .46441 Mdot
.96971 .46416 Mdot
.96976 .46391 Mdot
.96981 .46366 Mdot
.96986 .46341 Mdot
.96991 .46315 Mdot
.96995 .4629 Mdot
.97 .46265 Mdot
.97005 .4624 Mdot
.9701 .46215 Mdot
.97014 .4619 Mdot
.97019 .46165 Mdot
.97024 .46139 Mdot
.97029 .46114 Mdot
.97033 .46089 Mdot
.97038 .46064 Mdot
.97043 .46038 Mdot
.97048 .46013 Mdot
.97052 .45988 Mdot
.97057 .45963 Mdot
.97062 .45937 Mdot
.97067 .45912 Mdot
.97071 .45887 Mdot
.97076 .45861 Mdot
.97081 .45836 Mdot
.97086 .4581 Mdot
.97091 .45785 Mdot
.97095 .4576 Mdot
.971 .45734 Mdot
.97105 .45709 Mdot
.9711 .45683 Mdot
.97114 .45658 Mdot
.97119 .45632 Mdot
.97124 .45607 Mdot
.97129 .45581 Mdot
.97133 .45556 Mdot
.97138 .4553 Mdot
.97143 .45505 Mdot
.97148 .45479 Mdot
.97152 .45453 Mdot
.97157 .45428 Mdot
.97162 .45402 Mdot
.97167 .45377 Mdot
.97171 .45351 Mdot
.97176 .45325 Mdot
.97181 .453 Mdot
.97186 .45274 Mdot
.97191 .45248 Mdot
.97195 .45222 Mdot
.972 .45197 Mdot
.97205 .45171 Mdot
.9721 .45145 Mdot
.97214 .45119 Mdot
.97219 .45094 Mdot
.97224 .45068 Mdot
.97229 .45042 Mdot
.97233 .45016 Mdot
.97238 .4499 Mdot
.97243 .44964 Mdot
.97248 .44938 Mdot
.97252 .44913 Mdot
.97257 .44887 Mdot
.97262 .44861 Mdot
.97267 .44835 Mdot
.97271 .44809 Mdot
.97276 .44783 Mdot
.97281 .44757 Mdot
.97286 .44731 Mdot
.97291 .44705 Mdot
.97295 .44679 Mdot
.973 .44653 Mdot
.97305 .44627 Mdot
.9731 .44601 Mdot
.97314 .44575 Mdot
.97319 .44549 Mdot
.97324 .44522 Mdot
.97329 .44496 Mdot
.97333 .4447 Mdot
.97338 .44444 Mdot
.97343 .44418 Mdot
.97348 .44392 Mdot
.97352 .44365 Mdot
.97357 .44339 Mdot
.97362 .44313 Mdot
.97367 .44287 Mdot
.97371 .44261 Mdot
.97376 .44234 Mdot
.97381 .44208 Mdot
.97386 .44182 Mdot
.9739 .44156 Mdot
.97395 .44129 Mdot
.974 .44103 Mdot
.97405 .44077 Mdot
.9741 .4405 Mdot
.97414 .44024 Mdot
.97419 .43997 Mdot
.97424 .43971 Mdot
.97429 .43945 Mdot
.97433 .43918 Mdot
.97438 .43892 Mdot
.97443 .43865 Mdot
.97448 .43839 Mdot
.97452 .43812 Mdot
.97457 .43786 Mdot
.97462 .43759 Mdot
.97467 .43733 Mdot
.97471 .43706 Mdot
.97476 .4368 Mdot
.97481 .43653 Mdot
.97486 .43627 Mdot
.9749 .436 Mdot
.97495 .43574 Mdot
.975 .43547 Mdot
.97505 .4352 Mdot
.9751 .43494 Mdot
.97514 .43467 Mdot
.97519 .43441 Mdot
.97524 .43414 Mdot
.97529 .43387 Mdot
.97533 .43361 Mdot
.97538 .43334 Mdot
.97543 .43307 Mdot
.97548 .4328 Mdot
.97552 .43254 Mdot
.97557 .43227 Mdot
.97562 .432 Mdot
.97567 .43173 Mdot
.97571 .43147 Mdot
.97576 .4312 Mdot
.97581 .43093 Mdot
.97586 .43066 Mdot
.9759 .43039 Mdot
.97595 .43013 Mdot
.976 .42986 Mdot
.97605 .42959 Mdot
.9761 .42932 Mdot
.97614 .42905 Mdot
.97619 .42878 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oo
oo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX0
0?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z
000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oook
JPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000
oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000RoookJP?o001o2OoonfX5
o`000?oooo]ZoooonfX?oookJP008_oonfX3o`00O`Wooo]Z1Ol0003ooookJXCooo]Z1Ol00025oook
JP008_oonfX3o`00O`Wooo]Z1Ol00019oookJPKo0000U_oonfX7o`0009Kooo]Z2?l00023oookJP00
4_oonfX:o`00O`Kooo]Z0ol007l9oookJPGo0000B?oonfX8o`0009Cooo]Z2_l0002BoookJP_o0000
P_oonfX001;ooo]Z2_l007l6oookJP?o001o2OoonfX6o`0004Kooo]Z2_l0002BoookJPco0000T?oo
nfX=o`00087ooo]Z000RoookJP?o001o2OoonfX5o`0004Kooo]Z3?l0002@oookJPko0000SooonfX6
o`000003oookJ_l0003o000000Go0000P?oonfX002;ooo]Z0ol007l9oookJPGo0000AOoonfX6o`00
00;ooo]Z1_l0002>oookJPKo00000ooonfX6o`0008kooo]Z1_l00004oookJPKo0000OooonfX002;o
oo]Z0ol007l9oookJPGo0000A?oonfX6o`0000Cooo]Z1_l0002=oookJPGo00001_oonfX5o`0008co
oo]Z1_l00006oookJPGo0000OooonfX002;ooo]Z0ol007l9oookJPGo0000@ooonfX6o`0000Kooo]Z
1_l0002;oookJPGo00001ooonfX6o`0008_ooo]Z1Ol00008oookJPGo0000O_oonfX001oooo]Z1_l0
07l9oookJPGo0000@ooonfX5o`0000Sooo]Z1Ol0002:oookJPKo00002?oonfX5o`0008[ooo]Z1Ol0
0009oookJPGo0000O_oonfX001oooo]Z1_l007l9oookJPGo0000@_oonfX5o`0000[ooo]Z1Ol00029
oookJPGo00002_oonfX5o`0008Wooo]Z1Ol0000:oookJPGo0000OOoonfX0027ooo]Z1?l007l9oook
JPGo0000@_oonfX5o`0000[ooo]Z1Ol00028oookJPGo00002ooonfX5o`0008Sooo]Z1Ol0000;oook
JPGo0000OOoonfX002;ooo]Z0ol007l9oookJPGo0000@OoonfX5o`0000cooo]Z1Ol00027oookJPGo
00003?oonfX5o`0008Oooo]Z1Ol0000<oookJPGo0000O?oonfX002kooo]Z1Ol00011oookJPGo0000
3?oonfX5o`0008Kooo]Z1Ol0000=oookJPGo0000Q_oonfX5o`0000gooo]Z1Ol0001loookJP00;_oo
nfX5o`00043ooo]Z1Ol0000>oookJPGo0000QOoonfX5o`0000kooo]Z1Ol00025oookJPGo00003_oo
nfX5o`0007_ooo]Z000^oookJPGo0000@?oonfX5o`0000kooo]Z1Ol00025oookJPCo00003ooonfX5
o`0008Cooo]Z1Ol0000?oookJPGo0000NooonfX002kooo]Z1Ol0000ooookJPGo00004?oonfX4o`00
08Cooo]Z1Ol0000@oookJPGo0000PooonfX5o`00013ooo]Z1Ol0001joookJP00;_oonfX5o`0003oo
oo]Z1Ol0000@oookJPGo0000PooonfX5o`00013ooo]Z1Ol00023oookJPCo00004OoonfX5o`0007[o
oo]Z000^oookJPGo0000?ooonfX4o`00017ooo]Z1Ol00022oookJPGo00004_oonfX4o`0008;ooo]Z
1Ol0000BoookJPCo0000N_oonfX002kooo]Z1Ol0000noookJPGo00004_oonfX5o`00087ooo]Z1Ol0
000BoookJPGo0000POoonfX5o`0001;ooo]Z1Ol0001ioookJP00;_oonfX5o`0003kooo]Z1Ol0000B
oookJPGo0000POoonfX4o`0001?ooo]Z1Ol00021oookJPCo00004ooonfX5o`0007Wooo]Z000^oook
JPGo0000?_oonfX4o`0001Cooo]Z1?l00020oookJPGo00005?oonfX4o`00083ooo]Z1Ol0000Doook
JPCo0000NOoonfX002kooo]Z1Ol0000moookJPGo00005?oonfX5o`0007oooo]Z1Ol0000DoookJPGo
0000OooonfX4o`0001Gooo]Z1Ol0001hoookJP00;_oonfX5o`0003gooo]Z1Ol0000DoookJPGo0000
OooonfX4o`0001Gooo]Z1Ol0001ooookJPCo00005OoonfX5o`0007Sooo]Z000^oookJPGo0000?Ooo
nfX4o`0001Kooo]Z1?l0001noookJPGo00005_oonfX4o`0007kooo]Z1Ol0000FoookJPCo0000N?oo
nfX002kooo]Z1Ol0000loookJPGo00005_oonfX5o`0007gooo]Z1Ol0000FoookJPGo0000OOoonfX4
o`0001Oooo]Z1Ol0001goookJP00;_oonfX5o`0003cooo]Z1Ol0000FoookJPGo0000OOoonfX4o`00
01Oooo]Z1Ol0001moookJPCo00005ooonfX5o`0007Oooo]Z000^oookJPGo0000??oonfX4o`0001So
oo]Z1?l0001loookJPGo00006?oonfX4o`0007cooo]Z1Ol0000HoookJPCo0000MooonfX002kooo]Z
1Ol0000koookJPGo00006?oonfX4o`0007cooo]Z1Ol0000HoookJPGo0000NooonfX5o`0001Sooo]Z
1Ol0001foookJP00;_oonfX5o`0003_ooo]Z1Ol0000HoookJPGo0000NooonfX4o`0001Wooo]Z1Ol0
001koookJPCo00006OoonfX5o`0007Kooo]Z000^oookJPGo0000>ooonfX4o`0001Wooo]Z1Ol0001k
oookJPCo00006_oonfX4o`0007[ooo]Z1Ol0000JoookJPCo0000M_oonfX002kooo]Z1Ol0000koook
JPCo00006_oonfX4o`0007[ooo]Z1Ol0000JoookJPCo0000N_oonfX5o`0001[ooo]Z1?l0001foook
JP00;_oonfX5o`0003[ooo]Z1Ol0000JoookJPGo0000NOoonfX5o`0001[ooo]Z1Ol0001ioookJPCo
00006ooonfX5o`0007Gooo]Z000^oookJPGo0000>_oonfX4o`0001_ooo]Z1Ol0001ioookJPCo0000
6ooonfX5o`0007Wooo]Z1?l0000KoookJPGo0000MOoonfX002kooo]Z1Ol0000joookJPCo00007?oo
nfX4o`0007Wooo]Z1?l0000LoookJPCo0000N?oonfX5o`0001cooo]Z1?l0001eoookJP00;_oonfX5
o`0003Wooo]Z1Ol0000LoookJPCo0000N?oonfX5o`0001cooo]Z1?l0001hoookJPGo00007?oonfX4
o`0007Gooo]Z000^oookJPGo0000>OoonfX5o`0001cooo]Z1Ol0001goookJPCo00007OoonfX5o`00
07Oooo]Z1?l0000MoookJPGo0000M?oonfX002kooo]Z1Ol0000ioookJPCo00007OoonfX5o`0007Oo
oo]Z1?l0000MoookJPGo0000MooonfX4o`0001gooo]Z1Ol0001doookJP00;_oonfX5o`0003Wooo]Z
1?l0000NoookJPCo0000M_oonfX5o`0001kooo]Z1?l0001foookJPGo00007_oonfX4o`0007Cooo]Z
000^oookJPGo0000>?oonfX5o`0001kooo]Z1?l0001foookJPGo00007_oonfX4o`0007Kooo]Z1Ol0
000NoookJPGo0000LooonfX002kooo]Z1Ol0000hoookJPGo00007_oonfX5o`0007Gooo]Z1?l0000O
oookJPGo0000MOoonfX4o`0001oooo]Z1Ol0001coookJP00;_oonfX5o`0003Sooo]Z1?l0000Ooook
JPGo0000MOoonfX4o`00023ooo]Z1?l0001eoookJPCo00008?oonfX4o`0007?ooo]Z000^oookJPGo
0000>?oonfX4o`00023ooo]Z1?l0001doookJPGo00008?oonfX4o`0007Cooo]Z1Ol0000PoookJPCo
0000LooonfX002kooo]Z1Ol0000goookJPGo00008?oonfX4o`0007Cooo]Z1Ol0000PoookJPCo0000
M?oonfX5o`00023ooo]Z1?l0001coookJP00;_oonfX5o`0003Oooo]Z1Ol0000PoookJPGo0000Looo
nfX4o`00027ooo]Z1Ol0001coookJPCo00008OoonfX5o`0007;ooo]Z000^oookJPGo0000=ooonfX4
o`00027ooo]Z1Ol0001coookJPCo00008OoonfX5o`0007?ooo]Z1?l0000QoookJPGo0000L_oonfX0
02kooo]Z1Ol0000goookJPCo00008_oonfX4o`0007?ooo]Z1?l0000RoookJPCo0000L_oonfX5o`00
02;ooo]Z1?l0001boookJP00;_oonfX5o`0003Kooo]Z1Ol0000RoookJPCo0000L_oonfX5o`0002;o
oo]Z1?l0001boookJPGo00008_oonfX4o`0007;ooo]Z000^oookJPGo0000=_oonfX5o`0002;ooo]Z
1Ol0001aoookJPGo00008_oonfX5o`00077ooo]Z1?l0000SoookJPGo0000LOoonfX002kooo]Z1Ol0
000foookJPCo00008ooonfX5o`00077ooo]Z1?l0000SoookJPGo0000LOoonfX4o`0002?ooo]Z1Ol0
001aoookJP00;_oonfX5o`0003Kooo]Z1?l0000ToookJPCo0000LOoonfX4o`0002Cooo]Z1?l0001`
oookJPGo00009?oonfX4o`00077ooo]Z000^oookJPGo0000=_oonfX4o`0002Cooo]Z1?l0001`oook
JPGo00009?oonfX4o`00073ooo]Z1Ol0000ToookJPCo0000LOoonfX002kooo]Z1Ol0000eoookJPGo
00009?oonfX5o`0006oooo]Z1Ol0000ToookJPGo0000KooonfX4o`0002Gooo]Z1Ol0001`oookJP00
;_oonfX5o`0003Gooo]Z1Ol0000ToookJPGo0000KooonfX4o`0002Gooo]Z1Ol0001_oookJPCo0000
9OoonfX5o`00073ooo]Z000^oookJPGo0000=OoonfX4o`0002Kooo]Z1?l0001_oookJPCo00009_oo
nfX4o`0006oooo]Z1?l0000VoookJPCo0000L?oonfX002kooo]Z1Ol0000eoookJPCo00009_oonfX4
o`0006oooo]Z1?l0000VoookJPCo0000K_oonfX5o`0002Kooo]Z1?l0001`oookJP00;_oonfX5o`00
03Cooo]Z1Ol0000VoookJPCo0000K_oonfX5o`0002Kooo]Z1?l0001^oookJPGo00009_oonfX4o`00
073ooo]Z000^oookJPGo0000=?oonfX5o`0002Kooo]Z1Ol0001]oookJPCo00009ooonfX5o`0006go
oo]Z1?l0000WoookJPGo0000KooonfX002kooo]Z1Ol0000doookJPCo00009ooonfX5o`0006gooo]Z
1?l0000WoookJPGo0000KOoonfX4o`0002Oooo]Z1Ol0001_oookJP00;_oonfX5o`0003Cooo]Z1?l0
000XoookJPCo0000KOoonfX4o`0002Sooo]Z1?l0001]oookJPCo0000:?oonfX4o`0006oooo]Z000^
oookJPGo0000=?oonfX4o`0002Sooo]Z1?l0001/oookJPGo0000:?oonfX4o`0006cooo]Z1Ol0000X
oookJPCo0000KooonfX002kooo]Z1Ol0000coookJPGo0000:?oonfX4o`0006cooo]Z1Ol0000Xoook
JPCo0000K?oonfX5o`0002Sooo]Z1?l0001_oookJP00;_oonfX5o`0003?ooo]Z1Ol0000XoookJPGo
0000JooonfX4o`0002Wooo]Z1Ol0001[oookJPCo0000:OoonfX5o`0006kooo]Z000^oookJPGo0000
<ooonfX4o`0002Wooo]Z1Ol0001[oookJPCo0000:OoonfX5o`0006_ooo]Z1?l0000YoookJPGo0000
K_oonfX002kooo]Z1Ol0000coookJPCo0000:_oonfX4o`0006_ooo]Z1?l0000ZoookJPCo0000Jooo
nfX4o`0002[ooo]Z1?l0001^oookJP00;_oonfX5o`0003?ooo]Z1?l0000ZoookJPCo0000J_oonfX5
o`0002[ooo]Z1?l0001ZoookJPGo0000:_oonfX4o`0006kooo]Z000^oookJPGo0000<_oonfX5o`00
02[ooo]Z1?l0001ZoookJPGo0000:_oonfX4o`0006[ooo]Z1?l0000[oookJPCo0000K_oonfX002ko
oo]Z1Ol0000boookJPGo0000:_oonfX5o`0006Wooo]Z1?l0000[oookJPGo0000JOoonfX4o`0002_o
oo]Z1Ol0001]oookJP00;_oonfX5o`0003;ooo]Z1?l0000/oookJPCo0000JOoonfX4o`0002_ooo]Z
1Ol0001YoookJPCo0000:ooonfX5o`0006gooo]Z000^oookJPGo0000<_oonfX4o`0002cooo]Z1?l0
001YoookJPCo0000;?oonfX4o`0006Wooo]Z1?l0000/oookJPCo0000KOoonfX002kooo]Z1Ol0000b
oookJPCo0000;?oonfX4o`0006Sooo]Z1Ol0000/oookJPCo0000J?oonfX5o`0002cooo]Z1?l0001]
oookJP00;_oonfX5o`00037ooo]Z1Ol0000/oookJPCo0000J?oonfX5o`0002cooo]Z1?l0001Xoook
JPCo0000;OoonfX4o`0006gooo]Z000^oookJPGo0000<OoonfX5o`0002cooo]Z1Ol0001WoookJPCo
0000;OoonfX5o`0006Oooo]Z1?l0000]oookJPGo0000K?oonfX002kooo]Z1Ol0000aoookJPCo0000
;_oonfX4o`0006Oooo]Z1?l0000]oookJPGo0000IooonfX4o`0002gooo]Z1Ol0001/oookJP00;_oo
nfX5o`00037ooo]Z1?l0000^oookJPCo0000IooonfX4o`0002kooo]Z1?l0001WoookJPCo0000;_oo
nfX4o`0006cooo]Z000^oookJPGo0000<OoonfX4o`0002kooo]Z1?l0001VoookJPGo0000;_oonfX4
o`0006Kooo]Z1Ol0000^oookJPCo0000K?oonfX0017ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00
O`Wooo]Z1Ol0000`oookJPGo0000;_oonfX4o`0006Kooo]Z1Ol0000^oookJPCo0000I_oonfX5o`00
02kooo]Z1?l0001/oookJP004?oonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2?oonfX5o`00033o
oo]Z1Ol0000^oookJPGo0000IOoonfX4o`0002oooo]Z1Ol0001UoookJPCo0000;ooonfX5o`0006_o
oo]Z000@oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o
001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`00033ooo]Z1?l0000_oookJPGo0000IOoonfX4o`00
02oooo]Z1Ol0001UoookJPCo0000;ooonfX5o`0006_ooo]Z0003oookJP[o001o0_oonfX3o`00O`?o
oo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0000`oookJPCo0000<?oonfX4o`0006Go
oo]Z1?l0000`oookJPCo0000IOoonfX4o`00033ooo]Z1?l0001[oookJP000ooonfX:o`00O`;ooo]Z
0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1_l0000_oookJPCo0000<?oonfX4o`0006Gooo]Z
1?l0000`oookJPCo0000I?oonfX5o`00033ooo]Z1?l0001[oookJP003ooonfX3o`00O`?ooo]Z0ol0
07l<oookJP?o001o1ooonfX5o`0002oooo]Z1Ol0000`oookJPCo0000I?oonfX5o`00033ooo]Z1?l0
001ToookJPGo0000<?oonfX4o`0006_ooo]Z000?oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2
oookJPCo001o1ooonfX5o`0002oooo]Z1Ol0000`oookJPGo0000HooonfX5o`00033ooo]Z1Ol0001S
oookJPCo0000<OoonfX4o`0006_ooo]Z000?oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l8oook
JPGo0000;ooonfX4o`00037ooo]Z1Ol0001SoookJPCo0000<OoonfX5o`0006?ooo]Z1?l0000aoook
JPGo0000J_oonfX000oooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`Wooo]Z1Ol0000_oookJPCo
0000<_oonfX4o`0006?ooo]Z1?l0000boookJPCo0000HooonfX4o`0003;ooo]Z1?l0001ZoookJP00
3ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3OoonfX5o`0002oooo]Z1?l0000boookJPCo0000
HooonfX4o`0003;ooo]Z1?l0001RoookJPGo0000<_oonfX4o`0006[ooo]Z000@oookJP?o001o00Co
oo]Zo`00Ool007oo001o2?oonfX2o`00O`gooo]Z1Ol0000_oookJPCo0000<_oonfX4o`0006;ooo]Z
1Ol0000boookJPCo0000H_oonfX5o`0003;ooo]Z1?l0001ZoookJP004?oonfX7o`00O`Wooo]Z1ol0
07l7oookJPGo0000;_oonfX5o`0003;ooo]Z1?l0001RoookJPGo0000<_oonfX4o`0006;ooo]Z1?l0
000coookJPCo0000J_oonfX0017ooo]Z1Ol007l:oookJPOo001o1ooonfX5o`0002kooo]Z1Ol0000b
oookJPGo0000HOoonfX4o`0003?ooo]Z1Ol0001QoookJPCo0000<ooonfX5o`0006Wooo]Z000^oook
JPGo0000;_oonfX4o`0003Cooo]Z1?l0001QoookJPCo0000<ooonfX5o`00067ooo]Z1?l0000coook
JPGo0000JOoonfX002kooo]Z1Ol0000^oookJPCo0000=?oonfX4o`00067ooo]Z1?l0000doookJPCo
0000HOoonfX4o`0003Cooo]Z1?l0001YoookJP00;_oonfX5o`0002kooo]Z1?l0000doookJPCo0000
HOoonfX4o`0003Cooo]Z1?l0001PoookJPGo0000=?oonfX4o`0006Wooo]Z000^oookJPGo0000;Ooo
nfX5o`0003Cooo]Z1?l0001PoookJPGo0000=?oonfX4o`00063ooo]Z1Ol0000doookJPCo0000JOoo
nfX002kooo]Z1Ol0000]oookJPGo0000=?oonfX5o`0005oooo]Z1Ol0000doookJPGo0000GooonfX4
o`0003Gooo]Z1?l0001YoookJP00;_oonfX5o`0002gooo]Z1?l0000eoookJPGo0000GooonfX4o`00
03Gooo]Z1Ol0001OoookJPCo0000=OoonfX5o`0006Sooo]Z000^oookJPGo0000;OoonfX4o`0003Ko
oo]Z1?l0001OoookJPCo0000=_oonfX4o`0005oooo]Z1?l0000foookJPCo0000J?oonfX002kooo]Z
1Ol0000]oookJPCo0000=_oonfX4o`0005oooo]Z1?l0000foookJPCo0000GooonfX4o`0003Kooo]Z
1?l0001XoookJP00;_oonfX5o`0002gooo]Z1?l0000foookJPCo0000G_oonfX5o`0003Kooo]Z1?l0
001NoookJPGo0000=_oonfX4o`0006Sooo]Z000^oookJPGo0000;?oonfX5o`0003Kooo]Z1?l0001N
oookJPGo0000=_oonfX4o`0005kooo]Z1?l0000goookJPCo0000J?oonfX002kooo]Z1Ol0000/oook
JPGo0000=_oonfX5o`0005gooo]Z1?l0000goookJPGo0000GOoonfX4o`0003Oooo]Z1Ol0001Woook
JP00;_oonfX5o`0002cooo]Z1?l0000goookJPGo0000GOoonfX4o`0003Oooo]Z1Ol0001MoookJPCo
0000=ooonfX5o`0006Oooo]Z000^oookJPGo0000;?oonfX4o`0003Sooo]Z1?l0001MoookJPCo0000
>?oonfX4o`0005gooo]Z1?l0000hoookJPCo0000IooonfX002kooo]Z1Ol0000/oookJPCo0000>?oo
nfX4o`0005gooo]Z1?l0000hoookJPCo0000G?oonfX5o`0003Sooo]Z1?l0001WoookJP00;_oonfX5
o`0002cooo]Z1?l0000hoookJPCo0000G?oonfX5o`0003Sooo]Z1?l0001LoookJPGo0000>?oonfX4
o`0006Oooo]Z000^oookJPGo0000:ooonfX5o`0003Sooo]Z1Ol0001KoookJPGo0000>?oonfX4o`00
05cooo]Z1?l0000ioookJPCo0000IooonfX002kooo]Z1Ol0000[oookJPCo0000>OoonfX5o`0005_o
oo]Z1?l0000ioookJPGo0000FooonfX4o`0003Wooo]Z1Ol0001VoookJP00;_oonfX5o`0002_ooo]Z
1?l0000joookJPCo0000FooonfX4o`0003Wooo]Z1Ol0001KoookJPCo0000>OoonfX5o`0006Kooo]Z
000^oookJPGo0000:ooonfX4o`0003[ooo]Z1?l0001KoookJPCo0000>_oonfX4o`0005_ooo]Z1?l0
000joookJPCo0000I_oonfX002kooo]Z1Ol0000[oookJPCo0000>_oonfX4o`0005_ooo]Z1?l0000j
oookJPCo0000F_oonfX5o`0003[ooo]Z1?l0001VoookJP00;_oonfX5o`0002[ooo]Z1Ol0000joook
JPCo0000F_oonfX5o`0003[ooo]Z1?l0001JoookJPGo0000>_oonfX4o`0006Kooo]Z000^oookJPGo
0000:_oonfX5o`0003[ooo]Z1Ol0001IoookJPGo0000>_oonfX4o`0005[ooo]Z1?l0000koookJPCo
0000I_oonfX002kooo]Z1Ol0000ZoookJPCo0000>ooonfX5o`0005Wooo]Z1?l0000koookJPGo0000
FOoonfX4o`0003_ooo]Z1Ol0001UoookJP00;_oonfX5o`0002[ooo]Z1?l0000loookJPCo0000FOoo
nfX4o`0003cooo]Z1?l0001IoookJPCo0000>ooonfX5o`0006Gooo]Z000^oookJPGo0000:_oonfX4
o`0003cooo]Z1?l0001IoookJPCo0000??oonfX4o`0005Wooo]Z1?l0000loookJPCo0000IOoonfX0
02kooo]Z1Ol0000ZoookJPCo0000??oonfX4o`0005Wooo]Z1?l0000loookJPCo0000F?oonfX5o`00
03cooo]Z1?l0001UoookJP00;_oonfX5o`0002Wooo]Z1Ol0000loookJPCo0000F?oonfX5o`0003co
oo]Z1?l0001HoookJPGo0000??oonfX4o`0006Gooo]Z000^oookJPGo0000:OoonfX5o`0003cooo]Z
1Ol0001GoookJPGo0000??oonfX4o`0005Sooo]Z1?l0000moookJPCo0000IOoonfX002kooo]Z1Ol0
000YoookJPCo0000?OoonfX5o`0005Oooo]Z1?l0000moookJPGo0000EooonfX4o`0003gooo]Z1Ol0
001ToookJP00;_oonfX5o`0002Wooo]Z1?l0000noookJPCo0000EooonfX4o`0003kooo]Z1?l0001G
oookJPCo0000?OoonfX5o`0006Cooo]Z000^oookJPGo0000:OoonfX4o`0003kooo]Z1?l0001Goook
JPCo0000?_oonfX4o`0005Oooo]Z1?l0000noookJPCo0000I?oonfX002kooo]Z1Ol0000YoookJPCo
0000?_oonfX4o`0005Oooo]Z1?l0000noookJPCo0000E_oonfX5o`0003kooo]Z1?l0001ToookJP00
;_oonfX5o`0002Sooo]Z1Ol0000noookJPCo0000E_oonfX5o`0003kooo]Z1?l0001FoookJPGo0000
?_oonfX4o`0006Cooo]Z000^oookJPGo0000:?oonfX5o`0003kooo]Z1Ol0001EoookJPGo0000?_oo
nfX4o`0005Kooo]Z1?l0000ooookJPCo0000I?oonfX002kooo]Z1Ol0000XoookJPCo0000?ooonfX5
o`0005Gooo]Z1?l0000ooookJPGo0000EOoonfX4o`0003oooo]Z1Ol0001SoookJP00;_oonfX5o`00
02Sooo]Z1?l00010oookJPCo0000EOoonfX4o`00043ooo]Z1?l0001EoookJPCo0000?ooonfX5o`00
06?ooo]Z000^oookJPGo0000:?oonfX4o`00043ooo]Z1?l0001EoookJPCo0000@?oonfX4o`0005Go
oo]Z1?l00010oookJPCo0000HooonfX002kooo]Z1Ol0000XoookJPCo0000@?oonfX4o`0005Gooo]Z
1?l00010oookJPCo0000E?oonfX5o`00043ooo]Z1?l0001SoookJP00;_oonfX5o`0002Oooo]Z1Ol0
0010oookJPCo0000E?oonfX5o`00043ooo]Z1?l0001DoookJPGo0000@?oonfX4o`0006?ooo]Z000^
oookJPGo00009ooonfX5o`00043ooo]Z1Ol0001CoookJPGo0000@?oonfX4o`0005Cooo]Z1?l00011
oookJPCo0000HooonfX002kooo]Z1Ol0000WoookJPCo0000@OoonfX5o`0005?ooo]Z1?l00011oook
JPGo0000DooonfX4o`00047ooo]Z1Ol0001RoookJP00;_oonfX5o`0002Oooo]Z1?l00012oookJPCo
0000DooonfX4o`0004;ooo]Z1?l0001CoookJPCo0000@OoonfX5o`0006;ooo]Z000^oookJPGo0000
9ooonfX4o`0004;ooo]Z1?l0001CoookJPCo0000@_oonfX4o`0005?ooo]Z1?l00012oookJPCo0000
H_oonfX002kooo]Z1Ol0000WoookJPCo0000@_oonfX4o`0005?ooo]Z1?l00012oookJPCo0000D_oo
nfX5o`0004;ooo]Z1?l0001RoookJP00;_oonfX5o`0002Kooo]Z1Ol00012oookJPCo0000D_oonfX5
o`0004;ooo]Z1?l0001BoookJPGo0000@_oonfX4o`0006;ooo]Z000^oookJPGo00009_oonfX5o`00
04;ooo]Z1Ol0001AoookJPGo0000@_oonfX4o`0005;ooo]Z1?l00013oookJPCo0000H_oonfX002ko
oo]Z1Ol0000VoookJPCo0000@ooonfX5o`00057ooo]Z1?l00013oookJPGo0000DOoonfX4o`0004?o
oo]Z1Ol0001QoookJP00;_oonfX5o`0002Kooo]Z1?l0000noookJPGo001o00?ooo]Zo`000?l00000
0_l00005o`00O`Gooo]Z1Ol007l5oookJPGo001o>?oonfX4o`0001_ooo]Z0ol007l5oookJPGo001o
1OoonfX5o`00O`Gooo]Z1Ol007l5oookJP?o001o1?l0001@oookJP03o`00Ool0003o000000;o0000
0ooonfX5o`00O`Gooo]Z1Ol007l5oookJPGo001o1OoonfX5o`00Oagooo]Z1Ol0000[oookJPWo001o
0ooonfX5o`00O`Gooo]Z1Ol007l5oookJPGo001o1OoonfX5o`00O`Oooo]Z000^oookJPGo00009_oo
nfX4o`0003gooo]Z1ol007l4o`0000Ko001o0ooonfX7o`00O`?ooo]Z1ol007lgoookJPCo00006ooo
nfX3o`00O`Cooo]Z1ol007l3oookJPOo001o0ooonfX7o`00O`?ooo]Z1?l007l4o`00053ooo]Z00?o
001oo`000?l000000_l00002oookJPOo001o0ooonfX7o`00O`?ooo]Z1ol007l3oookJPOo001o7Ooo
nfX4o`0002_ooo]Z2Ol007l2oookJPOo001o0ooonfX7o`00O`?ooo]Z1ol007l3oookJPOo001o1_oo
nfX002kooo]Z1Ol0000VoookJPCo0000??oonfX4o`00O`04oookJ_l007oo001oo`00O`Co00000_l0
07l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04
oookJ_l007oo001oo`00OcOooo]Z1?l0000KoookJP?o001o1?oonfX3o`00O`04oookJ_l007oo001o
o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o
0ooonfX3o`00O`03oookJ_l0003o000000;o0000D?oonfX5o`000003oookJ_l007oo001o00;o001o
00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o7OoonfX4o`0002_ooo]Z1?l0
07l7oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?o
oo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o1_oonfX0
02kooo]Z1Ol0000UoookJPGo0000??oonfX3o`00O`?ooo]Z0_l007l4o`000004o`00Oooonf[ooo]Z
oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z
0ol007leoookJPGo00006ooonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo
001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l2
oookJPCo0000D?oonfX5o`000004oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00
Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00
O`?ooo]Z0ol007lLoookJPCo0000;?oonfX4o`00O`Gooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00
Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00
Ool007l3oookJP?o001o1OoonfX002kooo]Z1Ol0000UoookJPGo0000@_oonfX2o`00O`Go00000ooo
nfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o
001o=OoonfX5o`0001_ooo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00
O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0_oo
nfX4o`00053ooo]Z1?l00008oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oook
J_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o7?oonfX4o`00
02gooo]Z1Ol007l3oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l0
1?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Gooo]Z
000^oookJPGo00009OoonfX4o`0004?ooo]Z0_l007l5o`0000?ooo]Z0ol007l01?oonf[o001oo`00
Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00OcGooo]Z1?l0000LoookJP?o
001o0ooonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00
Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`;ooo]Z1Ol0001?oookJPCo00002?oo
nfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o
001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00Oacooo]Z1Ol0000^oookJPCo001o0_oonfX3o`00
O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l5oookJP00;_oonfX5o`0002Gooo]Z1?l0
000noookJP;o001o0_oonfX4o`00O`Co00000ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z
0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o=OoonfX4o`0001cooo]Z0ol007l3oookJP?o
001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3
oookJP?o001o00Cooo]Zo`00Ool007oo001o0_oonfX5o`0004oooo]Z1?l00003oookJP;o001o0_oo
nfX4o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o
001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00Oacooo]Z1Ol0000_oookJP?o001o0_oonfX3o`00
O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l5oookJP00;_oonfX5o`0002Gooo]Z1?l0
000noookJPOo001o00?ooo]Zo`000?l000000_l00003oookJP?o001o00Cooo]Zo`00Ool007oo001o
0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007leoookJPCo00007?oonfX3o`00O`?o
oo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001o
o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJPCo0000CooonfX4o`0000?ooo]Z1ol0
07l2oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001o
o`00Ool007l3oookJP?o001o7OoonfX4o`00033ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol0
07l01?oonf[o001oo`00Ool007l3oookJP?o001o1OoonfX002kooo]Z1Ol0000UoookJPCo0000?_oo
nfX6o`00O`;ooo]Z1?l00003oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oook
J_l007oo001oo`00O`?ooo]Z0ol007leoookJPCo00007?oonfX3o`00O`?ooo]Z0ol007l3oookJP?o
001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l0
1?oonf[o001oo`00Ool007l3oookJPCo0000C_oonfX5o`0000?ooo]Z1_l007l3oookJP?o001o0ooo
nfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o
001o7OoonfX4o`0002[ooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00
O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Co
oo]Zo`00Ool007oo001o0ooonfX3o`00O`Gooo]Z000^oookJPGo00009?oonfX5o`0003kooo]Z0_l0
07l6oookJPCo00000ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001o
o`00Ool007l3oookJP?o001o=?oonfX5o`0001Wooo]Z1_l007l3oookJP?o001o0ooonfX3o`00O`04
oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Z
o`00Ool007oo001o0ooonfX4o`0004cooo]Z0_l007l5o`0000?ooo]Z0_l007l7oookJP?o001o0ooo
nfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o
001o7OoonfX4o`0002[ooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00
O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Co
oo]Zo`00Ool007oo001o0ooonfX3o`00O`Gooo]Z000^oookJPGo00009?oonfX5o`0003kooo]Z0_l0
07l6oookJPGo000000Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?o
oo]Z0ol007l01?oonf[o001oo`00Ool007leoookJPGo00006OoonfX6o`00O`Cooo]Z0ol007l01?oo
nf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l0
07oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`000003o`0004cooo]Z0_l007l4o`0000Cooo]Z
0_l007l8oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00
O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007lNoookJPCo0000:_oonfX4o`00O`;ooo]Z0ol007l2
oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z
0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o1_oonfX002ko
oo]Z1Ol0000ToookJPCo0000@?oonfX7o`00O`Go00001?l007l3oookJPOo001o0ooonfX7o`00OcGo
oo]Z1?l0000LoookJPCo001o1?oonfX7o`00O`?ooo]Z1ol007l3oookJPOo001o0ooonfX5o`00O`Go
0000COoonfX4o`0000Gooo]Z1ol007l2oookJPOo001o0ooonfX7o`00O`?ooo]Z1ol007lNoookJPGo
0000:_oonfX7o`00O`?ooo]Z1ol007l3oookJPOo001o0ooonfX7o`00O`?ooo]Z1ol007l6oookJP00
;_oonfX5o`0002Cooo]Z1?l00010oookJPOo001o00?ooo]Zo`000?l000000_l00003o`00O`Gooo]Z
1Ol007l5oookJPGo001o=_oonfX4o`0001gooo]Z0ol007l5oookJPGo001o1OoonfX5o`00O`Gooo]Z
1Ol007l5oookJPCo001o1Ol0001=oookJPCo00001OoonfX7o`00O`?ooo]Z1Ol007l5oookJPGo001o
1OoonfX5o`00Oaoooo]Z1Ol0000[oookJPGo001o1OoonfX5o`00O`Gooo]Z1Ol007l5oookJPGo001o
1OoonfX5o`00O`Oooo]Z000^oookJPGo00009?oonfX4o`0004Sooo]Z1?l0001=oookJPCo0000B?oo
nfX4o`0004gooo]Z1?l00018oookJPCo0000GooonfX002kooo]Z1Ol0000ToookJPCo0000B?oonfX4
o`0004gooo]Z1?l00018oookJPCo0000COoonfX4o`0004Sooo]Z1?l0001OoookJP00;_oonfX5o`00
02Cooo]Z1?l00018oookJPCo0000C?oonfX5o`0004Sooo]Z1?l0001<oookJPGo0000B?oonfX4o`00
05oooo]Z000^oookJPGo00008ooonfX5o`0004Sooo]Z1?l0001<oookJPGo0000B?oonfX4o`0004co
oo]Z1?l00019oookJPCo0000GooonfX002kooo]Z1Ol0000SoookJPCo0000BOoonfX5o`0004_ooo]Z
1?l00019oookJPGo0000BooonfX4o`0004Wooo]Z1Ol0001NoookJP00;_oonfX5o`0002?ooo]Z1?l0
001:oookJPCo0000BooonfX4o`0004Wooo]Z1Ol0001;oookJPCo0000BOoonfX5o`0005kooo]Z000R
oookJ_oo0000ool0000Co`0000gooo]Z000RoookJ_oo0000ool0000Co`0000gooo]Z000RoookJ_oo
0000ool0000Co`0000gooo]Z000RoookJ_oo0000ool0000Co`0000gooo]Z000RoookJ_oo0000ool0
000Co`0000gooo]Z000^oookJPGo00008_oonfX4o`0004_ooo]Z1Ol00004oookJP03o`000?oonf[o
oo]Z04;ooo]Z1?l0000doookJP03o`000?oonf[ooo]Z01Cooo]Z1Ol00019oookJPCo00005?oonfX0
0ol0003ooo]ZoookJP0doookJPGo0000@?oonfX00ol0003ooo]ZoookJP0JoookJP00;_oonfX5o`00
02;ooo]Z1?l0001<oookJPCo0000BOoonfX4o`0004cooo]Z1?l00019oookJPCo0000C?oonfX4o`00
05gooo]Z000^oookJPGo00008_oonfX4o`0004cooo]Z1?l00019oookJPCo0000C?oonfX4o`0004Wo
oo]Z1?l0001<oookJPCo0000GOoonfX002kooo]Z1Ol0000RoookJPCo0000C?oonfX4o`0004Sooo]Z
1Ol0001<oookJPCo0000B?oonfX5o`0004cooo]Z1?l0001MoookJP00;_oonfX5o`00027ooo]Z1Ol0
001<oookJPCo0000B?oonfX5o`0004cooo]Z1?l00018oookJPGo0000C?oonfX4o`0005gooo]Z000^
oookJPGo00008OoonfX5o`0004cooo]Z1Ol00017oookJPCo0000COoonfX5o`0004Oooo]Z1?l0001=
oookJPCo0000GOoonfX002kooo]Z1Ol0000QoookJPCo0000COoonfX5o`0004Oooo]Z1?l0001=oook
JPGo0000AooonfX4o`0004gooo]Z1Ol0001LoookJP00;_oonfX5o`00027ooo]Z1?l0001>oookJPCo
0000AooonfX4o`0004kooo]Z1?l00017oookJPCo0000COoonfX5o`0005cooo]Z000^oookJPGo0000
8OoonfX4o`0004kooo]Z1?l00017oookJPCo0000C_oonfX4o`0004Oooo]Z1?l0001>oookJPCo0000
G?oonfX002kooo]Z1Ol0000QoookJPCo0000C_oonfX4o`0004Oooo]Z1?l0001>oookJPCo0000A_oo
nfX5o`0004kooo]Z1?l0001LoookJP00;_oonfX5o`00023ooo]Z1Ol0001>oookJPCo0000A_oonfX5
o`0004kooo]Z1?l00016oookJPGo0000C_oonfX4o`0005cooo]Z000^oookJPGo00008?oonfX5o`00
04kooo]Z1Ol00015oookJPCo0000CooonfX5o`0004Gooo]Z1?l0001?oookJPCo0000G?oonfX002ko
oo]Z1Ol0000PoookJPCo0000CooonfX5o`0004Gooo]Z1?l0001?oookJPGo0000AOoonfX4o`0004oo
oo]Z1Ol0001KoookJP00;_oonfX5o`00023ooo]Z1?l0001@oookJPCo0000AOoonfX4o`00053ooo]Z
1?l00015oookJPCo0000CooonfX5o`0005_ooo]Z000^oookJPGo00008?oonfX4o`00053ooo]Z1?l0
0015oookJPCo0000D?oonfX4o`0004Gooo]Z1?l0001@oookJPCo0000FooonfX002kooo]Z1Ol0000P
oookJPCo0000D?oonfX4o`0004Gooo]Z1?l0001@oookJPCo0000A?oonfX5o`00053ooo]Z1?l0001K
oookJP00;_oonfX5o`0001oooo]Z1Ol0001@oookJPCo0000A?oonfX5o`00053ooo]Z1?l00014oook
JPGo0000D?oonfX4o`0005_ooo]Z000^oookJPGo00007ooonfX5o`00053ooo]Z1Ol00013oookJPCo
0000DOoonfX4o`0004Cooo]Z1?l0001AoookJPCo0000FooonfX002kooo]Z1Ol0000OoookJPCo0000
DOoonfX5o`0004?ooo]Z1?l0001AoookJPGo0000@ooonfX4o`00057ooo]Z1Ol0001JoookJP00;_oo
nfX5o`0001oooo]Z1?l0001BoookJPCo0000@ooonfX4o`0005;ooo]Z1?l00013oookJPCo0000DOoo
nfX5o`0005[ooo]Z000^oookJPGo00007ooonfX4o`0005;ooo]Z1?l00013oookJPCo0000D_oonfX4
o`0004?ooo]Z1?l0001BoookJPCo0000F_oonfX002kooo]Z1Ol0000OoookJPCo0000D_oonfX4o`00
04?ooo]Z1?l0001BoookJPCo0000@_oonfX5o`0005;ooo]Z1?l0001JoookJP00;_oonfX5o`0001ko
oo]Z1Ol0001BoookJPCo0000@_oonfX5o`0005;ooo]Z1?l00012oookJPGo0000D_oonfX4o`0005[o
oo]Z000^oookJPGo00007_oonfX5o`0005;ooo]Z1Ol00011oookJPGo0000D_oonfX4o`0004;ooo]Z
1?l0001CoookJPCo0000F_oonfX002kooo]Z1Ol0000NoookJPCo0000DooonfX5o`00047ooo]Z1?l0
001CoookJPGo0000@OoonfX4o`0005?ooo]Z1Ol0001IoookJP00;_oonfX5o`0001kooo]Z1?l0001D
oookJPCo0000@OoonfX4o`0005Cooo]Z1?l00011oookJPCo0000DooonfX5o`0005Wooo]Z000^oook
JPGo00007_oonfX4o`0005Cooo]Z1?l00011oookJPCo0000E?oonfX4o`00047ooo]Z1?l0001Doook
JPCo0000FOoonfX002kooo]Z1Ol0000NoookJPCo0000E?oonfX4o`00047ooo]Z1?l0001DoookJPCo
0000@?oonfX5o`0005Cooo]Z1?l0001IoookJP00;_oonfX5o`0001gooo]Z1Ol0001DoookJPCo0000
@?oonfX5o`0005Cooo]Z1?l00010oookJPGo0000E?oonfX4o`0005Wooo]Z000^oookJPGo00007Ooo
nfX5o`0005Cooo]Z1Ol0000ooookJPGo0000E?oonfX4o`00043ooo]Z1?l0001EoookJPCo0000FOoo
nfX002kooo]Z1Ol0000MoookJPCo0000EOoonfX5o`0003oooo]Z1?l0001EoookJPGo0000?ooonfX4
o`0005Gooo]Z1Ol0001HoookJP00;_oonfX5o`0001gooo]Z1?l0001FoookJPCo0000?ooonfX4o`00
05Gooo]Z1Ol0000ooookJPCo0000EOoonfX5o`0005Sooo]Z000^oookJPGo00007OoonfX4o`0005Ko
oo]Z1?l0000ooookJPCo0000E_oonfX4o`0003oooo]Z1?l0001FoookJPCo0000F?oonfX002kooo]Z
1Ol0000MoookJPCo0000E_oonfX4o`0003oooo]Z1?l0001FoookJPCo0000?_oonfX5o`0005Kooo]Z
1?l0001HoookJP00;_oonfX5o`0001cooo]Z1Ol0001FoookJPCo0000?_oonfX5o`0005Kooo]Z1?l0
000noookJPGo0000E_oonfX4o`0005Sooo]Z000^oookJPGo00007?oonfX5o`0005Kooo]Z1Ol0000m
oookJPGo0000E_oonfX4o`0003kooo]Z1?l0001GoookJPCo0000F?oonfX002kooo]Z1Ol0000Loook
JPCo0000EooonfX5o`0003gooo]Z1?l0001GoookJPGo0000?OoonfX4o`0005Oooo]Z1Ol0001Goook
JP00;_oonfX5o`0001cooo]Z1?l0001HoookJPCo0000?OoonfX4o`0005Oooo]Z1Ol0000moookJPCo
0000EooonfX5o`0005Oooo]Z000^oookJPGo00007?oonfX4o`0005Sooo]Z1?l0000moookJPCo0000
F?oonfX4o`0003gooo]Z1?l0001HoookJPCo0000EooonfX002kooo]Z1Ol0000LoookJPCo0000F?oo
nfX4o`0003gooo]Z1?l0001HoookJPCo0000??oonfX5o`0005Sooo]Z1?l0001GoookJP00;_oonfX5
o`0001_ooo]Z1Ol0001HoookJPCo0000??oonfX5o`0005Sooo]Z1?l0000loookJPGo0000F?oonfX4
o`0005Oooo]Z000^oookJPGo00006ooonfX5o`0005Sooo]Z1Ol0000koookJPGo0000F?oonfX4o`00
03cooo]Z1?l0001IoookJPCo0000EooonfX002kooo]Z1Ol0000KoookJPCo0000FOoonfX5o`0003_o
oo]Z1?l0001IoookJPGo0000>ooonfX4o`0005Wooo]Z1Ol0001FoookJP00;_oonfX5o`0001_ooo]Z
1?l0001JoookJPCo0000>ooonfX4o`0005[ooo]Z1?l0000koookJPCo0000FOoonfX5o`0005Kooo]Z
000^oookJPGo00006ooonfX4o`0005[ooo]Z1?l0000koookJPCo0000F_oonfX4o`0003_ooo]Z1?l0
001JoookJPCo0000E_oonfX002kooo]Z1Ol0000KoookJPCo0000F_oonfX4o`0003_ooo]Z1?l0001J
oookJPCo0000>_oonfX5o`0005[ooo]Z1?l0001FoookJP00;_oonfX5o`0001[ooo]Z1Ol0001Joook
JPCo0000>_oonfX5o`0005[ooo]Z1?l0000joookJPGo0000F_oonfX4o`0005Kooo]Z000^oookJPGo
00006_oonfX5o`0005[ooo]Z1Ol0000ioookJPCo0000FooonfX5o`0003Wooo]Z1?l0001KoookJPCo
0000E_oonfX002kooo]Z1Ol0000JoookJPCo0000FooonfX5o`0003Wooo]Z1?l0001KoookJPGo0000
>OoonfX4o`0005_ooo]Z1Ol0001EoookJP00;_oonfX5o`0001[ooo]Z1?l0001LoookJPCo0000>Ooo
nfX4o`0005cooo]Z1?l0000ioookJPCo0000FooonfX5o`0005Gooo]Z000^oookJPGo00006_oonfX4
o`0005cooo]Z1?l0000ioookJPCo0000G?oonfX4o`0003Wooo]Z1?l0001LoookJPCo0000EOoonfX0
02kooo]Z1Ol0000JoookJPCo0000G?oonfX4o`0003Sooo]Z1Ol0001LoookJPCo0000>?oonfX5o`00
05cooo]Z1?l0001EoookJP00;_oonfX5o`0001Wooo]Z1Ol0001LoookJPCo0000>?oonfX5o`0005co
oo]Z1?l0000hoookJPGo0000G?oonfX4o`0005Gooo]Z000^oookJPGo00006OoonfX5o`0005cooo]Z
1Ol0000goookJPCo0000GOoonfX5o`0003Oooo]Z1?l0001MoookJPCo0000EOoonfX002kooo]Z1Ol0
000IoookJPCo0000G_oonfX4o`0003Oooo]Z1?l0001MoookJPGo0000=ooonfX4o`0005gooo]Z1Ol0
001DoookJP00;_oonfX5o`0001Wooo]Z1?l0001NoookJPCo0000=ooonfX4o`0005kooo]Z1?l0000g
oookJPCo0000GOoonfX5o`0005Cooo]Z000^oookJPGo00006OoonfX4o`0005kooo]Z1?l0000goook
JPCo0000G_oonfX4o`0003Oooo]Z1?l0001NoookJPCo0000E?oonfX002kooo]Z1Ol0000HoookJPGo
0000G_oonfX4o`0003Kooo]Z1Ol0001NoookJPCo0000=_oonfX5o`0005kooo]Z1?l0001DoookJP00
;_oonfX5o`0001Sooo]Z1Ol0001NoookJPGo0000=OoonfX5o`0005kooo]Z1?l0000foookJPGo0000
G_oonfX4o`0003Oooo]Z0_l0000KoookJP00;_oonfX5o`0001Sooo]Z1?l0001OoookJPGo0000=Ooo
nfX4o`0005oooo]Z1Ol0000eoookJPCo0000GooonfX4o`0003Kooo]Z1?l0000JoookJP00;_oonfX5
o`0001Sooo]Z1?l0001PoookJPCo0000=OoonfX4o`0005oooo]Z1Ol0000eoookJPCo0000GooonfX5
o`0003Gooo]Z1?l0000JoookJP00;_oonfX5o`0001Sooo]Z1?l0001PoookJPCo0000=OoonfX4o`00
063ooo]Z1?l0000eoookJPCo0000H?oonfX4o`0003Gooo]Z1?l0000JoookJP00;_oonfX5o`0001So
oo]Z1?l0001PoookJPCo0000=OoonfX4o`00063ooo]Z1?l0000doookJPGo0000H?oonfX4o`0003Co
oo]Z1Ol0000JoookJP00;_oonfX5o`0001Oooo]Z1Ol0001PoookJPCo0000=?oonfX5o`00063ooo]Z
1?l0000doookJPGo0000H?oonfX4o`0003Cooo]Z1Ol0000JoookJP00;_oonfX5o`0001Oooo]Z1Ol0
001PoookJPGo0000<ooonfX4o`00067ooo]Z1?l0000doookJPCo0000HOoonfX4o`0003Cooo]Z1?l0
000KoookJP00;_oonfX5o`0001Oooo]Z1?l0001QoookJPGo0000<ooonfX4o`00067ooo]Z1Ol0000c
oookJPCo0000HOoonfX5o`0003?ooo]Z1?l0000KoookJP00;_oonfX5o`0001Oooo]Z1?l0001Roook
JPCo0000<ooonfX4o`0006;ooo]Z1?l0000coookJPCo0000HOoonfX5o`0003?ooo]Z1?l0000Koook
JP00;_oonfX5o`0001Oooo]Z1?l0001RoookJPCo0000<ooonfX4o`0006;ooo]Z1?l0000coookJPCo
0000H_oonfX4o`0003?ooo]Z1?l0000KoookJP00;_oonfX5o`0001Kooo]Z1Ol0001RoookJPCo0000
<_oonfX5o`0006;ooo]Z1?l0000boookJPGo0000H_oonfX4o`0003;ooo]Z1Ol0000KoookJP004Ooo
nfX5o`00O`Cooo]Z0ol007l3oookJPGo001o2OoonfX5o`0001Kooo]Z1Ol0001RoookJPGo0000<Ooo
nfX5o`0006;ooo]Z1?l0000boookJPGo0000H_oonfX4o`0003;ooo]Z1Ol0000KoookJP004?oonfX7
o`00O`?ooo]Z0ol007l2oookJPOo001o2?oonfX5o`0001Kooo]Z1?l0001SoookJPGo0000<OoonfX4
o`0006?ooo]Z1Ol0000aoookJPCo0000HooonfX4o`0003;ooo]Z1?l0000LoookJP004?oonfX3o`00
O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo
001oo`00O`Sooo]Z1Ol0000FoookJPCo0000I?oonfX4o`00037ooo]Z1?l0001SoookJPGo0000<Ooo
nfX4o`0006?ooo]Z1Ol0000aoookJPCo00007?oonfX000oooo]Z0ol007l3oookJP?o001o1_oonfX3
o`00O`?ooo]Z0ol007l7oookJPGo00005_oonfX4o`0006Cooo]Z1?l0000aoookJPCo0000I?oonfX4
o`00037ooo]Z1?l0001SoookJPGo0000<OoonfX4o`0001cooo]Z000?oookJP?o001o0ooonfX3o`00
O`cooo]Z0ol007l7oookJPKo00005OoonfX4o`0006Cooo]Z1?l0000aoookJPCo0000I?oonfX4o`00
033ooo]Z1Ol0001ToookJPCo0000<?oonfX5o`0001cooo]Z000?oookJP?o001o0ooonfX3o`00O`co
oo]Z0ol007l7oookJPGo00005OoonfX5o`0006Cooo]Z1?l0000`oookJPGo0000I?oonfX4o`00033o
oo]Z1Ol0001ToookJPCo0000<?oonfX5o`0001cooo]Z000?oookJP?o001o0ooonfX3o`00O`Oooo]Z
0_l007l2oookJPCo001o1ooonfX5o`0001Gooo]Z1Ol0001ToookJPGo0000;ooonfX4o`0006Gooo]Z
1Ol0000_oookJPCo0000IOoonfX4o`00033ooo]Z1?l0000MoookJP003ooonfX3o`00O`?ooo]Z0ol0
07l7oookJPOo001o2?oonfX5o`0001Gooo]Z1?l0001UoookJPGo0000;ooonfX4o`0006Gooo]Z1Ol0
000_oookJPCo0000IOoonfX5o`0002oooo]Z1?l0000MoookJP003ooonfX3o`00O`?ooo]Z0ol007l7
oookJPKo001o2OoonfX5o`0001Gooo]Z1?l0001VoookJPCo0000;ooonfX4o`0006Kooo]Z1?l0000_
oookJPCo0000IOoonfX5o`0002oooo]Z1?l0000MoookJP003ooonfX3o`00O`?ooo]Z0ol007l7oook
JP;o001o3OoonfX5o`0001Gooo]Z1?l0001VoookJPCo0000;ooonfX4o`0006Kooo]Z1?l0000_oook
JPCo0000I_oonfX4o`0002kooo]Z1Ol0000MoookJP004?oonfX3o`00O`04oookJ_l007oo001oo`00
O`Sooo]Z0_l007l=oookJPGo00005?oonfX5o`0006Kooo]Z1?l0000^oookJPGo0000I_oonfX4o`00
02kooo]Z1Ol0001VoookJPCo0000;_oonfX5o`0001gooo]Z000@oookJPOo001o2OoonfX7o`00O`Oo
oo]Z1Ol0000DoookJPGo0000I_oonfX5o`0002gooo]Z1Ol0001VoookJPCo0000;_oonfX4o`0006Oo
oo]Z1?l0000^oookJPCo00007_oonfX0017ooo]Z1Ol007l:oookJPOo001o1ooonfX5o`0001Cooo]Z
1?l0001WoookJPGo0000;OoonfX4o`0006Oooo]Z1Ol0000]oookJPCo0000IooonfX5o`0002gooo]Z
1?l0000NoookJP00;_oonfX5o`0001Cooo]Z1?l0001XoookJPCo0000;OoonfX4o`0006Sooo]Z1?l0
000]oookJPCo0000IooonfX5o`0002gooo]Z1?l0000NoookJP00;_oonfX5o`0001Cooo]Z1?l0001X
oookJPCo0000;OoonfX4o`0006Sooo]Z1?l0000]oookJPCo0000J?oonfX4o`0002gooo]Z1?l0000N
oookJP00;_oonfX5o`0001?ooo]Z1Ol0001XoookJPCo0000;?oonfX5o`0006Sooo]Z1?l0000/oook
JPGo0000J?oonfX4o`0002cooo]Z1Ol0000NoookJP00;_oonfX5o`0001?ooo]Z1Ol0001XoookJPGo
0000:ooonfX5o`0006Sooo]Z1?l0000/oookJPGo0000J?oonfX4o`0002cooo]Z1Ol0000NoookJP00
;_oonfX5o`0001?ooo]Z1?l0001YoookJPGo0000:ooonfX4o`0006Wooo]Z1Ol0000[oookJPCo0000
JOoonfX5o`0002_ooo]Z1?l0000OoookJP00;_oonfX5o`0001?ooo]Z1?l0001ZoookJPCo0000:ooo
nfX4o`0006Wooo]Z1Ol0000[oookJPCo0000JOoonfX5o`0002_ooo]Z1?l0000OoookJP00;_oonfX5
o`0001?ooo]Z1?l0001ZoookJPCo0000:ooonfX4o`0006[ooo]Z1?l0000[oookJPCo0000J_oonfX4
o`0002_ooo]Z1?l0000OoookJP00;_oonfX5o`0001;ooo]Z1Ol0001ZoookJPCo0000:_oonfX5o`00
06[ooo]Z1?l0000ZoookJPGo0000J_oonfX4o`0002[ooo]Z1Ol0000OoookJP00;_oonfX5o`0001;o
oo]Z1Ol0001ZoookJPGo0000:OoonfX5o`0006[ooo]Z1?l0000ZoookJPGo0000J_oonfX4o`0002[o
oo]Z1Ol0000OoookJP00;_oonfX5o`0001;ooo]Z1?l0001[oookJPGo0000:OoonfX4o`0006_ooo]Z
1Ol0000YoookJPCo0000JooonfX5o`0002Wooo]Z1?l0000PoookJP00;_oonfX5o`0001;ooo]Z1?l0
001/oookJPCo0000:OoonfX4o`0006_ooo]Z1Ol0000YoookJPCo0000JooonfX5o`0002Wooo]Z1?l0
000PoookJP00;_oonfX5o`0001;ooo]Z1?l0001/oookJPCo0000:OoonfX4o`0006cooo]Z1?l0000Y
oookJPCo0000K?oonfX4o`0002Wooo]Z1?l0000PoookJP00;_oonfX5o`00017ooo]Z1Ol0001/oook
JPCo0000:?oonfX5o`0006cooo]Z1?l0000XoookJPGo0000K?oonfX4o`0002Sooo]Z1Ol0000Poook
JP00;_oonfX5o`00017ooo]Z1Ol0001/oookJPGo00009ooonfX5o`0006cooo]Z1Ol0000WoookJPCo
0000KOoonfX4o`0002Sooo]Z1?l0000QoookJP00;_oonfX5o`00017ooo]Z1?l0001]oookJPGo0000
9ooonfX4o`0006gooo]Z1Ol0000WoookJPCo0000KOoonfX5o`0002Oooo]Z1?l0000QoookJP00;_oo
nfX5o`00017ooo]Z1?l0001^oookJPCo00009ooonfX4o`0006kooo]Z1?l0000WoookJPCo0000KOoo
nfX5o`0002Oooo]Z1?l0000QoookJP00;_oonfX5o`00013ooo]Z1Ol0001^oookJPCo00009_oonfX5
o`0006kooo]Z1?l0000VoookJPGo0000K_oonfX4o`0002Kooo]Z1Ol0000QoookJP00;_oonfX5o`00
013ooo]Z1Ol0001^oookJPGo00009OoonfX5o`0006kooo]Z1?l0000VoookJPGo0000K_oonfX4o`00
02Kooo]Z1Ol0000QoookJP00;_oonfX5o`00013ooo]Z1?l0001_oookJPGo00009OoonfX4o`0006oo
oo]Z1Ol0000UoookJPCo0000KooonfX4o`0002Kooo]Z1?l0000RoookJP00;_oonfX5o`00013ooo]Z
1?l0001`oookJPCo00009OoonfX4o`0006oooo]Z1Ol0000UoookJPCo0000KooonfX5o`0002Gooo]Z
1?l0000RoookJP00;_oonfX5o`00013ooo]Z1?l0001`oookJPCo00009OoonfX4o`00073ooo]Z1?l0
000UoookJPCo0000KooonfX5o`0002Gooo]Z1?l0000RoookJP00;_oonfX5o`0000oooo]Z1Ol0001`
oookJPCo00009?oonfX5o`00073ooo]Z1?l0000ToookJPGo0000L?oonfX4o`0002Cooo]Z1Ol0000R
oookJP00;_oonfX5o`0000oooo]Z1Ol0001`oookJPGo00008ooonfX5o`00073ooo]Z1?l0000Toook
JPGo0000L?oonfX4o`0002Cooo]Z1Ol0000RoookJP00;_oonfX5o`0000oooo]Z1?l0001aoookJPGo
00008ooonfX4o`00077ooo]Z1Ol0000SoookJPCo0000LOoonfX5o`0002?ooo]Z1?l0000SoookJP00
;_oonfX5o`0000oooo]Z1?l0001boookJPCo00008ooonfX4o`0007;ooo]Z1?l0000SoookJPCo0000
LOoonfX5o`0002?ooo]Z1?l0000SoookJP00;_oonfX5o`0000kooo]Z1Ol0001boookJPCo00008_oo
nfX5o`0007;ooo]Z1?l0000RoookJPGo0000L_oonfX4o`0002;ooo]Z1Ol0000SoookJP00;_oonfX5
o`0000kooo]Z1Ol0001boookJPGo00008OoonfX5o`0007;ooo]Z1?l0000RoookJPGo0000L_oonfX4
o`0002;ooo]Z1Ol0000SoookJP00;_oonfX5o`0000kooo]Z1?l0001coookJPGo00008OoonfX4o`00
07?ooo]Z1Ol0000QoookJPCo0000LooonfX4o`0002;ooo]Z1?l0000ToookJP00;_oonfX5o`0000ko
oo]Z1?l0001doookJPCo00008OoonfX4o`0007?ooo]Z1Ol0000QoookJPCo0000LooonfX5o`00027o
oo]Z1?l0000ToookJP00;_oonfX5o`0000gooo]Z1Ol0001doookJPCo00008?oonfX5o`0007Cooo]Z
1?l0000QoookJPCo0000M?oonfX4o`00023ooo]Z1Ol0000ToookJP00;_oonfX5o`0000gooo]Z1Ol0
001doookJPGo00007ooonfX5o`0007Cooo]Z1?l0000PoookJPGo0000M?oonfX4o`00023ooo]Z1Ol0
000ToookJP00;_oonfX5o`0000gooo]Z1?l0001eoookJPGo00007ooonfX4o`0007Gooo]Z1Ol0000O
oookJPCo0000MOoonfX4o`00023ooo]Z1?l0000UoookJP00;_oonfX5o`0000gooo]Z1?l0001foook
JPCo00007ooonfX4o`0007Gooo]Z1Ol0000OoookJPCo0000MOoonfX5o`0001oooo]Z1?l0000Uoook
JP00;_oonfX5o`0000cooo]Z1Ol0001foookJPCo00007_oonfX5o`0007Kooo]Z1?l0000OoookJPCo
0000MOoonfX5o`0001oooo]Z1?l0000UoookJP00;_oonfX5o`0000cooo]Z1Ol0001foookJPGo0000
7OoonfX5o`0007Kooo]Z1?l0000NoookJPGo0000M_oonfX4o`0001kooo]Z1Ol0000UoookJP00;_oo
nfX5o`0000cooo]Z1?l0001goookJPGo00007OoonfX4o`0007Oooo]Z1Ol0000MoookJPCo0000Mooo
nfX4o`0001kooo]Z1?l0000VoookJP00;_oonfX5o`0000cooo]Z1?l0001hoookJPCo00007OoonfX4
o`0007Oooo]Z1Ol0000MoookJPCo0000MooonfX5o`0001gooo]Z1?l0000VoookJP00;_oonfX5o`00
00_ooo]Z1Ol0001hoookJPCo00007?oonfX5o`0007Sooo]Z1?l0000LoookJPGo0000N?oonfX4o`00
01cooo]Z1Ol0000VoookJP00;_oonfX5o`0000_ooo]Z1Ol0001hoookJPGo00006ooonfX5o`0007So
oo]Z1?l0000LoookJPGo0000N?oonfX4o`0001cooo]Z1Ol0000VoookJP00;_oonfX5o`0000_ooo]Z
1?l0001ioookJPGo00006ooonfX4o`0007Wooo]Z1Ol0000KoookJPCo0000NOoonfX5o`0001_ooo]Z
1?l0000WoookJP00;_oonfX5o`0000_ooo]Z1?l0001joookJPCo00006ooonfX4o`0007Wooo]Z1Ol0
000KoookJPCo0000NOoonfX5o`0001_ooo]Z1?l0000WoookJP00;_oonfX5o`0000[ooo]Z1Ol0001j
oookJPCo00006_oonfX5o`0007[ooo]Z1?l0000JoookJPGo0000N_oonfX4o`0001[ooo]Z1Ol0000W
oookJP00;_oonfX5o`0000[ooo]Z1Ol0001joookJPGo00006OoonfX5o`0007[ooo]Z1Ol0000Ioook
JPGo0000N_oonfX4o`0001[ooo]Z1Ol0000WoookJP00;_oonfX5o`0000[ooo]Z1?l0001loookJPCo
00006OoonfX4o`0007_ooo]Z1Ol0000IoookJPCo0000NooonfX5o`0001Wooo]Z1?l0000XoookJP00
;_oonfX5o`0000Wooo]Z1Ol0001loookJPCo00006?oonfX5o`0007cooo]Z1?l0000HoookJPGo0000
NooonfX5o`0001Sooo]Z1Ol0000XoookJP00;_oonfX5o`0000Wooo]Z1Ol0001loookJPGo00005ooo
nfX5o`0007cooo]Z1?l0000HoookJPGo0000O?oonfX4o`0001Sooo]Z1Ol0000XoookJP00;_oonfX5
o`0000Wooo]Z1?l0001moookJPGo00005ooonfX4o`0007gooo]Z1Ol0000GoookJPCo0000OOoonfX5
o`0001Oooo]Z1?l0000YoookJP00;_oonfX5o`0000Sooo]Z1Ol0001noookJPCo00005_oonfX5o`00
07kooo]Z1?l0000GoookJPCo0000OOoonfX5o`0001Oooo]Z1?l0000YoookJP00;_oonfX5o`0000So
oo]Z1Ol0001noookJPGo00005OoonfX5o`0007kooo]Z1?l0000FoookJPGo0000O_oonfX4o`0001Ko
oo]Z1Ol0000YoookJP00;_oonfX5o`0000Sooo]Z1?l0001ooookJPGo00005OoonfX4o`0007oooo]Z
1Ol0000EoookJPCo0000OooonfX5o`0001Gooo]Z1Ol0000YoookJP00;_oonfX5o`0000Oooo]Z1Ol0
0020oookJPCo00005?oonfX5o`0007oooo]Z1Ol0000EoookJPCo0000OooonfX5o`0001Gooo]Z1?l0
000ZoookJP00;_oonfX5o`0000Oooo]Z1Ol00020oookJPGo00004ooonfX5o`00083ooo]Z1?l0000D
oookJPGo0000P?oonfX4o`0001Cooo]Z1Ol0000ZoookJP00;_oonfX5o`0000Oooo]Z1?l00021oook
JPGo00004ooonfX4o`00087ooo]Z1Ol0000CoookJPCo0000POoonfX5o`0001?ooo]Z1Ol0000Zoook
JP00;_oonfX5o`0000Kooo]Z1Ol00022oookJPCo00004_oonfX5o`00087ooo]Z1Ol0000BoookJPGo
0000POoonfX5o`0001?ooo]Z1?l0000[oookJP00;_oonfX5o`0000Kooo]Z1Ol00022oookJPGo0000
4OoonfX5o`0008;ooo]Z1Ol0000AoookJPGo0000P_oonfX4o`0001;ooo]Z1Ol0000[oookJP00;_oo
nfX5o`0000Gooo]Z1Ol00023oookJPGo00004OoonfX4o`0008?ooo]Z1Ol0000AoookJPCo0000Pooo
nfX5o`00017ooo]Z1Ol0000[oookJP00;_oonfX5o`0000Gooo]Z1Ol00024oookJPGo00003ooonfX5
o`0008Cooo]Z1?l0000@oookJPGo0000PooonfX5o`00013ooo]Z1Ol0000/oookJP00;_oonfX5o`00
00Gooo]Z1?l00025oookJPGo00003ooonfX5o`0008Cooo]Z1Ol0000?oookJPGo0000Q?oonfX5o`00
00oooo]Z1Ol0000/oookJP00;_oonfX5o`0000Cooo]Z1Ol00026oookJPGo00003OoonfX5o`0008Go
oo]Z1Ol0000>oookJPGo0000QOoonfX5o`0000oooo]Z1?l0000]oookJP00;_oonfX5o`0000Cooo]Z
1Ol00026oookJPGo00003OoonfX5o`0008Kooo]Z1Ol0000=oookJPGo0000Q_oonfX4o`0000kooo]Z
1Ol0000]oookJP00;_oonfX5o`0000?ooo]Z1Ol00028oookJPGo00002ooonfX5o`0008Oooo]Z1Ol0
000<oookJPGo0000QooonfX5o`0000gooo]Z1?l0000^oookJP00;_oonfX5o`0000?ooo]Z1Ol00028
oookJPGo00002ooonfX5o`0008Sooo]Z1Ol0000;oookJPGo0000QooonfX5o`0000cooo]Z1Ol0000^
oookJP00;_oonfX5o`0000;ooo]Z1Ol0002:oookJPGo00002OoonfX5o`0008Wooo]Z1Ol0000:oook
JPGo0000ROoonfX5o`0000_ooo]Z1Ol0000^oookJP00;_oonfX5o`000003oookJ_l0003o000000?o
0000RooonfX5o`0000Sooo]Z1_l0002:oookJPGo00002OoonfX5o`0008Wooo]Z1_l00009oookJPGo
0000;ooonfX002;ooo]Z0ol007l9oookJP_o0000S?oonfX5o`0000Oooo]Z1Ol0002;oookJPKo0000
1ooonfX5o`0008_ooo]Z1Ol00008oookJPGo0000<?oonfX002;ooo]Z0ol007l9oookJP[o0000SOoo
nfX6o`0000Gooo]Z1Ol0002=oookJPGo00001_oonfX6o`0008cooo]Z1Ol00007oookJPGo0000<?oo
nfX002;ooo]Z0ol007l9oookJPWo0000SooonfX6o`0000;ooo]Z1ol0002>oookJPKo00000ooonfX6
o`0008gooo]Z1_l00005oookJPGo0000<OoonfX002;ooo]Z0ol007l9oookJPWo0000T?oonfX=o`00
08oooo]Z3_l0002?oookJPKo00000_oonfX7o`00037ooo]Z000RoookJP?o001o2OoonfX8o`0009;o
oo]Z2ol0002AoookJPco0000TOoonfX=o`0003;ooo]Z000RoookJP?o001o2OoonfX6o`0009Gooo]Z
2Ol0002CoookJP[o0000TooonfX;o`0003?ooo]Z000RoookJP?o001o2OoonfX5o`0009Oooo]Z1_l0
002GoookJPOo0000UOoonfX9o`0003Cooo]Z000RoookJP?o001o2OoonfX5o`000?oooo]Zd_oonfX6
o`0003Kooo]Z000RoookJP?o001o2OoonfX5o`000?oooo]ZoooonfX?oookJP007ooonfX6o`00O`Wo
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX001oooo]Z1_l007l9oookJPGo0000oooonf[ooookJPoooo]Z
000QoookJPCo001o2OoonfX5o`000?oooo]ZoooonfX?oookJP008_oonfX3o`00O`Wooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX00?oooo]ZoooonfY2oookJP00oooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oo
oo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX0
0?oooo]ZoooonfY2oookJP00\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1941.8, -1.15883, 40.0401, \
0.0065342}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
Second-Order Linear Homogeneous ODEs with Constant Coefficients, \
Analysis of the Solution Basis\
\>", "Subtitle"],

Cell["\<\
Analysis of basis solutions to  y'' + \[Beta]y' + \[Gamma]y = 0 in \
terms of constant coefficients \[Beta] and \[Gamma]\
\>", "Text",
  CellTags->"mmtag:21:second_order_odes__characterizing_solution_behavior"]
}, Open  ]],

Cell[CellGroupData[{

Cell["First write a general expression for this homogeneous ODE:", \
"Subsubsection"],

Cell[BoxData[
    \(TheODE[function_, \ var_]\  := \ 
      D[function[var], {var, 2}]\  + \ \[Beta]\ D[function[var], 
            var]\  + \ \[Gamma]\ function[var]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TheODE[y, x]\)], "Input"],

Cell[BoxData[
    RowBox[{\(\[Gamma]\ y[x]\), "+", 
      RowBox[{"\[Beta]", " ", 
        RowBox[{
          SuperscriptBox["y", "\[Prime]",
            MultilineFunction->None], "[", "x", "]"}]}], "+", 
      RowBox[{
        SuperscriptBox["y", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "x", "]"}]}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Guess a solution and substitute it into the left-hand side of the \
ODE:\
\>", "Subsubsection"],

Cell[BoxData[
    \(TheGuess[x_]\  := \ Exp[\[Lambda]\ x]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TheODE[TheGuess, x]\)], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(x\ \[Lambda]\)\ \[Gamma] + \[ExponentialE]\^\(x\ \
\[Lambda]\)\ \[Beta]\ \[Lambda] + \[ExponentialE]\^\(x\ \[Lambda]\)\ \
\[Lambda]\^2\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
This will be a solution when the resulting quadratic expression in \
\[Lambda] is equal to 0:\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LambaSolution\  = \ 
      Solve[TheODE[TheGuess, x] \[Equal] 0, \[Lambda]]\)], "Input"],

Cell[BoxData[
    \({{\[Lambda] \[Rule] 
          1\/2\ \((\(-\[Beta]\) - \@\(\[Beta]\^2 - 4\ \[Gamma]\))\)}, {\
\[Lambda] \[Rule] 
          1\/2\ \((\(-\[Beta]\) + \@\(\[Beta]\^2 - 4\ \[Gamma]\))\)}}\)], \
"Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The two roots \[Lambda]+ and \[Lambda]+ are:", "Subsubsection",
  CellTags->
  "mmtag:21:second_order_odes__general solution_for_constant_coefficients"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LambdaPlus = \ \[Lambda] /. \(Flatten[
            LambaSolution]\)[\([2]\)]\)], "Input"],

Cell[BoxData[
    \(1\/2\ \((\(-\[Beta]\) + \@\(\[Beta]\^2 - 4\ \[Gamma]\))\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LambdaMinus = \ \[Lambda] /. \(Flatten[
            LambaSolution]\)[\([1]\)]\)], "Input"],

Cell[BoxData[
    \(1\/2\ \((\(-\[Beta]\) - \@\(\[Beta]\^2 - 4\ \[Gamma]\))\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Assuming that \[Beta] and \[Gamma] are real, the solutions can be \
characterized by the roots of the quadratic equation. That is, our solution \
is known to be ",
  Cell[BoxData[
      \(TraditionalForm\`e\^\[Lambda]t\)]],
  ":  the solution monotonically grows or shrinks in time if the roots are \
real-positive or real-negative. The condition that the roots are real is \
\[Gamma] <",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\[Beta]\^2\)\)\/4\)]],
  "\n\nIf the roots have an imaginary part, the solutions can oscillate. \
Whether the oscillation amplitudes grow or shrink depends on whether the real \
part of \[Lambda] is positive or negative."
}], "Text"]
}, Open  ]],

Cell["\<\
We now do some calculations to make an annotated map on the \[Beta]\
\[Dash]\[Gamma] plane of solution scenarios for the \[Lambda] values:\
\>", \
"Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ComplexReal\  = \ 
      Plot[\[Beta]^2/4, {\[Beta], \(-1\), 1}, 
        AxesLabel \[Rule] {"\<\[Beta]\>", "\<\[Gamma]\>"}]\)], "Input",
  CellTags->"mmtag:21:graphics__building_piece_by_piece"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.0147151 2.35442 [
[.02381 .00222 -13.4688 -20 ]
[.02381 .00222 13.4688 0 ]
[.2619 .00222 -20.9688 -20 ]
[.2619 .00222 20.9688 0 ]
[.7381 .00222 -14.5 -20 ]
[.7381 .00222 14.5 0 ]
[.97619 .00222 -7 -20 ]
[.97619 .00222 7 0 ]
[1.025 .01472 0 -10 ]
[1.025 .01472 15.9375 10 ]
[.4875 .13244 -39 -10 ]
[.4875 .13244 0 10 ]
[.4875 .25016 -29 -10 ]
[.4875 .25016 0 10 ]
[.4875 .36788 -39 -10 ]
[.4875 .36788 0 10 ]
[.4875 .4856 -29 -10 ]
[.4875 .4856 0 10 ]
[.4875 .60332 -39 -10 ]
[.4875 .60332 0 10 ]
[.5 .64303 -7.28125 0 ]
[.5 .64303 7.28125 20 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .02097 L
s
gsave
.02381 .00222 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .01472 m
.2619 .02097 L
s
gsave
.2619 .00222 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .01472 m
.7381 .02097 L
s
gsave
.7381 .00222 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .01472 m
.97619 .02097 L
s
gsave
.97619 .00222 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.01 w
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
%%BeginResource: font Helvetica-Bold-MISO
%%BeginFont: Helvetica-Bold-MISO
/Helvetica-Bold /Helvetica-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
0.000 0.000 rmoveto
64.750 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(b) show
74.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.5 .13244 m
.50625 .13244 L
s
gsave
.4875 .13244 -100 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.05) show
1.000 setlinewidth
grestore
.5 .25016 m
.50625 .25016 L
s
gsave
.4875 .25016 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.1) show
1.000 setlinewidth
grestore
.5 .36788 m
.50625 .36788 L
s
gsave
.4875 .36788 -100 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.15) show
1.000 setlinewidth
grestore
.5 .4856 m
.50625 .4856 L
s
gsave
.4875 .4856 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.5 .60332 m
.50625 .60332 L
s
gsave
.4875 .60332 -100 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .03826 m
.50375 .03826 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .08535 m
.50375 .08535 L
s
.5 .10889 m
.50375 .10889 L
s
.5 .15598 m
.50375 .15598 L
s
.5 .17952 m
.50375 .17952 L
s
.5 .20307 m
.50375 .20307 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .2737 m
.50375 .2737 L
s
.5 .29724 m
.50375 .29724 L
s
.5 .32079 m
.50375 .32079 L
s
.5 .34433 m
.50375 .34433 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .41497 m
.50375 .41497 L
s
.5 .43851 m
.50375 .43851 L
s
.5 .46205 m
.50375 .46205 L
s
.5 .50914 m
.50375 .50914 L
s
.5 .53269 m
.50375 .53269 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57977 m
.50375 .57977 L
s
.01 w
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -68.2812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
%%BeginResource: font Helvetica-Bold-MISO
%%BeginFont: Helvetica-Bold-MISO
/Helvetica-Bold /Helvetica-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
0.000 0.000 rmoveto
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(g) show
73.562 19.000 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .60332 m
.06244 .51168 L
.10458 .42058 L
.14415 .34341 L
.18221 .27686 L
.22272 .21429 L
.26171 .16211 L
.30316 .11529 L
.34309 .07863 L
.3815 .05117 L
.40095 .04018 L
.42237 .03036 L
.44268 .02324 L
.45178 .02075 L
.46172 .01852 L
.4671 .01752 L
.4721 .01674 L
.47727 .01606 L
.48196 .01556 L
.48658 .01518 L
.4887 .01505 L
.49093 .01493 L
.49332 .01483 L
.49438 .0148 L
.49552 .01477 L
.49675 .01474 L
.49789 .01473 L
.49859 .01472 L
.49925 .01472 L
.50049 .01472 L
.50163 .01472 L
.50286 .01474 L
.50401 .01476 L
.50508 .01478 L
.50754 .01486 L
.51014 .01498 L
.51268 .01513 L
.51504 .0153 L
.5204 .0158 L
.5293 .01694 L
.53882 .01863 L
.54906 .02096 L
.56016 .02411 L
.58032 .03146 L
.60019 .04077 L
.62123 .05287 L
.65912 .08044 L
.69946 .11799 L
.73829 .1621 L
.77956 .21759 L
Mistroke
.81932 .2794 L
.85757 .34659 L
.89827 .42644 L
.93745 .51144 L
.97619 .60332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00;_oonfX3o`00OfSooo]Z1Ol007l4oook
JP?o001o0ooonfX5o`00Om3ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00Of[ooo]Z0ol007m2oook
JP00;_oonfX3o`00OfOooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Olkooo]Z1ol007l3oookJP?o
001o0_oonfX7o`00OfWooo]Z0ol007m2oookJP00;_oonfX3o`00OfOooo]Z0ol007l01?oonf[o001o
o`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007o>oook
JP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Z
o`00Ool007oo001oJOoonfX3o`00Od;ooo]Z000NoookJP[o001o1_oonfX3o`00Oe[ooo]Z2_l007l2
oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001oc?oonfX3o`00O`?ooo]Z0ol007l6
oookJP?o001o0ooonfX3o`00OfSooo]Z0ol007m2oookJP007_oonfX:o`00O`Kooo]Z0ol007mJoook
JP[o001o0_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001oc?oonfX3o`00O`?ooo]Z0ol007l<oook
JP?o001oJ?oonfX3o`00Od;ooo]Z000^oookJP?o001oI_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o
001oc?oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001oJ?oonfX3o`00Od;ooo]Z000^oookJP?o001o
I_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00Olcooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`;ooo]Z1?l007mXoookJP?o001o@_oonfX002kooo]Z0ol007mVoookJP?o001o0ooo
nfX3o`00O`Oooo]Z1ol007o=oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007mYoookJP?o001o@_oo
nfX002kooo]Z0ol007mVoookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007o>oookJP?o001o0ooonfX3
o`00O`Oooo]Z1_l007mZoookJP?o001o@_oonfX002_ooo]Z1_l007mVoookJP?o001o0ooonfX3o`00
O`Oooo]Z0_l007oBoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007m[oookJPKo001o@_oonfX002_o
oo]Z1_l007mWoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Om?ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l8oookJP;o001oJooonfX6o`00Od;ooo]Z000]oookJPCo001oIooonfX7o`00
O`Wooo]Z1ol007mQoookJPCo0000J?oonfX7o`00O`Wooo]Z1ol007mWoookJPCo001o@_oonfX002ko
oo]Z0ol007mXoookJPGo001o2_oonfX7o`00Of7ooo]Z1?l0001YoookJPGo001o2_oonfX7o`00OfSo
oo]Z0ol007lHoookJP04odA2NOl007oo001ookZhKbKooo]Z003ooookJQ7ooo]Z1?l0003ooookJP?o
oo]Z00Cok^Y[o`00Ool007ooA49i9_oonfX00?oooo]Z4OoonfX4o`000?oooo]Z1?oonfX01?mgMGGo
001oo`00OooMfF`UoookJP00oooonfXAoookJPCo0000oooonfX4oookJP04omgIK?l007oo001oohN5
LbGooo]Z003ooookJQ7ooo]Z1?l0003ooookJPGooo]Z00Co411mo`00Oolb<W[oEE=g0_l007l00omE
DgOok^Y[oookJP0OoookJP00oooonfXAoookJPCo0000oooonfX5oookJP09odA2NOl007oo001oodA2
NOoonf[o<S9jo`00OolQ8Gcok^Y[01oooo]Z003ooookJQ7ooo]Z1?l0003ooookJPGooo]Z00KoQhEc
o`00Ool007ooMgEeoookJ_nYYg42o`00O`03ogMeMOoonf[ooo]Z01gooo]Z000JoookJ_oo0000lOl0
000>oookJP06olc8K_l007oo001oofITM_oonf[ok^Y[0_l007l00ol@47gooo]ZoookJP0MoookJP00
6_oonf[oo`000?7o00003ooonfX2o`00O`03oc8bN_oonf[ooo]Z00?o001o7ooonfX001[ooo]Zool0
003ao`0000oooo]Z00?oA49io`00Ool007l00_oonfX2o`00O`03oa0@OOoonf[ooo]Z01gooo]Z000J
oookJ_oo0000lOl0000?oookJP05ohN5Lol007oo001ookZhKon7QG<00_l007l00on7QG?ooo]Zoook
JP0MoookJP00:?oonfX00ol0003ooo]ZoookJP1boookJP03o`000?oonf[ooo]Z05?ooo]Z3ol0000>
oookJPCo00003ooonfX@o`0005Cooo]Z00?o0000oookJ_oonfX0L_oonfX00ol0003ooo]ZoookJP0J
oookJP03olc8K_l007oo001o00?o001o00?o8B5lonkZJooonfX07_oonfX00?3ooo]Z3_l0000Boook
JPCo00005?oonfX>o`000>Cooo]Z0_l007l01_m4@WWooo]ZonkZJolQ8Gco001oolc8KQkooo]Z003]
oookJPco00005ooonfX4o`0001Wooo]Z2ol0003RoookJP03odA2NOl007oo001o00;ooo]Z00?ogMU/
o`00Oolb<WX07_oonfX00>[ooo]Z2ol0000KoookJPCo00007OoonfX:o`000=oooo]Z00Co^[Q_o`00
Ool007oo^[Q_0_oonfX2o`00Oakooo]Z003XoookJP[o00007_oonfX4o`00023ooo]Z2Ol0003Noook
JP07ogMeMOl007oo8B5lonkZJonj^6oo001ooa0@O@0NoookJP00iOoonfX:o`00027ooo]Z1?l0000R
oookJPWo0000gOoonfX01_nYYg7o<S9jo`00Ool007ooA49iolc8KQkooo]Z003SoookJPWo00009?oo
nfX4o`0002Gooo]Z2?l0003ooookJP00hOoonfX9o`0002Kooo]Z1?l0000WoookJPOo0000o_oonfX0
0=oooo]Z2?l0000YoookJPGo0000:?oonfX7o`000?cooo]Z003NoookJPOo0000:ooonfX4o`0002_o
oo]Z1ol0003joookJP00g?oonfX7o`0002gooo]Z1?l0000/oookJPSo0000n?oonfX00=_ooo]Z1_l0
000_oookJPCo0000;_oonfX9o`000?Gooo]Z003IoookJPOo0000<?oonfX4o`00033ooo]Z2Ol0003c
oookJP00f?oonfX6o`0003;ooo]Z1?l0000boookJPWo0000lOoonfX00=Kooo]Z1ol0000coookJPCo
0000=OoonfX8o`000>oooo]Z003EoookJPKo0000=OoonfX4o`0003Oooo]Z1ol0003^oookJP00dooo
nfX7o`0003Kooo]Z1?l0000ioookJPKo0000kOoonfX00=;ooo]Z1_l0000hoookJPCo0000>ooonfX6
o`000>_ooo]Z003@oookJPOo0000>OoonfX4o`0003cooo]Z1_l0003ZoookJP00cooonfX6o`0003_o
oo]Z1?l0000moookJPKo0000jOoonfX00<gooo]Z1ol0000loookJPGo0000?_oonfX5o`000>Sooo]Z
003<oookJPKo0000?_oonfX4o`00043ooo]Z1_l0003VoookJP00booonfX6o`0003oooo]Z1?l00011
oookJPKo0000iOoonfX00<Wooo]Z1_l00011oookJPCo0000@_oonfX6o`000>Cooo]Z0038oookJPKo
0000@_oonfX4o`0004Cooo]Z1_l0003RoookJP00a_oonfX7o`0004?ooo]Z1?l00015oookJPKo0000
hOoonfX00<Gooo]Z1_l00015oookJPCo0000A_oonfX6o`000>3ooo]Z0033oookJPOo0000A_oonfX4
o`0004Sooo]Z1Ol0003OoookJP00`_oonfX6o`0004Sooo]Z1?l00019oookJPKo0000gOoonfX00<7o
oo]Z1_l00019oookJPCo0000B_oonfX6o`000=cooo]Z0030oookJPGo0000BooonfX4o`0004_ooo]Z
1_l0003KoookJP00_ooonfX5o`0004cooo]Z1Ol0001<oookJPGo0000f_oonfX00;kooo]Z1Ol0001=
oookJPCo0000C_oonfX5o`000=Wooo]Z002moookJPGo0000C_oonfX4o`0004oooo]Z1Ol0003Hoook
JP00_?oonfX5o`0004oooo]Z1?l0001@oookJPGo0000eooonfX00;_ooo]Z1Ol0001@oookJPCo0000
DOoonfX5o`000=Kooo]Z002ioookJPKo0000DOoonfX4o`0005;ooo]Z1Ol0003EoookJP00^?oonfX6
o`0005;ooo]Z1?l0001CoookJPKo0000dooonfX00;Oooo]Z1_l0001CoookJPCo0000E?oonfX6o`00
0=;ooo]Z002foookJPGo0000EOoonfX4o`0005Gooo]Z1_l0003AoookJP00]OoonfX5o`0005Kooo]Z
1?l0001GoookJPGo0000d?oonfX00;Cooo]Z1Ol0001GoookJPCo0000F?oonfX5o`000<oooo]Z002c
oookJPGo0000F?oonfX4o`0005Wooo]Z1Ol0003>oookJP00/_oonfX5o`0005Wooo]Z1Ol0001Ioook
JPGo0000cOoonfX00;7ooo]Z1Ol0001JoookJPCo0000FooonfX5o`000<cooo]Z002`oookJPGo0000
FooonfX4o`0005cooo]Z1Ol0003;oookJP00/?oonfX4o`0005cooo]Z1?l0001MoookJPGo0000b_oo
nfX00:oooo]Z1?l0001MoookJPCo0000G_oonfX4o`000<[ooo]Z002^oookJPGo0000GOoonfX4o`00
05oooo]Z1?l00039oookJP00[OoonfX5o`0005kooo]Z1?l0001OoookJPGo0000b?oonfX00:cooo]Z
1Ol0001OoookJPCo0000H?oonfX5o`000<Oooo]Z002[oookJPGo0000>OoonfX5o`00O`Cooo]Z0ol0
07l3oookJPGo001o1OoonfX5o`00O`Wooo]Z1?l0001QoookJPGo0000a_oonfX00:[ooo]Z1Ol0000i
oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l3oookJPOo001o2?oonfX4o`0006;ooo]Z1Ol00035
oookJP00ZOoonfX5o`0003[ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o0_oonfX3
o`00O`04oookJ_l007oo001oo`00O`;ooo]Z1?l007l01?oonf[o001oo`00Ool007l8oookJPCo0000
HooonfX5o`000<Cooo]Z002YoookJPCo0000>_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooo
nfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l7oookJPCo0000I?oonfX4o`000<Cooo]Z
002XoookJPCo0000>ooonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z0ol0
07l7oookJPKo0000HooonfX4o`000<?ooo]Z002WoookJPGo0000>ooonfX3o`00O`?ooo]Z0ol007l6
oookJP?o001o0ooonfX3o`00O`Oooo]Z0ol007l7oookJPCo0000IOoonfX5o`000<;ooo]Z002Voook
JPGo0000??oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`;ooo]Z0_l007l2oook
JPCo001o1ooonfX4o`0006Kooo]Z1Ol00031oookJP00YOoonfX5o`0003gooo]Z0ol007l3oookJP?o
001o1_oonfX3o`00O`?ooo]Z0ol007l2oookJPOo001o2?oonfX4o`0006Oooo]Z1Ol00030oookJP00
Y?oonfX5o`0003kooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l2oookJPKo001o
2OoonfX4o`0006Sooo]Z1Ol0002ooookJP00XooonfX5o`0003oooo]Z0ol007l3oookJP?o001o1_oo
nfX3o`00O`?ooo]Z0ol007l2oookJP;o001o3OoonfX4o`0006Wooo]Z1Ol0002noookJP00XooonfX4
o`00047ooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP?o001o00Cooo]Zo`00Ool007oo001o
0ooonfX2o`00O`gooo]Z1?l0001ZoookJPGo0000_OoonfX00:;ooo]Z1?l00012oookJPOo001o2?oo
nfX7o`00O`Cooo]Z1ol007l7oookJPCo0000JooonfX4o`000;gooo]Z002QoookJPGo0000@ooonfX5
o`00O`[ooo]Z1Ol007l5oookJPOo001o1ooonfX4o`0006cooo]Z1?l0002loookJP00X?oonfX5o`00
06_ooo]Z1?l0001/oookJPGo0000^ooonfX009oooo]Z1Ol0001/oookJPCo0000KOoonfX5o`000;[o
oo]Z002NoookJPGo0000KOoonfX5o`0006gooo]Z1Ol0002ioookJP00WOoonfX5o`0006kooo]Z1?l0
001_oookJPGo0000^?oonfX009cooo]Z1Ol0001_oookJPCo0000L?oonfX5o`000;Oooo]Z002Loook
JPCo0000L?oonfX4o`00077ooo]Z1?l0002goookJP00VooonfX4o`00077ooo]Z1?l0001boookJPCo
0000]_oonfX009[ooo]Z1Ol0001aoookJPCo0000L_oonfX5o`000;Gooo]Z002IoookJPGo0000L_oo
nfX4o`0007?ooo]Z1Ol0002doookJP00VOoonfX4o`0007?ooo]Z1?l0001doookJPGo0000/ooonfX0
09Sooo]Z1?l0001doookJPCo0000MOoonfX4o`000;?ooo]Z002GoookJPGo0000M?oonfX4o`0007Ko
oo]Z1?l0002boookJP00UooonfX4o`0007Gooo]Z1?l0001foookJPGo0000/OoonfX009Kooo]Z1?l0
001foookJPCo0000MooonfX5o`000;3ooo]Z002EoookJPGo0000M_oonfX5o`0007Oooo]Z1?l0002`
oookJP00U?oonfX5o`0007Oooo]Z1?l0001ioookJPCo0000[ooonfX009Cooo]Z1?l0001hoookJPCo
0000NOoonfX5o`000:kooo]Z002CoookJPCo0000NOoonfX4o`0007[ooo]Z1Ol0002]oookJP00T_oo
nfX5o`0007Wooo]Z1?l0001koookJPGo0000[?oonfX0097ooo]Z1Ol0001joookJPCo0000O?oonfX4
o`000:cooo]Z002AoookJPCo0000NooonfX4o`0007gooo]Z1?l0002[oookJP00T?oonfX4o`0007co
oo]Z1?l0001moookJPGo0000Z_oonfX008oooo]Z1Ol0001loookJPCo0000O_oonfX5o`000:Wooo]Z
002>oookJPGo0000OOoonfX4o`0007oooo]Z1?l0002YoookJP00S_oonfX4o`0007kooo]Z1?l00020
oookJPCo0000Z?oonfX008gooo]Z1?l0001ooookJPGo0000OooonfX5o`000:Oooo]Z002<oookJPGo
0000OooonfX4o`00087ooo]Z1Ol0002VoookJP00S?oonfX4o`00083ooo]Z1?l00022oookJPGo0000
YOoonfX008_ooo]Z1?l00021oookJPCo0000PooonfX4o`000:Gooo]Z002:oookJPGo0000POoonfX4
o`0008Cooo]Z1?l0002ToookJP00ROoonfX5o`0008;ooo]Z1?l00024oookJPGo0000XooonfX008Wo
oo]Z1?l00023oookJPCo0000QOoonfX5o`000:;ooo]Z0028oookJPCo0000Q?oonfX4o`0008Kooo]Z
1?l0002RoookJP00QooonfX5o`0008Cooo]Z1?l00027oookJPCo0000XOoonfX008Oooo]Z1?l00025
oookJPCo0000QooonfX5o`000:3ooo]Z0026oookJPCo0000Q_oonfX4o`0008Sooo]Z1?l0002Poook
JP00QOoonfX5o`0008Kooo]Z1?l00029oookJPCo0000WooonfX008Gooo]Z1?l00027oookJPGo0000
R?oonfX4o`0009oooo]Z0024oookJPCo0000R?oonfX4o`0008[ooo]Z1?l0002NoookJP00Q?oonfX4
o`0008Sooo]Z1?l0002:oookJPGo0000WOoonfX008?ooo]Z1?l00029oookJPCo0000RooonfX4o`00
09gooo]Z0022oookJPGo0000ROoonfX4o`0008cooo]Z1?l0002LoookJP00P_oonfX4o`0008[ooo]Z
1?l0002<oookJPCo0000W?oonfX0087ooo]Z1?l0002;oookJPCo0000SOoonfX4o`0009_ooo]Z0020
oookJPGo0000K_oonfX5o`00O`Cooo]Z0ol007l5oookJP?o001o2OoonfX4o`0008gooo]Z1Ol0002J
oookJP00P?oonfX4o`0006kooo]Z1ol007l3oookJP?o001o1OoonfX3o`00O`Wooo]Z1?l0002>oook
JPCo0000V_oonfX007oooo]Z1?l0001_oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00
O`Gooo]Z0ol007l9oookJPCo0000SooonfX4o`0009Wooo]Z001noookJPGo0000K_oonfX3o`00O`?o
oo]Z0ol007l:oookJP?o001o2OoonfX4o`0008oooo]Z1Ol0002HoookJP00O_oonfX4o`0006oooo]Z
0ol007l3oookJP?o001o2_oonfX3o`00O`Wooo]Z1_l0002>oookJPCo0000V?oonfX007gooo]Z1?l0
001`oookJP?o001o0ooonfX3o`00O`[ooo]Z0ol007l9oookJPCo0000TOoonfX4o`0009Oooo]Z001l
oookJPGo0000L?oonfX3o`00O`?ooo]Z0ol007l:oookJP?o001o2OoonfX4o`00097ooo]Z1?l0002G
oookJP00O?oonfX4o`00077ooo]Z0ol007l3oookJP?o001o2_oonfX3o`00O`Wooo]Z1?l0002Boook
JPCo0000U_oonfX007_ooo]Z1?l0001boookJP?o001o0ooonfX3o`00O`[ooo]Z0ol007l9oookJPCo
0000T_oonfX5o`0009Gooo]Z001joookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o
2OoonfX4o`0009?ooo]Z1?l0002EoookJP00N_oonfX4o`0007Cooo]Z0ol007l01?oonf[o001oo`00
Ool007l8oookJPKo001o2OoonfX4o`0009Cooo]Z1?l0002DoookJP00NOoonfX4o`0007Gooo]Z1ol0
07l:oookJPCo001o2OoonfX4o`0009Cooo]Z1?l0002DoookJP00NOoonfX4o`0007Kooo]Z1Ol007l<
oookJP?o001o2OoonfX4o`0009Gooo]Z1?l0002CoookJP00N?oonfX4o`0009Cooo]Z1?l0002Eoook
JPGo0000T_oonfX007Oooo]Z1Ol0002DoookJPCo0000U_oonfX4o`0009;ooo]Z001goookJPCo0000
UOoonfX4o`0009Oooo]Z1?l0002AoookJP00M_oonfX4o`0009Kooo]Z1Ol0002FoookJPCo0000TOoo
nfX007Gooo]Z1Ol0002FoookJPCo0000V?oonfX4o`00093ooo]Z001eoookJPCo0000UooonfX4o`00
09Sooo]Z1Ol0002?oookJP00M?oonfX4o`0009Sooo]Z1?l0002IoookJPCo0000SooonfX007Cooo]Z
1?l0002HoookJPCo0000V_oonfX4o`0008kooo]Z001coookJPCo0000VOoonfX4o`0009[ooo]Z1?l0
002>oookJP00L_oonfX5o`0009Wooo]Z1?l0002KoookJPCo0000SOoonfX007;ooo]Z1?l0002Joook
JPCo0000VooonfX5o`0008cooo]Z001aoookJPCo0000VooonfX4o`0009cooo]Z1?l0002<oookJP00
LOoonfX4o`0009_ooo]Z1?l0002MoookJPCo0000RooonfX0073ooo]Z1?l0002LoookJPCo0000WOoo
nfX4o`0008_ooo]Z001_oookJPGo0000W?oonfX4o`0009kooo]Z1?l0002:oookJP00KooonfX4o`00
09gooo]Z1Ol0002MoookJPCo0000R_oonfX006kooo]Z1?l0002NoookJPCo0000WooonfX4o`0008Wo
oo]Z001^oookJPCo0000W_oonfX4o`0009oooo]Z1Ol00028oookJP00KOoonfX4o`0009oooo]Z1?l0
002PoookJPCo0000R?oonfX006cooo]Z1Ol0002OoookJPCo0000XOoonfX4o`0008Oooo]Z001/oook
JPCo0000X?oonfX4o`000:7ooo]Z1?l00027oookJP00JooonfX4o`000:7ooo]Z1?l0002RoookJPCo
0000Q_oonfX006_ooo]Z1?l0002QoookJPCo0000X_oonfX5o`0008Gooo]Z001ZoookJPCo0000X_oo
nfX4o`000:?ooo]Z1?l00025oookJP00JOoonfX5o`000:;ooo]Z1?l0002ToookJPCo0000Q?oonfX0
06Wooo]Z1?l0002SoookJPCo0000Y?oonfX4o`0008Cooo]Z001XoookJPCo0000Y?oonfX5o`000:Co
oo]Z1?l00023oookJP00J?oonfX4o`000:Cooo]Z1?l0002UoookJPCo0000PooonfX006Oooo]Z1?l0
002UoookJPCo0000Y_oonfX4o`0008;ooo]Z001VoookJPGo0000YOoonfX4o`000:Kooo]Z1Ol00021
oookJP00I_oonfX4o`000:Kooo]Z1?l0002WoookJPCo0000POoonfX006Gooo]Z1?l0002WoookJPCo
0000Z?oonfX4o`00083ooo]Z001UoookJPCo0000YooonfX4o`000:Sooo]Z1?l00020oookJP00I?oo
nfX4o`000:Sooo]Z1?l0002YoookJPCo0000OooonfX006?ooo]Z1Ol0002XoookJPCo0000ZOoonfX4
o`0007oooo]Z001SoookJPCo0000ZOoonfX4o`000:[ooo]Z1?l0001noookJP00H_oonfX4o`000:[o
oo]Z1?l0002ZoookJPGo0000OOoonfX006;ooo]Z1?l0002ZoookJPCo0000ZooonfX4o`0007gooo]Z
001QoookJPCo0000ZooonfX5o`000:_ooo]Z1?l0001loookJP00HOoonfX4o`000:_ooo]Z1?l0002/
oookJPCo0000O?oonfX0063ooo]Z1?l0002/oookJPCo0000[OoonfX4o`0007_ooo]Z001PoookJPCo
0000[?oonfX4o`000:gooo]Z1?l0001koookJP00GooonfX4o`000:gooo]Z1?l0002^oookJPCo0000
N_oonfX005oooo]Z1?l0002]oookJPCo0000[_oonfX4o`0007[ooo]Z001NoookJPCo0000[_oonfX4
o`000:oooo]Z1?l0001ioookJP00G_oonfX4o`0008Oooo]Z1Ol007l4oookJP?o001o1OoonfX3o`00
O`Gooo]Z1Ol007l9oookJPCo0000[ooonfX4o`0007Wooo]Z001MoookJPCo0000QooonfX7o`00O`?o
oo]Z0ol007l5oookJP?o001o1?oonfX7o`00O`Sooo]Z1?l0002`oookJPCo0000N?oonfX005gooo]Z
1?l00027oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Gooo]Z0ol007l3oookJPCo
001o00Cooo]Zo`00Ool007oo001o2?oonfX4o`000;3ooo]Z1?l0001hoookJP00G?oonfX4o`0008Oo
oo]Z0ol007l3oookJP?o001o2_oonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o1ooonfX4o`000;7o
oo]Z1?l0001goookJP00G?oonfX4o`0008Oooo]Z0ol007l3oookJP?o001o2_oonfX3o`00O`Wooo]Z
0ol007l7oookJPKo0000[ooonfX4o`0007Oooo]Z001KoookJPCo0000R?oonfX3o`00O`?ooo]Z0ol0
07l:oookJP?o001o2OoonfX3o`00O`Oooo]Z1?l0002boookJPCo0000M_oonfX005_ooo]Z1?l00028
oookJP?o001o0ooonfX3o`00O`[ooo]Z0ol007l4oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l0002b
oookJPCo0000M_oonfX005[ooo]Z1?l00029oookJP?o001o0ooonfX3o`00O`[ooo]Z0ol007l4oook
JPOo001o2?oonfX4o`000;?ooo]Z1?l0001eoookJP00F_oonfX4o`0008Wooo]Z0ol007l3oookJP?o
001o2_oonfX3o`00O`Cooo]Z1_l007l9oookJPCo0000/ooonfX4o`0007Gooo]Z001IoookJPCo0000
R_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o1?oonfX2o`00O`gooo]Z1?l0002doookJPCo0000
M?oonfX005Wooo]Z1?l0002;oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX6o`00O`Cooo]Z
0_l007l=oookJPCo0000]?oonfX4o`0007Cooo]Z001HoookJPCo0000S?oonfX7o`00O`[ooo]Z1?l0
07l5oookJPOo001o1ooonfX4o`000;Gooo]Z1?l0001coookJP00F?oonfX4o`0008gooo]Z1Ol007l<
oookJP?o001o1OoonfX7o`00O`Oooo]Z1?l0002eoookJPCo0000LooonfX005Oooo]Z1?l0002eoook
JPCo0000]_oonfX4o`0007;ooo]Z001GoookJPCo0000]OoonfX4o`000;Kooo]Z1Ol0001aoookJP00
E_oonfX4o`000;Kooo]Z1?l0002goookJPCo0000LOoonfX005Kooo]Z1?l0002foookJPGo0000]ooo
nfX4o`00073ooo]Z001EoookJPCo0000]ooonfX4o`000;Sooo]Z1?l0001`oookJP00EOoonfX4o`00
0;Oooo]Z1?l0002ioookJPCo0000KooonfX005Cooo]Z1?l0002hoookJPCo0000^OoonfX4o`0006oo
oo]Z001DoookJPCo0000^?oonfX4o`000;[ooo]Z1?l0001^oookJP00DooonfX4o`000;Wooo]Z1?l0
002joookJPCo0000K_oonfX005?ooo]Z1?l0002ioookJPCo0000^ooonfX4o`0006gooo]Z001Boook
JPCo0000^_oonfX4o`000;_ooo]Z1?l0001]oookJP00D_oonfX4o`000;[ooo]Z1?l0002loookJPCo
0000K?oonfX0057ooo]Z1?l0002koookJPCo0000_?oonfX4o`0006cooo]Z001AoookJPCo0000^ooo
nfX4o`000;gooo]Z1?l0001[oookJP00D?oonfX4o`000;cooo]Z1Ol0002loookJPCo0000JooonfX0
053ooo]Z1?l0002loookJPCo0000__oonfX4o`0006[ooo]Z001?oookJPCo0000_OoonfX4o`000;ko
oo]Z1?l0001ZoookJP00CooonfX4o`000;gooo]Z1?l0002ooookJPCo0000JOoonfX004kooo]Z1?l0
002noookJPCo0000_ooonfX4o`0006Wooo]Z001>oookJPCo0000__oonfX4o`000<3ooo]Z1?l0001X
oookJP00COoonfX4o`000;oooo]Z1?l00030oookJPCo0000J?oonfX004gooo]Z1?l0002ooookJPCo
0000`OoonfX4o`0006Oooo]Z001<oookJPCo0000`?oonfX4o`000<7ooo]Z1?l0001WoookJP00C?oo
nfX4o`000<3ooo]Z1?l00032oookJPCo0000I_oonfX004_ooo]Z1?l00031oookJPCo0000`_oonfX4
o`0006Kooo]Z001;oookJPCo0000`OoonfX4o`000<?ooo]Z0ol0001VoookJP00BooonfX3o`000<;o
oo]Z1Ol00032oookJPCo0000IOoonfX004[ooo]Z1?l00032oookJPCo0000`ooonfX4o`0006Gooo]Z
001:oookJPCo0000`_oonfX4o`000<Cooo]Z1?l0001ToookJP00BOoonfX4o`000<?ooo]Z1?l00034
oookJPCo0000I?oonfX004Wooo]Z1?l00033oookJPCo0000aOoonfX4o`0006?ooo]Z0018oookJPCo
0000a?oonfX4o`000<Gooo]Z1?l0001SoookJP00B?oonfX4o`000<Cooo]Z1?l00036oookJPCo0000
H_oonfX004Oooo]Z1?l00035oookJPCo0000a_oonfX4o`0006;ooo]Z0017oookJPCo0000aOoonfX4
o`000<Oooo]Z1?l0001QoookJP00A_oonfX4o`000<Kooo]Z1?l00037oookJPCo0000HOoonfX004Ko
oo]Z1?l00036oookJPCo0000b?oonfX3o`00067ooo]Z0015oookJPCo0000aooonfX4o`000<Sooo]Z
1?l0001PoookJP00AOoonfX4o`000<Oooo]Z1Ol00037oookJPCo0000H?oonfX004Cooo]Z1?l00038
oookJPCo0000bOoonfX4o`0005oooo]Z0014oookJPCo0000b?oonfX4o`000<Wooo]Z1?l0001Ooook
JP00A?oonfX3o`000<Wooo]Z1?l0003:oookJPCo0000G_oonfX004?ooo]Z1?l00039oookJPCo0000
b_oonfX4o`0005kooo]Z0013oookJPCo0000bOoonfX4o`000<_ooo]Z1?l0001MoookJP00@_oonfX4
o`000<[ooo]Z1?l0003;oookJPCo0000GOoonfX004;ooo]Z1?l0002]oookJPGo001o1?oonfX3o`00
O`03oookJ_l007oo001o00Oo001o1ooonfX4o`000<cooo]Z1?l0001LoookJP00@OoonfX4o`000:go
oo]Z1ol007l3oookJP?o001o00?ooo]Zo`00Ool007l01ol007l7oookJPCo0000c?oonfX4o`0005co
oo]Z0011oookJPCo0000[OoonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o
001oo`00O`02o`00O`cooo]Z1?l0003=oookJP?o0000G?oonfX0043ooo]Z1?l0002]oookJP?o001o
0ooonfX3o`00O`Oooo]Z1?l007l;oookJPCo0000cOoonfX4o`0005_ooo]Z0010oookJPCo0000[Ooo
nfX3o`00O`?ooo]Z0ol007l8oookJPGo001o2OoonfX6o`000<_ooo]Z1?l0001KoookJP00?ooonfX4
o`000:kooo]Z0ol007l3oookJP?o001o2_oonfX4o`00O`Sooo]Z1?l0003>oookJPCo0000F_oonfX0
03oooo]Z1?l0002^oookJP?o001o0ooonfX3o`00O`_ooo]Z0ol007l8oookJPCo0000c_oonfX4o`00
05[ooo]Z000noookJPCo0000[ooonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX4o`000<oo
oo]Z1?l0001IoookJP00?_oonfX4o`000:oooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z
0ol007l7oookJPCo0000cooonfX4o`0005Wooo]Z000moookJPCo0000/?oonfX3o`00O`?ooo]Z0ol0
07l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0003@oookJPCo0000F?oonfX003gooo]Z1?l0002a
oookJP?o001o00Cooo]Zo`00Ool007oo001o1ooonfX4o`00O`;ooo]Z0ol007l7oookJPCo0000d?oo
nfX4o`0005Sooo]Z000moookJP?o0000/_oonfX7o`00O`Sooo]Z1ol007l8oookJPCo0000dOoonfX4
o`0005Oooo]Z000loookJPCo0000/ooonfX5o`00O`[ooo]Z1Ol007l9oookJPCo0000dOoonfX4o`00
05Oooo]Z000loookJPCo0000d?oonfX4o`000=;ooo]Z0ol0001GoookJP00>ooonfX4o`000=7ooo]Z
1?l0003BoookJPCo0000E_oonfX003_ooo]Z1?l0003AoookJPCo0000d_oonfX4o`0005Kooo]Z000j
oookJPCo0000d_oonfX5o`000=;ooo]Z1?l0001EoookJP00>_oonfX4o`000=;ooo]Z1?l0003Coook
JPCo0000EOoonfX003Wooo]Z1?l0003CoookJPCo0000e?oonfX4o`0005Cooo]Z000ioookJPCo0000
dooonfX4o`000=Cooo]Z1?l0001DoookJP00>OoonfX3o`000=Cooo]Z1?l0003EoookJP?o0000E?oo
nfX003Sooo]Z1?l0003DoookJPCo0000eOoonfX4o`0005?ooo]Z000hoookJPCo0000e?oonfX4o`00
0=Gooo]Z1?l0001CoookJP00=ooonfX4o`000=Gooo]Z1?l0003FoookJPCo0000D_oonfX003Oooo]Z
1?l0003EoookJPCo0000e_oonfX4o`0005;ooo]Z000foookJPCo0000e_oonfX4o`000=Oooo]Z1?l0
001AoookJP00=_oonfX4o`000=Kooo]Z1?l0003GoookJPCo0000DOoonfX003Kooo]Z0ol0003Goook
JPGo0000eooonfX3o`00057ooo]Z000eoookJPCo0000eooonfX4o`000=Sooo]Z1?l0001@oookJP00
=OoonfX4o`000=Oooo]Z1?l0003HoookJPCo0000D?oonfX003Cooo]Z1?l0003HoookJPCo0000fOoo
nfX4o`0004oooo]Z000doookJPCo0000f?oonfX4o`000=Wooo]Z1?l0001?oookJP00<ooonfX4o`00
0=Wooo]Z1?l0003JoookJPCo0000C_oonfX003?ooo]Z1?l0003IoookJPCo0000f_oonfX4o`0004ko
oo]Z000coookJP?o0000f_oonfX4o`000=_ooo]Z0ol0001>oookJP00<_oonfX4o`000=[ooo]Z1?l0
003KoookJPCo0000COoonfX003;ooo]Z1?l0003JoookJPCo0000fooonfX4o`0004gooo]Z000aoook
JPCo0000fooonfX4o`000=cooo]Z1?l0001<oookJP00<OoonfX4o`000=_ooo]Z1?l0003LoookJPCo
0000C?oonfX0033ooo]Z1?l0003LoookJPGo0000g?oonfX4o`0004_ooo]Z000`oookJPCo0000g?oo
nfX4o`000=gooo]Z1?l0001;oookJP00<?oonfX3o`000=gooo]Z1?l0003NoookJP?o0000BooonfX0
02oooo]Z1?l0003MoookJPCo0000g_oonfX4o`0004[ooo]Z000_oookJPCo0000gOoonfX4o`000=ko
oo]Z1?l0001:oookJP00;_oonfX4o`000=kooo]Z1?l0003OoookJPCo0000BOoonfX002kooo]Z1?l0
003NoookJPCo0000gooonfX4o`0004Wooo]Z000^oookJP?o0000gooonfX4o`000>3ooo]Z0ol00019
oookJP00;OoonfX4o`000=oooo]Z1?l0003PoookJPCo0000B?oonfX002gooo]Z1?l0003OoookJPCo
0000h?oonfX4o`0004Sooo]Z000/oookJPCo0000h?oonfX4o`000>7ooo]Z1?l00017oookJP00;?oo
nfX4o`000>3ooo]Z1Ol0003PoookJPCo0000AooonfX002_ooo]Z1?l0003QoookJPCo0000h_oonfX4
o`0004Kooo]Z000[oookJPCo0000hOoonfX4o`000>;ooo]Z1?l00016oookJP00:ooonfX3o`000>;o
oo]Z1?l0003SoookJP?o0000A_oonfX002[ooo]Z1?l0003RoookJPCo0000hooonfX4o`0004Gooo]Z
000ZoookJPCo0000h_oonfX4o`000>?ooo]Z1?l00015oookJP00:OoonfX4o`000>?ooo]Z1?l0003T
oookJPCo0000A?oonfX002Wooo]Z1?l0003SoookJPCo0000i?oonfX4o`0004Cooo]Z000XoookJPCo
0000_OoonfX5o`00O`Cooo]Z0ol007l00ooonf[o001oo`00O`07o`00O`?ooo]Z1Ol007l9oookJPCo
0000iOoonfX4o`0004?ooo]Z000XoookJPCo0000_?oonfX7o`00O`?ooo]Z0ol007l00ooonf[o001o
o`00O`07o`00O`;ooo]Z1ol007l8oookJPCo0000iOoonfX4o`0004?ooo]Z000XoookJP?o0000_Ooo
nfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`Kooo]Z
1?l007l01?oonf[o001oo`00Ool007l8oookJPCo0000i_oonfX3o`0004?ooo]Z000WoookJPCo0000
_?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo001o1OoonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000
i_oonfX4o`0004;ooo]Z000WoookJPCo0000_?oonfX3o`00O`?ooo]Z0ol007l8oookJPGo001o2Ooo
nfX3o`00O`Oooo]Z1_l0003ToookJPCo0000@_oonfX002Oooo]Z0ol0002moookJP?o001o0ooonfX3
o`00O`[ooo]Z1?l007l8oookJP?o001o1ooonfX4o`000>Oooo]Z0ol00012oookJP00iooonfX3o`00
O`?ooo]Z0ol007l;oookJP?o001o0ooonfX2o`00O`;ooo]Z1?l007l7oookJPCo0000oooonfX]oook
JP00iooonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o0_oonfX7o`00O`Sooo]Z1?l0003ooookJRgo
oo]Z003WoookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o0_oonfX6o`00O`Wooo]Z
1?l0003ooookJRgooo]Z003WoookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o0_oo
nfX2o`00O`gooo]Z1?l0003ooookJRgooo]Z003XoookJP?o001o00Cooo]Zo`00Ool007oo001o1ooo
nfX4o`00O`;ooo]Z0ol007l2oookJP;o001o3OoonfX4o`000?oooo]Z;OoonfX00>Sooo]Z1ol007l8
oookJPOo001o1?oonfX7o`00O`Oooo]Z1?l0003ooookJRgooo]Z003YoookJPGo001o2_oonfX5o`00
O`Gooo]Z1ol007l7oookJPCo0000oooonfX]oookJP00oooonfXAoookJPCo0000oooonfX]oookJP00
oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooook
JT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003o
oookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z
@_oonfX00?oooo]Z3ooonfX00ol@47go001oojVWL@3ooookJS3ooo]Z003ooookJPoooo]Z00?o<S9j
o`00Ool007l0oooonfX`oookJP00oooonfX?oookJP04olc8K_l007oo001ookZhKooooo]Z;ooonfX0
0?oooo]Z4?oonfX00onHUW;o001oohN5L`3ooookJRoooo]Z003ooookJQ7ooo]Z00?oMgEeoc8bN_oo
nfX0oooonfX^oookJP00oooonfXBoookJP03o`00OonHUW;ooo]Z0?oooo]Z;OoonfX00?oooo]Z4_oo
nfX00olQ8Gco411moiRFLP3ooookJRgooo]Z003ooookJQ;ooo]Z00Co001ookZhKol007ooc<Q^oooo
nfX/oookJP00oooonfXAoookJP06olc8K_l007oooo]ZoeECMol@47gok^Y[oooonfX[oookJP00oooo
nfX>oookJP09o`00Oon7QG?ooo]ZogMeMOl007oooo]ZomgIK?l007ooIVAf0?oooo]Z:ooonfX00?oo
oo]Z3_oonfX01On7QG?o001oo`00Ool007oo<S9j00;ooo]Z00?oEE=go`00OooMfF`0oooonfXZoook
JP00oooonfX?oookJP04ohN5Lol007oo411molc8KP;ooo]Z00?ogMU/oc8bN_m4@WT0oooonfXZoook
JP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
0000\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.17342, -0.0225929, \
0.00427295, 0.000864222}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ComplexRealAnnote\  = 
      Show[ComplexReal, 
        Graphics[
          Text["\<Complex\nCongugate\nRoots\>", {0.25, 0.25}, {\(-1\), 1}]], 
        Graphics[Text["\<Real Roots\>", {0.75, 0.05}]]]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.0147151 2.35442 [
[.02381 .00222 -13.4688 -20 ]
[.02381 .00222 13.4688 0 ]
[.2619 .00222 -20.9688 -20 ]
[.2619 .00222 20.9688 0 ]
[.7381 .00222 -14.5 -20 ]
[.7381 .00222 14.5 0 ]
[.97619 .00222 -7 -20 ]
[.97619 .00222 7 0 ]
[1.025 .01472 0 -10 ]
[1.025 .01472 15.9375 10 ]
[.4875 .13244 -39 -10 ]
[.4875 .13244 0 10 ]
[.4875 .25016 -29 -10 ]
[.4875 .25016 0 10 ]
[.4875 .36788 -39 -10 ]
[.4875 .36788 0 10 ]
[.4875 .4856 -29 -10 ]
[.4875 .4856 0 10 ]
[.4875 .60332 -39 -10 ]
[.4875 .60332 0 10 ]
[.5 .64303 -7.28125 0 ]
[.5 .64303 7.28125 20 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .02097 L
s
gsave
.02381 .00222 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .01472 m
.2619 .02097 L
s
gsave
.2619 .00222 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .01472 m
.7381 .02097 L
s
gsave
.7381 .00222 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .01472 m
.97619 .02097 L
s
gsave
.97619 .00222 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.01 w
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
%%BeginResource: font Helvetica-Bold-MISO
%%BeginFont: Helvetica-Bold-MISO
/Helvetica-Bold /Helvetica-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
0.000 0.000 rmoveto
64.750 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(b) show
74.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.5 .13244 m
.50625 .13244 L
s
gsave
.4875 .13244 -100 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.05) show
1.000 setlinewidth
grestore
.5 .25016 m
.50625 .25016 L
s
gsave
.4875 .25016 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.1) show
1.000 setlinewidth
grestore
.5 .36788 m
.50625 .36788 L
s
gsave
.4875 .36788 -100 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.15) show
1.000 setlinewidth
grestore
.5 .4856 m
.50625 .4856 L
s
gsave
.4875 .4856 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.5 .60332 m
.50625 .60332 L
s
gsave
.4875 .60332 -100 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .03826 m
.50375 .03826 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .08535 m
.50375 .08535 L
s
.5 .10889 m
.50375 .10889 L
s
.5 .15598 m
.50375 .15598 L
s
.5 .17952 m
.50375 .17952 L
s
.5 .20307 m
.50375 .20307 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .2737 m
.50375 .2737 L
s
.5 .29724 m
.50375 .29724 L
s
.5 .32079 m
.50375 .32079 L
s
.5 .34433 m
.50375 .34433 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .41497 m
.50375 .41497 L
s
.5 .43851 m
.50375 .43851 L
s
.5 .46205 m
.50375 .46205 L
s
.5 .50914 m
.50375 .50914 L
s
.5 .53269 m
.50375 .53269 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57977 m
.50375 .57977 L
s
.01 w
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -68.2812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
%%BeginResource: font Helvetica-Bold-MISO
%%BeginFont: Helvetica-Bold-MISO
/Helvetica-Bold /Helvetica-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
0.000 0.000 rmoveto
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(g) show
73.562 19.000 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .60332 m
.06244 .51168 L
.10458 .42058 L
.14415 .34341 L
.18221 .27686 L
.22272 .21429 L
.26171 .16211 L
.30316 .11529 L
.34309 .07863 L
.3815 .05117 L
.40095 .04018 L
.42237 .03036 L
.44268 .02324 L
.45178 .02075 L
.46172 .01852 L
.4671 .01752 L
.4721 .01674 L
.47727 .01606 L
.48196 .01556 L
.48658 .01518 L
.4887 .01505 L
.49093 .01493 L
.49332 .01483 L
.49438 .0148 L
.49552 .01477 L
.49675 .01474 L
.49789 .01473 L
.49859 .01472 L
.49925 .01472 L
.50049 .01472 L
.50163 .01472 L
.50286 .01474 L
.50401 .01476 L
.50508 .01478 L
.50754 .01486 L
.51014 .01498 L
.51268 .01513 L
.51504 .0153 L
.5204 .0158 L
.5293 .01694 L
.53882 .01863 L
.54906 .02096 L
.56016 .02411 L
.58032 .03146 L
.60019 .04077 L
.62123 .05287 L
.65912 .08044 L
.69946 .11799 L
.73829 .1621 L
.77956 .21759 L
Mistroke
.81932 .2794 L
.85757 .34659 L
.89827 .42644 L
.93745 .51144 L
.97619 .60332 L
Mfstroke
gsave
.61905 .60332 -61 -62 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 66 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
0.000 0.000 rmoveto
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(Complex) show
63.000 38.000 moveto
(Congugate) show
63.000 57.000 moveto
(Roots) show
113.750 57.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.85714 .13244 -109.844 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
0.000 0.000 rmoveto
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(Real) show
105.938 19.000 moveto
(Roots) show
156.688 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00;_oonfX3o`00OfSooo]Z1Ol007l4oook
JP?o001o0ooonfX5o`00Om3ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00Of[ooo]Z0ol007m2oook
JP00;_oonfX3o`00OfOooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Olkooo]Z1ol007l3oookJP?o
001o0_oonfX7o`00OfWooo]Z0ol007m2oookJP00;_oonfX3o`00OfOooo]Z0ol007l01?oonf[o001o
o`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007o>oook
JP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Z
o`00Ool007oo001oJOoonfX3o`00Od;ooo]Z000NoookJP[o001o1_oonfX3o`00Oe[ooo]Z2_l007l2
oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001oc?oonfX3o`00O`?ooo]Z0ol007l6
oookJP?o001o0ooonfX3o`00OfSooo]Z0ol007m2oookJP007_oonfX:o`00O`Kooo]Z0ol007mJoook
JP[o001o0_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001oc?oonfX3o`00O`?ooo]Z0ol007l<oook
JP?o001oJ?oonfX3o`00Od;ooo]Z000^oookJP?o001oI_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o
001oc?oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001oJ?oonfX3o`00Od;ooo]Z000^oookJP?o001o
I_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00Olcooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`;ooo]Z1?l007mXoookJP?o001o@_oonfX002kooo]Z0ol007mVoookJP?o001o0ooo
nfX3o`00O`Oooo]Z1ol007o=oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007mYoookJP?o001o@_oo
nfX002kooo]Z0ol007mVoookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007o>oookJP?o001o0ooonfX3
o`00O`Oooo]Z1_l007mZoookJP?o001o@_oonfX002_ooo]Z1_l007mVoookJP?o001o0ooonfX3o`00
O`Oooo]Z0_l007oBoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007m[oookJPKo001o@_oonfX002_o
oo]Z1_l007mWoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Om?ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l8oookJP;o001oJooonfX6o`00Od;ooo]Z000]oookJPCo001oIooonfX7o`00
O`Wooo]Z1ol007mQoookJPCo0000J?oonfX7o`00O`Wooo]Z1ol007mWoookJPCo001o@_oonfX002ko
oo]Z0ol007mXoookJPGo001o2_oonfX7o`00Of7ooo]Z1?l0001YoookJPGo001o2_oonfX7o`00OfSo
oo]Z0ol007lHoookJP04odA2NOl007oo001ookZhKbKooo]Z003ooookJQ7ooo]Z1?l0003ooookJP?o
oo]Z00Cok^Y[o`00Ool007ooA49i9_oonfX00?oooo]Z4OoonfX4o`000?oooo]Z1?oonfX01?mgMGGo
001oo`00OooMfF`UoookJP00oooonfXAoookJPCo0000oooonfX4oookJP04omgIK?l007oo001oohN5
LbGooo]Z003ooookJQ7ooo]Z1?l0003ooookJPGooo]Z00Co411mo`00Oolb<W[oEE=g0_l007l00omE
DgOok^Y[oookJP0OoookJP00oooonfXAoookJPCo0000oooonfX5oookJP09odA2NOl007oo001oodA2
NOoonf[o<S9jo`00OolQ8Gcok^Y[01oooo]Z003ooookJQ7ooo]Z1?l0003ooookJPGooo]Z00KoQhEc
o`00Ool007ooMgEeoookJ_nYYg42o`00O`03ogMeMOoonf[ooo]Z01gooo]Z000JoookJ_oo0000lOl0
000>oookJP06olc8K_l007oo001oofITM_oonf[ok^Y[0_l007l00ol@47gooo]ZoookJP0MoookJP00
6_oonf[oo`000?7o00003ooonfX2o`00O`03oc8bN_oonf[ooo]Z00?o001o7ooonfX001[ooo]Zool0
003ao`0000oooo]Z00?oA49io`00Ool007l00_oonfX2o`00O`03oa0@OOoonf[ooo]Z01gooo]Z000J
oookJ_oo0000lOl0000?oookJP05ohN5Lol007oo001ookZhKon7QG<00_l007l00on7QG?ooo]Zoook
JP0MoookJP00:?oonfX00ol0003ooo]ZoookJP1boookJP03o`000?oonf[ooo]Z05?ooo]Z3ol0000>
oookJPCo00003ooonfX@o`0005Cooo]Z00?o0000oookJ_oonfX0L_oonfX00ol0003ooo]ZoookJP0J
oookJP03olc8K_l007oo001o00?o001o00?o8B5lonkZJooonfX07_oonfX00?3ooo]Z3_l0000Boook
JPCo00005?oonfX>o`000>Cooo]Z0_l007l01_m4@WWooo]ZonkZJolQ8Gco001oolc8KQkooo]Z003]
oookJPco00005ooonfX4o`0001Wooo]Z2ol0003RoookJP03odA2NOl007oo001o00;ooo]Z00?ogMU/
o`00Oolb<WX07_oonfX00>[ooo]Z2ol0000KoookJPCo00007OoonfX:o`000=oooo]Z00Co^[Q_o`00
Ool007oo^[Q_0_oonfX2o`00Oakooo]Z003XoookJP[o00007_oonfX4o`00023ooo]Z2Ol0003Noook
JP07ogMeMOl007oo8B5lonkZJonj^6oo001ooa0@O@0NoookJP00iOoonfX:o`00027ooo]Z1?l0000R
oookJPWo0000gOoonfX01_nYYg7o<S9jo`00Ool007ooA49iolc8KQkooo]Z003SoookJPWo00009?oo
nfX4o`0002Gooo]Z2?l0003ooookJP00hOoonfX9o`0002Kooo]Z1?l0000WoookJPOo0000o_oonfX0
0=oooo]Z2?l0000YoookJPGo0000:?oonfX7o`000?cooo]Z003NoookJPOo0000:ooonfX4o`0002_o
oo]Z1ol0003joookJP00g?oonfX7o`0002gooo]Z1?l0000/oookJPSo0000n?oonfX00=_ooo]Z1_l0
000_oookJPCo0000;_oonfX9o`000?Gooo]Z003IoookJPOo0000<?oonfX4o`00033ooo]Z2Ol0003c
oookJP00f?oonfX6o`0003;ooo]Z1?l0000boookJPWo0000lOoonfX00=Kooo]Z1ol0000coookJPCo
0000=OoonfX8o`000>oooo]Z003EoookJPKo0000=OoonfX4o`0003Oooo]Z1ol0003^oookJP00dooo
nfX7o`0003Kooo]Z1?l0000ioookJPKo0000kOoonfX00=;ooo]Z1_l0000hoookJPCo0000>ooonfX6
o`000>_ooo]Z003@oookJPOo0000>OoonfX4o`0003cooo]Z1_l0003ZoookJP00cooonfX6o`0003_o
oo]Z1?l0000moookJPKo0000jOoonfX00<gooo]Z1ol0000loookJPGo0000?_oonfX5o`000>Sooo]Z
003<oookJPKo0000?_oonfX4o`00043ooo]Z1_l0003VoookJP00booonfX6o`0003oooo]Z1?l00011
oookJPKo0000iOoonfX00<Wooo]Z1_l00011oookJPCo0000@_oonfX6o`000>Cooo]Z0038oookJPKo
0000@_oonfX4o`0004Cooo]Z1_l0003RoookJP00a_oonfX7o`0004?ooo]Z1?l00015oookJPKo0000
hOoonfX00<Gooo]Z1_l00015oookJPCo0000A_oonfX6o`000>3ooo]Z0033oookJPOo0000A_oonfX4
o`0004Sooo]Z1Ol0003OoookJP00`_oonfX6o`0004Sooo]Z1?l00019oookJPKo0000gOoonfX00<7o
oo]Z1_l00019oookJPCo0000B_oonfX6o`000=cooo]Z0030oookJPGo0000BooonfX4o`0004_ooo]Z
1_l0003KoookJP00_ooonfX5o`0004cooo]Z1Ol0001<oookJPGo0000f_oonfX00;kooo]Z1Ol0001=
oookJPCo0000C_oonfX5o`000=Wooo]Z002moookJPGo0000C_oonfX4o`0004oooo]Z1Ol0003Hoook
JP00_?oonfX5o`0004oooo]Z1?l0001@oookJPGo0000eooonfX00;_ooo]Z1Ol0001@oookJPCo0000
DOoonfX5o`000=Kooo]Z002ioookJPKo0000DOoonfX4o`0005;ooo]Z1Ol0003EoookJP00^?oonfX6
o`0005;ooo]Z1?l0001CoookJPKo0000dooonfX00;Oooo]Z1_l0001CoookJPCo0000E?oonfX6o`00
0=;ooo]Z002foookJPGo0000EOoonfX4o`0005Gooo]Z1_l0003AoookJP00]OoonfX5o`0005Kooo]Z
1?l0001GoookJPGo0000d?oonfX00;Cooo]Z1Ol0001GoookJPCo0000F?oonfX5o`000<oooo]Z002c
oookJPGo0000F?oonfX4o`0005Wooo]Z1Ol0003>oookJP00/_oonfX5o`0005Wooo]Z1Ol0001Ioook
JPGo0000cOoonfX00;7ooo]Z1Ol0001JoookJPCo0000FooonfX5o`000<cooo]Z002`oookJPGo0000
FooonfX4o`0005cooo]Z1Ol0003;oookJP00/?oonfX4o`0005cooo]Z1?l0001MoookJPGo0000b_oo
nfX00:oooo]Z1?l0001MoookJPCo0000G_oonfX4o`000<[ooo]Z002^oookJPGo0000GOoonfX4o`00
05oooo]Z1?l00039oookJP00[OoonfX5o`0005kooo]Z1?l0001OoookJPGo0000b?oonfX00:cooo]Z
1Ol0001OoookJPCo0000H?oonfX5o`000<Oooo]Z002[oookJPGo0000>OoonfX5o`00O`Cooo]Z0ol0
07l3oookJPGo001o1OoonfX5o`00O`Wooo]Z1?l0001QoookJPGo00006_oonfX3o`00O`Gooo]Z0ol0
07l4oookJPGo001o1OoonfX4o`00O`05oookJ_l007oo001oo`00OooonfX00ol007l6oookJP?o001o
1OoonfX3o`00O`Gooo]Z1?l007l8oookJPCo001o1ooonfX4o`00O`Cooo]Z1Ol007m=oookJP00Z_oo
nfX5o`0003Wooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`?ooo]Z1ol007l8oookJPCo0000H_oo
nfX5o`0001Wooo]Z0ol007l5oookJP?o001o0ooonfX7o`00O`?ooo]Z2?l007l2oookJP?o001o1_oo
nfX3o`00O`Gooo]Z0ol007l3oookJPSo001o1?oonfX8o`00O`Cooo]Z1Ol007l2oookJPSo001oC?oo
nfX00:Wooo]Z1Ol0000joookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`;ooo]Z0ol0
07l01?oonf[o001oo`00Ool007l2oookJPCo001o00Cooo]Zo`00Ool007oo001o2?oonfX4o`0006?o
oo]Z1Ol0000HoookJP?o001o1OoonfX3o`00O`;ooo]Z1?l007l2oookJP?o001o0_oonfX3o`00O`;o
oo]Z0ol007l2oookJP?o001o1_oonfX3o`00O`Gooo]Z0ol007l3oookJP?o001o0_oonfX3o`00O`Co
oo]Z0ol007l2oookJP?o001o1?oonfX3o`00O`Cooo]Z0ol007l3oookJP?o001oBooonfX00:Wooo]Z
1?l0000joookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo
001o0ooonfX3o`00O`Oooo]Z1?l0001ToookJPCo00006?oonfX3o`00O`Gooo]Z0ol007l2oookJP?o
001o2?oonfX3o`00O`;ooo]Z0ol007l2oookJP?o001o1_oonfX3o`00O`Gooo]Z0ol007l2oookJP?o
001o1?oonfX3o`00O`;ooo]Z0ol007l4oookJP?o001o0ooonfX3o`00O`Wooo]Z1?l007m;oookJP00
Z?oonfX4o`0003_ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7oookJP?o001o
1ooonfX6o`0006?ooo]Z1?l0000GoookJP?o001o1OoonfX3o`00O`;ooo]Z2Ol007l2oookJPCo001o
00Cooo]Zo`00Ool007oo001o0_oonfX3o`00O`Kooo]Z0ol007l5oookJP?o001o0_oonfX3o`00O`Co
oo]Z0ol007l2oookJP?o001o1?oonfX3o`00O`?ooo]Z0ol007l6oookJPOo001oBooonfX00:Oooo]Z
1Ol0000koookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1ooonfX3o`00O`Oooo]Z
1?l0001UoookJPGo00005_oonfX:o`00O`?ooo]Z2Ol007l3oookJPOo001o0_oonfX3o`00O`Kooo]Z
2_l007l3oookJP?o001o1?oonfX3o`00O`;ooo]Z0ol007l4oookJP?o001o0ooonfX3o`00O`Cooo]Z
1ol007m=oookJP00Y_oonfX5o`0003cooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol0
07l2oookJP;o001o0_oonfX4o`00O`Oooo]Z1?l0001VoookJPGo00005OoonfX:o`00O`?ooo]Z0ol0
07l3oookJP?o001o1ooonfX3o`00O`;ooo]Z0ol007l6oookJP[o001o0ooonfX3o`00O`Cooo]Z0ol0
07l2oookJP?o001o1?oonfX3o`00O`?ooo]Z0ol007l4oookJPCo001oD?oonfX00:Gooo]Z1Ol0000m
oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o0_oonfX7o`00O`Sooo]Z1?l0001W
oookJPGo00005?oonfX3o`00O`Gooo]Z0ol007l2oookJP?o001o0ooonfX3o`00O`;ooo]Z0ol007l2
oookJP?o001o0_oonfX3o`00O`Kooo]Z0ol007l5oookJP?o001o0ooonfX3o`00O`;ooo]Z0ol007l4
oookJP?o001o0_oonfX3o`00O`Cooo]Z0ol007l4oookJP?o001o0ooonfX3o`00Od_ooo]Z002Toook
JPGo0000?_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`;ooo]Z1_l007l9oook
JPCo0000J?oonfX5o`0001?ooo]Z0ol007l5oookJP?o001o0ooonfX7o`00O`?ooo]Z2?l007l2oook
JP?o001o1_oonfX3o`00O`Gooo]Z0ol007l3oookJPSo001o1?oonfX8o`00O`?ooo]Z1_l007l3oook
JPOo001oC?oonfX00:?ooo]Z1Ol0000ooookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o
001o0_oonfX2o`00O`gooo]Z1?l0001YoookJPGo00004_oonfX3o`00O`Gooo]Z0ol007l4oookJPGo
001o1_oonfX4o`00O`Cooo]Z0ol007l6oookJP?o001o1OoonfX3o`00O`Gooo]Z1?l007l8oookJPCo
001o1OoonfX6o`00O`Cooo]Z1Ol007m=oookJP00XooonfX4o`00047ooo]Z0ol007l01?oonf[o001o
o`00Ool007l8oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX2o`00O`gooo]Z1?l0001Zoook
JPGo00004OoonfX3o`00O`Gooo]Z0ol007lGoookJP?o001o1_oonfX3o`00O`Gooo]Z0ol007lKoook
JP?o001oF?oonfX00:;ooo]Z1?l00012oookJPOo001o2?oonfX7o`00O`Cooo]Z1ol007l7oookJPCo
0000JooonfX4o`00017ooo]Z2_l007lHoookJP?o001o1_oonfX:o`00Oacooo]Z0ol007mHoookJP00
XOoonfX5o`0004?ooo]Z1Ol007l:oookJPGo001o1OoonfX7o`00O`Oooo]Z1?l0001/oookJPCo0000
4?oonfX9o`00OaWooo]Z0ol007l6oookJPWo001oN?oonfX00:3ooo]Z1Ol0001[oookJPCo0000K?oo
nfX5o`000;_ooo]Z002OoookJPGo0000K?oonfX4o`0006gooo]Z1Ol0002joookJP00W_oonfX5o`00
06gooo]Z1Ol0001]oookJPGo0000^OoonfX009gooo]Z1Ol0001^oookJPCo0000KooonfX5o`000;So
oo]Z002LoookJPGo0000KooonfX4o`00073ooo]Z1Ol0002goookJP00W?oonfX4o`00073ooo]Z1?l0
001aoookJPCo0000]ooonfX009_ooo]Z1?l0001aoookJPCo0000L_oonfX4o`000;Kooo]Z002Joook
JPGo0000LOoonfX4o`0007;ooo]Z1Ol0002eoookJP00VOoonfX5o`0007;ooo]Z1?l0001coookJPGo
0000]?oonfX009Wooo]Z1?l0001coookJPCo0000M?oonfX5o`000;?ooo]Z002HoookJPCo0000M?oo
nfX4o`0007Gooo]Z1?l0002coookJP00UooonfX5o`0007Cooo]Z1?l0001foookJPCo0000/_oonfX0
09Oooo]Z1?l0001eoookJPCo0000M_oonfX5o`000;7ooo]Z002FoookJPCo0000M_oonfX4o`0007Oo
oo]Z1Ol0002`oookJP00UOoonfX5o`0007Kooo]Z1Ol0001goookJPCo0000/?oonfX009Cooo]Z1Ol0
001goookJPCo0000NOoonfX4o`000:oooo]Z002DoookJPCo0000N?oonfX4o`0007Wooo]Z1Ol0002^
oookJP00TooonfX4o`0007Wooo]Z1?l0001joookJPGo0000[OoonfX009;ooo]Z1Ol0001ioookJPCo
0000NooonfX5o`000:cooo]Z002AoookJPGo0000N_oonfX4o`0007cooo]Z1?l0002/oookJP00TOoo
nfX4o`0007_ooo]Z1?l0001moookJPCo0000ZooonfX0093ooo]Z1?l0001loookJPCo0000OOoonfX5
o`000:[ooo]Z002?oookJPGo0000O?oonfX4o`0007kooo]Z1Ol0002YoookJP00S_oonfX5o`0007go
oo]Z1?l0001ooookJPCo0000ZOoonfX008kooo]Z1?l0001noookJPCo0000P?oonfX4o`000:Sooo]Z
002=oookJPCo0000OooonfX5o`0007oooo]Z1Ol0002WoookJP00S?oonfX5o`0007oooo]Z1?l00021
oookJPGo0000Y_oonfX008cooo]Z1?l00020oookJPCo0000P_oonfX5o`000:Gooo]Z002;oookJPCo
0000POoonfX4o`0008?ooo]Z1?l0002UoookJP00R_oonfX5o`00087ooo]Z1?l00024oookJPCo0000
Y?oonfX008Wooo]Z1Ol00022oookJPCo0000Q?oonfX5o`000:?ooo]Z0029oookJPCo0000PooonfX4
o`0008Gooo]Z1Ol0002RoookJP00R?oonfX4o`0008Cooo]Z1?l00026oookJPCo0000X_oonfX008Oo
oo]Z1Ol00024oookJPCo0000QooonfX4o`000:7ooo]Z0027oookJPCo0000QOoonfX4o`0008Oooo]Z
1Ol0002PoookJP00Q_oonfX4o`0008Kooo]Z1?l00028oookJPCo0000X?oonfX008Gooo]Z1Ol00026
oookJPCo0000ROoonfX4o`0009oooo]Z0025oookJPCo0000QooonfX5o`0008Sooo]Z1?l0002Ooook
JP00Q?oonfX4o`0008Sooo]Z1?l0002:oookJPCo0000W_oonfX008Cooo]Z1?l00028oookJPCo0000
R_oonfX5o`0009gooo]Z0023oookJPCo0000ROoonfX4o`0008_ooo]Z1?l0002MoookJP00P_oonfX5
o`0008Wooo]Z1?l0002<oookJPCo0000W?oonfX008;ooo]Z1?l0002:oookJPCo0000S?oonfX4o`00
09cooo]Z0021oookJPCo0000RooonfX4o`0008gooo]Z1?l0002KoookJP00P?oonfX5o`0006kooo]Z
1Ol007l4oookJP?o001o1OoonfX3o`00O`Wooo]Z1?l0002=oookJPGo0000V_oonfX0083ooo]Z1?l0
001^oookJPOo001o0ooonfX3o`00O`Gooo]Z0ol007l9oookJPCo0000S_oonfX4o`0009[ooo]Z001o
oookJPCo0000KooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l5oookJP?o001o2Ooo
nfX4o`0008oooo]Z1?l0002IoookJP00O_oonfX5o`0006kooo]Z0ol007l3oookJP?o001o2_oonfX3
o`00O`Wooo]Z1?l0002?oookJPGo0000V?oonfX007kooo]Z1?l0001_oookJP?o001o0ooonfX3o`00
O`[ooo]Z0ol007l9oookJPKo0000S_oonfX4o`0009Sooo]Z001moookJPCo0000L?oonfX3o`00O`?o
oo]Z0ol007l:oookJP?o001o2OoonfX4o`00097ooo]Z1?l0002GoookJP00O?oonfX5o`00073ooo]Z
0ol007l3oookJP?o001o2_oonfX3o`00O`Wooo]Z1?l0002AoookJPCo0000UooonfX007cooo]Z1?l0
001aoookJP?o001o0ooonfX3o`00O`[ooo]Z0ol007l9oookJPCo0000T_oonfX4o`0009Kooo]Z001k
oookJPCo0000L_oonfX3o`00O`?ooo]Z0ol007l:oookJP?o001o2OoonfX4o`0009;ooo]Z1Ol0002E
oookJP00N_oonfX5o`0007;ooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`Wooo]Z1?l0002Coook
JPCo0000UOoonfX007[ooo]Z1?l0001doookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX6o`00
O`Wooo]Z1?l0002DoookJPCo0000U?oonfX007Wooo]Z1?l0001eoookJPOo001o2_oonfX4o`00O`Wo
oo]Z1?l0002DoookJPCo0000U?oonfX007Wooo]Z1?l0001foookJPGo001o3?oonfX3o`00O`Wooo]Z
1?l0002EoookJPCo0000TooonfX007Sooo]Z1?l0002DoookJPCo0000UOoonfX5o`0009;ooo]Z001g
oookJPGo0000U?oonfX4o`0009Kooo]Z1?l0002BoookJP00MooonfX4o`0009Gooo]Z1?l0002Goook
JPCo0000TOoonfX007Kooo]Z1?l0002FoookJPGo0000U_oonfX4o`00097ooo]Z001eoookJPGo0000
U_oonfX4o`0009Sooo]Z1?l0002@oookJP00MOoonfX4o`0009Oooo]Z1?l0002HoookJPGo0000Sooo
nfX007Cooo]Z1?l0002HoookJPCo0000VOoonfX4o`0008oooo]Z001doookJPCo0000V?oonfX4o`00
09[ooo]Z1?l0002>oookJP00LooonfX4o`0009Wooo]Z1?l0002JoookJPCo0000S_oonfX007;ooo]Z
1Ol0002IoookJPCo0000VooonfX4o`0008gooo]Z001boookJPCo0000V_oonfX4o`0009_ooo]Z1Ol0
002<oookJP00LOoonfX4o`0009_ooo]Z1?l0002LoookJPCo0000S?oonfX0077ooo]Z1?l0002Koook
JPCo0000WOoonfX4o`0008_ooo]Z001`oookJPCo0000W?oonfX4o`0009gooo]Z1?l0002;oookJP00
KooonfX5o`0009cooo]Z1?l0002NoookJPCo0000R_oonfX006oooo]Z1?l0002MoookJPGo0000WOoo
nfX4o`0008[ooo]Z001^oookJPCo0000W_oonfX4o`0009oooo]Z1?l00029oookJP00K_oonfX4o`00
09kooo]Z1?l0002OoookJPGo0000R?oonfX006gooo]Z1?l0002OoookJPCo0000X?oonfX4o`0008So
oo]Z001/oookJPGo0000WooonfX4o`000:7ooo]Z1?l00027oookJP00K?oonfX4o`000:3ooo]Z1?l0
002QoookJPCo0000QooonfX006_ooo]Z1?l0002QoookJPCo0000X_oonfX4o`0008Kooo]Z001[oook
JPCo0000XOoonfX4o`000:;ooo]Z1Ol00025oookJP00J_oonfX4o`000:;ooo]Z1?l0002SoookJPCo
0000QOoonfX006Wooo]Z1Ol0002RoookJPCo0000Y?oonfX4o`0008Cooo]Z001YoookJPCo0000Xooo
nfX4o`000:Cooo]Z1?l00024oookJP00J?oonfX4o`000:Cooo]Z1Ol0002ToookJPCo0000PooonfX0
06Sooo]Z1?l0002ToookJPCo0000YOoonfX4o`0008?ooo]Z001WoookJPCo0000YOoonfX4o`000:Ko
oo]Z1?l00022oookJP00I_oonfX5o`000:Gooo]Z1?l0002VoookJPGo0000POoonfX006Kooo]Z1?l0
002VoookJPCo0000YooonfX4o`00087ooo]Z001UoookJPCo0000YooonfX4o`000:Sooo]Z1?l00020
oookJP00IOoonfX4o`000:Oooo]Z1?l0002XoookJPCo0000P?oonfX006Cooo]Z1?l0002XoookJPCo
0000ZOoonfX4o`0007oooo]Z001SoookJPGo0000Z?oonfX4o`000:Wooo]Z1?l0001ooookJP00Hooo
nfX4o`000:Wooo]Z1?l0002ZoookJPCo0000O_oonfX006;ooo]Z1?l0002ZoookJPCo0000Z_oonfX5
o`0007gooo]Z001RoookJPCo0000Z_oonfX4o`000:_ooo]Z1?l0001moookJP00HOoonfX4o`000:_o
oo]Z1Ol0002[oookJPCo0000O?oonfX0067ooo]Z1?l0002[oookJPCo0000[?oonfX4o`0007cooo]Z
001PoookJPCo0000[?oonfX4o`000:gooo]Z1?l0001koookJP00H?oonfX4o`000:cooo]Z1?l0002]
oookJPCo0000NooonfX005oooo]Z1?l0002]oookJPCo0000[_oonfX4o`0007[ooo]Z001OoookJPCo
0000[OoonfX4o`000:kooo]Z1?l0001joookJP00G_oonfX4o`000:kooo]Z1?l0002_oookJPCo0000
NOoonfX005kooo]Z1?l00027oookJPGo001o1?oonfX3o`00O`Gooo]Z0ol007l5oookJPGo001o2Ooo
nfX4o`000:oooo]Z1?l0001ioookJP00GOoonfX4o`0008Oooo]Z1ol007l3oookJP?o001o1OoonfX3
o`00O`Cooo]Z1ol007l8oookJPCo0000/?oonfX4o`0007Sooo]Z001MoookJPCo0000QooonfX3o`00
O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l5oookJP?o001o0ooonfX4o`00O`04oookJ_l007oo
001oo`00O`Sooo]Z1?l0002`oookJPCo0000N?oonfX005cooo]Z1?l00027oookJP?o001o0ooonfX3
o`00O`[ooo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0002aoookJPCo0000MooonfX0
05cooo]Z1?l00027oookJP?o001o0ooonfX3o`00O`[ooo]Z0ol007l9oookJP?o001o1ooonfX6o`00
0:oooo]Z1?l0001goookJP00FooonfX4o`0008Sooo]Z0ol007l3oookJP?o001o2_oonfX3o`00O`Wo
oo]Z0ol007l7oookJPCo0000/_oonfX4o`0007Kooo]Z001KoookJPCo0000R?oonfX3o`00O`?ooo]Z
0ol007l:oookJP?o001o1?oonfX2o`00O`;ooo]Z1?l007l7oookJPCo0000/_oonfX4o`0007Kooo]Z
001JoookJPCo0000ROoonfX3o`00O`?ooo]Z0ol007l:oookJP?o001o1?oonfX7o`00O`Sooo]Z1?l0
002coookJPCo0000MOoonfX005[ooo]Z1?l00029oookJP?o001o0ooonfX3o`00O`[ooo]Z0ol007l4
oookJPKo001o2OoonfX4o`000;?ooo]Z1?l0001eoookJP00FOoonfX4o`0008[ooo]Z0ol007l3oook
JP?o001o1ooonfX6o`00O`Cooo]Z0_l007l=oookJPCo0000]?oonfX4o`0007Cooo]Z001IoookJPCo
0000RooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1_l007l4oookJP;o001o3OoonfX4o`00
0;Cooo]Z1?l0001doookJP00F?oonfX4o`0008cooo]Z1ol007l:oookJPCo001o1OoonfX7o`00O`Oo
oo]Z1?l0002eoookJPCo0000LooonfX005Sooo]Z1?l0002=oookJPGo001o3?oonfX3o`00O`Gooo]Z
1ol007l7oookJPCo0000]OoonfX4o`0007?ooo]Z001GoookJPCo0000]OoonfX4o`000;Kooo]Z1?l0
001boookJP00EooonfX4o`000;Gooo]Z1?l0002foookJPGo0000LOoonfX005Kooo]Z1?l0002foook
JPCo0000]ooonfX4o`00077ooo]Z001FoookJPCo0000]_oonfX5o`000;Oooo]Z1?l0001`oookJP00
EOoonfX4o`000;Oooo]Z1?l0002hoookJPCo0000L?oonfX005Gooo]Z1?l0002goookJPCo0000^Ooo
nfX4o`0006oooo]Z001DoookJPCo0000^?oonfX4o`000;Wooo]Z1?l0001_oookJP00E?oonfX4o`00
0;Sooo]Z1?l0002joookJPCo0000K_oonfX005?ooo]Z1?l0002ioookJPCo0000^_oonfX4o`0006ko
oo]Z001CoookJPCo0000^OoonfX4o`000;_ooo]Z1?l0001]oookJP00D_oonfX4o`000;[ooo]Z1?l0
002koookJPCo0000KOoonfX005;ooo]Z1?l0002joookJPCo0000_?oonfX4o`0006cooo]Z001Aoook
JPCo0000^ooonfX4o`000;cooo]Z1?l0001/oookJP00DOoonfX4o`000;_ooo]Z1?l0002moookJPCo
0000JooonfX0053ooo]Z1?l0002loookJPGo0000_?oonfX4o`0006_ooo]Z001@oookJPCo0000_?oo
nfX4o`000;kooo]Z1?l0001ZoookJP00CooonfX4o`000;gooo]Z1?l0002noookJPCo0000J_oonfX0
04oooo]Z1?l0002moookJPCo0000_ooonfX4o`0006Wooo]Z001>oookJPCo0000__oonfX4o`000;oo
oo]Z1?l0001YoookJP00C_oonfX4o`000;kooo]Z1?l00030oookJPCo0000J?oonfX004gooo]Z1?l0
002ooookJPCo0000`?oonfX4o`0006Sooo]Z001=oookJPCo0000_ooonfX4o`000<7ooo]Z1?l0001W
oookJP00C?oonfX4o`000<3ooo]Z1?l00031oookJPCo0000IooonfX004cooo]Z1?l00030oookJPCo
0000`_oonfX4o`0006Kooo]Z001;oookJPCo0000`OoonfX4o`000<;ooo]Z1?l0001VoookJP00Booo
nfX4o`000<7ooo]Z1?l00033oookJP?o0000I_oonfX004_ooo]Z0ol00032oookJPGo0000`_oonfX4
o`0006Gooo]Z001:oookJPCo0000`_oonfX4o`000<?ooo]Z1?l0001UoookJP00B_oonfX4o`000<;o
oo]Z1?l00034oookJPCo0000I?oonfX004Wooo]Z1?l00033oookJPCo0000a?oonfX4o`0006Cooo]Z
0019oookJPCo0000`ooonfX4o`000<Gooo]Z1?l0001SoookJP00B?oonfX4o`000<Cooo]Z1?l00035
oookJPCo0000HooonfX004Sooo]Z1?l00034oookJPCo0000a_oonfX4o`0006;ooo]Z0017oookJPCo
0000aOoonfX4o`000<Kooo]Z1?l0001RoookJP00AooonfX4o`000<Gooo]Z1?l00037oookJPCo0000
HOoonfX004Kooo]Z1?l00036oookJPCo0000aooonfX4o`00067ooo]Z0016oookJPCo0000a_oonfX4
o`000<Sooo]Z0ol0001QoookJP00AOoonfX4o`000<Oooo]Z1?l00038oookJPCo0000H?oonfX004Go
oo]Z1?l00037oookJPGo0000aooonfX4o`00063ooo]Z0014oookJPCo0000b?oonfX4o`000<Wooo]Z
1?l0001OoookJP00A?oonfX4o`000<Sooo]Z1?l00039oookJPCo0000GooonfX004Cooo]Z0ol00039
oookJPCo0000b_oonfX4o`0005kooo]Z0013oookJPCo0000bOoonfX4o`000<[ooo]Z1?l0001Noook
JP00@ooonfX4o`000<Wooo]Z1?l0003;oookJPCo0000GOoonfX004;ooo]Z1?l0003:oookJPCo0000
booonfX4o`0005gooo]Z0012oookJPCo0000[OoonfX5o`00O`Cooo]Z0ol007l00ooonf[o001oo`00
O`07o`00O`Oooo]Z1?l0003<oookJPCo0000G?oonfX0047ooo]Z1?l0002]oookJPOo001o0ooonfX3
o`00O`03oookJ_l007oo001o00Oo001o1ooonfX4o`000<cooo]Z1?l0001LoookJP00@OoonfX4o`00
0:gooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l<
oookJPCo0000cOoonfX3o`0005cooo]Z0010oookJPCo0000[OoonfX3o`00O`?ooo]Z0ol007l7oook
JPCo001o2ooonfX4o`000<gooo]Z1?l0001KoookJP00@?oonfX4o`000:gooo]Z0ol007l3oookJP?o
001o2?oonfX5o`00O`Wooo]Z1_l0003;oookJPCo0000FooonfX003oooo]Z1?l0002^oookJP?o001o
0ooonfX3o`00O`[ooo]Z1?l007l8oookJPCo0000c_oonfX4o`0005[ooo]Z000ooookJPCo0000[_oo
nfX3o`00O`?ooo]Z0ol007l;oookJP?o001o2?oonfX4o`000<kooo]Z1?l0001JoookJP00?_oonfX4
o`000:oooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1?l0003?oookJPCo0000FOoonfX0
03kooo]Z1?l0002_oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1ooonfX4o`00
0<oooo]Z1?l0001IoookJP00?OoonfX4o`000;3ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?o
oo]Z0ol007l7oookJPCo0000d?oonfX4o`0005Sooo]Z000moookJPCo0000/OoonfX3o`00O`04oook
J_l007oo001oo`00O`Oooo]Z1?l007l2oookJP?o001o1ooonfX4o`0003cooo]Z0ol007l5oookJP?o
001o1OoonfX4o`00O`Sooo]Z1?l007l7oookJPCo001o1?oonfX5o`00Of3ooo]Z1?l0001HoookJP00
?OoonfX3o`000;;ooo]Z1ol007l8oookJPOo001o2?oonfX4o`0003cooo]Z0ol007l5oookJP?o001o
0ooonfX8o`00O`Cooo]Z2?l007l4oookJPGo001o0_oonfX8o`00Of3ooo]Z1?l0001GoookJP00??oo
nfX4o`000;?ooo]Z1Ol007l:oookJPGo001o2OoonfX4o`0003cooo]Z0ol007l5oookJP?o001o0ooo
nfX3o`00O`;ooo]Z0ol007l4oookJP?o001o0_oonfX3o`00O`Cooo]Z0ol007l4oookJP?o001o0ooo
nfX3o`00Oeoooo]Z1?l0001GoookJP00??oonfX4o`000=3ooo]Z1?l0000loookJP?o001o1OoonfX3
o`00O`;ooo]Z0ol007l4oookJP?o001o0_oonfX3o`00O`Cooo]Z0ol007l3oookJP?o001o2OoonfX4
o`00Of3ooo]Z0ol0001GoookJP00>ooonfX4o`000=7ooo]Z1?l0000loookJP?o001o1OoonfX3o`00
O`;ooo]Z0ol007l4oookJP?o001o0_oonfX3o`00O`Cooo]Z0ol007l3oookJP?o001o1_oonfX7o`00
Of3ooo]Z1?l0001FoookJP00>ooonfX4o`000=7ooo]Z1?l0000loookJP[o001o0ooonfX3o`00O`Co
oo]Z0ol007l2oookJP?o001o1?oonfX3o`00O`?ooo]Z0ol007l4oookJPOo001oH_oonfX4o`0005Ko
oo]Z000joookJPCo0000d_oonfX5o`0003_ooo]Z2_l007l3oookJP?o001o1?oonfX3o`00O`;ooo]Z
0ol007l4oookJP?o001o0ooonfX3o`00O`Cooo]Z1?l007mVoookJPCo0000EOoonfX003[ooo]Z1?l0
003BoookJPCo0000??oonfX3o`00O`Gooo]Z0ol007l3oookJP?o001o0_oonfX3o`00O`Cooo]Z0ol0
07l2oookJP?o001o1?oonfX3o`00O`Cooo]Z0ol007l3oookJP?o001oHOoonfX4o`0005Gooo]Z000i
oookJPCo0000dooonfX4o`0003cooo]Z0ol007l5oookJP?o001o0ooonfX8o`00O`Cooo]Z2?l007l3
oookJPKo001o0ooonfX7o`00Of?ooo]Z1?l0001DoookJP00>OoonfX4o`000=?ooo]Z1?l0000loook
JP?o001o1OoonfX3o`00O`Gooo]Z1?l007l8oookJPCo001o1OoonfX6o`00O`Cooo]Z1Ol007mToook
JPCo0000E?oonfX003Wooo]Z0ol0003DoookJPCo0000??oonfX3o`00O`Gooo]Z0ol007lKoookJP?o
001oL?oonfX3o`0005Cooo]Z000hoookJPCo0000e?oonfX4o`0003cooo]Z2_l007lLoookJP?o001o
L?oonfX4o`0005?ooo]Z000hoookJPCo0000e?oonfX4o`0003cooo]Z2Ol007n@oookJPCo0000Dooo
nfX003Oooo]Z1?l0003EoookJPCo0000e_oonfX4o`0005;ooo]Z000goookJPCo0000eOoonfX4o`00
0=Kooo]Z1?l0001BoookJP00=_oonfX4o`000=Kooo]Z1?l0001RoookJPGo001o4OoonfX5o`00Oe[o
oo]Z1?l0001AoookJP00=_oonfX4o`000=Kooo]Z1?l0001QoookJPOo001o3ooonfX7o`00OeWooo]Z
1?l0001AoookJP00=_oonfX3o`000=Oooo]Z1Ol0001OoookJP?o001o0ooonfX3o`00O`gooo]Z0ol0
07l3oookJP?o001oFOoonfX3o`00057ooo]Z000eoookJPCo0000eooonfX4o`0006Kooo]Z0ol007lC
oookJP?o001oFOoonfX4o`00053ooo]Z000eoookJPCo0000eooonfX4o`0003oooo]Z1Ol007l8oook
JPCo001o1OoonfX3o`00O`?ooo]Z0ol007l4oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX4
o`00O`04oookJ_l007oo001oo`00O`Cooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJPCo001o
00Cooo]Zo`00Ool007oo001o0ooonfX4o`00O`Cooo]Z1Ol007lnoookJPCo0000D?oonfX003Cooo]Z
1?l0003HoookJPCo0000?_oonfX7o`00O`Gooo]Z2?l007l3oookJP?o001o0ooonfX3o`00O`?ooo]Z
2?l007l2oookJPWo001o0ooonfX8o`00O`;ooo]Z2?l007l3oookJPGo001o0ooonfX7o`00Ockooo]Z
1?l0001?oookJP00=?oonfX4o`000=Sooo]Z1?l0000moookJP?o001o0ooonfX3o`00O`Cooo]Z0ol0
07l2oookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l2oookJPCo001o00?ooo]Zo`00Ool007l00_l0
07l2oookJP?o001o0_oonfX4o`00O`;ooo]Z1?l007l00ooonf[o001oo`00O`02o`00O`;ooo]Z0ol0
07l2oookJP?o001o0ooonfX3o`00O`Cooo]Z1?l007l2oookJP?o001o?OoonfX4o`0004oooo]Z000c
oookJPCo0000fOoonfX4o`0003gooo]Z0ol007l4oookJP?o001o0_oonfX3o`00O`Cooo]Z0ol007l2
oookJP?o001o0ooonfX3o`00O`;ooo]Z0ol007l3oookJP?o001o0_oonfX3o`00O`?ooo]Z0ol007l2
oookJP?o001o0ooonfX3o`00O`;ooo]Z0ol007l2oookJP?o001o0ooonfX3o`00O`Cooo]Z0ol007m4
oookJPCo0000C_oonfX003?ooo]Z1?l0003IoookJPCo0000??oonfX3o`00O`Gooo]Z0ol007l2oook
JP?o001o1?oonfX3o`00O`;ooo]Z0ol007l3oookJP?o001o0_oonfX3o`00O`?ooo]Z0ol007l2oook
JP?o001o0ooonfX3o`00O`;ooo]Z0ol007l3oookJP?o001o0_oonfX4o`00O`04oookJ_l007oo001o
o`00O`?ooo]Z0ol007l4oookJPWo001o?_oonfX4o`0004kooo]Z000coookJP?o0000f_oonfX4o`00
03cooo]Z0ol007l:oookJP?o001o1?oonfX3o`00O`;ooo]Z0ol007l3oookJP?o001o0_oonfX3o`00
O`?ooo]Z0ol007l2oookJP?o001o0ooonfX3o`00O`;ooo]Z0ol007l3oookJP?o001o0ooonfX7o`00
O`?ooo]Z0ol007l4oookJPWo001o?ooonfX3o`0004kooo]Z000boookJPCo0000f_oonfX4o`0003co
oo]Z0ol007l:oookJP?o001o1?oonfX3o`00O`;ooo]Z0ol007l3oookJP?o001o0_oonfX3o`00O`?o
oo]Z0ol007l2oookJP?o001o0ooonfX3o`00O`;ooo]Z0ol007l3oookJP?o001o1ooonfX3o`00O`?o
oo]Z0ol007l4oookJP?o001o0ooonfX3o`00Ocoooo]Z1?l0001=oookJP00<_oonfX4o`000=[ooo]Z
1?l0000loookJP?o001o2ooonfX3o`00O`;ooo]Z0ol007l3oookJPCo001o0_oonfX3o`00O`;ooo]Z
1?l007l00ooonf[o001oo`00O`02o`00O`;ooo]Z0ol007l3oookJP?o001o0_oonfX4o`00O`03oook
J_l007oo001o00;o001o0_oonfX3o`00O`;ooo]Z0ol007l3oookJP?o001o1?oonfX3o`00O`?ooo]Z
0ol007looookJPCo0000COoonfX0037ooo]Z1?l0003KoookJPCo0000??oonfX3o`00O`Gooo]Z0ol0
07l3oookJPSo001o0ooonfX9o`00O`?ooo]Z2?l007l2oookJP?o001o0ooonfX3o`00O`?ooo]Z2?l0
07l2oookJPSo001o0_oonfX6o`00O`?ooo]Z1ol007m1oookJPCo0000C?oonfX0037ooo]Z1?l0003K
oookJPCo0000?OoonfX3o`00O`Cooo]Z0ol007l5oookJPCo001o1OoonfX3o`00O`03oookJ_l007oo
001o00;o001o1OoonfX3o`00O`04oookJ_l007oo001oo`00O`;ooo]Z0ol007l3oookJP?o001o1?oo
nfX3o`00O`04oookJ_l007oo001oo`00O`Cooo]Z1?l007l4oookJPKo001o1?oonfX5o`00Od;ooo]Z
1?l0001<oookJP00<?oonfX4o`000=cooo]Z1Ol0000loookJP?o001o0ooonfX3o`00OdKooo]Z0ol0
07m>oookJPCo0000BooonfX0033ooo]Z1?l0003LoookJPCo0000?_oonfX8o`00OdKooo]Z0ol007m>
oookJPCo0000BooonfX0033ooo]Z0ol0003MoookJPCo0000?ooonfX5o`00Oi[ooo]Z0ol0001;oook
JP00;ooonfX4o`000=gooo]Z1?l0003NoookJPCo0000B_oonfX002oooo]Z1?l0003MoookJPCo0000
g_oonfX4o`0004[ooo]Z000^oookJPCo0000g_oonfX4o`0006Kooo]Z0ol007mfoookJPCo0000BOoo
nfX002kooo]Z1?l0003NoookJPCo0000I_oonfX3o`00OgKooo]Z1?l00019oookJP00;_oonfX3o`00
0=oooo]Z1?l0001VoookJP?o001oMooonfX3o`0004Wooo]Z000]oookJPCo0000gooonfX4o`0006Ko
oo]Z0ol007mgoookJPCo0000B?oonfX002gooo]Z1?l0003OoookJPCo0000?ooonfX5o`00O`Sooo]Z
1?l007l5oookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l2oookJP?o001o00Cooo]Zo`00Ool007oo
001o1?oonfX3o`00O`Cooo]Z1Ol007l4oookJP?o001o0ooonfX3o`00OeKooo]Z1?l00018oookJP00
;?oonfX4o`000>3ooo]Z1?l0000noookJPOo001o1OoonfX8o`00O`?ooo]Z0ol007l3oookJP?o001o
0ooonfX3o`00O`;ooo]Z2?l007l3oookJP?o001o0ooonfX7o`00O`Cooo]Z0ol007l01?oonf[o001o
o`00Ool007mHoookJPCo0000AooonfX002cooo]Z1?l0003PoookJPGo0000??oonfX3o`00O`?ooo]Z
0ol007l4oookJP?o001o0_oonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`;ooo]Z
1?l007l00ooonf[o001oo`00O`02o`00O`;ooo]Z0ol007l2oookJPCo001o0_oonfX3o`00O`?ooo]Z
0ol007l01?oonf[o001oo`00Ool007mHoookJPCo0000AooonfX002_ooo]Z1?l0003QoookJPCo0000
?OoonfX3o`00O`Cooo]Z0ol007l2oookJP?o001o1?oonfX3o`00O`;ooo]Z0ol007l3oookJP?o001o
0ooonfX3o`00O`;ooo]Z0ol007l3oookJP?o001o0_oonfX3o`00O`;ooo]Z0ol007l:oookJPGo001o
F_oonfX4o`0004Kooo]Z000[oookJPCo0000hOoonfX4o`0003cooo]Z0ol007l5oookJP?o001o0_oo
nfX3o`00O`Cooo]Z0ol007l2oookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l2oookJP?o001o0ooo
nfX3o`00O`;ooo]Z0ol007l2oookJPWo001o1OoonfX3o`00Oe_ooo]Z1?l00016oookJP00:ooonfX3
o`000>;ooo]Z1?l0000loookJP?o001o2_oonfX3o`00O`Cooo]Z0ol007l2oookJP?o001o0ooonfX3
o`00O`?ooo]Z0ol007l2oookJP?o001o0ooonfX3o`00O`;ooo]Z0ol007l2oookJPWo001o1OoonfX3
o`00Oecooo]Z0ol00016oookJP00:_oonfX4o`000>;ooo]Z1?l0000loookJP?o001o2_oonfX3o`00
O`Cooo]Z0ol007l2oookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l2oookJP?o001o0ooonfX3o`00
O`;ooo]Z0ol007l2oookJP?o001o0ooonfX3o`00O`Cooo]Z1Ol007mKoookJPCo0000AOoonfX002[o
oo]Z1?l0003RoookJPCo0000??oonfX3o`00O`_ooo]Z0ol007l2oookJP?o001o0ooonfX4o`00O`;o
oo]Z1?l007l2oookJP?o001o0_oonfX4o`00O`03oookJ_l007oo001o00;o001o0_oonfX3o`00O`;o
oo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00Oe[ooo]Z1?l00015oook
JP00:OoonfX4o`000>?ooo]Z1?l0000loookJP?o001o1OoonfX3o`00O`?ooo]Z2?l007l3oookJPoo
001o0_oonfX8o`00O`?ooo]Z0ol007l3oookJPOo001o1?oonfX3o`00O`04oookJ_l007oo001oo`00
Oe_ooo]Z1?l00014oookJP00:OoonfX4o`000>?ooo]Z1?l0000moookJP?o001o1?oonfX3o`00O`Go
oo]Z1?l007l5oookJP?o001o00?ooo]Zo`00Ool007l00_l007l2oookJPCo001o0ooonfX3o`00O`04
oookJ_l007oo001oo`00O`Cooo]Z0ol007l4oookJPGo001o1?oonfX3o`00O`?ooo]Z0ol007mJoook
JPCo0000A?oonfX002Sooo]Z1?l0002moookJPGo001o1?oonfX3o`00O`03oookJ_l007oo001o00Oo
001o0ooonfX5o`00O`Wooo]Z1?l0000moookJP?o001o0ooonfX3o`00Ob_ooo]Z0ol007maoookJPCo
0000@ooonfX002Sooo]Z1?l0002loookJPOo001o0ooonfX3o`00O`03oookJ_l007oo001o00Oo001o
0_oonfX7o`00O`Sooo]Z1?l0000noookJPSo001o:ooonfX3o`00Og7ooo]Z1?l00013oookJP00:?oo
nfX3o`000;gooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l0
0_l007l6oookJPCo001o00Cooo]Zo`00Ool007oo001o2?oonfX4o`0003oooo]Z1Ol007l]oookJP?o
001oL_oonfX3o`0004?ooo]Z000WoookJPCo0000_?oonfX3o`00O`?ooo]Z0ol007l7oookJPCo001o
1OoonfX3o`00O`?ooo]Z0ol007l7oookJPCo0000i_oonfX4o`0004;ooo]Z000WoookJPCo0000_?oo
nfX3o`00O`?ooo]Z0ol007l8oookJPGo001o2OoonfX3o`00O`Oooo]Z1_l0003ToookJPCo0000@_oo
nfX002Oooo]Z0ol0002moookJP?o001o0ooonfX3o`00O`[ooo]Z1?l007l8oookJP?o001o1ooonfX4
o`000>Oooo]Z0ol00012oookJP00iooonfX3o`00O`?ooo]Z0ol007l;oookJP?o001o0ooonfX2o`00
O`;ooo]Z1?l007l7oookJPCo0000oooonfX]oookJP00iooonfX3o`00O`?ooo]Z0ol007l<oookJP?o
001o0_oonfX7o`00O`Sooo]Z1?l0003ooookJRgooo]Z003WoookJP?o001o0ooonfX3o`00O`Kooo]Z
0ol007l3oookJP?o001o0_oonfX6o`00O`Wooo]Z1?l0003ooookJRgooo]Z003WoookJP?o001o0ooo
nfX3o`00O`Kooo]Z0ol007l3oookJP?o001o0_oonfX2o`00O`gooo]Z1?l0003ooookJRgooo]Z003X
oookJP?o001o00Cooo]Zo`00Ool007oo001o1ooonfX4o`00O`;ooo]Z0ol007l2oookJP;o001o3Ooo
nfX4o`000?oooo]Z;OoonfX00>Sooo]Z1ol007l8oookJPOo001o1?oonfX7o`00O`Oooo]Z1?l0003o
oookJRgooo]Z003YoookJPGo001o2_oonfX5o`00O`Gooo]Z1ol007l7oookJPCo0000oooonfX]oook
JP00oooonfXAoookJPCo0000oooonfX]oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oo
nfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]Z
oooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oook
JP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]Z3ooonfX00ol@47go001oojVW
L@3ooookJS3ooo]Z003ooookJPoooo]Z00?o<S9jo`00Ool007l0oooonfX`oookJP00oooonfX?oook
JP04olc8K_l007oo001ookZhKooooo]Z;ooonfX00?oooo]Z4?oonfX00onHUW;o001oohN5L`3ooook
JRoooo]Z003ooookJQ7ooo]Z00?oMgEeoc8bN_oonfX0oooonfX^oookJP00oooonfXBoookJP03o`00
OonHUW;ooo]Z0?oooo]Z;OoonfX00?oooo]Z4_oonfX00olQ8Gco411moiRFLP3ooookJRgooo]Z003o
oookJQ;ooo]Z00Co001ookZhKol007ooc<Q^oooonfX/oookJP00oooonfXAoookJP06olc8K_l007oo
oo]ZoeECMol@47gok^Y[oooonfX[oookJP00oooonfX>oookJP09o`00Oon7QG?ooo]ZogMeMOl007oo
oo]ZomgIK?l007ooIVAf0?oooo]Z:ooonfX00?oooo]Z3_oonfX01On7QG?o001oo`00Ool007oo<S9j
00;ooo]Z00?oEE=go`00OooMfF`0oooonfXZoookJP00oooonfX?oookJP04ohN5Lol007oo411molc8
KP;ooo]Z00?ogMU/oc8bN_m4@WT0oooonfXZoookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z
@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oo
oo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.17342, -0.0225929, \
0.00427295, 0.000864222}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "If the roots complex, then the sign of the real part is determined only by \
the sign of \[Beta]; i.e., \[Lambda] = ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[Beta]\)\/2\)]],
  "\[PlusMinus] ",
  Cell[BoxData[
      FormBox[
        SqrtBox[
          RowBox[{
            FormBox[\(\((\[Beta]\/2)\)\^2\),
              "TraditionalForm"], "-", " ", "\[Gamma]"}]], TraditionalForm]]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ComplexPosNeg\  = 
      ParametricPlot[{0, t}, {t, 0,  .25}, 
        PlotStyle \[Rule] {Thickness[0.015], Hue[0]}, 
        DisplayFunction \[Rule] Identity]\)], "Input"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ComplexPosNegAnnote\  = \ 
      Show[ComplexPosNeg, 
        Graphics[
          Text[StyleForm["\<Positive\nReal\nPart\>", 
              FontColor \[Rule] Hue[0]], {\(- .5\), 0.15}, {\(-1\), 1}]], 
        Graphics[
          Text[StyleForm["\<Negative\nReal\nPart\>", 
              FontColor \[Rule] Hue[0]], { .5, 0.15}, {1, 1}]], 
        DisplayFunction \[Rule] $DisplayFunction]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.0147151 2.35442 [
[.11905 .00222 -20.9688 -20 ]
[.11905 .00222 20.9688 0 ]
[.30952 .00222 -20.9688 -20 ]
[.30952 .00222 20.9688 0 ]
[.69048 .00222 -14.5 -20 ]
[.69048 .00222 14.5 0 ]
[.88095 .00222 -14.5 -20 ]
[.88095 .00222 14.5 0 ]
[.4875 .13244 -39 -10 ]
[.4875 .13244 0 10 ]
[.4875 .25016 -29 -10 ]
[.4875 .25016 0 10 ]
[.4875 .36788 -39 -10 ]
[.4875 .36788 0 10 ]
[.4875 .4856 -29 -10 ]
[.4875 .4856 0 10 ]
[.4875 .60332 -39 -10 ]
[.4875 .60332 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .01472 m
.11905 .02097 L
s
gsave
.11905 .00222 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.30952 .01472 m
.30952 .02097 L
s
gsave
.30952 .00222 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.69048 .01472 m
.69048 .02097 L
s
gsave
.69048 .00222 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.88095 .01472 m
.88095 .02097 L
s
gsave
.88095 .00222 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.125 Mabswid
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.07143 .01472 m
.07143 .01847 L
s
.02381 .01472 m
.02381 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.97619 .01472 m
.97619 .01847 L
s
.01 w
0 .01472 m
1 .01472 L
s
.25 Mabswid
.5 .13244 m
.50625 .13244 L
s
gsave
.4875 .13244 -100 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.05) show
1.000 setlinewidth
grestore
.5 .25016 m
.50625 .25016 L
s
gsave
.4875 .25016 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.1) show
1.000 setlinewidth
grestore
.5 .36788 m
.50625 .36788 L
s
gsave
.4875 .36788 -100 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.15) show
1.000 setlinewidth
grestore
.5 .4856 m
.50625 .4856 L
s
gsave
.4875 .4856 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.5 .60332 m
.50625 .60332 L
s
gsave
.4875 .60332 -100 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .03826 m
.50375 .03826 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .08535 m
.50375 .08535 L
s
.5 .10889 m
.50375 .10889 L
s
.5 .15598 m
.50375 .15598 L
s
.5 .17952 m
.50375 .17952 L
s
.5 .20307 m
.50375 .20307 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .2737 m
.50375 .2737 L
s
.5 .29724 m
.50375 .29724 L
s
.5 .32079 m
.50375 .32079 L
s
.5 .34433 m
.50375 .34433 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .41497 m
.50375 .41497 L
s
.5 .43851 m
.50375 .43851 L
s
.5 .46205 m
.50375 .46205 L
s
.5 .50914 m
.50375 .50914 L
s
.5 .53269 m
.50375 .53269 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57977 m
.50375 .57977 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.015 w
.5 .01472 m
.5 .01544 L
.5 .0161 L
.5 .01687 L
.5 .01759 L
.5 .01825 L
.5 .01887 L
.5 .01955 L
.5 .02026 L
.5 .02098 L
.5 .02176 L
.5 .02249 L
.5 .02315 L
.5 .02393 L
.5 .02438 L
.5 .02479 L
.5 .02554 L
.5 .02634 L
.5 .02674 L
.5 .02717 L
.5 .02793 L
.5 .02835 L
.5 .02875 L
.5 .02918 L
.5 .02965 L
.5 .03005 L
.5 .03049 L
.5 .03128 L
.5 .03205 L
.5 .03277 L
.5 .03346 L
.5 .03411 L
.5 .03482 L
.5 .03559 L
.5 .03635 L
.5 .03716 L
.5 .03784 L
.5 .03859 L
.5 .03903 L
.5 .03944 L
.5 .03988 L
.5 .04035 L
.5 .04114 L
.5 .04159 L
.5 .04201 L
.5 .04279 L
.5 .04351 L
.5 .0439 L
.5 .04433 L
.5 .04512 L
Mistroke
.5 .04559 L
.5 .04603 L
.5 .04643 L
.5 .04687 L
.5 .04734 L
.5 .04784 L
.5 .04826 L
.5 .04873 L
.5 .04917 L
.5 .04957 L
.5 .05003 L
.5 .05047 L
.5 .05124 L
.5 .05168 L
.5 .05208 L
.5 .0528 L
.5 .05358 L
.5 .05431 L
.5 .05498 L
.5 .05572 L
.5 .05654 L
.5 .05695 L
.5 .05738 L
.5 .05817 L
.5 .05861 L
.5 .05901 L
.5 .05945 L
.5 .05992 L
.5 .0607 L
.5 .06114 L
.5 .06156 L
.5 .06234 L
.5 .06304 L
.5 .06386 L
.5 .06463 L
.5 .06534 L
.5 .06609 L
.5 .06681 L
.5 .06746 L
.5 .06819 L
.5 .06899 L
.5 .06939 L
.5 .06982 L
.5 .07059 L
.5 .07102 L
.5 .07141 L
.5 .07184 L
.5 .0723 L
.5 .07306 L
.5 .0735 L
Mistroke
.5 .07391 L
.5 .07467 L
.5 .07536 L
.5 .07616 L
.5 .07692 L
.5 .07764 L
.5 .07829 L
.5 .07904 L
.5 .07975 L
.5 .0804 L
.5 .081 L
.5 .08167 L
.5 .08237 L
.5 .08307 L
.5 .08383 L
.5 .08455 L
.5 .0852 L
.5 .08596 L
.5 .08639 L
.5 .08679 L
.5 .08752 L
.5 .0883 L
.5 .08901 L
.5 .08978 L
.5 .09058 L
.5 .09133 L
.5 .09203 L
.5 .09267 L
.5 .0934 L
.5 .0941 L
.5 .09486 L
.5 .09566 L
.5 .09634 L
.5 .0971 L
.5 .09791 L
.5 .09836 L
.5 .09878 L
.5 .09958 L
.5 .10035 L
.5 .10106 L
.5 .10171 L
.5 .10245 L
.5 .10315 L
.5 .1038 L
.5 .1044 L
.5 .10506 L
.5 .10575 L
.5 .10646 L
.5 .10721 L
.5 .10792 L
Mistroke
.5 .10857 L
.5 .10932 L
.5 .10975 L
.5 .11015 L
.5 .11088 L
.5 .11165 L
.5 .11239 L
.5 .1132 L
.5 .11397 L
.5 .11468 L
.5 .11539 L
.5 .11603 L
.5 .11676 L
.5 .11746 L
.5 .11822 L
.5 .11902 L
.5 .11971 L
.5 .12046 L
.5 .12127 L
.5 .12173 L
.5 .12214 L
.5 .12295 L
.5 .12371 L
.5 .12436 L
.5 .12508 L
.5 .12582 L
.5 .12653 L
.5 .12718 L
.5 .12778 L
.5 .12844 L
.5 .12913 L
.5 .12983 L
.5 .13059 L
.5 .1313 L
.5 .13194 L
.5 .1327 L
.5 .13313 L
.5 .13353 L
.5 .13425 L
.5 .13502 L
.5 .13577 L
.5 .13658 L
.5 .13735 L
.5 .13807 L
.5 .13877 L
.5 .13942 L
.5 .14015 L
.5 .14085 L
.5 .14161 L
.5 .14242 L
Mistroke
.5 .14311 L
.5 .14386 L
.5 .14467 L
.5 .14513 L
.5 .14554 L
.5 .14635 L
.5 .14711 L
.5 .14776 L
.5 .14848 L
.5 .14923 L
.5 .14993 L
.5 .15059 L
.5 .15119 L
.5 .15184 L
.5 .15254 L
.5 .15324 L
.5 .154 L
.5 .15471 L
.5 .15535 L
.5 .15611 L
.5 .15654 L
.5 .15694 L
.5 .15766 L
.5 .15843 L
.5 .15918 L
.5 .16 L
.5 .16077 L
.5 .16149 L
.5 .16213 L
.5 .16284 L
.5 .16358 L
.5 .16427 L
.5 .16504 L
.5 .16585 L
.5 .16654 L
.5 .16729 L
.5 .16811 L
.5 .16856 L
.5 .16898 L
.5 .16978 L
.5 .17055 L
.5 .1712 L
.5 .17192 L
.5 .17267 L
.5 .17337 L
.5 .17403 L
.5 .17463 L
.5 .17532 L
.5 .17598 L
.5 .17668 L
Mistroke
.5 .17744 L
.5 .17815 L
.5 .17879 L
.5 .17956 L
.5 .17998 L
.5 .18038 L
.5 .1811 L
.5 .18187 L
.5 .18262 L
.5 .18305 L
.5 .18344 L
.5 .18417 L
.5 .18494 L
.5 .18562 L
.5 .18626 L
.5 .18697 L
.5 .18773 L
.5 .18849 L
.5 .18892 L
.5 .18933 L
.5 .19014 L
.5 .19059 L
.5 .19101 L
.5 .19175 L
.5 .19255 L
.5 .19331 L
.5 .19401 L
.5 .19466 L
.5 .19537 L
.5 .19603 L
.5 .19663 L
.5 .19734 L
.5 .19811 L
.5 .19884 L
.5 .19952 L
.5 .20028 L
.5 .201 L
.5 .20164 L
.5 .20234 L
.5 .2031 L
.5 .2039 L
.5 .20459 L
.5 .20534 L
.5 .20615 L
.5 .2069 L
.5 .20729 L
.5 .20772 L
.5 .20817 L
.5 .20859 L
.5 .20937 L
Mistroke
.5 .21007 L
.5 .21089 L
.5 .21167 L
.5 .21236 L
.5 .2131 L
.5 .21379 L
.5 .21442 L
.5 .21516 L
.5 .21597 L
.5 .21673 L
.5 .21743 L
.5 .21818 L
.5 .21898 L
.5 .21973 L
.5 .22042 L
.5 .22123 L
.5 .22169 L
.5 .22211 L
.5 .22289 L
.5 .22328 L
.5 .22372 L
.5 .22413 L
.5 .22458 L
.5 .22537 L
.5 .2258 L
.5 .22621 L
.5 .22666 L
.5 .22714 L
.5 .22756 L
.5 .22801 L
.5 .22844 L
.5 .22883 L
.5 .22957 L
.5 .23036 L
.5 .23111 L
.5 .23192 L
.5 .23269 L
.5 .23341 L
.5 .23411 L
.5 .23475 L
.5 .23549 L
.5 .23619 L
.5 .23695 L
.5 .23776 L
.5 .23844 L
.5 .2392 L
.5 .24001 L
.5 .24046 L
.5 .24088 L
.5 .24169 L
Mistroke
.5 .24245 L
.5 .2431 L
.5 .24382 L
.5 .24456 L
.5 .24527 L
.5 .24592 L
.5 .24652 L
.5 .24718 L
.5 .24787 L
.5 .24858 L
.5 .24933 L
.5 .25004 L
.5 .25069 L
.5 .25145 L
.5 .25188 L
.5 .25227 L
.5 .253 L
.5 .25376 L
.5 .25451 L
.5 .25533 L
.5 .2561 L
.5 .25682 L
.5 .25753 L
.5 .25817 L
.5 .25891 L
.5 .2596 L
.5 .26037 L
.5 .26118 L
.5 .26186 L
.5 .26262 L
.5 .26343 L
.5 .26389 L
.5 .2643 L
.5 .26511 L
.5 .26587 L
.5 .26653 L
.5 .26724 L
.5 .26799 L
.5 .2687 L
.5 .26935 L
.5 .26995 L
.5 .27064 L
.5 .2713 L
.5 .27201 L
.5 .27276 L
.5 .27348 L
.5 .27412 L
.5 .27488 L
.5 .27531 L
.5 .2757 L
Mistroke
.5 .27643 L
.5 .2772 L
.5 .27795 L
.5 .27838 L
.5 .27877 L
.5 .27949 L
.5 .28026 L
.5 .28094 L
.5 .28159 L
.5 .28229 L
.5 .28305 L
.5 .28381 L
.5 .28425 L
.5 .28465 L
.5 .28546 L
.5 .28591 L
.5 .28633 L
.5 .28707 L
.5 .28787 L
.5 .28863 L
.5 .28933 L
.5 .28998 L
.5 .29069 L
.5 .29135 L
.5 .29195 L
.5 .29266 L
.5 .29343 L
.5 .29416 L
.5 .29483 L
.5 .2956 L
.5 .29632 L
.5 .29696 L
.5 .29766 L
.5 .29842 L
.5 .29922 L
.5 .29991 L
.5 .30066 L
.5 .30147 L
.5 .30222 L
.5 .30261 L
.5 .30304 L
.5 .30349 L
.5 .30391 L
.5 .30468 L
.5 .30539 L
.5 .30617 L
.5 .30698 L
.5 .30767 L
.5 .30841 L
.5 .3091 L
Mistroke
.5 .30973 L
.5 .31048 L
.5 .31128 L
.5 .31204 L
.5 .31274 L
.5 .31349 L
.5 .31429 L
.5 .31505 L
.5 .31574 L
.5 .31654 L
.5 .317 L
.5 .31743 L
.5 .3182 L
.5 .31859 L
.5 .31903 L
.5 .31945 L
.5 .31989 L
.5 .32068 L
.5 .32112 L
.5 .32152 L
.5 .32197 L
.5 .32245 L
.5 .32287 L
.5 .32332 L
.5 .32375 L
.5 .32414 L
.5 .32489 L
.5 .32567 L
.5 .32642 L
.5 .32723 L
.5 .328 L
.5 .32871 L
.5 .32942 L
.5 .33006 L
.5 .3308 L
.5 .3315 L
.5 .33226 L
.5 .33306 L
.5 .33375 L
.5 .3345 L
.5 .33531 L
.5 .33577 L
.5 .33618 L
.5 .33699 L
.5 .33775 L
.5 .3384 L
.5 .33912 L
.5 .33987 L
.5 .34057 L
.5 .34122 L
Mistroke
.5 .34182 L
.5 .34248 L
.5 .34317 L
.5 .34388 L
.5 .34463 L
.5 .34534 L
.5 .34599 L
.5 .34675 L
.5 .34718 L
.5 .34757 L
.5 .3483 L
.5 .34907 L
.5 .34982 L
.5 .35063 L
.5 .3514 L
.5 .35212 L
.5 .35283 L
.5 .35347 L
.5 .35421 L
.5 .3549 L
.5 .35567 L
.5 .35647 L
.5 .35716 L
.5 .35792 L
.5 .35873 L
.5 .35919 L
.5 .3596 L
.5 .36041 L
.5 .36117 L
.5 .36182 L
.5 .36254 L
.5 .36329 L
.5 .36399 L
.5 .36465 L
.5 .36525 L
.5 .36594 L
.5 .3666 L
.5 .36731 L
.5 .36806 L
.5 .36877 L
.5 .36942 L
.5 .37018 L
.5 .37061 L
.5 .371 L
.5 .37173 L
.5 .37249 L
.5 .37324 L
.5 .37367 L
.5 .37406 L
.5 .37479 L
Mistroke
.5 .37555 L
.5 .37624 L
.5 .37688 L
.5 .37758 L
.5 .37834 L
.5 .37911 L
.5 .37954 L
.5 .37994 L
.5 .38075 L
.5 .38121 L
.5 .38162 L
.5 .38236 L
.5 .38316 L
.5 .38392 L
.5 .38462 L
.5 .38527 L
.5 .38597 L
.5 .38664 L
.5 .38724 L
.5 .38795 L
.5 .38872 L
.5 .38945 L
.5 .39012 L
.5 .39089 L
.5 .3916 L
.5 .39225 L
.5 .39294 L
.5 .39371 L
.5 .39451 L
.5 .3952 L
.5 .39595 L
.5 .39676 L
.5 .39751 L
.5 .3979 L
.5 .39833 L
.5 .39877 L
.5 .3992 L
.5 .39997 L
.5 .40067 L
.5 .40145 L
.5 .40227 L
.5 .40296 L
.5 .40369 L
.5 .40439 L
.5 .40502 L
.5 .40576 L
.5 .40656 L
.5 .40732 L
.5 .40802 L
.5 .40877 L
Mistroke
.5 .40957 L
.5 .41033 L
.5 .41102 L
.5 .41183 L
.5 .41228 L
.5 .41271 L
.5 .41348 L
.5 .41387 L
.5 .41431 L
.5 .41473 L
.5 .41517 L
.5 .41596 L
.5 .41639 L
.5 .4168 L
.5 .41725 L
.5 .41773 L
.5 .41815 L
.5 .4186 L
.5 .41903 L
.5 .41942 L
.5 .42017 L
.5 .42095 L
.5 .4217 L
.5 .42251 L
.5 .42328 L
.5 .42399 L
.5 .4247 L
.5 .42534 L
.5 .42608 L
.5 .42677 L
.5 .42753 L
.5 .42834 L
.5 .42902 L
.5 .42978 L
.5 .43059 L
.5 .43104 L
.5 .43146 L
.5 .43227 L
.5 .43303 L
.5 .43368 L
.5 .43439 L
.5 .43514 L
.5 .43584 L
.5 .4365 L
.5 .4371 L
.5 .43775 L
.5 .43845 L
.5 .43915 L
.5 .43991 L
.5 .44062 L
Mistroke
.5 .44126 L
.5 .44202 L
.5 .44245 L
.5 .44285 L
.5 .44357 L
.5 .44434 L
.5 .44509 L
.5 .4459 L
.5 .44667 L
.5 .44739 L
.5 .4481 L
.5 .44874 L
.5 .44948 L
.5 .45017 L
.5 .45094 L
.5 .45174 L
.5 .45243 L
.5 .45319 L
.5 .454 L
.5 .45445 L
.5 .45487 L
.5 .45568 L
.5 .45644 L
.5 .45709 L
.5 .45781 L
.5 .45856 L
.5 .45926 L
.5 .45991 L
.5 .46051 L
.5 .46117 L
.5 .46186 L
.5 .46257 L
.5 .46332 L
.5 .46404 L
.5 .46468 L
.5 .46544 L
.5 .46587 L
.5 .46626 L
.5 .46699 L
.5 .46776 L
.5 .46851 L
.5 .46893 L
.5 .46933 L
.5 .47005 L
.5 .47082 L
.5 .4715 L
.5 .47214 L
.5 .47285 L
.5 .47361 L
.5 .47437 L
Mistroke
.5 .4748 L
.5 .4752 L
.5 .47601 L
.5 .47647 L
.5 .47688 L
.5 .47762 L
.5 .47842 L
.5 .47918 L
.5 .47988 L
.5 .48053 L
.5 .48123 L
.5 .48189 L
.5 .4825 L
.5 .48321 L
.5 .48398 L
.5 .4847 L
.5 .48538 L
.5 .48614 L
.5 .48686 L
.5 .4875 L
.5 .4882 L
.5 .48896 L
.5 .48977 L
.5 .49045 L
.5 .49121 L
.5 .49201 L
.5 .49276 L
.5 .49315 L
.5 .49358 L
.5 .49403 L
.5 .49445 L
.5 .49522 L
.5 .49593 L
.5 .4967 L
.5 .49752 L
.5 .49821 L
.5 .49895 L
.5 .49964 L
.5 .50027 L
.5 .50101 L
.5 .50182 L
.5 .50258 L
.5 .50328 L
.5 .50402 L
.5 .50482 L
.5 .50558 L
.5 .50627 L
.5 .50708 L
.5 .50753 L
.5 .50796 L
Mistroke
.5 .50873 L
.5 .50917 L
.5 .50956 L
.5 .50998 L
.5 .51042 L
.5 .5112 L
.5 .51164 L
.5 .51205 L
.5 .5125 L
.5 .51298 L
.5 .5134 L
.5 .51385 L
.5 .51428 L
.5 .51467 L
.5 .51542 L
.5 .5162 L
.5 .51695 L
.5 .51776 L
.5 .51853 L
.5 .51924 L
.5 .51995 L
.5 .52058 L
.5 .52132 L
.5 .52202 L
.5 .52278 L
.5 .52358 L
.5 .52427 L
.5 .52502 L
.5 .52583 L
.5 .52629 L
.5 .5267 L
.5 .52751 L
.5 .52827 L
.5 .52892 L
.5 .52964 L
.5 .53038 L
.5 .53109 L
.5 .53174 L
.5 .53234 L
.5 .533 L
.5 .53369 L
.5 .53439 L
.5 .53515 L
.5 .53586 L
.5 .5365 L
.5 .53726 L
.5 .53769 L
.5 .53809 L
.5 .53881 L
.5 .53958 L
Mistroke
.5 .54033 L
.5 .54114 L
.5 .54191 L
.5 .54263 L
.5 .54334 L
.5 .54398 L
.5 .54472 L
.5 .54541 L
.5 .54618 L
.5 .54698 L
.5 .54767 L
.5 .54842 L
.5 .54924 L
.5 .54969 L
.5 .55011 L
.5 .55091 L
.5 .55168 L
.5 .55233 L
.5 .55304 L
.5 .55379 L
.5 .55449 L
.5 .55515 L
.5 .55575 L
.5 .55641 L
.5 .5571 L
.5 .55781 L
.5 .55856 L
.5 .55927 L
.5 .55992 L
.5 .56068 L
.5 .5611 L
.5 .5615 L
.5 .56222 L
.5 .56299 L
.5 .56374 L
.5 .56417 L
.5 .56456 L
.5 .56528 L
.5 .56605 L
.5 .56673 L
.5 .56737 L
.5 .56808 L
.5 .56884 L
.5 .5696 L
.5 .57003 L
.5 .57043 L
.5 .57124 L
.5 .57169 L
.5 .57211 L
.5 .57285 L
Mistroke
.5 .57365 L
.5 .57441 L
.5 .57511 L
.5 .57576 L
.5 .57646 L
.5 .57712 L
.5 .57773 L
.5 .57843 L
.5 .5792 L
.5 .57993 L
.5 .58061 L
.5 .58137 L
.5 .58209 L
.5 .58273 L
.5 .58343 L
.5 .58419 L
.5 .58499 L
.5 .58568 L
.5 .58643 L
.5 .58698 L
.5 .58748 L
.5 .58804 L
.5 .58862 L
.5 .58913 L
.5 .58961 L
.5 .59013 L
.5 .5907 L
.5 .59117 L
.5 .59169 L
.5 .59222 L
.5 .59273 L
.5 .5932 L
.5 .59362 L
.5 .59412 L
.5 .59458 L
.5 .59509 L
.5 .59564 L
.5 .59622 L
.5 .59677 L
.5 .59727 L
.5 .59773 L
.5 .59827 L
.5 .59878 L
.5 .59932 L
.5 .5999 L
.5 .60045 L
.5 .60095 L
.5 .60154 L
.5 .60217 L
.5 .60277 L
Mistroke
.5 .60332 L
Mfstroke
0 g
gsave
.02381 .36788 -61 -62 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 66 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(Positive) show
63.000 38.000 moveto
(Real) show
63.000 57.000 moveto
(Part) show
97.938 57.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .36788 -139.812 -62 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 66 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(Negative) show
63.000 38.000 moveto
(Real) show
63.000 57.000 moveto
(Part) show
97.938 57.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00COoonfX5o`00O`Cooo]Z0ol007l6oook
JP?o001oD_oonfX5o`00O`Cooo]Z0ol007l00ooonf[o001oo`00O`07o`00Ok7ooo]Z1Ol007l4oook
JP?o001o00?ooo]Zo`00Ool007l01ol007mAoookJPGo001o1?oonfX3o`00O`Kooo]Z0ol007m9oook
JP00C?oonfX7o`00O`?ooo]Z0ol007l6oookJP?o001oDOoonfX7o`00O`?ooo]Z0ol007l00ooonf[o
001oo`00O`07o`00Ok3ooo]Z1ol007l3oookJP?o001o00?ooo]Zo`00Ool007l01ol007m@oookJPOo
001o0ooonfX3o`00O`Kooo]Z0ol007m9oookJP00C?oonfX3o`00O`04oookJ_l007oo001oo`00O`?o
oo]Z0ol007l6oookJP?o001oDOoonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooo
nf[o001oo`00O`02o`00OkGooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Z
o`00Ool007l00_l007mEoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol0
07m9oookJP00@?oonfX:o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l6oookJPWo001o@ooo
nfX:o`00O`;ooo]Z0ol007l3oookJP?o001o1ooonfX4o`00Ok?ooo]Z0ol007l3oookJP?o001o1ooo
nfX4o`00Oe?ooo]Z0ol007l3oookJP?o001o1_oonfX9o`00OdSooo]Z0010oookJP[o001o00Cooo]Z
o`00Ool007oo001o0ooonfX3o`00O`Kooo]Z2Ol007m3oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol0
07l8oookJPGo001o/OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo001oDOoonfX3o`00O`?ooo]Z0ol0
07l6oookJPWo001oB?oonfX004_ooo]Z0ol007l3oookJP?o001o1_oonfX2o`00O`?ooo]Z0ol007m@
oookJP?o001o0ooonfX3o`00O`[ooo]Z1?l007n`oookJP?o001o0ooonfX3o`00O`[ooo]Z1?l007m@
oookJP?o001o0ooonfX3o`00O`Kooo]Z0_l007l3oookJP?o001oBOoonfX004_ooo]Z0ol007l3oook
JP?o001o1ooonfX2o`00O`;ooo]Z0ol007m@oookJP?o001o0ooonfX3o`00O`_ooo]Z0ol007n`oook
JP?o001o0ooonfX3o`00O`_ooo]Z0ol007m@oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oook
JP?o001oBOoonfX004_ooo]Z0ol007l3oookJP?o001o1ooonfX3o`00O`04oookJ_l007oo001oo`00
Oe3ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ojoooo]Z0ol007l3oookJP?o001o3?oonfX3o`00
Odoooo]Z0ol007l3oookJP?o001o1ooonfX3o`00O`04oookJ_l007oo001oo`00OdWooo]Z001;oook
JP?o001o0ooonfX3o`00O`Sooo]Z0_l007l01?oonf[o001oo`00Ool007m@oookJP?o001o0ooonfX3
o`00O`Kooo]Z0ol007l3oookJP?o001o[ooonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3
o`00Odoooo]Z0ol007l3oookJP?o001o2?oonfX2o`00O`04oookJ_l007oo001oo`00OdWooo]Z001;
oookJP?o001o0ooonfX3o`00O`Wooo]Z1Ol007m@oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3
oookJP?o001o[ooonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00Odoooo]Z0ol007l3
oookJP?o001o2OoonfX5o`00OdWooo]Z001<oookJP?o001o00Cooo]Zo`00Ool007oo001o2_oonfX5
o`00Oe7ooo]Z0ol007l01?oonf[o001oo`00Ool007l7oookJPCo001o0_oonfX3o`00Oe?ooo]Z1Ol0
001HoookJP?o001o00Cooo]Zo`00Ool007oo001o1ooonfX4o`00O`;ooo]Z0ol007m@oookJP?o001o
00Cooo]Zo`00Ool007oo001o2_oonfX5o`00OdWooo]Z001<oookJPOo001o2ooonfX4o`00Oe7ooo]Z
1ol007l8oookJPOo001oE?oonfX5o`0005Sooo]Z1ol007l8oookJPOo001oDOoonfX7o`00O`_ooo]Z
1?l007m9oookJP00COoonfX5o`00O`gooo]Z0ol007mBoookJPGo001o2_oonfX5o`00OeGooo]Z1Ol0
001IoookJPGo001o2_oonfX5o`00Oe?ooo]Z1Ol007l=oookJP?o001oBOoonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7?oonfX8ool00?oooo]Z7_oo
nfX000oooo]Zool0000=o`0000Soo`00ool0000>o`00013ooo]Z000?oookJ_oo00003Ol00008ool0
0?oo00003_l0000@oookJP003ooonf[oo`0000go00002?oo003oo`0000ko00004?oonfX000oooo]Z
ool0000=o`0000Soo`00ool0000>o`00013ooo]Z000?oookJ_oo00003Ol00008ool00?oo00003_l0
000@oookJP00DOoonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z063ooo]Z2?oo001S
oookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0D?oonfX0057ooo]Z00?o0000oook
J_oonfX0I?oonfX00ol0003ooo]ZoookJP1PoookJPSoo`00HooonfX00ol0003ooo]ZoookJP1Toook
JP03o`000?oonf[ooo]Z053ooo]Z003ooookJQcooo]Z2?oo003ooookJQkooo]Z003ooookJQcooo]Z
2?oo003ooookJQkooo]Z003ooookJQcooo]Z2?oo003ooookJQkooo]Z003ooookJQcooo]Z2?oo003o
oookJQkooo]Z003ooookJQcooo]Z2?oo003ooookJQkooo]Z003ooookJQcooo]Z2?oo003ooookJQko
oo]Z003ooookJQcooo]Z2?oo003ooookJQkooo]Z003ooookJQcooo]Z2?oo003ooookJQkooo]Z003o
oookJQcooo]Z2?oo003ooookJQkooo]Z003ooookJQcooo]Z2?oo003ooookJQkooo]Z003ooookJQco
oo]Z2?oo003ooookJQkooo]Z003ooookJQcooo]Z2?oo003ooookJQkooo]Z003ooookJQcooo]Z2?oo
003ooookJQkooo]Z003ooookJQcooo]Z2?oo003ooookJQkooo]Z003ooookJQcooo]Z2?oo003ooook
JQkooo]Z003ooookJQcooo]Z2?oo003ooookJQkooo]Z003ooookJQcooo]Z2?oo003ooookJQkooo]Z
003ooookJQcooo]Z2?oo003ooookJQkooo]Z003ooookJQcooo]Z2?oo003ooookJQkooo]Z003ooook
JQcooo]Z2?oo003ooookJQkooo]Z003ooookJQcooo]Z2?oo003ooookJQkooo]Z003ooookJQcooo]Z
2?oo003ooookJQkooo]Z003ooookJQcooo]Z2?oo003ooookJQkooo]Z003ooookJQcooo]Z2?oo003o
oookJQkooo]Z003ooookJQcooo]Z2?oo003ooookJQkooo]Z003ooookJQcooo]Z2?oo003ooookJQko
oo]Z003ooookJQcooo]Z2?oo003ooookJQkooo]Z003ooookJQcooo]Z2?oo003ooookJQkooo]Z003o
oookJQcooo]Z2?oo003ooookJQkooo]Z003ooookJQcooo]Z2?oo003ooookJQkooo]Z003ooookJQco
oo]Z2?oo003ooookJQkooo]Z003ooookJQcooo]Z2?oo003ooookJQkooo]Z003ooookJQcooo]Z2?oo
003ooookJQkooo]Z003ooookJQcooo]Z2?oo003ooookJQkooo]Z003ooookJQcooo]Z2?oo003ooook
JQkooo]Z003ooookJQcooo]Z2?oo003ooookJQkooo]Z003ooookJQcooo]Z2?oo003ooookJQkooo]Z
003ooookJQcooo]Z2?oo003ooookJQkooo]Z003ooookJQcooo]Z2?oo003ooookJQkooo]Z003ooook
JQcooo]Z2?oo003ooookJQkooo]Z003ooookJQcooo]Z2?oo003ooookJQkooo]Z003ooookJQcooo]Z
2?oo003ooookJQkooo]Z003ooookJQcooo]Z2?oo003ooookJQkooo]Z003ooookJQcooo]Z2?oo003o
oookJQkooo]Z003ooookJQcooo]Z2?oo003ooookJQkooo]Z003ooookJQcooo]Z2?oo003ooookJQko
oo]Z003ooookJQcooo]Z2?oo003ooookJQkooo]Z003ooookJQcooo]Z2?oo003ooookJQkooo]Z003o
oookJQcooo]Z2?oo003ooookJQkooo]Z003ooookJQcooo]Z2?oo003ooookJQkooo]Z003ooookJQco
oo]Z2?oo003ooookJQkooo]Z003ooookJQcooo]Z2?oo003ooookJQkooo]Z003ooookJQcooo]Z2?oo
003ooookJQkooo]Z003ooookJQcooo]Z2?oo003ooookJQkooo]Z003ooookJQcooo]Z2?oo003ooook
JQkooo]Z003eoookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l5oookJPGo001o2?oonfX8ool00?oo
oo]Z7_oonfX00?Cooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`?ooo]Z1ol007l7oookJPSoo`00
oooonfXNoookJP00m?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l2oookJP?o001o
00Cooo]Zo`00Ool007oo001o0_oonfX4o`00O`04oookJ_l007oo001oo`00O`Oooo]Z2?oo003ooook
JQkooo]Z003coookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool0
07oo001o0ooonfX3o`00O`Kooo]Z2?oo003ooookJQkooo]Z003coookJP?o001o0ooonfX3o`00O`Ko
oo]Z0ol007l3oookJP?o001o1ooonfX3o`00O`Kooo]Z2?oo003ooookJQkooo]Z003coookJP?o001o
0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1ooonfX3o`00O`Kooo]Z2?oo003ooookJQkooo]Z
003coookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o0_oonfX2o`00O`;ooo]Z1?l0
07l6oookJPSoo`00oooonfXNoookJP00looonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3
o`00O`;ooo]Z1ol007l7oookJPSoo`00oooonfXNoookJP00looonfX3o`00O`?ooo]Z0ol007l6oook
JP?o001o0ooonfX3o`00O`;ooo]Z1_l007l8oookJPSoo`00oooonfXNoookJP00looonfX3o`00O`?o
oo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`;ooo]Z0_l007l<oookJPSoo`00oooonfXNoookJP00
m?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP;o001o3?oonfX8ool00?oooo]Z7_oonfX00?Cooo]Z1ol007l8oookJPOo001o1?oonfX7o`00O`Ko
oo]Z2?oo003ooookJQkooo]Z003eoookJPGo001o2_oonfX5o`00O`Gooo]Z1ol007l6oookJPSoo`00
oooonfXNoookJP00oooonfXLoookJPSoo`00oooonfXNoookJP00oooonfXLoookJPSoo`00oooonfXN
oookJP00oooonfXLoookJPSoo`00oooonfXNoookJP00oooonfXLoookJPSoo`00oooonfXNoookJP00
oooonfXLoookJPSoo`00oooonfXNoookJP00oooonfXLoookJPSoo`00oooonfXNoookJP00oooonfXL
oookJPSoo`00oooonfXNoookJP00oooonfXLoookJPSoo`00oooonfXNoookJP00oooonfXLoookJPSo
o`00oooonfXNoookJP00oooonfXLoookJPSoo`00oooonfXNoookJP00oooonfXLoookJPSoo`00oooo
nfXNoookJP00oooonfXLoookJPSoo`00oooonfXNoookJP00oooonfXLoookJPSoo`00oooonfXNoook
JP00oooonfXLoookJPSoo`00oooonfXNoookJP00oooonfXLoookJPSoo`00oooonfXNoookJP00oooo
nfXLoookJPSoo`00oooonfXNoookJP00oooonfXLoookJPSoo`00oooonfXNoookJP00oooonfXLoook
JPSoo`00oooonfXNoookJP00oooonfXLoookJPSoo`00oooonfXNoookJP00oooonfXLoookJPSoo`00
oooonfXNoookJP00oooonfXLoookJPSoo`00oooonfXNoookJP00oooonfXLoookJPSoo`00oooonfXN
oookJP00oooonfXLoookJPSoo`00oooonfXNoookJP00oooonfXLoookJPSoo`00oooonfXNoookJP00
oooonfXLoookJPSoo`00oooonfXNoookJP00oooonfXLoookJPSoo`00oooonfXNoookJP00oooonfXL
oookJPSoo`00oooonfXNoookJP00oooonfXLoookJPSoo`00oooonfXNoookJP00oooonfXLoookJPSo
o`00oooonfXNoookJP00oooonfXLoookJPSoo`00oooonfXNoookJP00oooonfXLoookJPSoo`00oooo
nfXNoookJP00oooonfXLoookJPSoo`00oooonfXNoookJP00oooonfXLoookJPSoo`00oooonfXNoook
JP00oooonfXLoookJPSoo`00oooonfXNoookJP00oooonfXLoookJPSoo`00oooonfXNoookJP00oooo
nfXLoookJPSoo`00oooonfXNoookJP00oooonfXLoookJPSoo`00oooonfXNoookJP00oooonfXLoook
JPSoo`00oooonfXNoookJP00oooonfXLoookJPSoo`00oooonfXNoookJP00oooonfXLoookJPSoo`00
oooonfXNoookJP00oooonfXLoookJPSoo`00oooonfXNoookJP00oooonfXLoookJPSoo`00oooonfXN
oookJP00oooonfXLoookJPSoo`00oooonfXNoookJP00oooonfXLoookJPSoo`00oooonfXNoookJP00
oooonfXLoookJPSoo`00oooonfXNoookJP00oooonfXLoookJPSoo`00oooonfXNoookJP00oooonfXL
oookJPSoo`00oooonfXNoookJP00oooonfXLoookJPSoo`00oooonfXNoookJP00oooonfXLoookJPSo
o`00oooonfXNoookJP00oooonfXLoookJPSoo`00oooonfXNoookJP00oooonfX5o`00O`Cooo]Z0ol0
07l5oookJP?o001o2?oonfX8ool00?oooo]Z7_oonfX00?kooo]Z1ol007l3oookJP?o001o1OoonfX3
o`00O`Sooo]Z2?oo003ooookJQkooo]Z003noookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3
o`00O`Gooo]Z0ol007l8oookJPSoo`00oooonfXNoookJP00oOoonfX3o`00O`?ooo]Z0ol007l:oook
JP?o001o2?oonfX8ool00?oooo]Z7_oonfX00?gooo]Z0ol007l3oookJP?o001o2_oonfX3o`00O`So
oo]Z2?oo003ooookJQkooo]Z003moookJP?o001o0ooonfX3o`00O`[ooo]Z0ol007l8oookJPSoo`00
oooonfXNoookJP00oOoonfX3o`00O`?ooo]Z0ol007l:oookJP?o001o2?oonfX8ool00?oooo]Z7_oo
nfX00?gooo]Z0ol007l3oookJP?o001o2_oonfX3o`00O`Sooo]Z2?oo003ooookJQkooo]Z003moook
JP?o001o0ooonfX3o`00O`[ooo]Z0ol007l8oookJPSoo`00oooonfXNoookJP00oOoonfX3o`00O`?o
oo]Z0ol007l7oookJPKo001o2?oonfX8ool00?oooo]Z7_oonfX00?kooo]Z0ol007l01?oonf[o001o
o`00Ool007l8oookJPKo001o2?oonfX8ool00?oooo]Z7_oonfX00?kooo]Z1ol007l:oookJPCo001o
2?oonfX8ool00?oooo]Z7_oonfX00?oooo]Z1Ol007l<oookJP?o001o2?oonfX8ool00?oooo]Z7_oo
nfX00?oooo]Z7?oonfX8ool00?oooo]Z7_oonfX00?oooo]Z7?oonfX8ool00?oooo]Z7_oonfX00?oo
oo]Z7?oonfX8ool00?oooo]Z7_oonfX0027ooo]Z0ooo000:oookJPCoo`0000Gooo]Zool00?oo003o
o`00oookJP03ool000Kooo]Z1?oo003GoookJPSoo`00/OoonfX3ool000[ooo]Z1?oo00001Ooonf[o
o`00ool00?oo003ooo]Z00?oo`001_oonfX4ool004Wooo]Z000QoookJP?oo`002OoonfX8ool000;o
oo]Z0ooo0005oookJPGoo`00eooonfX8ool00;7ooo]Z0ooo0009oookJPSoo`000_oonfX3ool000Go
oo]Z1Ooo0019oookJP008OoonfX3ool000Wooo]Z0ooo0002oookJP?oo`000_oonfX3ool000Gooo]Z
0ooo003IoookJPSoo`00/OoonfX3ool000Wooo]Z0ooo0002oookJP?oo`000_oonfX3ool000Gooo]Z
0ooo001;oookJP008OoonfX3ool000Wooo]Z0ooo0002oookJP?oo`000_oonfX3ool000Gooo]Z0ooo
003IoookJPSoo`00/OoonfX3ool000Wooo]Z0ooo0002oookJP?oo`000_oonfX3ool000Gooo]Z0ooo
001;oookJP008OoonfX3ool000Wooo]Z1?oo00001?oonf[oo`00ool00?oo0002oookJP?oo`001Ooo
nfX3ool00=Wooo]Z2?oo002aoookJP?oo`002OoonfX4ool00004oookJ_oo003oo`00ool000;ooo]Z
0ooo0005oookJP?oo`00BooonfX0027ooo]Z2?oo0005oookJPOoo`000_oonfX3ool000Gooo]Z0ooo
003IoookJPSoo`00/OoonfX8ool000Gooo]Z1ooo0002oookJP?oo`001OoonfX3ool004_ooo]Z000Q
oookJPWoo`002?oonfX3ool000;ooo]Z1?oo0004oookJP?oo`00fOoonfX8ool00;7ooo]Z2Ooo0008
oookJP?oo`000_oonfX4ool000Cooo]Z0ooo001;oookJP008OoonfX3ool000?ooo]Z1?oo0002oook
JP?oo`000_oonfX3ool000;ooo]Z1_oo0002oookJP?oo`00fOoonfX8ool00;7ooo]Z0ooo0003oook
JPCoo`000_oonfX3ool000;ooo]Z0ooo0002oookJPKoo`000_oonfX3ool004_ooo]Z000QoookJP?o
o`001?oonfX3ool000;ooo]Z2?oo0002oookJPKoo`0000?ooo]Zool00?oo00001?oo003GoookJPSo
o`00/OoonfX3ool000Cooo]Z0ooo0002oookJPSoo`000_oonfX6ool00003oookJ_oo003oo`0000Co
o`00BOoonfX0027ooo]Z0ooo0004oookJP?oo`001?oonfX4ool000Cooo]Z0ooo00001?oonf[oo`00
ool00?oonfX6ool00=Oooo]Z2?oo002aoookJP?oo`001?oonfX3ool000Cooo]Z1?oo0004oookJP?o
o`0000Cooo]Zool00?oo003ooo]Z1_oo0019oookJP008OoonfX3ool000?ooo]Z1?oo000DoookJP?o
o`00fOoonfX8ool00;7ooo]Z0ooo0003oookJPCoo`005?oonfX3ool004_ooo]Z000QoookJPWoo`00
5OoonfX3ool00=Wooo]Z2?oo002aoookJPWoo`005OoonfX3ool004_ooo]Z000QoookJPSoo`00l_oo
nfX8ool00;7ooo]Z2?oo001ToookJP00oooonfXLoookJPSoo`00oooonfXNoookJP00oooonfXLoook
JPSoo`00oooonfXNoookJP00oooonfXLoookJPSoo`00oooonfXNoookJP00oooonfXLoookJPSoo`00
oooonfXNoookJP00oooonfXLoookJPSoo`00oooonfXNoookJP00oooonfXLoookJPSoo`00oooonfXN
oookJP008OoonfX3ool000Gooo]Z0ooo0004oookJPGoo`001OoonfX4ool00005oookJ_oo003oo`00
ool00?oonfX00ooo003EoookJPSoo`00/OoonfX3ool000Gooo]Z0ooo0004oookJPGoo`001OoonfX4
ool00005oookJ_oo003oo`00ool00?oonfX00ooo0017oookJP008OoonfX3ool000Gooo]Z0ooo0003
oookJPOoo`000ooonfX8ool000;ooo]Z0ooo003EoookJPSoo`00/OoonfX3ool000Gooo]Z0ooo0003
oookJPOoo`000ooonfX8ool000;ooo]Z0ooo0017oookJP008OoonfX3ool000Gooo]Z0ooo0002oook
JPCoo`000_oonfX3ool000;ooo]Z0ooo0002oookJP?oo`000_oonfX3ool00=Gooo]Z2?oo002aoook
JP?oo`001OoonfX3ool000;ooo]Z1?oo0002oookJP?oo`000_oonfX3ool000;ooo]Z0ooo0002oook
JP?oo`00AooonfX0027ooo]Z0ooo0005oookJP?oo`000_oonfX3ool000Sooo]Z0ooo0002oookJP?o
o`000_oonfX3ool00=Gooo]Z2?oo002aoookJP?oo`001OoonfX3ool000;ooo]Z0ooo0008oookJP?o
o`000_oonfX3ool000;ooo]Z0ooo0017oookJP008OoonfX3ool000Gooo]Z0ooo0002oookJPWoo`00
0_oonfX4ool00004oookJ_oo003oo`00ool000;ooo]Z0ooo003EoookJPSoo`00/OoonfX3ool000Go
oo]Z0ooo0002oookJPWoo`000_oonfX4ool00004oookJ_oo003oo`00ool000;ooo]Z0ooo0017oook
JP008OoonfX:ool000?ooo]Z2Ooo0003oookJPOoo`000_oonfX3ool00=Gooo]Z2?oo002aoookJP[o
o`000ooonfX9ool000?ooo]Z1ooo0002oookJP?oo`00AooonfX0027ooo]Z2_oo0003oookJP?oo`00
0ooonfX3ool000Oooo]Z0ooo0002oookJP?oo`00eOoonfX8ool00;7ooo]Z2_oo0003oookJP?oo`00
0ooonfX3ool000Oooo]Z0ooo0002oookJP?oo`00AooonfX0027ooo]Z0ooo0005oookJP?oo`000_oo
nfX3ool000?ooo]Z0ooo0002oookJP?oo`000_oonfX3ool000;ooo]Z0ooo003EoookJPSoo`00/Ooo
nfX3ool000Gooo]Z0ooo0002oookJP?oo`000ooonfX3ool000;ooo]Z0ooo0002oookJP?oo`000_oo
nfX3ool004Oooo]Z000QoookJP?oo`001OoonfX3ool000?ooo]Z1ooo0003oookJPSoo`000_oonfX3
ool00=Gooo]Z2?oo002aoookJP?oo`001OoonfX3ool000?ooo]Z1ooo0003oookJPSoo`000_oonfX3
ool004Oooo]Z000QoookJP?oo`001OoonfX3ool000Cooo]Z1Ooo0006oookJPCoo`001?oonfX3ool0
0=Gooo]Z2?oo002aoookJP?oo`001OoonfX3ool000Cooo]Z1Ooo0006oookJPCoo`001?oonfX3ool0
04Oooo]Z000QoookJP?oo`001OoonfX3ool001Oooo]Z0ooo003EoookJPSoo`00/OoonfX3ool000Go
oo]Z0ooo000GoookJP?oo`00AooonfX0027ooo]Z2_oo000HoookJP?oo`00eOoonfX8ool00;7ooo]Z
2_oo000HoookJP?oo`00AooonfX0027ooo]Z2Ooo000IoookJP?oo`00eOoonfX8ool00;7ooo]Z2Ooo
000IoookJP?oo`00AooonfX00?oooo]Z7?oonfX8ool00?oooo]Z7_oonfX00?oooo]Z7?oonfX8ool0
0?oooo]Z7_oonfX00?oooo]Z7?oonfX8ool00<[ooo]Z1Ooo001>oookJP00oooonfXLoookJPSoo`00
bOoonfX7ool004gooo]Z003ooookJQcooo]Z2?oo0038oookJP?oo`000ooonfX3ool004cooo]Z003o
oookJQcooo]Z2?oo003>oookJP?oo`00C?oonfX0027ooo]Z0ooo000<oookJPCoo`001ooonfX5ool0
00Cooo]Z0ooo0004oookJPCoo`000_oonfX3ool000Cooo]Z1Ooo0005oookJPGoo`00]?oonfX8ool0
0;7ooo]Z0ooo0004oookJP?oo`001?oonfX5ool000Kooo]Z0ooo00001?oonf[oo`00ool00?oo0003
oookJPCoo`0000Cooo]Zool00?oo003oo`000ooonfX4ool000;ooo]Z0ooo0004oookJPGoo`001Ooo
nfX5ool002;ooo]Z000QoookJP?oo`002_oonfX8ool000?ooo]Z2?oo0003oookJP?oo`000ooonfX5
ool000;ooo]Z0ooo0004oookJPGoo`001?oonfX7ool00;?ooo]Z2?oo002aoookJP?oo`000ooonfX4
ool000?ooo]Z1ooo0004oookJPSoo`000_oonfX8ool000?ooo]Z1Ooo0002oookJP?oo`001?oonfX5
ool000Cooo]Z1ooo000QoookJP008OoonfX3ool000[ooo]Z0ooo0002oookJP?oo`000ooonfX3ool0
00?ooo]Z0ooo0002oookJP?oo`000ooonfX3ool000Cooo]Z0ooo0003oookJPOoo`000_oonfX4ool0
00;ooo]Z0ooo002boookJPSoo`00/OoonfX3ool000?ooo]Z1?oo0002oookJPCoo`000_oonfX3ool0
00;ooo]Z1?oo00000ooonf[oo`00ool00002ool000;ooo]Z0ooo0002oookJP?oo`000ooonfX3ool0
00Cooo]Z0ooo0003oookJPOoo`000_oonfX4ool000;ooo]Z0ooo000PoookJP008OoonfX3ool000Wo
oo]Z0ooo0004oookJP?oo`001ooonfX4ool000;ooo]Z0ooo0003oookJP?oo`001?oonfX3ool000?o
oo]Z0ooo00001?oonf[oo`00ool00?oo0002oookJP?oo`00^?oonfX8ool00;7ooo]Z0ooo0002oook
JPGoo`000_oonfX3ool000Sooo]Z0ooo0003oookJP?oo`000_oonfX3ool000;ooo]Z0ooo0003oook
JP?oo`001?oonfX3ool000?ooo]Z0ooo00001?oonf[oo`00ool00?oo0002oookJP?oo`009_oonfX0
027ooo]Z0ooo0009oookJP?oo`001?oonfX3ool000Cooo]Z1ooo0002oookJP?oo`000ooonfX3ool0
00Cooo]Z0ooo0003oookJP?oo`0000Cooo]Zool00?oo003oo`000_oonfX9ool00;;ooo]Z2?oo002a
oookJP?oo`000_oonfX5ool000;ooo]Z2Ooo0002oookJP?oo`000ooonfX3ool000;ooo]Z1?oo0000
1?oonf[oo`00ool00?oo0003oookJP?oo`001?oonfX3ool000?ooo]Z0ooo00001?oonf[oo`00ool0
0?oo0002oookJPWoo`008?oonfX0027ooo]Z2?oo0004oookJP?oo`001?oonfX3ool000;ooo]Z1ooo
0004oookJP?oo`000ooonfX3ool000Cooo]Z0ooo0003oookJP?oo`0000Cooo]Zool00?oo003oo`00
0_oonfX9ool00;;ooo]Z2?oo002aoookJP?oo`0000?ooo]Zool00?oo00001?oo0002oookJPWoo`00
0_oonfX3ool000?ooo]Z0ooo0003oookJPOoo`000ooonfX3ool000Cooo]Z0ooo0003oookJP?oo`00
00Cooo]Zool00?oo003oo`000_oonfX9ool0023ooo]Z000QoookJPWoo`000ooonfX3ool000Cooo]Z
0ooo0002oookJPCoo`001ooonfX3ool000?ooo]Z0ooo0004oookJP?oo`000_oonfX3ool000?ooo]Z
0ooo00001?oonf[oo`00ool00?oo0003oookJP?oo`00/_oonfX8ool00;7ooo]Z0ooo00001?oonf[o
o`00ool00?oonfX3ool000;ooo]Z0ooo0003oookJP?oo`000_oonfX3ool000?ooo]Z0ooo0007oook
JP?oo`000ooonfX3ool000Cooo]Z0ooo0002oookJP?oo`000ooonfX3ool00004oookJ_oo003oo`00
ool000?ooo]Z0ooo000PoookJP008OoonfX3ool000?ooo]Z1?oo0003oookJP?oo`000_oonfX3ool0
00?ooo]Z0ooo0003oookJP?oo`000_oonfX3ool000?ooo]Z0ooo0004oookJP?oo`000_oonfX3ool0
00?ooo]Z0ooo00001?oonf[oo`00ool00?oo0003oookJP?oo`00/_oonfX8ool00;7ooo]Z1_oo0000
1?oonf[oo`00ool00?oo0002oookJP?oo`000ooonfX3ool000;ooo]Z1?oo00000ooonf[oo`00ool0
0002ool000;ooo]Z0ooo0002oookJP?oo`000ooonfX3ool000Cooo]Z0ooo0002oookJP?oo`000ooo
nfX3ool00004oookJ_oo003oo`00ool000?ooo]Z0ooo000PoookJP008OoonfX3ool000Cooo]Z0ooo
0003oookJPSoo`001?oonfX7ool000?ooo]Z0ooo0002oookJPKoo`000_oonfX3ool000;ooo]Z0ooo
0003oookJP?oo`000_oonfX7ool00;?ooo]Z2?oo002aoookJPGoo`000_oonfX3ool000?ooo]Z1ooo
0004oookJPSoo`000_oonfX8ool000;ooo]Z1_oo0002oookJP?oo`000_oonfX3ool000?ooo]Z0ooo
0002oookJPOoo`008OoonfX0027ooo]Z0ooo0004oookJP?oo`001OoonfX4ool000Oooo]Z1Ooo0004
oookJP?oo`000_oonfX6ool000;ooo]Z0ooo00001?oonf[oo`00ool00?oo0005oookJP?oo`000_oo
nfX5ool00;Cooo]Z2?oo002aoookJPGoo`000_oonfX3ool000Cooo]Z1Ooo0006oookJP?oo`0000Co
oo]Zool00?oo003oo`001?oonfX4ool000Cooo]Z1_oo0002oookJP?oo`0000Cooo]Zool00?oo003o
o`001OoonfX3ool000;ooo]Z1Ooo000RoookJP008OoonfX3ool000?ooo]Z1?oo000OoookJP?oo`00
Z?oonfX5o`00O`Cooo]Z0ol007l5oookJP?o001o1OoonfX5o`00O`Sooo]Z2?oo002aoookJPCoo`00
0ooonfX3ool002?ooo]Z0ooo000loookJP008OoonfX9ool001[ooo]Z0ooo0003oookJP?oo`001?oo
nfX3ool00:3ooo]Z1ol007l3oookJP?o001o1OoonfX3o`00O`Cooo]Z1ol007l7oookJPSoo`00/Ooo
nfX4ool000?ooo]Z0ooo000SoookJP?oo`001?oonfX3ool003Gooo]Z000QoookJPSoo`006ooonfX3
ool000[ooo]Z0ooo002PoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Gooo]Z0ol0
07l3oookJPCo001o00Cooo]Zo`00Ool007oo001o1ooonfX8ool00;7ooo]Z0ooo0004oookJP?oo`00
:_oonfX3ool003Gooo]Z003coookJP?o001o0ooonfX3o`00O`[ooo]Z0ol007l3oookJP?o001o0ooo
nfX3o`00O`Kooo]Z2?oo003ooookJQkooo]Z003coookJP?o001o0ooonfX3o`00O`[ooo]Z0ol007l9
oookJP?o001o1_oonfX8ool00?oooo]Z7_oonfX00??ooo]Z0ol007l3oookJP?o001o2_oonfX3o`00
O`Wooo]Z0ol007l6oookJPSoo`00oooonfXNoookJP00looonfX3o`00O`?ooo]Z0ol007l:oookJP?o
001o1?oonfX2o`00O`;ooo]Z1?l007l6oookJPSoo`00oooonfXNoookJP00looonfX3o`00O`?ooo]Z
0ol007l:oookJP?o001o1?oonfX7o`00O`Oooo]Z2?oo003ooookJQkooo]Z003coookJP?o001o0ooo
nfX3o`00O`[ooo]Z0ol007l4oookJPKo001o2?oonfX8ool00?oooo]Z7_oonfX00??ooo]Z0ol007l3
oookJP?o001o1ooonfX6o`00O`Cooo]Z0_l007l<oookJPSoo`00oooonfXNoookJP00m?oonfX3o`00
O`04oookJ_l007oo001oo`00O`Sooo]Z1_l007l4oookJP;o001o3?oonfX8ool00?oooo]Z7_oonfX0
0?Cooo]Z1ol007l:oookJPCo001o1OoonfX7o`00O`Kooo]Z2?oo003ooookJQkooo]Z003eoookJPGo
001o3?oonfX3o`00O`Gooo]Z1ol007l6oookJPSoo`00oooonfXNoookJP00oooonfXLoookJPSoo`00
oooonfXNoookJP00oooonfXLoookJPSoo`00oooonfXNoookJP00oooonfXLoookJPSoo`00oooonfXN
oookJP00oooonfXLoookJPSoo`00oooonfXNoookJP00oooonfXLoookJPSoo`00oooonfXNoookJP00
oooonfXLoookJPSoo`00oooonfXNoookJP00oooonfXLoookJPSoo`00oooonfXNoookJP00oooonfXL
oookJPSoo`00oooonfXNoookJP00oooonfXLoookJPSoo`00oooonfXNoookJP00oooonfXLoookJPSo
o`00oooonfXNoookJP00oooonfXLoookJPSoo`00oooonfXNoookJP00oooonfXLoookJPSoo`00oooo
nfXNoookJP00oooonfXLoookJPSoo`00oooonfXNoookJP00oooonfXLoookJPSoo`00oooonfXNoook
JP00oooonfXLoookJPSoo`00oooonfXNoookJP00oooonfXLoookJPSoo`00oooonfXNoookJP00oooo
nfXLoookJPSoo`00oooonfXNoookJP00oooonfXLoookJPSoo`00oooonfXNoookJP00oooonfXLoook
JPSoo`00oooonfXNoookJP00oooonfXLoookJPSoo`00oooonfXNoookJP00oooonfXLoookJPSoo`00
oooonfXNoookJP00oooonfXLoookJPSoo`00oooonfXNoookJP00oooonfXLoookJPSoo`00oooonfXN
oookJP00oooonfXLoookJPSoo`00oooonfXNoookJP00oooonfXLoookJPSoo`00oooonfXNoookJP00
oooonfXLoookJPSoo`00oooonfXNoookJP00oooonfXLoookJPSoo`00oooonfXNoookJP00oooonfXL
oookJPSoo`00oooonfXNoookJP00oooonfXLoookJPSoo`00oooonfXNoookJP00oooonfXLoookJPSo
o`00oooonfXNoookJP00oooonfXLoookJPSoo`00oooonfXNoookJP00oooonfXLoookJPSoo`00oooo
nfXNoookJP00oooonfXLoookJPSoo`00oooonfXNoookJP00oooonfXLoookJPSoo`00oooonfXNoook
JP00oooonfXLoookJPSoo`00oooonfXNoookJP00oooonfXLoookJPSoo`00oooonfXNoookJP00oooo
nfXLoookJPSoo`00oooonfXNoookJP00oooonfXLoookJPSoo`00oooonfXNoookJP00oooonfXLoook
JPSoo`00oooonfXNoookJP00oooonfXLoookJPSoo`00oooonfXNoookJP00oooonfXLoookJPSoo`00
oooonfXNoookJP00oooonfXLoookJPSoo`00oooonfXNoookJP00oooonfXLoookJPSoo`00oooonfXN
oookJP00oooonfXLoookJPSoo`00oooonfXNoookJP00oooonfXLoookJPSoo`00oooonfXNoookJP00
oooonfXLoookJPSoo`00oooonfXNoookJP00oooonfXLoookJPSoo`00oooonfXNoookJP00oooonfXL
oookJPSoo`00oooonfXNoookJP00oooonfXLoookJPSoo`00oooonfXNoookJP00oooonfXLoookJPSo
o`00oooonfXNoookJP00oooonfX5o`00O`Cooo]Z0ol007l00ooonf[o001oo`00O`07o`00O`Kooo]Z
2?oo003ooookJQkooo]Z003noookJPOo001o0ooonfX3o`00O`03oookJ_l007oo001o00Oo001o1_oo
nfX8ool00?oooo]Z7_oonfX00?kooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?o
oo]Zo`00Ool007l00_l007l;oookJPSoo`00oooonfXNoookJP00oOoonfX3o`00O`?ooo]Z0ol007l7
oookJPCo001o2_oonfX8ool00?oooo]Z7_oonfX00?gooo]Z0ol007l3oookJP?o001o2?oonfX5o`00
O`Sooo]Z2?oo003ooookJQkooo]Z003moookJP?o001o0ooonfX3o`00O`[ooo]Z1?l007l7oookJPSo
o`00oooonfXNoookJP00oOoonfX3o`00O`?ooo]Z0ol007l;oookJP?o001o1ooonfX8ool00?oooo]Z
7_oonfX00?gooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Kooo]Z2?oo003ooookJQkooo]Z003m
oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1_oonfX8ool00?oooo]Z7_oonfX0
0?gooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l6oookJPSoo`00oooonfXNoook
JP00o_oonfX3o`00O`04oookJ_l007oo001oo`00O`Oooo]Z1?l007l2oookJP?o001o1_oonfX8ool0
0?oooo]Z7_oonfX00?kooo]Z1ol007l8oookJPOo001o1ooonfX8ool00?oooo]Z7_oonfX00?oooo]Z
1Ol007l:oookJPGo001o2?oonfX8ool00?oooo]Z7_oonfX00?oooo]Z7?oonfX8ool00?oooo]Z7_oo
nfX00?oooo]Z7?oonfX8ool00?oooo]Z7_oonfX00?oooo]Z7?oonfX8ool00?oooo]Z7_oonfX00?oo
oo]Z7?oonfX8ool00?oooo]Z7_oonfX00?oooo]Z7?oonfX8ool00?oooo]Z7_oonfX00?oooo]Z7?oo
nfX8ool00?oooo]Z7_oonfX00?oooo]Z7?oonfX8ool00?oooo]Z7_oonfX00?oooo]Z7?oonfX8ool0
0?oooo]Z7_oonfX00?oooo]Z7?oonfX8ool00?oooo]Z7_oonfX00?oooo]Z7?oonfX8ool00?oooo]Z
7_oonfX00?oooo]Z7?oonfX8ool00?oooo]Z7_oonfX00?oooo]Z7?oonfX8ool00?oooo]Z7_oonfX0
0?oooo]Z7?oonfX8ool00?oooo]Z7_oonfX00?oooo]Z7?oonfX8ool00?oooo]Z7_oonfX00?oooo]Z
7?oonfX8ool00?oooo]Z7_oonfX00?oooo]Z7?oonfX8ool00?oooo]Z7_oonfX00?oooo]Z7?oonfX8
ool00?oooo]Z7_oonfX00?oooo]Z7?oonfX8ool00?oooo]Z7_oonfX00?oooo]Z7?oonfX8ool00?oo
oo]Z7_oonfX00?oooo]Z7?oonfX8ool00?oooo]Z7_oonfX00?oooo]Z7?oonfX8ool00?oooo]Z7_oo
nfX00?oooo]Z7?oonfX8ool00?oooo]Z7_oonfX00?oooo]Z7?oonfX8ool00?oooo]Z7_oonfX00?oo
oo]Z7?oonfX8ool00?oooo]Z7_oonfX00?oooo]Z7?oonfX8ool00?oooo]Z7_oonfX00?oooo]Z7?oo
nfX8ool00?oooo]Z7_oonfX00?oooo]Z7?oonfX8ool00?oooo]Z7_oonfX00?oooo]Z7?oonfX8ool0
0?oooo]Z7_oonfX00?oooo]Z7?oonfX8ool00?oooo]Z7_oonfX00?oooo]Z7?oonfX8ool00?oooo]Z
7_oonfX00?oooo]Z7?oonfX8ool00?oooo]Z7_oonfX00?oooo]Z7?oonfX8ool00?oooo]Z7_oonfX0
0?oooo]Z7?oonfX8ool00?oooo]Z7_oonfX00?oooo]Z7?oonfX8ool00?oooo]Z7_oonfX00?oooo]Z
7?oonfX8ool00?oooo]Z7_oonfX00?oooo]Z7?oonfX8ool00?oooo]Z7_oonfX00?oooo]Z7?oonfX8
ool00?oooo]Z7_oonfX00?oooo]Z7?oonfX8ool00?oooo]Z7_oonfX00?oooo]Z7?oonfX8ool00?oo
oo]Z7_oonfX00?oooo]Z7?oonfX8ool00?oooo]Z7_oonfX00?oooo]Z7?oonfX8ool00?oooo]Z7_oo
nfX00?oooo]Z7?oonfX8ool00?oooo]Z7_oonfX00?oooo]Z7?oonfX8ool00?oooo]Z7_oonfX00?oo
oo]Z7?oonfX8ool00?oooo]Z7_oonfX00?oooo]Z7?oonfX8ool00?oooo]Z7_oonfX00?oooo]Z7?oo
nfX8ool00?oooo]Z7_oonfX00?oooo]Z7?oonfX8ool00?oooo]Z7_oonfX00?oooo]Z7?oonfX8ool0
0?oooo]Z7_oonfX00?oooo]Z7?oonfX8ool00?oooo]Z7_oonfX00?oooo]Z7?oonfX8ool00?oooo]Z
7_oonfX00?oooo]Z7?oonfX8ool00?oooo]Z7_oonfX00?Gooo]Z1Ol007l4oookJP?o001o00?ooo]Z
o`00Ool007l01ol007l3oookJPGo001o2?oonfX8ool00?oooo]Z7_oonfX00?Cooo]Z1ol007l3oook
JP?o001o00?ooo]Zo`00Ool007l01ol007l2oookJPOo001o1ooonfX8ool00?oooo]Z7_oonfX00?Co
oo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l6oook
JPCo001o00Cooo]Zo`00Ool007oo001o1ooonfX8ool00?oooo]Z7_oonfX00??ooo]Z0ol007l3oook
JP?o001o1ooonfX4o`00O`Gooo]Z0ol007l3oookJP?o001o1_oonfX8ool00?oooo]Z7_oonfX00??o
oo]Z0ol007l3oookJP?o001o2?oonfX5o`00O`Wooo]Z0ol007l6oookJPSoo`00oooonfXNoookJP00
looonfX3o`00O`?ooo]Z0ol007l:oookJPCo001o2?oonfX3o`00O`Kooo]Z2?oo003ooookJQkooo]Z
003coookJP?o001o0ooonfX3o`00O`_ooo]Z0ol007l3oookJP;o001o0_oonfX4o`00O`Kooo]Z2?oo
003ooookJQkooo]Z003coookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l2oookJPOo001o1ooonfX8
ool00?oooo]Z7_oonfX00??ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l2oook
JPKo001o2?oonfX8ool00?oooo]Z7_oonfX00??ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?o
oo]Z0ol007l2oookJP;o001o3_oonfX5o`000?oooo]Z7ooonfX00?Cooo]Z0ol007l01?oonf[o001o
o`00Ool007l7oookJPCo001o0_oonfX3o`00O`;ooo]Z0_l007l>oookJPGo0000oooonfXOoookJP00
m?oonfX7o`00O`Sooo]Z1ol007l4oookJPOo001o2?oonfX5o`000?oooo]Z7ooonfX00?Gooo]Z1Ol0
07l:oookJPGo001o1OoonfX7o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-0.559534, -0.0210535, \
0.0019462, 0.000787255}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ComplexPlot\  = Show[ComplexRealAnnote, ComplexPosNegAnnote]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.0147151 2.35442 [
[.02381 .00222 -13.4688 -20 ]
[.02381 .00222 13.4688 0 ]
[.2619 .00222 -20.9688 -20 ]
[.2619 .00222 20.9688 0 ]
[.7381 .00222 -14.5 -20 ]
[.7381 .00222 14.5 0 ]
[.97619 .00222 -7 -20 ]
[.97619 .00222 7 0 ]
[1.025 .01472 0 -10 ]
[1.025 .01472 15.9375 10 ]
[.4875 .13244 -39 -10 ]
[.4875 .13244 0 10 ]
[.4875 .25016 -29 -10 ]
[.4875 .25016 0 10 ]
[.4875 .36788 -39 -10 ]
[.4875 .36788 0 10 ]
[.4875 .4856 -29 -10 ]
[.4875 .4856 0 10 ]
[.4875 .60332 -39 -10 ]
[.4875 .60332 0 10 ]
[.5 .64303 -7.28125 0 ]
[.5 .64303 7.28125 20 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .02097 L
s
gsave
.02381 .00222 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .01472 m
.2619 .02097 L
s
gsave
.2619 .00222 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .01472 m
.7381 .02097 L
s
gsave
.7381 .00222 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .01472 m
.97619 .02097 L
s
gsave
.97619 .00222 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.01 w
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
%%BeginResource: font Helvetica-Bold-MISO
%%BeginFont: Helvetica-Bold-MISO
/Helvetica-Bold /Helvetica-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
0.000 0.000 rmoveto
64.750 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(b) show
74.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.5 .13244 m
.50625 .13244 L
s
gsave
.4875 .13244 -100 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.05) show
1.000 setlinewidth
grestore
.5 .25016 m
.50625 .25016 L
s
gsave
.4875 .25016 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.1) show
1.000 setlinewidth
grestore
.5 .36788 m
.50625 .36788 L
s
gsave
.4875 .36788 -100 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.15) show
1.000 setlinewidth
grestore
.5 .4856 m
.50625 .4856 L
s
gsave
.4875 .4856 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.5 .60332 m
.50625 .60332 L
s
gsave
.4875 .60332 -100 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .03826 m
.50375 .03826 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .08535 m
.50375 .08535 L
s
.5 .10889 m
.50375 .10889 L
s
.5 .15598 m
.50375 .15598 L
s
.5 .17952 m
.50375 .17952 L
s
.5 .20307 m
.50375 .20307 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .2737 m
.50375 .2737 L
s
.5 .29724 m
.50375 .29724 L
s
.5 .32079 m
.50375 .32079 L
s
.5 .34433 m
.50375 .34433 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .41497 m
.50375 .41497 L
s
.5 .43851 m
.50375 .43851 L
s
.5 .46205 m
.50375 .46205 L
s
.5 .50914 m
.50375 .50914 L
s
.5 .53269 m
.50375 .53269 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57977 m
.50375 .57977 L
s
.01 w
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -68.2812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
%%BeginResource: font Helvetica-Bold-MISO
%%BeginFont: Helvetica-Bold-MISO
/Helvetica-Bold /Helvetica-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
0.000 0.000 rmoveto
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(g) show
73.562 19.000 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .60332 m
.06244 .51168 L
.10458 .42058 L
.14415 .34341 L
.18221 .27686 L
.22272 .21429 L
.26171 .16211 L
.30316 .11529 L
.34309 .07863 L
.3815 .05117 L
.40095 .04018 L
.42237 .03036 L
.44268 .02324 L
.45178 .02075 L
.46172 .01852 L
.4671 .01752 L
.4721 .01674 L
.47727 .01606 L
.48196 .01556 L
.48658 .01518 L
.4887 .01505 L
.49093 .01493 L
.49332 .01483 L
.49438 .0148 L
.49552 .01477 L
.49675 .01474 L
.49789 .01473 L
.49859 .01472 L
.49925 .01472 L
.50049 .01472 L
.50163 .01472 L
.50286 .01474 L
.50401 .01476 L
.50508 .01478 L
.50754 .01486 L
.51014 .01498 L
.51268 .01513 L
.51504 .0153 L
.5204 .0158 L
.5293 .01694 L
.53882 .01863 L
.54906 .02096 L
.56016 .02411 L
.58032 .03146 L
.60019 .04077 L
.62123 .05287 L
.65912 .08044 L
.69946 .11799 L
.73829 .1621 L
.77956 .21759 L
Mistroke
.81932 .2794 L
.85757 .34659 L
.89827 .42644 L
.93745 .51144 L
.97619 .60332 L
Mfstroke
gsave
.61905 .60332 -61 -62 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 66 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
0.000 0.000 rmoveto
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(Complex) show
63.000 38.000 moveto
(Congugate) show
63.000 57.000 moveto
(Roots) show
113.750 57.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.85714 .13244 -109.844 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
0.000 0.000 rmoveto
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(Real) show
105.938 19.000 moveto
(Roots) show
156.688 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
1 0 0 r
.015 w
.5 .01472 m
.5 .01544 L
.5 .0161 L
.5 .01687 L
.5 .01759 L
.5 .01825 L
.5 .01887 L
.5 .01955 L
.5 .02026 L
.5 .02098 L
.5 .02176 L
.5 .02249 L
.5 .02315 L
.5 .02393 L
.5 .02438 L
.5 .02479 L
.5 .02554 L
.5 .02634 L
.5 .02674 L
.5 .02717 L
.5 .02793 L
.5 .02835 L
.5 .02875 L
.5 .02918 L
.5 .02965 L
.5 .03005 L
.5 .03049 L
.5 .03128 L
.5 .03205 L
.5 .03277 L
.5 .03346 L
.5 .03411 L
.5 .03482 L
.5 .03559 L
.5 .03635 L
.5 .03716 L
.5 .03784 L
.5 .03859 L
.5 .03903 L
.5 .03944 L
.5 .03988 L
.5 .04035 L
.5 .04114 L
.5 .04159 L
.5 .04201 L
.5 .04279 L
.5 .04351 L
.5 .0439 L
.5 .04433 L
.5 .04512 L
Mistroke
.5 .04559 L
.5 .04603 L
.5 .04643 L
.5 .04687 L
.5 .04734 L
.5 .04784 L
.5 .04826 L
.5 .04873 L
.5 .04917 L
.5 .04957 L
.5 .05003 L
.5 .05047 L
.5 .05124 L
.5 .05168 L
.5 .05208 L
.5 .0528 L
.5 .05358 L
.5 .05431 L
.5 .05498 L
.5 .05572 L
.5 .05654 L
.5 .05695 L
.5 .05738 L
.5 .05817 L
.5 .05861 L
.5 .05901 L
.5 .05945 L
.5 .05992 L
.5 .0607 L
.5 .06114 L
.5 .06156 L
.5 .06234 L
.5 .06304 L
.5 .06386 L
.5 .06463 L
.5 .06534 L
.5 .06609 L
.5 .06681 L
.5 .06746 L
.5 .06819 L
.5 .06899 L
.5 .06939 L
.5 .06982 L
.5 .07059 L
.5 .07102 L
.5 .07141 L
.5 .07184 L
.5 .0723 L
.5 .07306 L
.5 .0735 L
Mistroke
.5 .07391 L
.5 .07467 L
.5 .07536 L
.5 .07616 L
.5 .07692 L
.5 .07764 L
.5 .07829 L
.5 .07904 L
.5 .07975 L
.5 .0804 L
.5 .081 L
.5 .08167 L
.5 .08237 L
.5 .08307 L
.5 .08383 L
.5 .08455 L
.5 .0852 L
.5 .08596 L
.5 .08639 L
.5 .08679 L
.5 .08752 L
.5 .0883 L
.5 .08901 L
.5 .08978 L
.5 .09058 L
.5 .09133 L
.5 .09203 L
.5 .09267 L
.5 .0934 L
.5 .0941 L
.5 .09486 L
.5 .09566 L
.5 .09634 L
.5 .0971 L
.5 .09791 L
.5 .09836 L
.5 .09878 L
.5 .09958 L
.5 .10035 L
.5 .10106 L
.5 .10171 L
.5 .10245 L
.5 .10315 L
.5 .1038 L
.5 .1044 L
.5 .10506 L
.5 .10575 L
.5 .10646 L
.5 .10721 L
.5 .10792 L
Mistroke
.5 .10857 L
.5 .10932 L
.5 .10975 L
.5 .11015 L
.5 .11088 L
.5 .11165 L
.5 .11239 L
.5 .1132 L
.5 .11397 L
.5 .11468 L
.5 .11539 L
.5 .11603 L
.5 .11676 L
.5 .11746 L
.5 .11822 L
.5 .11902 L
.5 .11971 L
.5 .12046 L
.5 .12127 L
.5 .12173 L
.5 .12214 L
.5 .12295 L
.5 .12371 L
.5 .12436 L
.5 .12508 L
.5 .12582 L
.5 .12653 L
.5 .12718 L
.5 .12778 L
.5 .12844 L
.5 .12913 L
.5 .12983 L
.5 .13059 L
.5 .1313 L
.5 .13194 L
.5 .1327 L
.5 .13313 L
.5 .13353 L
.5 .13425 L
.5 .13502 L
.5 .13577 L
.5 .13658 L
.5 .13735 L
.5 .13807 L
.5 .13877 L
.5 .13942 L
.5 .14015 L
.5 .14085 L
.5 .14161 L
.5 .14242 L
Mistroke
.5 .14311 L
.5 .14386 L
.5 .14467 L
.5 .14513 L
.5 .14554 L
.5 .14635 L
.5 .14711 L
.5 .14776 L
.5 .14848 L
.5 .14923 L
.5 .14993 L
.5 .15059 L
.5 .15119 L
.5 .15184 L
.5 .15254 L
.5 .15324 L
.5 .154 L
.5 .15471 L
.5 .15535 L
.5 .15611 L
.5 .15654 L
.5 .15694 L
.5 .15766 L
.5 .15843 L
.5 .15918 L
.5 .16 L
.5 .16077 L
.5 .16149 L
.5 .16213 L
.5 .16284 L
.5 .16358 L
.5 .16427 L
.5 .16504 L
.5 .16585 L
.5 .16654 L
.5 .16729 L
.5 .16811 L
.5 .16856 L
.5 .16898 L
.5 .16978 L
.5 .17055 L
.5 .1712 L
.5 .17192 L
.5 .17267 L
.5 .17337 L
.5 .17403 L
.5 .17463 L
.5 .17532 L
.5 .17598 L
.5 .17668 L
Mistroke
.5 .17744 L
.5 .17815 L
.5 .17879 L
.5 .17956 L
.5 .17998 L
.5 .18038 L
.5 .1811 L
.5 .18187 L
.5 .18262 L
.5 .18305 L
.5 .18344 L
.5 .18417 L
.5 .18494 L
.5 .18562 L
.5 .18626 L
.5 .18697 L
.5 .18773 L
.5 .18849 L
.5 .18892 L
.5 .18933 L
.5 .19014 L
.5 .19059 L
.5 .19101 L
.5 .19175 L
.5 .19255 L
.5 .19331 L
.5 .19401 L
.5 .19466 L
.5 .19537 L
.5 .19603 L
.5 .19663 L
.5 .19734 L
.5 .19811 L
.5 .19884 L
.5 .19952 L
.5 .20028 L
.5 .201 L
.5 .20164 L
.5 .20234 L
.5 .2031 L
.5 .2039 L
.5 .20459 L
.5 .20534 L
.5 .20615 L
.5 .2069 L
.5 .20729 L
.5 .20772 L
.5 .20817 L
.5 .20859 L
.5 .20937 L
Mistroke
.5 .21007 L
.5 .21089 L
.5 .21167 L
.5 .21236 L
.5 .2131 L
.5 .21379 L
.5 .21442 L
.5 .21516 L
.5 .21597 L
.5 .21673 L
.5 .21743 L
.5 .21818 L
.5 .21898 L
.5 .21973 L
.5 .22042 L
.5 .22123 L
.5 .22169 L
.5 .22211 L
.5 .22289 L
.5 .22328 L
.5 .22372 L
.5 .22413 L
.5 .22458 L
.5 .22537 L
.5 .2258 L
.5 .22621 L
.5 .22666 L
.5 .22714 L
.5 .22756 L
.5 .22801 L
.5 .22844 L
.5 .22883 L
.5 .22957 L
.5 .23036 L
.5 .23111 L
.5 .23192 L
.5 .23269 L
.5 .23341 L
.5 .23411 L
.5 .23475 L
.5 .23549 L
.5 .23619 L
.5 .23695 L
.5 .23776 L
.5 .23844 L
.5 .2392 L
.5 .24001 L
.5 .24046 L
.5 .24088 L
.5 .24169 L
Mistroke
.5 .24245 L
.5 .2431 L
.5 .24382 L
.5 .24456 L
.5 .24527 L
.5 .24592 L
.5 .24652 L
.5 .24718 L
.5 .24787 L
.5 .24858 L
.5 .24933 L
.5 .25004 L
.5 .25069 L
.5 .25145 L
.5 .25188 L
.5 .25227 L
.5 .253 L
.5 .25376 L
.5 .25451 L
.5 .25533 L
.5 .2561 L
.5 .25682 L
.5 .25753 L
.5 .25817 L
.5 .25891 L
.5 .2596 L
.5 .26037 L
.5 .26118 L
.5 .26186 L
.5 .26262 L
.5 .26343 L
.5 .26389 L
.5 .2643 L
.5 .26511 L
.5 .26587 L
.5 .26653 L
.5 .26724 L
.5 .26799 L
.5 .2687 L
.5 .26935 L
.5 .26995 L
.5 .27064 L
.5 .2713 L
.5 .27201 L
.5 .27276 L
.5 .27348 L
.5 .27412 L
.5 .27488 L
.5 .27531 L
.5 .2757 L
Mistroke
.5 .27643 L
.5 .2772 L
.5 .27795 L
.5 .27838 L
.5 .27877 L
.5 .27949 L
.5 .28026 L
.5 .28094 L
.5 .28159 L
.5 .28229 L
.5 .28305 L
.5 .28381 L
.5 .28425 L
.5 .28465 L
.5 .28546 L
.5 .28591 L
.5 .28633 L
.5 .28707 L
.5 .28787 L
.5 .28863 L
.5 .28933 L
.5 .28998 L
.5 .29069 L
.5 .29135 L
.5 .29195 L
.5 .29266 L
.5 .29343 L
.5 .29416 L
.5 .29483 L
.5 .2956 L
.5 .29632 L
.5 .29696 L
.5 .29766 L
.5 .29842 L
.5 .29922 L
.5 .29991 L
.5 .30066 L
.5 .30147 L
.5 .30222 L
.5 .30261 L
.5 .30304 L
.5 .30349 L
.5 .30391 L
.5 .30468 L
.5 .30539 L
.5 .30617 L
.5 .30698 L
.5 .30767 L
.5 .30841 L
.5 .3091 L
Mistroke
.5 .30973 L
.5 .31048 L
.5 .31128 L
.5 .31204 L
.5 .31274 L
.5 .31349 L
.5 .31429 L
.5 .31505 L
.5 .31574 L
.5 .31654 L
.5 .317 L
.5 .31743 L
.5 .3182 L
.5 .31859 L
.5 .31903 L
.5 .31945 L
.5 .31989 L
.5 .32068 L
.5 .32112 L
.5 .32152 L
.5 .32197 L
.5 .32245 L
.5 .32287 L
.5 .32332 L
.5 .32375 L
.5 .32414 L
.5 .32489 L
.5 .32567 L
.5 .32642 L
.5 .32723 L
.5 .328 L
.5 .32871 L
.5 .32942 L
.5 .33006 L
.5 .3308 L
.5 .3315 L
.5 .33226 L
.5 .33306 L
.5 .33375 L
.5 .3345 L
.5 .33531 L
.5 .33577 L
.5 .33618 L
.5 .33699 L
.5 .33775 L
.5 .3384 L
.5 .33912 L
.5 .33987 L
.5 .34057 L
.5 .34122 L
Mistroke
.5 .34182 L
.5 .34248 L
.5 .34317 L
.5 .34388 L
.5 .34463 L
.5 .34534 L
.5 .34599 L
.5 .34675 L
.5 .34718 L
.5 .34757 L
.5 .3483 L
.5 .34907 L
.5 .34982 L
.5 .35063 L
.5 .3514 L
.5 .35212 L
.5 .35283 L
.5 .35347 L
.5 .35421 L
.5 .3549 L
.5 .35567 L
.5 .35647 L
.5 .35716 L
.5 .35792 L
.5 .35873 L
.5 .35919 L
.5 .3596 L
.5 .36041 L
.5 .36117 L
.5 .36182 L
.5 .36254 L
.5 .36329 L
.5 .36399 L
.5 .36465 L
.5 .36525 L
.5 .36594 L
.5 .3666 L
.5 .36731 L
.5 .36806 L
.5 .36877 L
.5 .36942 L
.5 .37018 L
.5 .37061 L
.5 .371 L
.5 .37173 L
.5 .37249 L
.5 .37324 L
.5 .37367 L
.5 .37406 L
.5 .37479 L
Mistroke
.5 .37555 L
.5 .37624 L
.5 .37688 L
.5 .37758 L
.5 .37834 L
.5 .37911 L
.5 .37954 L
.5 .37994 L
.5 .38075 L
.5 .38121 L
.5 .38162 L
.5 .38236 L
.5 .38316 L
.5 .38392 L
.5 .38462 L
.5 .38527 L
.5 .38597 L
.5 .38664 L
.5 .38724 L
.5 .38795 L
.5 .38872 L
.5 .38945 L
.5 .39012 L
.5 .39089 L
.5 .3916 L
.5 .39225 L
.5 .39294 L
.5 .39371 L
.5 .39451 L
.5 .3952 L
.5 .39595 L
.5 .39676 L
.5 .39751 L
.5 .3979 L
.5 .39833 L
.5 .39877 L
.5 .3992 L
.5 .39997 L
.5 .40067 L
.5 .40145 L
.5 .40227 L
.5 .40296 L
.5 .40369 L
.5 .40439 L
.5 .40502 L
.5 .40576 L
.5 .40656 L
.5 .40732 L
.5 .40802 L
.5 .40877 L
Mistroke
.5 .40957 L
.5 .41033 L
.5 .41102 L
.5 .41183 L
.5 .41228 L
.5 .41271 L
.5 .41348 L
.5 .41387 L
.5 .41431 L
.5 .41473 L
.5 .41517 L
.5 .41596 L
.5 .41639 L
.5 .4168 L
.5 .41725 L
.5 .41773 L
.5 .41815 L
.5 .4186 L
.5 .41903 L
.5 .41942 L
.5 .42017 L
.5 .42095 L
.5 .4217 L
.5 .42251 L
.5 .42328 L
.5 .42399 L
.5 .4247 L
.5 .42534 L
.5 .42608 L
.5 .42677 L
.5 .42753 L
.5 .42834 L
.5 .42902 L
.5 .42978 L
.5 .43059 L
.5 .43104 L
.5 .43146 L
.5 .43227 L
.5 .43303 L
.5 .43368 L
.5 .43439 L
.5 .43514 L
.5 .43584 L
.5 .4365 L
.5 .4371 L
.5 .43775 L
.5 .43845 L
.5 .43915 L
.5 .43991 L
.5 .44062 L
Mistroke
.5 .44126 L
.5 .44202 L
.5 .44245 L
.5 .44285 L
.5 .44357 L
.5 .44434 L
.5 .44509 L
.5 .4459 L
.5 .44667 L
.5 .44739 L
.5 .4481 L
.5 .44874 L
.5 .44948 L
.5 .45017 L
.5 .45094 L
.5 .45174 L
.5 .45243 L
.5 .45319 L
.5 .454 L
.5 .45445 L
.5 .45487 L
.5 .45568 L
.5 .45644 L
.5 .45709 L
.5 .45781 L
.5 .45856 L
.5 .45926 L
.5 .45991 L
.5 .46051 L
.5 .46117 L
.5 .46186 L
.5 .46257 L
.5 .46332 L
.5 .46404 L
.5 .46468 L
.5 .46544 L
.5 .46587 L
.5 .46626 L
.5 .46699 L
.5 .46776 L
.5 .46851 L
.5 .46893 L
.5 .46933 L
.5 .47005 L
.5 .47082 L
.5 .4715 L
.5 .47214 L
.5 .47285 L
.5 .47361 L
.5 .47437 L
Mistroke
.5 .4748 L
.5 .4752 L
.5 .47601 L
.5 .47647 L
.5 .47688 L
.5 .47762 L
.5 .47842 L
.5 .47918 L
.5 .47988 L
.5 .48053 L
.5 .48123 L
.5 .48189 L
.5 .4825 L
.5 .48321 L
.5 .48398 L
.5 .4847 L
.5 .48538 L
.5 .48614 L
.5 .48686 L
.5 .4875 L
.5 .4882 L
.5 .48896 L
.5 .48977 L
.5 .49045 L
.5 .49121 L
.5 .49201 L
.5 .49276 L
.5 .49315 L
.5 .49358 L
.5 .49403 L
.5 .49445 L
.5 .49522 L
.5 .49593 L
.5 .4967 L
.5 .49752 L
.5 .49821 L
.5 .49895 L
.5 .49964 L
.5 .50027 L
.5 .50101 L
.5 .50182 L
.5 .50258 L
.5 .50328 L
.5 .50402 L
.5 .50482 L
.5 .50558 L
.5 .50627 L
.5 .50708 L
.5 .50753 L
.5 .50796 L
Mistroke
.5 .50873 L
.5 .50917 L
.5 .50956 L
.5 .50998 L
.5 .51042 L
.5 .5112 L
.5 .51164 L
.5 .51205 L
.5 .5125 L
.5 .51298 L
.5 .5134 L
.5 .51385 L
.5 .51428 L
.5 .51467 L
.5 .51542 L
.5 .5162 L
.5 .51695 L
.5 .51776 L
.5 .51853 L
.5 .51924 L
.5 .51995 L
.5 .52058 L
.5 .52132 L
.5 .52202 L
.5 .52278 L
.5 .52358 L
.5 .52427 L
.5 .52502 L
.5 .52583 L
.5 .52629 L
.5 .5267 L
.5 .52751 L
.5 .52827 L
.5 .52892 L
.5 .52964 L
.5 .53038 L
.5 .53109 L
.5 .53174 L
.5 .53234 L
.5 .533 L
.5 .53369 L
.5 .53439 L
.5 .53515 L
.5 .53586 L
.5 .5365 L
.5 .53726 L
.5 .53769 L
.5 .53809 L
.5 .53881 L
.5 .53958 L
Mistroke
.5 .54033 L
.5 .54114 L
.5 .54191 L
.5 .54263 L
.5 .54334 L
.5 .54398 L
.5 .54472 L
.5 .54541 L
.5 .54618 L
.5 .54698 L
.5 .54767 L
.5 .54842 L
.5 .54924 L
.5 .54969 L
.5 .55011 L
.5 .55091 L
.5 .55168 L
.5 .55233 L
.5 .55304 L
.5 .55379 L
.5 .55449 L
.5 .55515 L
.5 .55575 L
.5 .55641 L
.5 .5571 L
.5 .55781 L
.5 .55856 L
.5 .55927 L
.5 .55992 L
.5 .56068 L
.5 .5611 L
.5 .5615 L
.5 .56222 L
.5 .56299 L
.5 .56374 L
.5 .56417 L
.5 .56456 L
.5 .56528 L
.5 .56605 L
.5 .56673 L
.5 .56737 L
.5 .56808 L
.5 .56884 L
.5 .5696 L
.5 .57003 L
.5 .57043 L
.5 .57124 L
.5 .57169 L
.5 .57211 L
.5 .57285 L
Mistroke
.5 .57365 L
.5 .57441 L
.5 .57511 L
.5 .57576 L
.5 .57646 L
.5 .57712 L
.5 .57773 L
.5 .57843 L
.5 .5792 L
.5 .57993 L
.5 .58061 L
.5 .58137 L
.5 .58209 L
.5 .58273 L
.5 .58343 L
.5 .58419 L
.5 .58499 L
.5 .58568 L
.5 .58643 L
.5 .58698 L
.5 .58748 L
.5 .58804 L
.5 .58862 L
.5 .58913 L
.5 .58961 L
.5 .59013 L
.5 .5907 L
.5 .59117 L
.5 .59169 L
.5 .59222 L
.5 .59273 L
.5 .5932 L
.5 .59362 L
.5 .59412 L
.5 .59458 L
.5 .59509 L
.5 .59564 L
.5 .59622 L
.5 .59677 L
.5 .59727 L
.5 .59773 L
.5 .59827 L
.5 .59878 L
.5 .59932 L
.5 .5999 L
.5 .60045 L
.5 .60095 L
.5 .60154 L
.5 .60217 L
.5 .60277 L
Mistroke
.5 .60332 L
Mfstroke
0 g
gsave
.2619 .36788 -61 -62 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 66 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(Positive) show
63.000 38.000 moveto
(Real) show
63.000 57.000 moveto
(Part) show
97.938 57.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.7381 .36788 -139.812 -62 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 66 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(Negative) show
63.000 38.000 moveto
(Real) show
63.000 57.000 moveto
(Part) show
97.938 57.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00;_oonfX3o`00OfSooo]Z1Ol007l4oook
JP?o001o0ooonfX5o`00Om3ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00Of[ooo]Z0ol007m2oook
JP00;_oonfX3o`00OfOooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Olkooo]Z1ol007l3oookJP?o
001o0_oonfX7o`00OfWooo]Z0ol007m2oookJP00;_oonfX3o`00OfOooo]Z0ol007l01?oonf[o001o
o`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007o>oook
JP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Z
o`00Ool007oo001oJOoonfX3o`00Od;ooo]Z000NoookJP[o001o1_oonfX3o`00Oe[ooo]Z2_l007l2
oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001oc?oonfX3o`00O`?ooo]Z0ol007l6
oookJP?o001o0ooonfX3o`00OfSooo]Z0ol007m2oookJP007_oonfX:o`00O`Kooo]Z0ol007mJoook
JP[o001o0_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001oc?oonfX3o`00O`?ooo]Z0ol007l<oook
JP?o001oJ?oonfX3o`00Od;ooo]Z000^oookJP?o001oI_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o
001oc?oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001oJ?oonfX3o`00Od;ooo]Z000^oookJP?o001o
I_oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00Olcooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`;ooo]Z1?l007mXoookJP?o001o@_oonfX002kooo]Z0ol007mVoookJP?o001o0ooo
nfX3o`00O`Oooo]Z1ol007o=oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007mYoookJP?o001o@_oo
nfX002kooo]Z0ol007mVoookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007o>oookJP?o001o0ooonfX3
o`00O`Oooo]Z1_l007mZoookJP?o001o@_oonfX002_ooo]Z1_l007mVoookJP?o001o0ooonfX3o`00
O`Oooo]Z0_l007oBoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007m[oookJPKo001o@_oonfX002_o
oo]Z1_l007mWoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Om?ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l8oookJP;o001oJooonfX6o`00Od;ooo]Z000]oookJPCo001oIooonfX7o`00
O`Wooo]Z1ol007mQoookJPCo0000J?oonfX7o`00O`Wooo]Z1ol007mWoookJPCo001o@_oonfX002ko
oo]Z0ol007mXoookJPGo001o2_oonfX7o`00Of7ooo]Z1?l0001YoookJPGo001o2_oonfX7o`00OfSo
oo]Z0ol007lHoookJP04odA2NOl007oo001ookZhKbKooo]Z003ooookJQ7ooo]Z1?l0003ooookJP?o
oo]Z00Cok^Y[o`00Ool007ooA49i9_oonfX00?oooo]Z4OoonfX4o`000?oooo]Z1?oonfX01?mgMGGo
001oo`00OooMfF`UoookJP00oooonfXAoookJPCo0000oooonfX4oookJP04omgIK?l007oo001oohN5
LbGooo]Z003ooookJQ7ooo]Z1?l0003ooookJPGooo]Z00Co411mo`00Oolb<W[oEE=g0_l007l00omE
DgOok^Y[oookJP0OoookJP00oooonfX@oookJPOoo`00oooonfX3oookJP09odA2NOl007oo001oodA2
NOoonf[o<S9jo`00OolQ8Gcok^Y[01oooo]Z003ooookJQ3ooo]Z1ooo003ooookJP?ooo]Z00KoQhEc
o`00Ool007ooMgEeoookJ_nYYg42o`00O`03ogMeMOoonf[ooo]Z01gooo]Z000JoookJ_Go00001ooo
003do`0000kooo]Z00Koc<Q^o`00Ool007ooIVAfoookJ_o^jV/2o`00O`03oa0@OOoonf[ooo]Z01go
oo]Z000JoookJ_Go00001ooo003do`0000oooo]Z0_l007l00olb<W[ooo]ZoookJP03o`00Oaoooo]Z
000JoookJ_Go00001ooo003do`0000oooo]Z00?oA49io`00Ool007l00_oonfX2o`00O`03oa0@OOoo
nf[ooo]Z01gooo]Z000JoookJ_Go00001ooo003do`0000oooo]Z00GoQhEco`00Ool007oo^[Q_ohN5
L`02o`00O`03ohN5Looonf[ooo]Z01gooo]Z000XoookJP03o`000?oonf[ooo]Z07;ooo]Z00?o0000
oookJ_oonfX0DooonfX?o`0000gooo]Z1ooo000=oookJQ3o0000E?oonfX00ol0003ooo]ZoookJP1b
oookJP03o`000?oonf[ooo]Z01[ooo]Z00?oc<Q^o`00Ool007l00ol007l00olQ8Gcok^Y[oookJP0N
oookJP00l?oonfX>o`00017ooo]Z1ooo000BoookJPko0000i?oonfX2o`00O`06odA2NOoonf[ok^Y[
ob4QO?l007ooc<Q^7_oonfX00>gooo]Z3?l0000FoookJPOoo`005ooonfX;o`000>;ooo]Z00?oA49i
o`00Ool007l00_oonfX00ooMfFco001ooc8bNP0NoookJP00j_oonfX;o`0001[ooo]Z1ooo000Koook
JP[o0000gooonfX01?nj^6oo001oo`00Oonj^6l2oookJP;o001o7_oonfX00>Sooo]Z2_l0000Moook
JPOoo`007_oonfX9o`000=kooo]Z00OoMgEeo`00OolQ8Gcok^Y[okZhKol007oo411m01kooo]Z003U
oookJP[o00008?oonfX7ool0023ooo]Z2Ol0003MoookJP06ojVWLOlb<W[o001oo`00Oom4@WWoc<Q^
7_oonfX00>?ooo]Z2Ol0000SoookJPOoo`008ooonfX8o`000?oooo]Z003QoookJPWo00009OoonfX7
ool002Gooo]Z1ol0003noookJP00gooonfX8o`0002Sooo]Z1ooo000WoookJPOo0000o?oonfX00=ko
oo]Z1ol0000ZoookJPOoo`00:OoonfX7o`000?[ooo]Z003LoookJPOo0000;?oonfX7ool002[ooo]Z
2?l0003hoookJP00fooonfX6o`0002kooo]Z1ooo000/oookJPWo0000mOoonfX00=Wooo]Z1ol0000_
oookJPOoo`00;_oonfX9o`000??ooo]Z003HoookJPKo0000<OoonfX7ool0033ooo]Z2Ol0003aoook
JP00e_oonfX7o`0003;ooo]Z1ooo000coookJPSo0000kooonfX00=Gooo]Z1_l0000doookJPOoo`00
=OoonfX7o`000>kooo]Z003CoookJPOo0000=OoonfX7ool003Oooo]Z1_l0003]oookJP00d_oonfX6
o`0003Oooo]Z1ooo000ioookJPKo0000jooonfX00=3ooo]Z1ol0000hoookJPOoo`00>_oonfX6o`00
0>[ooo]Z003?oookJPKo0000>_oonfX7ool003_ooo]Z1_l0003YoookJP00cOoonfX7o`0003_ooo]Z
1ooo000moookJPGo0000j?oonfX00<cooo]Z1_l0000moookJPOoo`00?_oonfX6o`000>Kooo]Z003;
oookJPKo0000?_oonfX7ool003oooo]Z1_l0003UoookJP00bOoonfX6o`00043ooo]Z1ooo0010oook
JPKo0000i?oonfX00<Sooo]Z1_l00011oookJPOoo`00@_oonfX6o`000>;ooo]Z0036oookJPOo0000
@_oonfX7ool004?ooo]Z1_l0003QoookJP00aOoonfX6o`0004Cooo]Z1ooo0014oookJPKo0000h?oo
nfX00<?ooo]Z1ol00015oookJPOoo`00A_oonfX5o`000=oooo]Z0032oookJPKo0000AooonfX7ool0
04Oooo]Z1_l0003MoookJP00`OoonfX6o`0004Sooo]Z1ooo0018oookJPKo0000g?oonfX00<3ooo]Z
1Ol0001:oookJPOoo`00BOoonfX6o`000=_ooo]Z002ooookJPGo0000BooonfX7ool004_ooo]Z1Ol0
003JoookJP00__oonfX5o`0004cooo]Z1ooo001<oookJPGo0000fOoonfX00;gooo]Z1Ol0001=oook
JPOoo`00COoonfX5o`000=Sooo]Z002loookJPGo0000C_oonfX7ool004kooo]Z1Ol0003GoookJP00
^ooonfX5o`0004oooo]Z1ooo001?oookJPGo0000e_oonfX00;Wooo]Z1_l0001@oookJPOoo`00D?oo
nfX5o`000=Gooo]Z002hoookJPKo0000DOoonfX7ool0057ooo]Z1_l0003CoookJP00]ooonfX6o`00
05;ooo]Z1ooo001BoookJPKo0000d_oonfX00;Kooo]Z1Ol0001DoookJPOoo`00DooonfX6o`000=7o
oo]Z002eoookJPGo0000EOoonfX7ool005Gooo]Z1Ol0003@oookJP00]?oonfX5o`0005Kooo]Z1ooo
001FoookJPGo0000cooonfX00;?ooo]Z1Ol0001GoookJPOoo`00EooonfX5o`000<kooo]Z002boook
JPGo0000F?oonfX7ool005Sooo]Z1Ol0003=oookJP00/OoonfX5o`0005Wooo]Z1ooo001IoookJPGo
0000c?oonfX00;3ooo]Z1Ol0001JoookJPOoo`00F_oonfX5o`000<_ooo]Z002`oookJPCo0000Fooo
nfX7ool005_ooo]Z1Ol0003:oookJP00[ooonfX4o`0005cooo]Z1ooo001LoookJPCo0000b_oonfX0
0:kooo]Z1Ol0001LoookJPOoo`00GOoonfX4o`000<Wooo]Z002]oookJPGo0000GOoonfX7ool005go
oo]Z1Ol00038oookJP00[?oonfX5o`0005kooo]Z1ooo001NoookJPGo0000aooonfX00:_ooo]Z1Ol0
000ioookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l5oookJPGo001o2?oonfX7ool005oooo]Z1Ol0
000JoookJP?o001o1OoonfX3o`00O`Cooo]Z1Ol007l5oookJPCo001o00Gooo]Zo`00Ool007oo001o
oookJP03o`00O`Kooo]Z0ol007l5oookJP?o001o1OoonfX4o`00O`Sooo]Z1?l007l7oookJPCo001o
1?oonfX5o`00Odgooo]Z002ZoookJPGo0000>OoonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o0ooo
nfX7o`00O`Oooo]Z1ooo001PoookJPGo00006OoonfX3o`00O`Gooo]Z0ol007l3oookJPOo001o0ooo
nfX8o`00O`;ooo]Z0ol007l6oookJP?o001o1OoonfX3o`00O`?ooo]Z2?l007l4oookJPSo001o1?oo
nfX5o`00O`;ooo]Z2?l007m<oookJP00ZOoonfX5o`0003[ooo]Z0ol007l01?oonf[o001oo`00Ool0
07l3oookJP?o001o0_oonfX3o`00O`04oookJ_l007oo001oo`00O`;ooo]Z1?l007l01?oonf[o001o
o`00Ool007l7oookJPOoo`00HOoonfX5o`0001Sooo]Z0ol007l5oookJP?o001o0_oonfX4o`00O`;o
oo]Z0ol007l2oookJP?o001o0_oonfX3o`00O`;ooo]Z0ol007l6oookJP?o001o1OoonfX3o`00O`?o
oo]Z0ol007l2oookJP?o001o1?oonfX3o`00O`;ooo]Z0ol007l4oookJP?o001o1?oonfX3o`00O`?o
oo]Z0ol007m;oookJP00ZOoonfX4o`0003[ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z
0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1_oonfX7ool006;ooo]Z1?l0000HoookJP?o
001o1OoonfX3o`00O`;ooo]Z0ol007l8oookJP?o001o0_oonfX3o`00O`;ooo]Z0ol007l6oookJP?o
001o1OoonfX3o`00O`;ooo]Z0ol007l4oookJP?o001o0_oonfX3o`00O`Cooo]Z0ol007l3oookJP?o
001o2OoonfX4o`00Od_ooo]Z002XoookJPCo0000>ooonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o
0ooonfX3o`00O`Oooo]Z0ol007l6oookJPOoo`00HooonfX4o`0001Oooo]Z0ol007l5oookJP?o001o
0_oonfX9o`00O`;ooo]Z1?l007l01?oonf[o001oo`00Ool007l2oookJP?o001o1_oonfX3o`00O`Go
oo]Z0ol007l2oookJP?o001o1?oonfX3o`00O`;ooo]Z0ol007l4oookJP?o001o0ooonfX3o`00O`Ko
oo]Z1ol007m;oookJP00YooonfX5o`0003_ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z
0ol007l7oookJP?o001o1_oonfX7ool006?ooo]Z1Ol0000FoookJP[o001o0ooonfX9o`00O`?ooo]Z
1ol007l2oookJP?o001o1_oonfX:o`00O`?ooo]Z0ol007l4oookJP?o001o0_oonfX3o`00O`Cooo]Z
0ol007l3oookJP?o001o1?oonfX7o`00Odgooo]Z002VoookJPGo0000??oonfX3o`00O`?ooo]Z0ol0
07l6oookJP?o001o0ooonfX3o`00O`;ooo]Z0_l007l2oookJPCo001o1_oonfX7ool006Cooo]Z1Ol0
000EoookJP[o001o0ooonfX3o`00O`?ooo]Z0ol007l7oookJP?o001o0_oonfX3o`00O`Kooo]Z2_l0
07l3oookJP?o001o1?oonfX3o`00O`;ooo]Z0ol007l4oookJP?o001o0ooonfX3o`00O`Cooo]Z1?l0
07m@oookJP00YOoonfX5o`0003gooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l2
oookJPOo001o1ooonfX7ool006Gooo]Z1Ol0000DoookJP?o001o1OoonfX3o`00O`;ooo]Z0ol007l3
oookJP?o001o0_oonfX3o`00O`;ooo]Z0ol007l2oookJP?o001o1_oonfX3o`00O`Gooo]Z0ol007l3
oookJP?o001o0_oonfX3o`00O`Cooo]Z0ol007l2oookJP?o001o1?oonfX3o`00O`Cooo]Z0ol007l3
oookJP?o001oBooonfX00:Cooo]Z1Ol0000noookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oook
JP?o001o0_oonfX6o`00O`Sooo]Z1ooo001VoookJPGo00004ooonfX3o`00O`Gooo]Z0ol007l3oook
JPOo001o0ooonfX8o`00O`;ooo]Z0ol007l6oookJP?o001o1OoonfX3o`00O`?ooo]Z2?l007l4oook
JPSo001o0ooonfX6o`00O`?ooo]Z1ol007m<oookJP00XooonfX5o`0003oooo]Z0ol007l3oookJP?o
001o1_oonfX3o`00O`?ooo]Z0ol007l2oookJP;o001o3?oonfX7ool006Oooo]Z1Ol0000BoookJP?o
001o1OoonfX3o`00O`Cooo]Z1Ol007l6oookJPCo001o1?oonfX3o`00O`Kooo]Z0ol007l5oookJP?o
001o1OoonfX4o`00O`Sooo]Z1?l007l5oookJPKo001o1?oonfX5o`00Odgooo]Z002SoookJPCo0000
@OoonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP;o001o3?oonfX7ool006Sooo]Z1Ol0000AoookJP?o001o1OoonfX3o`00OaOooo]Z0ol007l6oook
JP?o001o1OoonfX3o`00Oa_ooo]Z0ol007mHoookJP00X_oonfX4o`0004;ooo]Z1ol007l8oookJPOo
001o1?oonfX7o`00O`Kooo]Z1ooo001YoookJPCo00004OoonfX:o`00OaSooo]Z0ol007l6oookJP[o
001o7?oonfX3o`00OeSooo]Z002QoookJPGo0000@ooonfX5o`00O`[ooo]Z1Ol007l5oookJPOo001o
1_oonfX7ool006[ooo]Z1?l0000@oookJPWo001o6OoonfX3o`00O`Kooo]Z2Ol007mhoookJP00X?oo
nfX5o`0006[ooo]Z1ooo001ZoookJPGo0000^ooonfX009oooo]Z1Ol0001[oookJPOoo`00JooonfX5
o`000;[ooo]Z002NoookJPGo0000K?oonfX7ool006cooo]Z1Ol0002ioookJP00WOoonfX5o`0006go
oo]Z1ooo001]oookJPGo0000^?oonfX009cooo]Z1Ol0001^oookJPOoo`00K_oonfX5o`000;Oooo]Z
002LoookJPCo0000KooonfX7ool006oooo]Z1?l0002goookJP00VooonfX4o`00073ooo]Z1ooo001`
oookJPCo0000]_oonfX009[ooo]Z1Ol0001`oookJPOoo`00L?oonfX5o`000;Gooo]Z002IoookJPGo
0000LOoonfX7ool0077ooo]Z1Ol0002doookJP00VOoonfX4o`0007;ooo]Z1ooo001boookJPGo0000
/ooonfX009Sooo]Z1?l0001coookJPOoo`00LooonfX4o`000;?ooo]Z002GoookJPGo0000LooonfX7
ool007Cooo]Z1?l0002boookJP00UooonfX4o`0007Cooo]Z1ooo001doookJPGo0000/OoonfX009Ko
oo]Z1?l0001eoookJPOoo`00MOoonfX5o`000;3ooo]Z002EoookJPGo0000MOoonfX7ool007Kooo]Z
1?l0002`oookJP00U?oonfX5o`0007Kooo]Z1ooo001goookJPCo0000[ooonfX009Cooo]Z1?l0001g
oookJPOoo`00MooonfX5o`000:kooo]Z002CoookJPCo0000N?oonfX7ool007Sooo]Z1Ol0002]oook
JP00T_oonfX5o`0007Sooo]Z1ooo001ioookJPGo0000[?oonfX0097ooo]Z1Ol0001ioookJPOoo`00
N_oonfX4o`000:cooo]Z002AoookJPCo0000N_oonfX7ool007_ooo]Z1?l0002[oookJP00T?oonfX4
o`0007_ooo]Z1ooo001koookJPGo0000Z_oonfX008oooo]Z1Ol0001koookJPOoo`00O?oonfX5o`00
0:Wooo]Z002>oookJPGo0000O?oonfX7ool007gooo]Z1?l0002YoookJP00S_oonfX4o`0007gooo]Z
1ooo001noookJPCo0000Z?oonfX008gooo]Z1?l0001noookJPOoo`00O_oonfX5o`000:Oooo]Z002<
oookJPGo0000O_oonfX7ool007oooo]Z1Ol0002VoookJP00S?oonfX4o`0007oooo]Z1ooo0020oook
JPGo0000YOoonfX008_ooo]Z1?l00020oookJPOoo`00POoonfX4o`000:Gooo]Z002:oookJPGo0000
P?oonfX7ool008;ooo]Z1?l0002ToookJP00ROoonfX5o`00087ooo]Z1ooo0022oookJPGo0000Xooo
nfX008Wooo]Z1?l00022oookJPOoo`00PooonfX5o`000:;ooo]Z0028oookJPCo0000PooonfX7ool0
08Cooo]Z1?l0002RoookJP00QooonfX5o`0008?ooo]Z1ooo0025oookJPCo0000XOoonfX008Oooo]Z
1?l00024oookJPOoo`00QOoonfX5o`000:3ooo]Z0026oookJPCo0000QOoonfX7ool008Kooo]Z1?l0
002PoookJP00QOoonfX5o`0008Gooo]Z1ooo0027oookJPCo0000WooonfX008Gooo]Z1?l00026oook
JPOoo`00QooonfX4o`0009oooo]Z0024oookJPCo0000QooonfX7ool008Sooo]Z1?l0002NoookJP00
Q?oonfX4o`0008Oooo]Z1ooo0028oookJPGo0000WOoonfX008?ooo]Z1?l00028oookJPOoo`00ROoo
nfX4o`0009gooo]Z0022oookJPGo0000R?oonfX7ool008[ooo]Z1?l0002LoookJP00P_oonfX4o`00
08Wooo]Z1ooo002:oookJPCo0000W?oonfX0087ooo]Z1?l0002:oookJPOoo`00RooonfX4o`0009_o
oo]Z0020oookJPGo0000K_oonfX5o`00O`Cooo]Z0ol007l5oookJP?o001o2?oonfX7ool008_ooo]Z
1Ol0002JoookJP00P?oonfX4o`0006kooo]Z1ol007l3oookJP?o001o1OoonfX3o`00O`Sooo]Z1ooo
002<oookJPCo0000V_oonfX007oooo]Z1?l0001_oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`Gooo]Z0ol007l8oookJPOoo`00SOoonfX4o`0009Wooo]Z001noookJPGo0000K_oonfX3
o`00O`?ooo]Z0ol007l:oookJP?o001o2?oonfX7ool008gooo]Z1Ol0002HoookJP00O_oonfX4o`00
06oooo]Z0ol007l3oookJP?o001o2_oonfX3o`00O`Sooo]Z1ooo002>oookJPCo0000V?oonfX007go
oo]Z1?l0001`oookJP?o001o0ooonfX3o`00O`[ooo]Z0ol007l8oookJPOoo`00SooonfX4o`0009Oo
oo]Z001loookJPGo0000L?oonfX3o`00O`?ooo]Z0ol007l:oookJP?o001o2?oonfX7ool008oooo]Z
1?l0002GoookJP00O?oonfX4o`00077ooo]Z0ol007l3oookJP?o001o2_oonfX3o`00O`Sooo]Z1ooo
002@oookJPCo0000U_oonfX007_ooo]Z1?l0001boookJP?o001o0ooonfX3o`00O`[ooo]Z0ol007l8
oookJPOoo`00T?oonfX5o`0009Gooo]Z001joookJPGo0000L_oonfX3o`00O`?ooo]Z0ol007l7oook
JPKo001o2?oonfX7ool0097ooo]Z1?l0002EoookJP00N_oonfX4o`0002;ooo]Z0ooo000:oookJPCo
o`0000Gooo]Zool00?oo003oo`00oookJP03ool000Kooo]Z1?oo000_oookJP?o001o00Cooo]Zo`00
Ool007oo001o2?oonfX6o`00O`Sooo]Z1ooo000UoookJP?oo`002_oonfX4ool00005oookJ_oo003o
o`00ool00?oonfX00ooo0006oookJPCoo`00B_oonfX4o`0009Cooo]Z001ioookJPCo00008ooonfX3
ool000Wooo]Z2?oo0002oookJP?oo`001OoonfX5ool002oooo]Z1ol007l:oookJPCo001o2?oonfX7
ool002Gooo]Z0ooo0009oookJPSoo`000_oonfX3ool000Gooo]Z1Ooo001:oookJPCo0000U?oonfX0
07Wooo]Z1?l0000SoookJP?oo`002OoonfX3ool000;ooo]Z0ooo0002oookJP?oo`001OoonfX3ool0
03;ooo]Z1Ol007l<oookJP?o001o2?oonfX7ool002Gooo]Z0ooo0009oookJP?oo`000_oonfX3ool0
00;ooo]Z0ooo0005oookJP?oo`00COoonfX4o`0009?ooo]Z001hoookJPCo00009?oonfX3ool000Wo
oo]Z0ooo0002oookJP?oo`000_oonfX3ool000Gooo]Z0ooo001>oookJPOoo`009OoonfX3ool000Wo
oo]Z0ooo0002oookJP?oo`000_oonfX3ool000Gooo]Z0ooo001=oookJPGo0000T_oonfX007Oooo]Z
1Ol0000ToookJP?oo`002OoonfX4ool00004oookJ_oo003oo`00ool000;ooo]Z0ooo0005oookJP?o
o`00C_oonfX7ool002Gooo]Z0ooo0009oookJPCoo`0000Cooo]Zool00?oo003oo`000_oonfX3ool0
00Gooo]Z0ooo001>oookJPCo0000T_oonfX007Oooo]Z1?l0000UoookJPSoo`001OoonfX7ool000;o
oo]Z0ooo0005oookJP?oo`00C_oonfX7ool002Gooo]Z2?oo0005oookJPOoo`000_oonfX3ool000Go
oo]Z0ooo001?oookJPCo0000TOoonfX007Kooo]Z1?l0000VoookJPWoo`002?oonfX3ool000;ooo]Z
1?oo0004oookJP?oo`00C_oonfX7ool002Gooo]Z2Ooo0008oookJP?oo`000_oonfX4ool000Cooo]Z
0ooo001?oookJPCo0000TOoonfX007Gooo]Z1Ol0000VoookJP?oo`000ooonfX4ool000;ooo]Z0ooo
0002oookJP?oo`000_oonfX6ool000;ooo]Z0ooo001>oookJPOoo`009OoonfX3ool000?ooo]Z1?oo
0002oookJP?oo`000_oonfX3ool000;ooo]Z1_oo0002oookJP?oo`00D?oonfX4o`00093ooo]Z001e
oookJPCo00009ooonfX3ool000Cooo]Z0ooo0002oookJPSoo`000_oonfX6ool00003oookJ_oo003o
o`0000Coo`00C?oonfX7ool002Gooo]Z0ooo0004oookJP?oo`000_oonfX8ool000;ooo]Z1_oo0000
0ooonf[oo`00ool00004ool004kooo]Z1Ol0002?oookJP00M?oonfX4o`0002Sooo]Z0ooo0004oook
JP?oo`001?oonfX4ool000Cooo]Z0ooo00001?oonf[oo`00ool00?oonfX6ool004cooo]Z1ooo000U
oookJP?oo`001?oonfX3ool000Cooo]Z1?oo0004oookJP?oo`0000Cooo]Zool00?oo003ooo]Z1_oo
001?oookJPCo0000SooonfX007Cooo]Z1?l0000XoookJP?oo`000ooonfX4ool001Cooo]Z0ooo001>
oookJPOoo`009OoonfX3ool000?ooo]Z1?oo000DoookJP?oo`00D_oonfX4o`0008kooo]Z001coook
JPCo0000:OoonfX9ool001Gooo]Z0ooo001>oookJPOoo`009OoonfX9ool001Gooo]Z0ooo001Boook
JPCo0000S_oonfX007;ooo]Z1Ol0000YoookJPSoo`00IooonfX7ool002Gooo]Z2?oo001/oookJPCo
0000SOoonfX007;ooo]Z1?l0002IoookJPOoo`00VOoonfX5o`0008cooo]Z001aoookJPCo0000V_oo
nfX7ool009[ooo]Z1?l0002<oookJP00LOoonfX4o`0009[ooo]Z1ooo002KoookJPCo0000RooonfX0
073ooo]Z1?l0002KoookJPOoo`00VooonfX4o`0008_ooo]Z001_oookJPGo0000VooonfX7ool009co
oo]Z1?l0002:oookJP00KooonfX4o`0009cooo]Z1ooo002LoookJPCo0000R_oonfX006kooo]Z1?l0
000^oookJP?oo`001OoonfX3ool000Cooo]Z1Ooo0005oookJPCoo`0000Gooo]Zool00?oo003oo`00
oookJP03ool004[ooo]Z1ooo000UoookJP?oo`001OoonfX3ool000Cooo]Z1Ooo0005oookJPCoo`00
00Gooo]Zool00?oo003oo`00oookJP03ool005?ooo]Z1?l00029oookJP00K_oonfX4o`0002kooo]Z
0ooo0005oookJP?oo`000ooonfX7ool000?ooo]Z2?oo0002oookJP?oo`00B_oonfX7ool002Gooo]Z
0ooo0005oookJP?oo`000ooonfX7ool000?ooo]Z2?oo0002oookJP?oo`00DooonfX5o`0008Sooo]Z
001]oookJPCo0000;ooonfX3ool000Gooo]Z0ooo0002oookJPCoo`000_oonfX3ool000;ooo]Z0ooo
0002oookJP?oo`000_oonfX3ool004[ooo]Z1ooo000UoookJP?oo`001OoonfX3ool000;ooo]Z1?oo
0002oookJP?oo`000_oonfX3ool000;ooo]Z0ooo0002oookJP?oo`00E?oonfX4o`0008Sooo]Z001/
oookJPGo0000;ooonfX3ool000Gooo]Z0ooo0002oookJP?oo`002?oonfX3ool000;ooo]Z0ooo0002
oookJP?oo`00B_oonfX7ool002Gooo]Z0ooo0005oookJP?oo`000_oonfX3ool000Sooo]Z0ooo0002
oookJP?oo`000_oonfX3ool005Gooo]Z1?l00027oookJP00K?oonfX4o`00033ooo]Z0ooo0005oook
JP?oo`000_oonfX9ool000;ooo]Z1?oo00001?oonf[oo`00ool00?oo0002oookJP?oo`00B_oonfX7
ool002Gooo]Z0ooo0005oookJP?oo`000_oonfX9ool000;ooo]Z1?oo00001?oonf[oo`00ool00?oo
0002oookJP?oo`00EOoonfX4o`0008Oooo]Z001[oookJPCo0000<OoonfX:ool000?ooo]Z2Ooo0003
oookJPOoo`000_oonfX3ool004[ooo]Z1ooo000UoookJP[oo`000ooonfX9ool000?ooo]Z1ooo0002
oookJP?oo`00E_oonfX4o`0008Kooo]Z001[oookJPCo0000<OoonfX:ool000?ooo]Z0ooo0003oook
JP?oo`001ooonfX3ool000;ooo]Z0ooo001:oookJPOoo`009OoonfX:ool000?ooo]Z0ooo0003oook
JP?oo`001ooonfX3ool000;ooo]Z0ooo001FoookJPGo0000QOoonfX006[ooo]Z1?l0000boookJP?o
o`001OoonfX3ool000;ooo]Z0ooo0003oookJP?oo`000_oonfX3ool000;ooo]Z0ooo0002oookJP?o
o`00B_oonfX7ool002Gooo]Z0ooo0005oookJP?oo`000_oonfX3ool000?ooo]Z0ooo0002oookJP?o
o`000_oonfX3ool000;ooo]Z0ooo001GoookJPCo0000QOoonfX006Wooo]Z1Ol0000boookJP?oo`00
1OoonfX3ool000?ooo]Z1ooo0003oookJPSoo`000_oonfX3ool004[ooo]Z1ooo000UoookJP?oo`00
1OoonfX3ool000?ooo]Z1ooo0003oookJPSoo`000_oonfX3ool005Sooo]Z1?l00024oookJP00JOoo
nfX4o`0003?ooo]Z0ooo0005oookJP?oo`001?oonfX5ool000Kooo]Z1?oo0004oookJP?oo`00B_oo
nfX7ool002Gooo]Z0ooo0005oookJP?oo`001?oonfX5ool000Kooo]Z1?oo0004oookJP?oo`00F?oo
nfX4o`0008Cooo]Z001XoookJPCo0000=?oonfX3ool000Gooo]Z0ooo000GoookJP?oo`00B_oonfX7
ool002Gooo]Z0ooo0005oookJP?oo`005ooonfX3ool005Wooo]Z1?l00023oookJP00J?oonfX4o`00
03Cooo]Z2_oo000HoookJP?oo`00B_oonfX7ool002Gooo]Z2_oo000HoookJP?oo`00FOoonfX4o`00
08?ooo]Z001WoookJPCo0000=OoonfX9ool001Wooo]Z0ooo001:oookJPOoo`009OoonfX9ool001Wo
oo]Z0ooo001JoookJPCo0000P_oonfX006Kooo]Z1Ol0002ToookJPOoo`00Y?oonfX5o`00087ooo]Z
001VoookJPCo0000YOoonfX7ool00:Gooo]Z1?l00021oookJP00IOoonfX4o`000:Kooo]Z1ooo000n
oookJPGoo`00HooonfX4o`00083ooo]Z001UoookJPCo0000Y_oonfX7ool003gooo]Z1ooo001Roook
JPCo0000P?oonfX006Cooo]Z1?l0002WoookJPOoo`00??oonfX3ool000?ooo]Z0ooo001RoookJPCo
0000OooonfX006?ooo]Z1Ol0002WoookJPOoo`00@_oonfX3ool006;ooo]Z1?l0001ooookJP00Hooo
nfX4o`0003Wooo]Z0ooo000<oookJPCoo`001ooonfX5ool000Cooo]Z0ooo0004oookJPCoo`000_oo
nfX3ool000Cooo]Z1Ooo0005oookJPGoo`00:OoonfX7ool002Gooo]Z0ooo0004oookJP?oo`001?oo
nfX5ool000Kooo]Z0ooo00001?oonf[oo`00ool00?oo0003oookJPCoo`0000Cooo]Zool00?oo003o
o`000ooonfX4ool000;ooo]Z0ooo0004oookJPGoo`001OoonfX5ool003Wooo]Z1?l0001noookJP00
H_oonfX4o`0003[ooo]Z0ooo000:oookJPSoo`000ooonfX8ool000?ooo]Z0ooo0003oookJPGoo`00
0_oonfX3ool000Cooo]Z1Ooo0004oookJPOoo`00:?oonfX7ool002Gooo]Z0ooo0003oookJPCoo`00
0ooonfX7ool000Cooo]Z2?oo0002oookJPSoo`000ooonfX5ool000;ooo]Z0ooo0004oookJPGoo`00
1?oonfX7ool003Sooo]Z1Ol0001moookJP00H_oonfX4o`0003[ooo]Z0ooo000:oookJP?oo`000_oo
nfX3ool000?ooo]Z0ooo0003oookJP?oo`000_oonfX3ool000?ooo]Z0ooo0004oookJP?oo`000ooo
nfX7ool000;ooo]Z1?oo0002oookJP?oo`009ooonfX7ool002Gooo]Z0ooo0003oookJPCoo`000_oo
nfX4ool000;ooo]Z0ooo0002oookJPCoo`0000?ooo]Zool00?oo00000_oo0002oookJP?oo`000_oo
nfX3ool000?ooo]Z0ooo0004oookJP?oo`000ooonfX7ool000;ooo]Z1?oo0002oookJP?oo`00>?oo
nfX4o`0007gooo]Z001QoookJPCo0000>ooonfX3ool000Wooo]Z0ooo0004oookJP?oo`001ooonfX4
ool000;ooo]Z0ooo0003oookJP?oo`001?oonfX3ool000?ooo]Z0ooo00001?oonf[oo`00ool00?oo
0002oookJP?oo`00;OoonfX7ool002Gooo]Z0ooo0002oookJPGoo`000_oonfX3ool000Sooo]Z0ooo
0003oookJP?oo`000_oonfX3ool000;ooo]Z0ooo0003oookJP?oo`001?oonfX3ool000?ooo]Z0ooo
00001?oonf[oo`00ool00?oo0002oookJP?oo`00?ooonfX4o`0007cooo]Z001QoookJPCo0000>ooo
nfX3ool000Wooo]Z0ooo0004oookJP?oo`001?oonfX7ool000;ooo]Z0ooo0003oookJP?oo`001?oo
nfX3ool000?ooo]Z0ooo00001?oonf[oo`00ool00?oo0002oookJPWoo`009ooonfX7ool002Gooo]Z
0ooo0002oookJPGoo`000_oonfX9ool000;ooo]Z0ooo0003oookJP?oo`000_oonfX4ool00004oook
J_oo003oo`00ool000?ooo]Z0ooo0004oookJP?oo`000ooonfX3ool00004oookJ_oo003oo`00ool0
00;ooo]Z2Ooo000ioookJPCo0000O?oonfX0063ooo]Z1?l0000loookJPSoo`001?oonfX3ool000Co
oo]Z0ooo0002oookJPOoo`001?oonfX3ool000?ooo]Z0ooo0004oookJP?oo`000ooonfX3ool00004
oookJ_oo003oo`00ool000;ooo]Z2Ooo000WoookJPOoo`009OoonfX3ool00003oookJ_oo003oo`00
00Coo`000_oonfX9ool000;ooo]Z0ooo0003oookJP?oo`000ooonfX7ool000?ooo]Z0ooo0004oook
JP?oo`000ooonfX3ool00004oookJ_oo003oo`00ool000;ooo]Z2Ooo000joookJPCo0000NooonfX0
063ooo]Z1?l0000loookJPWoo`000ooonfX3ool000Cooo]Z0ooo0002oookJPCoo`001ooonfX3ool0
00?ooo]Z0ooo0004oookJP?oo`000_oonfX3ool000?ooo]Z0ooo00001?oonf[oo`00ool00?oo0003
oookJP?oo`009ooonfX7ool002Gooo]Z0ooo00001?oonf[oo`00ool00?oonfX3ool000;ooo]Z0ooo
0003oookJP?oo`000_oonfX3ool000?ooo]Z0ooo0007oookJP?oo`000ooonfX3ool000Cooo]Z0ooo
0002oookJP?oo`000ooonfX3ool00004oookJ_oo003oo`00ool000?ooo]Z0ooo000joookJPCo0000
NooonfX005oooo]Z1?l0000moookJP?oo`000ooonfX4ool000?ooo]Z0ooo0002oookJP?oo`000ooo
nfX3ool000?ooo]Z0ooo0002oookJP?oo`000ooonfX3ool000Cooo]Z0ooo0002oookJP?oo`000ooo
nfX3ool00004oookJ_oo003oo`00ool000?ooo]Z0ooo000WoookJPOoo`009OoonfX6ool00004oook
J_oo003oo`00ool000;ooo]Z0ooo0003oookJP?oo`000_oonfX4ool00003oookJ_oo003oo`0000;o
o`000_oonfX3ool000;ooo]Z0ooo0003oookJP?oo`001?oonfX3ool000;ooo]Z0ooo0003oookJP?o
o`0000Cooo]Zool00?oo003oo`000ooonfX3ool003_ooo]Z1?l0001joookJP00GooonfX4o`0003go
oo]Z0ooo0004oookJP?oo`000ooonfX8ool000Cooo]Z1ooo0003oookJP?oo`000_oonfX6ool000;o
oo]Z0ooo0002oookJP?oo`000ooonfX3ool000;ooo]Z1ooo000XoookJPOoo`009OoonfX5ool000;o
oo]Z0ooo0003oookJPOoo`001?oonfX8ool000;ooo]Z2?oo0002oookJPKoo`000_oonfX3ool000;o
oo]Z0ooo0003oookJP?oo`000_oonfX7ool003cooo]Z1?l0001joookJP00G_oonfX4o`0003kooo]Z
0ooo0004oookJP?oo`001OoonfX4ool000Oooo]Z1Ooo0004oookJP?oo`000_oonfX6ool000;ooo]Z
0ooo00001?oonf[oo`00ool00?oo0005oookJP?oo`000_oonfX5ool002Wooo]Z1ooo000UoookJPGo
o`000_oonfX3ool000Cooo]Z1Ooo0006oookJP?oo`0000Cooo]Zool00?oo003oo`001?oonfX4ool0
00Cooo]Z1_oo0002oookJP?oo`0000Cooo]Zool00?oo003oo`001OoonfX3ool000;ooo]Z1Ooo000n
oookJPCo0000NOoonfX005kooo]Z1?l0000noookJP?oo`000ooonfX4ool001oooo]Z0ooo000Moook
JPGo001o1?oonfX3o`00O`Gooo]Z0ol007l5oookJPGo001o2?oonfX7ool002Gooo]Z1?oo0003oook
JP?oo`008ooonfX3ool005Sooo]Z1?l0001ioookJP00GOoonfX4o`0003oooo]Z2Ooo000JoookJP?o
o`000ooonfX3ool000Cooo]Z0ooo000EoookJPOo001o0ooonfX3o`00O`Gooo]Z0ol007l4oookJPOo
001o1ooonfX7ool002Gooo]Z1?oo0003oookJP?oo`008ooonfX3ool000Cooo]Z0ooo001BoookJPCo
0000N?oonfX005gooo]Z1?l0000ooookJPSoo`006ooonfX3ool000[ooo]Z0ooo000EoookJP?o001o
00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Gooo]Z0ol007l3oookJPCo001o00Cooo]Zo`00Ool0
07oo001o1ooonfX7ool002Gooo]Z0ooo0004oookJP?oo`00:_oonfX3ool005;ooo]Z1?l0001hoook
JP00G?oonfX4o`0008Oooo]Z0ol007l3oookJP?o001o2_oonfX3o`00O`?ooo]Z0ol007l3oookJP?o
001o1_oonfX7ool00:oooo]Z1?l0001goookJP00G?oonfX4o`0008Oooo]Z0ol007l3oookJP?o001o
2_oonfX3o`00O`Wooo]Z0ol007l6oookJPOoo`00[ooonfX4o`0007Oooo]Z001KoookJPCo0000R?oo
nfX3o`00O`?ooo]Z0ol007l:oookJP?o001o2OoonfX3o`00O`Kooo]Z1ooo002`oookJPCo0000M_oo
nfX005_ooo]Z1?l00028oookJP?o001o0ooonfX3o`00O`[ooo]Z0ol007l4oookJP;o001o0_oonfX4
o`00O`Kooo]Z1ooo002`oookJPCo0000M_oonfX005[ooo]Z1?l00029oookJP?o001o0ooonfX3o`00
O`[ooo]Z0ol007l4oookJPOo001o1ooonfX7ool00;7ooo]Z1?l0001eoookJP00F_oonfX4o`0008Wo
oo]Z0ol007l3oookJP?o001o2_oonfX3o`00O`Cooo]Z1_l007l8oookJPOoo`00/OoonfX4o`0007Go
oo]Z001IoookJPCo0000R_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o1?oonfX2o`00O`cooo]Z
1ooo002boookJPCo0000M?oonfX005Wooo]Z1?l0002;oookJP?o001o00Cooo]Zo`00Ool007oo001o
2?oonfX6o`00O`Cooo]Z0_l007l<oookJPOoo`00/_oonfX4o`0007Cooo]Z001HoookJPCo0000S?oo
nfX7o`00O`[ooo]Z1?l007l5oookJPOo001o1_oonfX7ool00;?ooo]Z1?l0001coookJP00F?oonfX4
o`0008gooo]Z1Ol007l<oookJP?o001o1OoonfX7o`00O`Kooo]Z1ooo002coookJPCo0000LooonfX0
05Oooo]Z1?l0002doookJPOoo`00]?oonfX4o`0007;ooo]Z001GoookJPCo0000]?oonfX7ool00;Co
oo]Z1Ol0001aoookJP00E_oonfX4o`000;Gooo]Z1ooo002eoookJPCo0000LOoonfX005Kooo]Z1?l0
002eoookJPOoo`00]_oonfX4o`00073ooo]Z001EoookJPCo0000]_oonfX7ool00;Kooo]Z1?l0001`
oookJP00EOoonfX4o`000;Kooo]Z1ooo002goookJPCo0000KooonfX005Cooo]Z1?l0002goookJPOo
o`00]ooonfX4o`0006oooo]Z001DoookJPCo0000]ooonfX7ool00;Sooo]Z1?l0001^oookJP00Dooo
nfX4o`000;Sooo]Z1ooo002hoookJPCo0000K_oonfX005?ooo]Z1?l0002hoookJPOoo`00^OoonfX4
o`0006gooo]Z001BoookJPCo0000^OoonfX7ool00;Wooo]Z1?l0001]oookJP00D_oonfX4o`000;Wo
oo]Z1ooo002joookJPCo0000K?oonfX0057ooo]Z1?l0002joookJPOoo`00^_oonfX4o`0006cooo]Z
001AoookJPCo0000^_oonfX7ool00;_ooo]Z1?l0001[oookJP00D?oonfX4o`000;_ooo]Z1ooo002k
oookJPCo0000JooonfX0053ooo]Z1?l0002koookJPOoo`00_?oonfX4o`0006[ooo]Z001?oookJPCo
0000_?oonfX7ool00;cooo]Z1?l0001ZoookJP00CooonfX4o`000;cooo]Z1ooo002moookJPCo0000
JOoonfX004kooo]Z1?l0002moookJPOoo`00_OoonfX4o`0006Wooo]Z001>oookJPCo0000_OoonfX7
ool00;kooo]Z1?l0001XoookJP00COoonfX4o`000;kooo]Z1ooo002noookJPCo0000J?oonfX004go
oo]Z1?l0002noookJPOoo`00_ooonfX4o`0006Oooo]Z001<oookJPCo0000_ooonfX7ool00;oooo]Z
1?l0001WoookJP00C?oonfX4o`000;oooo]Z1ooo0030oookJPCo0000I_oonfX004_ooo]Z1?l00030
oookJPOoo`00`?oonfX4o`0006Kooo]Z001;oookJPCo0000`?oonfX7ool00<7ooo]Z0ol0001Voook
JP00BooonfX3o`000<7ooo]Z1ooo0031oookJPCo0000IOoonfX004[ooo]Z1?l00031oookJPOoo`00
`OoonfX4o`0006Gooo]Z001:oookJPCo0000`OoonfX7ool00<;ooo]Z1?l0001ToookJP00BOoonfX4
o`000<;ooo]Z1ooo0032oookJPCo0000I?oonfX004Wooo]Z1?l00032oookJPOoo`00`ooonfX4o`00
06?ooo]Z0018oookJPCo0000`ooonfX7ool00<?ooo]Z1?l0001SoookJP00B?oonfX4o`000<?ooo]Z
1ooo0034oookJPCo0000H_oonfX004Oooo]Z1?l00034oookJPOoo`00a?oonfX4o`0006;ooo]Z0017
oookJPCo0000a?oonfX7ool00<Gooo]Z1?l0001QoookJP00A_oonfX4o`000<Gooo]Z1ooo0035oook
JPCo0000HOoonfX004Kooo]Z1?l00035oookJPOoo`00a_oonfX3o`00067ooo]Z0015oookJPCo0000
a_oonfX7ool00<Kooo]Z1?l0001PoookJP00AOoonfX4o`000<Kooo]Z1ooo0036oookJPCo0000H?oo
nfX004Cooo]Z1?l00037oookJPOoo`00aooonfX4o`0005oooo]Z0014oookJPCo0000aooonfX7ool0
0<Oooo]Z1?l0001OoookJP00A?oonfX3o`000<Sooo]Z1ooo0038oookJPCo0000G_oonfX004?ooo]Z
1?l00038oookJPOoo`00b?oonfX4o`0005kooo]Z0013oookJPCo0000b?oonfX7ool00<Wooo]Z1?l0
001MoookJP00@_oonfX4o`000<Wooo]Z1ooo0039oookJPCo0000GOoonfX004;ooo]Z1?l0002]oook
JPGo001o1?oonfX3o`00O`03oookJ_l007oo001o00Oo001o1_oonfX7ool00<[ooo]Z1?l0001Loook
JP00@OoonfX4o`000:gooo]Z1ol007l3oookJP?o001o00?ooo]Zo`00Ool007l01ol007l6oookJPOo
o`00b_oonfX4o`0005cooo]Z0011oookJPCo0000[OoonfX3o`00O`04oookJ_l007oo001oo`00O`?o
oo]Z0ol007l00ooonf[o001oo`00O`02o`00O`_ooo]Z1ooo003;oookJP?o0000G?oonfX0043ooo]Z
1?l0002]oookJP?o001o0ooonfX3o`00O`Oooo]Z1?l007l:oookJPOoo`00booonfX4o`0005_ooo]Z
0010oookJPCo0000[OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo001o2?oonfX7ool00<_ooo]Z1?l0
001KoookJP00?ooonfX4o`000:kooo]Z0ol007l3oookJP?o001o2_oonfX4o`00O`Oooo]Z1ooo003<
oookJPCo0000F_oonfX003oooo]Z1?l0002^oookJP?o001o0ooonfX3o`00O`_ooo]Z0ol007l7oook
JPOoo`00c?oonfX4o`0005[ooo]Z000noookJPCo0000[ooonfX3o`00O`?ooo]Z0ol007l<oookJP?o
001o1_oonfX7ool00<gooo]Z1?l0001IoookJP00?_oonfX4o`000:oooo]Z0ol007l3oookJP?o001o
1_oonfX3o`00O`?ooo]Z0ol007l6oookJPOoo`00cOoonfX4o`0005Wooo]Z000moookJPCo0000/?oo
nfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Kooo]Z1ooo003>oookJPCo0000F?oo
nfX003gooo]Z1?l0002aoookJP?o001o00Cooo]Zo`00Ool007oo001o1ooonfX4o`00O`;ooo]Z0ol0
07l6oookJPOoo`00>_oonfX3o`00O`Gooo]Z0ol007l5oookJPCo001o2?oonfX4o`00O`Oooo]Z1?l0
07l4oookJPGo001oH?oonfX4o`0005Sooo]Z000moookJP?o0000/_oonfX7o`00O`Sooo]Z1ol007l7
oookJPOoo`00>_oonfX3o`00O`Gooo]Z0ol007l3oookJPSo001o1?oonfX8o`00O`Cooo]Z1Ol007l2
oookJPSo001oH?oonfX4o`0005Oooo]Z000loookJPCo0000/ooonfX5o`00O`[ooo]Z1Ol007l8oook
JPOoo`00>_oonfX3o`00O`Gooo]Z0ol007l3oookJP?o001o0_oonfX3o`00O`Cooo]Z0ol007l2oook
JP?o001o1?oonfX3o`00O`Cooo]Z0ol007l3oookJP?o001oGooonfX4o`0005Oooo]Z000loookJPCo
0000cooonfX7ool003[ooo]Z0ol007l5oookJP?o001o0_oonfX3o`00O`Cooo]Z0ol007l2oookJP?o
001o1?oonfX3o`00O`?ooo]Z0ol007l9oookJPCo001oH?oonfX3o`0005Oooo]Z000koookJPCo0000
d?oonfX7ool003[ooo]Z0ol007l5oookJP?o001o0_oonfX3o`00O`Cooo]Z0ol007l2oookJP?o001o
1?oonfX3o`00O`?ooo]Z0ol007l6oookJPOo001oH?oonfX4o`0005Kooo]Z000koookJPCo0000d?oo
nfX7ool003[ooo]Z2_l007l3oookJP?o001o1?oonfX3o`00O`;ooo]Z0ol007l4oookJP?o001o0ooo
nfX3o`00O`Cooo]Z1ol007mRoookJPCo0000E_oonfX003[ooo]Z1?l0003AoookJPOoo`00>_oonfX:
o`00O`?ooo]Z0ol007l4oookJP?o001o0_oonfX3o`00O`Cooo]Z0ol007l3oookJP?o001o1?oonfX4
o`00OfKooo]Z1?l0001EoookJP00>_oonfX4o`000=7ooo]Z1ooo000joookJP?o001o1OoonfX3o`00
O`?ooo]Z0ol007l2oookJP?o001o1?oonfX3o`00O`;ooo]Z0ol007l4oookJP?o001o1?oonfX3o`00
O`?ooo]Z0ol007mQoookJPCo0000EOoonfX003Wooo]Z1?l0003BoookJPOoo`00>_oonfX3o`00O`Go
oo]Z0ol007l3oookJPSo001o1?oonfX8o`00O`?ooo]Z1_l007l3oookJPOo001oHooonfX4o`0005Co
oo]Z000ioookJPCo0000d_oonfX7ool003[ooo]Z0ol007l5oookJP?o001o1OoonfX4o`00O`Sooo]Z
1?l007l5oookJPKo001o1?oonfX5o`00OfCooo]Z1?l0001DoookJP00>OoonfX3o`000=?ooo]Z1ooo
000joookJP?o001o1OoonfX3o`00Oa_ooo]Z0ol007m`oookJP?o0000E?oonfX003Sooo]Z1?l0003C
oookJPOoo`00>_oonfX:o`00Oacooo]Z0ol007m`oookJPCo0000DooonfX003Sooo]Z1?l0003Coook
JPOoo`00>_oonfX9o`00Oi3ooo]Z1?l0001CoookJP00=ooonfX4o`000=Cooo]Z1ooo003DoookJPCo
0000D_oonfX003Oooo]Z1?l0003DoookJPOoo`00e?oonfX4o`0005;ooo]Z000foookJPCo0000eOoo
nfX7ool0063ooo]Z1Ol007lAoookJPGo001oF_oonfX4o`00057ooo]Z000foookJPCo0000eOoonfX7
ool005oooo]Z1ol007l?oookJPOo001oFOoonfX4o`00057ooo]Z000foookJP?o0000e_oonfX7ool0
05kooo]Z0ol007l3oookJP?o001o3OoonfX3o`00O`?ooo]Z0ol007mIoookJP?o0000DOoonfX003Go
oo]Z1?l0003FoookJPOoo`00I?oonfX3o`00Oa?ooo]Z0ol007mIoookJPCo0000D?oonfX003Gooo]Z
1?l0003FoookJPOoo`00?OoonfX5o`00O`Sooo]Z1?l007l5oookJP?o001o0ooonfX3o`00O`Cooo]Z
0ol007l01?oonf[o001oo`00Ool007l3oookJPCo001o00Cooo]Zo`00Ool007oo001o1?oonfX3o`00
O`04oookJ_l007oo001oo`00O`?ooo]Z1?l007l01?oonf[o001oo`00Ool007l3oookJPCo001o1?oo
nfX5o`00Ockooo]Z1?l0001@oookJP00=?oonfX4o`000=Oooo]Z1ooo000loookJPOo001o1OoonfX8
o`00O`?ooo]Z0ol007l3oookJP?o001o0ooonfX8o`00O`;ooo]Z2Ol007l3oookJPSo001o0_oonfX8
o`00O`?ooo]Z1Ol007l3oookJPOo001o?_oonfX4o`0004oooo]Z000doookJPCo0000eooonfX7ool0
03_ooo]Z0ol007l3oookJP?o001o1?oonfX3o`00O`;ooo]Z0ol007l3oookJP?o001o0ooonfX3o`00
O`;ooo]Z1?l007l00ooonf[o001oo`00O`02o`00O`;ooo]Z0ol007l2oookJPCo001o0_oonfX4o`00
O`03oookJ_l007oo001o00;o001o0_oonfX3o`00O`;ooo]Z0ol007l3oookJP?o001o1?oonfX4o`00
O`;ooo]Z0ol007lmoookJPCo0000CooonfX003?ooo]Z1?l0003HoookJPOoo`00>ooonfX3o`00O`Co
oo]Z0ol007l2oookJP?o001o1?oonfX3o`00O`;ooo]Z0ol007l3oookJP?o001o0_oonfX3o`00O`?o
oo]Z0ol007l2oookJP?o001o0ooonfX3o`00O`;ooo]Z0ol007l3oookJP?o001o0_oonfX3o`00O`;o
oo]Z0ol007l3oookJP?o001o1?oonfX3o`00OdCooo]Z1?l0001>oookJP00<ooonfX4o`000=Sooo]Z
1ooo000joookJP?o001o1OoonfX3o`00O`;ooo]Z0ol007l4oookJP?o001o0_oonfX3o`00O`?ooo]Z
0ol007l2oookJP?o001o0ooonfX3o`00O`;ooo]Z0ol007l3oookJP?o001o0_oonfX3o`00O`?ooo]Z
0ol007l2oookJPCo001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Cooo]Z2Ol007lnoookJPCo
0000C_oonfX003?ooo]Z0ol0003IoookJPOoo`00>_oonfX3o`00O`[ooo]Z0ol007l4oookJP?o001o
0_oonfX3o`00O`?ooo]Z0ol007l2oookJP?o001o0ooonfX3o`00O`;ooo]Z0ol007l3oookJP?o001o
0_oonfX3o`00O`?ooo]Z0ol007l3oookJPOo001o0ooonfX3o`00O`Cooo]Z2Ol007looookJP?o0000
C_oonfX003;ooo]Z1?l0003IoookJPOoo`00>_oonfX3o`00O`[ooo]Z0ol007l4oookJP?o001o0_oo
nfX3o`00O`?ooo]Z0ol007l2oookJP?o001o0ooonfX3o`00O`;ooo]Z0ol007l3oookJP?o001o0_oo
nfX3o`00O`?ooo]Z0ol007l7oookJP?o001o0ooonfX3o`00O`Cooo]Z0ol007l3oookJP?o001o?ooo
nfX4o`0004gooo]Z000boookJPCo0000fOoonfX7ool003[ooo]Z0ol007l;oookJP?o001o0_oonfX3
o`00O`?ooo]Z1?l007l2oookJP?o001o0_oonfX4o`00O`03oookJ_l007oo001o00;o001o0_oonfX3
o`00O`?ooo]Z0ol007l2oookJPCo001o00?ooo]Zo`00Ool007l00_l007l2oookJP?o001o0_oonfX3
o`00O`?ooo]Z0ol007l4oookJP?o001o0ooonfX3o`00Ocoooo]Z1?l0001=oookJP00<OoonfX4o`00
0=[ooo]Z1ooo000joookJP?o001o1OoonfX3o`00O`?ooo]Z2?l007l3oookJPWo001o0ooonfX8o`00
O`;ooo]Z0ol007l3oookJP?o001o0ooonfX8o`00O`;ooo]Z2?l007l2oookJPKo001o0ooonfX7o`00
Od7ooo]Z1?l0001<oookJP00<OoonfX4o`000=[ooo]Z1ooo000koookJP?o001o1?oonfX3o`00O`Go
oo]Z1?l007l5oookJP?o001o00?ooo]Zo`00Ool007l00_l007l5oookJP?o001o00Cooo]Zo`00Ool0
07oo001o0_oonfX3o`00O`?ooo]Z0ol007l4oookJP?o001o00Cooo]Zo`00Ool007oo001o1?oonfX4
o`00O`Cooo]Z1_l007l4oookJPGo001o@_oonfX4o`0004cooo]Z000`oookJPCo0000fooonfX7ool0
03_ooo]Z0ol007l3oookJP?o001oA_oonfX3o`00Odkooo]Z1?l0001;oookJP00<?oonfX4o`000=_o
oo]Z1ooo000loookJPSo001oA_oonfX3o`00Odkooo]Z1?l0001;oookJP00<?oonfX3o`000=cooo]Z
1ooo000moookJPGo001oV_oonfX3o`0004_ooo]Z000_oookJPCo0000g?oonfX7ool00=cooo]Z1?l0
001:oookJP00;ooonfX4o`000=cooo]Z1ooo003LoookJPCo0000B_oonfX002kooo]Z1?l0003Moook
JPOoo`00I?oonfX3o`00OgKooo]Z1?l00019oookJP00;_oonfX4o`000=gooo]Z1ooo001ToookJP?o
001oM_oonfX4o`0004Wooo]Z000^oookJP?o0000g_oonfX7ool006Cooo]Z0ol007mgoookJP?o0000
BOoonfX002gooo]Z1?l0003NoookJPOoo`00I?oonfX3o`00OgOooo]Z1?l00018oookJP00;OoonfX4
o`000=kooo]Z1ooo000moookJPGo001o2?oonfX4o`00O`Gooo]Z0ol007l3oookJP?o001o0ooonfX3
o`00O`;ooo]Z0ol007l01?oonf[o001oo`00Ool007l4oookJP?o001o1?oonfX5o`00O`Cooo]Z0ol0
07l3oookJP?o001oE_oonfX4o`0004Sooo]Z000/oookJPCo0000gooonfX7ool003cooo]Z1ol007l5
oookJPSo001o0ooonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o0_oonfX8o`00O`?ooo]Z0ol007l3
oookJPOo001o1?oonfX3o`00O`04oookJ_l007oo001oo`00OeSooo]Z1?l00017oookJP00;?oonfX4
o`000=oooo]Z1ooo000koookJP?o001o0ooonfX3o`00O`Cooo]Z0ol007l2oookJP?o001o0ooonfX3
o`00O`?ooo]Z0ol007l3oookJP?o001o0_oonfX4o`00O`03oookJ_l007oo001o00;o001o0_oonfX3
o`00O`;ooo]Z1?l007l2oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00OeSooo]Z1?l0
0017oookJP00:ooonfX4o`000>3ooo]Z1ooo000koookJP?o001o1?oonfX3o`00O`;ooo]Z0ol007l4
oookJP?o001o0_oonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o0_oonfX3o`00O`?ooo]Z0ol007l2
oookJP?o001o0_oonfX3o`00O`[ooo]Z1Ol007mJoookJPCo0000A_oonfX002_ooo]Z1?l0003Poook
JPOoo`00>_oonfX3o`00O`Gooo]Z0ol007l2oookJP?o001o1?oonfX3o`00O`;ooo]Z0ol007l3oook
JP?o001o0ooonfX3o`00O`;ooo]Z0ol007l3oookJP?o001o0_oonfX3o`00O`;ooo]Z2Ol007l5oook
JP?o001oFooonfX4o`0004Kooo]Z000[oookJP?o0000hOoonfX7ool003[ooo]Z0ol007l:oookJP?o
001o1?oonfX3o`00O`;ooo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`;ooo]Z0ol007l3oookJP?o
001o0_oonfX3o`00O`;ooo]Z2Ol007l5oookJP?o001oG?oonfX3o`0004Kooo]Z000ZoookJPCo0000
hOoonfX7ool003[ooo]Z0ol007l:oookJP?o001o1?oonfX3o`00O`;ooo]Z0ol007l3oookJP?o001o
0ooonfX3o`00O`;ooo]Z0ol007l3oookJP?o001o0_oonfX3o`00O`;ooo]Z0ol007l3oookJP?o001o
1?oonfX5o`00Oe_ooo]Z1?l00015oookJP00:_oonfX4o`000>7ooo]Z1ooo000joookJP?o001o2ooo
nfX3o`00O`;ooo]Z0ol007l3oookJPCo001o0_oonfX4o`00O`;ooo]Z0ol007l2oookJPCo001o00?o
oo]Zo`00Ool007l00_l007l2oookJP?o001o0_oonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o00Co
oo]Zo`00Ool007oo001oF_oonfX4o`0004Gooo]Z000YoookJPCo0000h_oonfX7ool003[ooo]Z0ol0
07l5oookJP?o001o0ooonfX8o`00O`?ooo]Z3ol007l2oookJPSo001o0ooonfX3o`00O`?ooo]Z1ol0
07l4oookJP?o001o00Cooo]Zo`00Ool007oo001oFooonfX4o`0004Cooo]Z000YoookJPCo0000h_oo
nfX7ool003_ooo]Z0ol007l4oookJP?o001o1OoonfX4o`00O`Gooo]Z0ol007l00ooonf[o001oo`00
O`02o`00O`;ooo]Z1?l007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o1?oonfX3o`00O`Cooo]Z
1Ol007l4oookJP?o001o0ooonfX3o`00Oe[ooo]Z1?l00014oookJP00:?oonfX4o`000;gooo]Z1Ol0
07l4oookJP?o001o00?ooo]Zo`00Ool007l01ol007l3oookJPGo001o2?oonfX7ool003_ooo]Z0ol0
07l3oookJP?o001o:ooonfX3o`00Og7ooo]Z1?l00013oookJP00:?oonfX4o`000;cooo]Z1ol007l3
oookJP?o001o00?ooo]Zo`00Ool007l01ol007l2oookJPOo001o1ooonfX7ool003cooo]Z2?l007l[
oookJP?o001oLOoonfX4o`0004?ooo]Z000XoookJP?o0000_OoonfX3o`00O`04oookJ_l007oo001o
o`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`Kooo]Z1?l007l01?oonf[o001oo`00Ool0
07l7oookJPOoo`00?OoonfX5o`00Obgooo]Z0ol007mboookJP?o0000@ooonfX002Oooo]Z1?l0002l
oookJP?o001o0ooonfX3o`00O`Oooo]Z1?l007l5oookJP?o001o0ooonfX3o`00O`Kooo]Z1ooo003T
oookJPCo0000@_oonfX002Oooo]Z1?l0002loookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol007l9oook
JP?o001o1_oonfX7ool00>Cooo]Z1?l00012oookJP009ooonfX3o`000;gooo]Z0ol007l3oookJP?o
001o2_oonfX4o`00O`Sooo]Z0ol007l6oookJPOoo`00iOoonfX3o`0004;ooo]Z003WoookJP?o001o
0ooonfX3o`00O`_ooo]Z0ol007l3oookJP;o001o0_oonfX4o`00O`Kooo]Z1ooo003ooookJR_ooo]Z
003WoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l2oookJPOo001o1ooonfX7ool00?oooo]Z:ooo
nfX00>Oooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l2oookJPKo001o2OoonfX4
o`000?oooo]Z;OoonfX00>Oooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l2oook
JP;o001o3OoonfX4o`000?oooo]Z;OoonfX00>Sooo]Z0ol007l01?oonf[o001oo`00Ool007l7oook
JPCo001o0_oonfX3o`00O`;ooo]Z0_l007l=oookJPCo0000oooonfX]oookJP00j?oonfX7o`00O`So
oo]Z1ol007l4oookJPOo001o1ooonfX4o`000?oooo]Z;OoonfX00>Wooo]Z1Ol007l:oookJPGo001o
1OoonfX7o`00O`Oooo]Z1?l0003ooookJRgooo]Z003ooookJQ7ooo]Z1?l0003ooookJRgooo]Z003o
oookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z
@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oo
oo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2
oookJP00oooonfX?oookJP03oa0@OOl007ooZJMa0?oooo]Z<?oonfX00?oooo]Z3ooonfX00olb<W[o
001oo`00O`3ooookJS3ooo]Z003ooookJPoooo]Z00Coc<Q^o`00Ool007oo^[Q_oooonfX_oookJP00
oooonfX@oookJP03oiRFL_l007ooQhEc0?oooo]Z;ooonfX00?oooo]Z4OoonfX00omgMGGo<S9joook
JP3ooookJRkooo]Z003ooookJQ;ooo]Z00?o001ooiRFL_oonfX0oooonfX]oookJP00oooonfXBoook
JP03ob4QO?l@47goV9Ib0?oooo]Z;OoonfX00?oooo]Z4_oonfX01?l007oo^[Q_o`00Ooo<b6kooook
JRcooo]Z003ooookJQ7ooo]Z00Koc<Q^o`00Oooonf[oEE=goa0@OOo^jV_ooookJR_ooo]Z003ooook
JPkooo]Z00Wo001oohN5Looonf[oMgEeo`00Oooonf[ogMU/o`00OomVI7H0oooonfX[oookJP00oooo
nfX>oookJP05ohN5Lol007oo001oo`00Oolb<WX00_oonfX00omEDgOo001oomgIK03ooookJR[ooo]Z
003ooookJPoooo]Z00CoQhEco`00Ool@47goc<Q^0_oonfX00ooMfFco<S9jodA2N@3ooookJR[ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oo
oo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX0
0001\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.17342, -0.0225929, \
0.00427295, 0.000864222}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
Find the conditions where the real roots are positive and/or \
negative\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Reduce[{LambdaPlus\  > 0, LambdaMinus > 0}]\)], "Input",
  CellTags->"mmtag:21:Reduce[]"],

Cell[BoxData[
    \(\[Beta] < 0 && 0 < \[Gamma] \[LessEqual] \[Beta]\^2\/4\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(AnnotePosRealRoots\  = 
      Graphics[Text[
          StyleForm["\<Positive Roots\>", 
            FontColor \[Rule] Hue[ .6]], {\(-1.0\), 0.025}, {\(-1\), 
            0}]]\)], "Input"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Reduce[{LambdaPlus\  > 0, LambdaMinus < 0}]\)], "Input"],

Cell[BoxData[
    \(\[Beta] \[Element] Reals && \[Gamma] < 0\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(MixedRealRoots\  = \ 
      Plot[0, {t, \(-1\), 1}, PlotStyle \[Rule] {Hue[0.6], Thickness[0.015]}, 
        DisplayFunction \[Rule] Identity]\), "\[IndentingNewLine]", 
    \(AnnoteMixedRealRoots\  = 
      Show[MixedRealRoots, 
        Graphics[
          Text[StyleForm["\<Mixed Real Roots\>", 
              FontColor \[Rule] Hue[ .6]], {0.2, \(-0.1\)}, {\(-1\), 0}]], 
        DisplayFunction \[Rule] $DisplayFunction]\)}], "Input"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.603319 5.88604 [
[.02381 .59082 -13.4688 -20 ]
[.02381 .59082 13.4688 0 ]
[.2619 .59082 -20.9688 -20 ]
[.2619 .59082 20.9688 0 ]
[.7381 .59082 -14.5 -20 ]
[.7381 .59082 14.5 0 ]
[.97619 .59082 -7 -20 ]
[.97619 .59082 7 0 ]
[.4875 .01472 -41.9375 -10 ]
[.4875 .01472 0 10 ]
[.4875 .13244 -51.9375 -10 ]
[.4875 .13244 0 10 ]
[.4875 .25016 -51.9375 -10 ]
[.4875 .25016 0 10 ]
[.4875 .36788 -51.9375 -10 ]
[.4875 .36788 0 10 ]
[.4875 .4856 -51.9375 -10 ]
[.4875 .4856 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .60332 m
.02381 .60957 L
s
gsave
.02381 .59082 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .60332 m
.2619 .60957 L
s
gsave
.2619 .59082 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .60332 m
.7381 .60957 L
s
gsave
.7381 .59082 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .60332 m
.97619 .60957 L
s
gsave
.97619 .59082 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .60332 m
.07143 .60707 L
s
.11905 .60332 m
.11905 .60707 L
s
.16667 .60332 m
.16667 .60707 L
s
.21429 .60332 m
.21429 .60707 L
s
.30952 .60332 m
.30952 .60707 L
s
.35714 .60332 m
.35714 .60707 L
s
.40476 .60332 m
.40476 .60707 L
s
.45238 .60332 m
.45238 .60707 L
s
.54762 .60332 m
.54762 .60707 L
s
.59524 .60332 m
.59524 .60707 L
s
.64286 .60332 m
.64286 .60707 L
s
.69048 .60332 m
.69048 .60707 L
s
.78571 .60332 m
.78571 .60707 L
s
.83333 .60332 m
.83333 .60707 L
s
.88095 .60332 m
.88095 .60707 L
s
.92857 .60332 m
.92857 .60707 L
s
.01 w
0 .60332 m
1 .60332 L
s
.25 Mabswid
.5 .01472 m
.50625 .01472 L
s
gsave
.4875 .01472 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.1) show
1.000 setlinewidth
grestore
.5 .13244 m
.50625 .13244 L
s
gsave
.4875 .13244 -112.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.08) show
1.000 setlinewidth
grestore
.5 .25016 m
.50625 .25016 L
s
gsave
.4875 .25016 -112.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.06) show
1.000 setlinewidth
grestore
.5 .36788 m
.50625 .36788 L
s
gsave
.4875 .36788 -112.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.04) show
1.000 setlinewidth
grestore
.5 .4856 m
.50625 .4856 L
s
gsave
.4875 .4856 -112.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.02) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .04415 m
.50375 .04415 L
s
.5 .07358 m
.50375 .07358 L
s
.5 .10301 m
.50375 .10301 L
s
.5 .16187 m
.50375 .16187 L
s
.5 .1913 m
.50375 .1913 L
s
.5 .22073 m
.50375 .22073 L
s
.5 .27959 m
.50375 .27959 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33845 m
.50375 .33845 L
s
.5 .39731 m
.50375 .39731 L
s
.5 .42674 m
.50375 .42674 L
s
.5 .45617 m
.50375 .45617 L
s
.5 .51503 m
.50375 .51503 L
s
.5 .54446 m
.50375 .54446 L
s
.5 .57389 m
.50375 .57389 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 .4 1 r
.015 w
.02381 .60332 m
.02499 .60332 L
.02605 .60332 L
.02729 .60332 L
.02846 .60332 L
.02954 .60332 L
.03053 .60332 L
.03163 .60332 L
.03279 .60332 L
.03395 .60332 L
.0352 .60332 L
.03638 .60332 L
.03746 .60332 L
.03873 .60332 L
.03944 .60332 L
.04011 .60332 L
.04132 .60332 L
.04262 .60332 L
.04327 .60332 L
.04396 .60332 L
.04519 .60332 L
.04588 .60332 L
.04652 .60332 L
.04722 .60332 L
.04797 .60332 L
.04862 .60332 L
.04933 .60332 L
.05061 .60332 L
.05186 .60332 L
.05302 .60332 L
.05414 .60332 L
.05519 .60332 L
.05634 .60332 L
.05759 .60332 L
.05882 .60332 L
.06012 .60332 L
.06123 .60332 L
.06244 .60332 L
.06315 .60332 L
.06381 .60332 L
.06453 .60332 L
.06529 .60332 L
.06657 .60332 L
.06729 .60332 L
.06797 .60332 L
.06924 .60332 L
.0704 .60332 L
.07103 .60332 L
.07173 .60332 L
.073 .60332 L
Mistroke
.07376 .60332 L
.07448 .60332 L
.07513 .60332 L
.07583 .60332 L
.0766 .60332 L
.0774 .60332 L
.07809 .60332 L
.07885 .60332 L
.07956 .60332 L
.0802 .60332 L
.08095 .60332 L
.08166 .60332 L
.08291 .60332 L
.08362 .60332 L
.08427 .60332 L
.08544 .60332 L
.08669 .60332 L
.08787 .60332 L
.08896 .60332 L
.09016 .60332 L
.09148 .60332 L
.09214 .60332 L
.09285 .60332 L
.09413 .60332 L
.09483 .60332 L
.09548 .60332 L
.09619 .60332 L
.09695 .60332 L
.09821 .60332 L
.09893 .60332 L
.09961 .60332 L
.10086 .60332 L
.10201 .60332 L
.10333 .60332 L
.10458 .60332 L
.10572 .60332 L
.10694 .60332 L
.1081 .60332 L
.10916 .60332 L
.11033 .60332 L
.11162 .60332 L
.11227 .60332 L
.11297 .60332 L
.11422 .60332 L
.11491 .60332 L
.11554 .60332 L
.11624 .60332 L
.11698 .60332 L
.11822 .60332 L
.11892 .60332 L
Mistroke
.11958 .60332 L
.12081 .60332 L
.12194 .60332 L
.12323 .60332 L
.12446 .60332 L
.12562 .60332 L
.12668 .60332 L
.12789 .60332 L
.12903 .60332 L
.13009 .60332 L
.13107 .60332 L
.13214 .60332 L
.13327 .60332 L
.13441 .60332 L
.13564 .60332 L
.1368 .60332 L
.13785 .60332 L
.13909 .60332 L
.13979 .60332 L
.14043 .60332 L
.14162 .60332 L
.14288 .60332 L
.14402 .60332 L
.14526 .60332 L
.14656 .60332 L
.14777 .60332 L
.14891 .60332 L
.14994 .60332 L
.15113 .60332 L
.15226 .60332 L
.15348 .60332 L
.15478 .60332 L
.15589 .60332 L
.15711 .60332 L
.15842 .60332 L
.15915 .60332 L
.15982 .60332 L
.16113 .60332 L
.16236 .60332 L
.16352 .60332 L
.16456 .60332 L
.16577 .60332 L
.1669 .60332 L
.16796 .60332 L
.16893 .60332 L
.16999 .60332 L
.17111 .60332 L
.17225 .60332 L
.17347 .60332 L
.17462 .60332 L
Mistroke
.17566 .60332 L
.17689 .60332 L
.17758 .60332 L
.17823 .60332 L
.1794 .60332 L
.18065 .60332 L
.18185 .60332 L
.18316 .60332 L
.18441 .60332 L
.18556 .60332 L
.1867 .60332 L
.18773 .60332 L
.18893 .60332 L
.19005 .60332 L
.19128 .60332 L
.19258 .60332 L
.19369 .60332 L
.19491 .60332 L
.19623 .60332 L
.19696 .60332 L
.19763 .60332 L
.19894 .60332 L
.20017 .60332 L
.20122 .60332 L
.20238 .60332 L
.20359 .60332 L
.20472 .60332 L
.20578 .60332 L
.20675 .60332 L
.20781 .60332 L
.20894 .60332 L
.21008 .60332 L
.21129 .60332 L
.21244 .60332 L
.21349 .60332 L
.21472 .60332 L
.21541 .60332 L
.21605 .60332 L
.21723 .60332 L
.21847 .60332 L
.21968 .60332 L
.221 .60332 L
.22224 .60332 L
.2234 .60332 L
.22454 .60332 L
.22558 .60332 L
.22677 .60332 L
.2279 .60332 L
.22914 .60332 L
.23044 .60332 L
Mistroke
.23155 .60332 L
.23277 .60332 L
.23409 .60332 L
.23482 .60332 L
.2355 .60332 L
.2368 .60332 L
.23804 .60332 L
.23909 .60332 L
.24025 .60332 L
.24146 .60332 L
.2426 .60332 L
.24365 .60332 L
.24462 .60332 L
.24569 .60332 L
.24681 .60332 L
.24795 .60332 L
.24917 .60332 L
.25032 .60332 L
.25137 .60332 L
.2526 .60332 L
.25329 .60332 L
.25393 .60332 L
.2551 .60332 L
.25635 .60332 L
.25756 .60332 L
.25888 .60332 L
.26013 .60332 L
.26129 .60332 L
.26233 .60332 L
.26348 .60332 L
.26467 .60332 L
.2658 .60332 L
.26704 .60332 L
.26835 .60332 L
.26946 .60332 L
.27068 .60332 L
.272 .60332 L
.27274 .60332 L
.27341 .60332 L
.27472 .60332 L
.27595 .60332 L
.27701 .60332 L
.27817 .60332 L
.27938 .60332 L
.28052 .60332 L
.28158 .60332 L
.28255 .60332 L
.28367 .60332 L
.28474 .60332 L
.28588 .60332 L
Mistroke
.2871 .60332 L
.28825 .60332 L
.2893 .60332 L
.29053 .60332 L
.29122 .60332 L
.29186 .60332 L
.29303 .60332 L
.29427 .60332 L
.29549 .60332 L
.29618 .60332 L
.29682 .60332 L
.29799 .60332 L
.29923 .60332 L
.30034 .60332 L
.30138 .60332 L
.30252 .60332 L
.30375 .60332 L
.30499 .60332 L
.30569 .60332 L
.30634 .60332 L
.30765 .60332 L
.30839 .60332 L
.30906 .60332 L
.31026 .60332 L
.31156 .60332 L
.31278 .60332 L
.31392 .60332 L
.31497 .60332 L
.31611 .60332 L
.31718 .60332 L
.31816 .60332 L
.3193 .60332 L
.32055 .60332 L
.32173 .60332 L
.32282 .60332 L
.32406 .60332 L
.32522 .60332 L
.32626 .60332 L
.32739 .60332 L
.32862 .60332 L
.32992 .60332 L
.33103 .60332 L
.33225 .60332 L
.33356 .60332 L
.33477 .60332 L
.33541 .60332 L
.3361 .60332 L
.33683 .60332 L
.33751 .60332 L
.33876 .60332 L
Mistroke
.33991 .60332 L
.34123 .60332 L
.34249 .60332 L
.3436 .60332 L
.3448 .60332 L
.34592 .60332 L
.34694 .60332 L
.34814 .60332 L
.34945 .60332 L
.35067 .60332 L
.35181 .60332 L
.35302 .60332 L
.35431 .60332 L
.35554 .60332 L
.35665 .60332 L
.35796 .60332 L
.3587 .60332 L
.35939 .60332 L
.36064 .60332 L
.36128 .60332 L
.36198 .60332 L
.36266 .60332 L
.36337 .60332 L
.36465 .60332 L
.36536 .60332 L
.36602 .60332 L
.36675 .60332 L
.36753 .60332 L
.3682 .60332 L
.36893 .60332 L
.36962 .60332 L
.37026 .60332 L
.37146 .60332 L
.37274 .60332 L
.37394 .60332 L
.37526 .60332 L
.37651 .60332 L
.37766 .60332 L
.3788 .60332 L
.37984 .60332 L
.38103 .60332 L
.38216 .60332 L
.38339 .60332 L
.3847 .60332 L
.38581 .60332 L
.38703 .60332 L
.38834 .60332 L
.38908 .60332 L
.38975 .60332 L
.39106 .60332 L
Mistroke
.39229 .60332 L
.39334 .60332 L
.3945 .60332 L
.39571 .60332 L
.39685 .60332 L
.39791 .60332 L
.39888 .60332 L
.39994 .60332 L
.40106 .60332 L
.40221 .60332 L
.40342 .60332 L
.40457 .60332 L
.40562 .60332 L
.40685 .60332 L
.40754 .60332 L
.40818 .60332 L
.40936 .60332 L
.4106 .60332 L
.41181 .60332 L
.41313 .60332 L
.41438 .60332 L
.41554 .60332 L
.41669 .60332 L
.41772 .60332 L
.41892 .60332 L
.42005 .60332 L
.42129 .60332 L
.42259 .60332 L
.42371 .60332 L
.42493 .60332 L
.42624 .60332 L
.42698 .60332 L
.42765 .60332 L
.42896 .60332 L
.43019 .60332 L
.43125 .60332 L
.43241 .60332 L
.43362 .60332 L
.43476 .60332 L
.43582 .60332 L
.43679 .60332 L
.43791 .60332 L
.43898 .60332 L
.44012 .60332 L
.44134 .60332 L
.44249 .60332 L
.44354 .60332 L
.44477 .60332 L
.44546 .60332 L
.4461 .60332 L
Mistroke
.44727 .60332 L
.44851 .60332 L
.44973 .60332 L
.45042 .60332 L
.45106 .60332 L
.45223 .60332 L
.45347 .60332 L
.45458 .60332 L
.45562 .60332 L
.45676 .60332 L
.45799 .60332 L
.45922 .60332 L
.45992 .60332 L
.46057 .60332 L
.46188 .60332 L
.46262 .60332 L
.46329 .60332 L
.46449 .60332 L
.46579 .60332 L
.46702 .60332 L
.46815 .60332 L
.4692 .60332 L
.47034 .60332 L
.47141 .60332 L
.47239 .60332 L
.47353 .60332 L
.47478 .60332 L
.47596 .60332 L
.47705 .60332 L
.47829 .60332 L
.47945 .60332 L
.48049 .60332 L
.48162 .60332 L
.48285 .60332 L
.48415 .60332 L
.48526 .60332 L
.48648 .60332 L
.48779 .60332 L
.489 .60332 L
.48963 .60332 L
.49033 .60332 L
.49105 .60332 L
.49174 .60332 L
.49299 .60332 L
.49413 .60332 L
.49539 .60332 L
.49671 .60332 L
.49783 .60332 L
.49902 .60332 L
.50014 .60332 L
Mistroke
.50116 .60332 L
.50236 .60332 L
.50366 .60332 L
.50489 .60332 L
.50603 .60332 L
.50723 .60332 L
.50853 .60332 L
.50975 .60332 L
.51087 .60332 L
.51218 .60332 L
.51292 .60332 L
.51361 .60332 L
.51486 .60332 L
.5155 .60332 L
.5162 .60332 L
.51687 .60332 L
.51759 .60332 L
.51886 .60332 L
.51958 .60332 L
.52024 .60332 L
.52096 .60332 L
.52174 .60332 L
.52241 .60332 L
.52314 .60332 L
.52383 .60332 L
.52447 .60332 L
.52568 .60332 L
.52695 .60332 L
.52816 .60332 L
.52947 .60332 L
.53072 .60332 L
.53187 .60332 L
.53301 .60332 L
.53405 .60332 L
.53525 .60332 L
.53637 .60332 L
.5376 .60332 L
.53891 .60332 L
.54002 .60332 L
.54124 .60332 L
.54255 .60332 L
.54329 .60332 L
.54396 .60332 L
.54526 .60332 L
.5465 .60332 L
.54755 .60332 L
.54871 .60332 L
.54992 .60332 L
.55105 .60332 L
.55211 .60332 L
Mistroke
.55308 .60332 L
.55415 .60332 L
.55527 .60332 L
.55641 .60332 L
.55763 .60332 L
.55878 .60332 L
.55982 .60332 L
.56105 .60332 L
.56175 .60332 L
.56238 .60332 L
.56356 .60332 L
.5648 .60332 L
.56601 .60332 L
.56734 .60332 L
.56858 .60332 L
.56974 .60332 L
.57088 .60332 L
.57192 .60332 L
.57312 .60332 L
.57425 .60332 L
.57548 .60332 L
.57679 .60332 L
.5779 .60332 L
.57912 .60332 L
.58044 .60332 L
.58118 .60332 L
.58185 .60332 L
.58315 .60332 L
.58439 .60332 L
.58544 .60332 L
.5866 .60332 L
.58782 .60332 L
.58895 .60332 L
.59001 .60332 L
.59098 .60332 L
.5921 .60332 L
.59317 .60332 L
.59431 .60332 L
.59553 .60332 L
.59668 .60332 L
.59773 .60332 L
.59896 .60332 L
.59965 .60332 L
.60029 .60332 L
.60146 .60332 L
.60271 .60332 L
.60392 .60332 L
.60461 .60332 L
.60525 .60332 L
.60642 .60332 L
Mistroke
.60766 .60332 L
.60876 .60332 L
.6098 .60332 L
.61094 .60332 L
.61217 .60332 L
.61341 .60332 L
.6141 .60332 L
.61475 .60332 L
.61607 .60332 L
.6168 .60332 L
.61747 .60332 L
.61867 .60332 L
.61997 .60332 L
.6212 .60332 L
.62233 .60332 L
.62339 .60332 L
.62452 .60332 L
.62559 .60332 L
.62657 .60332 L
.62771 .60332 L
.62896 .60332 L
.63014 .60332 L
.63123 .60332 L
.63247 .60332 L
.63363 .60332 L
.63467 .60332 L
.6358 .60332 L
.63703 .60332 L
.63833 .60332 L
.63944 .60332 L
.64066 .60332 L
.64197 .60332 L
.64318 .60332 L
.64381 .60332 L
.6445 .60332 L
.64523 .60332 L
.64591 .60332 L
.64716 .60332 L
.64831 .60332 L
.64956 .60332 L
.65088 .60332 L
.652 .60332 L
.65319 .60332 L
.65431 .60332 L
.65533 .60332 L
.65653 .60332 L
.65784 .60332 L
.65906 .60332 L
.6602 .60332 L
.6614 .60332 L
Mistroke
.6627 .60332 L
.66392 .60332 L
.66504 .60332 L
.66635 .60332 L
.66709 .60332 L
.66777 .60332 L
.66903 .60332 L
.66966 .60332 L
.67036 .60332 L
.67104 .60332 L
.67175 .60332 L
.67303 .60332 L
.67374 .60332 L
.6744 .60332 L
.67513 .60332 L
.67591 .60332 L
.67658 .60332 L
.67731 .60332 L
.678 .60332 L
.67864 .60332 L
.67984 .60332 L
.68112 .60332 L
.68232 .60332 L
.68364 .60332 L
.68488 .60332 L
.68603 .60332 L
.68718 .60332 L
.68821 .60332 L
.68941 .60332 L
.69053 .60332 L
.69176 .60332 L
.69307 .60332 L
.69418 .60332 L
.6954 .60332 L
.69671 .60332 L
.69745 .60332 L
.69812 .60332 L
.69942 .60332 L
.70066 .60332 L
.70171 .60332 L
.70286 .60332 L
.70407 .60332 L
.70521 .60332 L
.70627 .60332 L
.70724 .60332 L
.7083 .60332 L
.70942 .60332 L
.71056 .60332 L
.71178 .60332 L
.71293 .60332 L
Mistroke
.71398 .60332 L
.71521 .60332 L
.7159 .60332 L
.71654 .60332 L
.71771 .60332 L
.71896 .60332 L
.72017 .60332 L
.72149 .60332 L
.72273 .60332 L
.72389 .60332 L
.72503 .60332 L
.72607 .60332 L
.72727 .60332 L
.7284 .60332 L
.72963 .60332 L
.73094 .60332 L
.73205 .60332 L
.73327 .60332 L
.73458 .60332 L
.73532 .60332 L
.73599 .60332 L
.7373 .60332 L
.73853 .60332 L
.73959 .60332 L
.74075 .60332 L
.74196 .60332 L
.7431 .60332 L
.74416 .60332 L
.74513 .60332 L
.74619 .60332 L
.74731 .60332 L
.74846 .60332 L
.74967 .60332 L
.75083 .60332 L
.75187 .60332 L
.7531 .60332 L
.75379 .60332 L
.75443 .60332 L
.75561 .60332 L
.75685 .60332 L
.75806 .60332 L
.75875 .60332 L
.75939 .60332 L
.76056 .60332 L
.7618 .60332 L
.7629 .60332 L
.76394 .60332 L
.76508 .60332 L
.76631 .60332 L
.76754 .60332 L
Mistroke
.76824 .60332 L
.76889 .60332 L
.7702 .60332 L
.77094 .60332 L
.77161 .60332 L
.7728 .60332 L
.7741 .60332 L
.77533 .60332 L
.77646 .60332 L
.77752 .60332 L
.77865 .60332 L
.77972 .60332 L
.7807 .60332 L
.78184 .60332 L
.78309 .60332 L
.78427 .60332 L
.78536 .60332 L
.7866 .60332 L
.78776 .60332 L
.7888 .60332 L
.78993 .60332 L
.79116 .60332 L
.79246 .60332 L
.79357 .60332 L
.79479 .60332 L
.7961 .60332 L
.7973 .60332 L
.79793 .60332 L
.79863 .60332 L
.79936 .60332 L
.80004 .60332 L
.80129 .60332 L
.80243 .60332 L
.80369 .60332 L
.80501 .60332 L
.80612 .60332 L
.80731 .60332 L
.80843 .60332 L
.80945 .60332 L
.81066 .60332 L
.81196 .60332 L
.81318 .60332 L
.81432 .60332 L
.81552 .60332 L
.81682 .60332 L
.81804 .60332 L
.81916 .60332 L
.82047 .60332 L
.8212 .60332 L
.82189 .60332 L
Mistroke
.82315 .60332 L
.82385 .60332 L
.82448 .60332 L
.82516 .60332 L
.82587 .60332 L
.82715 .60332 L
.82786 .60332 L
.82852 .60332 L
.82925 .60332 L
.83002 .60332 L
.8307 .60332 L
.83143 .60332 L
.83212 .60332 L
.83275 .60332 L
.83396 .60332 L
.83524 .60332 L
.83644 .60332 L
.83775 .60332 L
.839 .60332 L
.84015 .60332 L
.84129 .60332 L
.84232 .60332 L
.84352 .60332 L
.84464 .60332 L
.84587 .60332 L
.84718 .60332 L
.84829 .60332 L
.8495 .60332 L
.85082 .60332 L
.85155 .60332 L
.85222 .60332 L
.85353 .60332 L
.85476 .60332 L
.85581 .60332 L
.85697 .60332 L
.85818 .60332 L
.85932 .60332 L
.86037 .60332 L
.86134 .60332 L
.86241 .60332 L
.86353 .60332 L
.86467 .60332 L
.86589 .60332 L
.86704 .60332 L
.86808 .60332 L
.86931 .60332 L
.87 .60332 L
.87064 .60332 L
.87182 .60332 L
.87306 .60332 L
Mistroke
.87427 .60332 L
.87559 .60332 L
.87684 .60332 L
.87799 .60332 L
.87914 .60332 L
.88017 .60332 L
.88137 .60332 L
.88249 .60332 L
.88373 .60332 L
.88503 .60332 L
.88615 .60332 L
.88737 .60332 L
.88868 .60332 L
.88942 .60332 L
.89009 .60332 L
.89139 .60332 L
.89263 .60332 L
.89368 .60332 L
.89484 .60332 L
.89605 .60332 L
.89719 .60332 L
.89825 .60332 L
.89922 .60332 L
.90029 .60332 L
.90141 .60332 L
.90255 .60332 L
.90377 .60332 L
.90492 .60332 L
.90596 .60332 L
.90719 .60332 L
.90789 .60332 L
.90852 .60332 L
.9097 .60332 L
.91094 .60332 L
.91216 .60332 L
.91284 .60332 L
.91348 .60332 L
.91464 .60332 L
.91589 .60332 L
.91699 .60332 L
.91803 .60332 L
.91917 .60332 L
.9204 .60332 L
.92163 .60332 L
.92233 .60332 L
.92297 .60332 L
.92429 .60332 L
.92502 .60332 L
.92569 .60332 L
.92689 .60332 L
Mistroke
.92819 .60332 L
.92941 .60332 L
.93055 .60332 L
.9316 .60332 L
.93273 .60332 L
.9338 .60332 L
.93478 .60332 L
.93592 .60332 L
.93717 .60332 L
.93835 .60332 L
.93944 .60332 L
.94068 .60332 L
.94184 .60332 L
.94288 .60332 L
.94401 .60332 L
.94524 .60332 L
.94654 .60332 L
.94765 .60332 L
.94887 .60332 L
.94975 .60332 L
.95057 .60332 L
.95146 .60332 L
.95241 .60332 L
.95324 .60332 L
.95401 .60332 L
.95486 .60332 L
.95577 .60332 L
.95653 .60332 L
.95737 .60332 L
.95824 .60332 L
.95905 .60332 L
.95981 .60332 L
.9605 .60332 L
.9613 .60332 L
.96206 .60332 L
.96287 .60332 L
.96377 .60332 L
.96471 .60332 L
.96559 .60332 L
.96641 .60332 L
.96716 .60332 L
.96802 .60332 L
.96884 .60332 L
.96972 .60332 L
.97067 .60332 L
.97155 .60332 L
.97236 .60332 L
.97331 .60332 L
.97433 .60332 L
.9753 .60332 L
Mistroke
.97619 .60332 L
Mfstroke
0 g
gsave
.59524 .01472 -61 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.400 1.000 setrgbcolor
0.000 0.000 rmoveto
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.400 1.000 setrgbcolor
(Mixed) show
118.875 19.000 moveto
(Real) show
161.812 19.000 moveto
(Roots) show
212.562 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.400 1.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfX5o`00O`Cooo]Z0ol007l5oookJP?o001o2_oonfX5o`0003Kooo]Z0ol0I_l2oookJP?o
06Ko0_oonfX3o`1Vo`;ooo]Z0ol0I_l2oookJP?o06Ko0ooonfX3o`1Vo`Cooo]Z1Ol0I_l6oookJP?o
06Ko00Cooo]Zo`1Vool0I_oo06Ko1OoonfX3o`1Vo`Gooo]Z0ol0I_l4oookJPGo06Ko1OoonfX4o`1V
o`05oookJ_l0I_oo06Koo`1VoooonfX00ol0I_l6oookJP?o06Ko1OoonfX3o`1Vo`Gooo]Z1?l0I_l8
oookJPCo06Ko1ooonfX4o`1Vo`Cooo]Z1Ol0I_mAoookJP00o_oonfX7o`00O`?ooo]Z0ol007l5oook
JP?o001o2_oonfX5o`0003Kooo]Z0ol0I_l2oookJP?o06Ko0_oonfX3o`1Vo`;ooo]Z0ol0I_l3oook
JP?o06Ko00Cooo]Zo`1Vool0I_oo06Ko1?oonfX7o`1Vo`Cooo]Z2?l0I_l5oookJP?o06Ko1OoonfX3
o`1Vo`?ooo]Z1ol0I_l3oookJPSo06Ko0_oonfX3o`1Vo`Kooo]Z0ol0I_l5oookJP?o06Ko0ooonfX8
o`1Vo`Cooo]Z2?l0I_l4oookJPGo06Ko0_oonfX8o`1Voe3ooo]Z003noookJP?o001o00Cooo]Zo`00
Ool007oo001o0ooonfX3o`00O`Gooo]Z0ol007l:oookJPGo0000=_oonfX3o`1Vo`;ooo]Z0ol0I_l2
oookJP?o06Ko0_oonfX3o`1Vo`?ooo]Z0ol0I_l01?oonf[o06Koo`1Vool0I_l3oookJPCo06Ko0_oo
nfX3o`1Vo`;ooo]Z1?l0I_l00ooonf[o06Koo`1Vo`02o`1Vo`Gooo]Z0ol0I_l5oookJP?o06Ko0_oo
nfX4o`1Vo`;ooo]Z0ol0I_l2oookJP?o06Ko0_oonfX3o`1Vo`;ooo]Z0ol0I_l6oookJP?o06Ko1Ooo
nfX3o`1Vo`?ooo]Z0ol0I_l2oookJP?o06Ko1?oonfX3o`1Vo`;ooo]Z0ol0I_l4oookJP?o06Ko1?oo
nfX3o`1Vo`?ooo]Z0ol0I_m?oookJP00lOoonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o2_oonfX3
o`00O`[ooo]Z1Ol0000foookJP?o06Ko0_oonfX00ol0I_oooo]Zo`1Vo`02oookJP?o06Ko0_oonfX3
o`1Vo`Cooo]Z1Ol0I_l4oookJP?o06Ko2?oonfX3o`1Vo`?ooo]Z0ol0I_l5oookJP?o06Ko1OoonfX3
o`1Vo`;ooo]Z0ol0I_l8oookJP?o06Ko0_oonfX3o`1Vo`;ooo]Z0ol0I_l6oookJP?o06Ko1OoonfX3
o`1Vo`;ooo]Z0ol0I_l4oookJP?o06Ko0_oonfX3o`1Vo`Cooo]Z0ol0I_l3oookJP?o06Ko2OoonfX4
o`1Vodoooo]Z003aoookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l:oookJP?o001o2_oonfX7o`00
03Cooo]Z0ol0I_l01?oonf[o06Koo`1VoooonfX2o`1Vo`04oookJ_l0I_oo06Koo`1Vo`;ooo]Z0ol0
I_l5oookJP?o06Ko1OoonfX9o`1Vo`;ooo]Z0ol0I_l3oookJP?o06Ko1OoonfX3o`1Vo`Gooo]Z0ol0
I_l2oookJPWo06Ko0_oonfX4o`1Vo`04oookJ_l0I_oo06Koo`1Vo`;ooo]Z0ol0I_l6oookJP?o06Ko
1OoonfX3o`1Vo`;ooo]Z0ol0I_l4oookJP?o06Ko0_oonfX3o`1Vo`Cooo]Z0ol0I_l3oookJP?o06Ko
1_oonfX7o`1Vodoooo]Z003moookJP?o001o0ooonfX3o`00O`[ooo]Z0ol007l:oookJPGo0000=_oo
nfX3o`1Vo`04oookJ_l0I_oo06KooookJP;o06Ko00Cooo]Zo`1Vool0I_oo06Ko0_oonfX3o`1Vo`Go
oo]Z0ol0I_l5oookJPWo06Ko0_oonfX3o`1Vo`?ooo]Z0ol0I_l5oookJP[o06Ko0ooonfX9o`1Vo`?o
oo]Z1ol0I_l2oookJP?o06Ko1_oonfX:o`1Vo`?ooo]Z0ol0I_l4oookJP?o06Ko0_oonfX3o`1Vo`Co
oo]Z0ol0I_l3oookJP?o06Ko1?oonfX7o`1Voe7ooo]Z003moookJP?o001o0ooonfX3o`00O`[ooo]Z
0ol007l:oookJPGo0000=_oonfX3o`1Vo`04oookJ_l0I_oo06KooookJP;o06Ko00Cooo]Zo`1Vool0
I_oo06Ko0_oonfX3o`1Vo`Cooo]Z1Ol0I_l4oookJP?o06Ko0ooonfX3o`1Vo`;ooo]Z0ol0I_l3oook
JP?o06Ko1OoonfX:o`1Vo`?ooo]Z0ol0I_l3oookJP?o06Ko1ooonfX3o`1Vo`;ooo]Z0ol0I_l6oook
JP[o06Ko0ooonfX3o`1Vo`Cooo]Z0ol0I_l2oookJP?o06Ko1?oonfX3o`1Vo`?ooo]Z0ol0I_l4oook
JPCo06KoE?oonfX00?gooo]Z0ol007l3oookJP?o001o2_oonfX3o`00O`[ooo]Z1Ol0000foookJP?o
06Ko00?ooo]Zo`1VoooonfX00_oonfX00ol0I_oooo]Zo`1Vo`02o`1Vo`;ooo]Z0ol0I_l3oookJP?o
06Ko00Cooo]Zo`1Vool0I_oo06Ko0ooonfX3o`1Vo`?ooo]Z0ol0I_l2oookJPCo06Ko00?ooo]Zo`1V
ool0I_l00_l0I_l5oookJP?o06Ko1OoonfX3o`1Vo`;ooo]Z0ol0I_l3oookJP?o06Ko0_oonfX3o`1V
o`;ooo]Z0ol0I_l2oookJP?o06Ko1_oonfX3o`1Vo`Gooo]Z0ol0I_l3oookJP?o06Ko0_oonfX3o`1V
o`Cooo]Z0ol0I_l2oookJP?o06Ko1?oonfX3o`1Vo`Cooo]Z0ol0I_l3oookJP?o06KoCooonfX00?go
oo]Z0ol007l3oookJP?o001o2_oonfX3o`00O`[ooo]Z1Ol0000foookJPGo06Ko0ooonfX5o`1Vo`;o
oo]Z0ol0I_l3oookJP?o06Ko00Cooo]Zo`1Vool0I_oo06Ko1?oonfX7o`1Vo`Cooo]Z2?l0I_l5oook
JP?o06Ko1OoonfX3o`1Vo`?ooo]Z1ol0I_l3oookJPSo06Ko0_oonfX3o`1Vo`Kooo]Z0ol0I_l5oook
JP?o06Ko0ooonfX8o`1Vo`Cooo]Z2?l0I_l3oookJPKo06Ko0ooonfX7o`1Voe3ooo]Z003moookJP?o
001o0ooonfX3o`00O`Oooo]Z1_l007l:oookJPGo0000=_oonfX5o`1Vo`?ooo]Z1Ol0I_l2oookJP?o
06Ko0_oonfX3o`1Vo`?ooo]Z0ol0I_l4oookJPGo06Ko1_oonfX3o`1Vo`04oookJ_l0I_oo06Koo`1V
o`Gooo]Z0ol0I_l5oookJP?o06Ko1?oonfX5o`1Vo`Kooo]Z1?l0I_l4oookJP?o06Ko1_oonfX3o`1V
o`Gooo]Z0ol0I_l5oookJPCo06Ko2?oonfX4o`1Vo`Gooo]Z1_l0I_l4oookJPGo06KoDOoonfX00?ko
oo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPKo001o2_oonfX5o`0003Kooo]Z1Ol0I_l3oook
JPGo06Ko8ooonfX3o`1Vo`Gooo]Z0ol0I_l5oookJP?o06Ko5ooonfX3o`1Vo`Kooo]Z0ol0I_l5oook
JP?o06Ko6ooonfX3o`1Voecooo]Z003noookJPOo001o2_oonfX4o`00O`[ooo]Z1Ol0000foookJPCo
06Ko1OoonfX4o`1Vo`;ooo]Z0ol0I_lNoookJP?o06Ko1OoonfX:o`1VoaSooo]Z0ol0I_l6oookJP[o
06Ko7?oonfX3o`1Voecooo]Z003ooookJPGo001o3?oonfX3o`00O`[ooo]Z1Ol0000foookJPCo06Ko
1OoonfX4o`1Vo`;ooo]Z0ol0I_lNoookJP?o06Ko1OoonfX9o`1VoaWooo]Z0ol0I_l6oookJPWo06Ko
O?oonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?Go
oo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`Gooo]Z1Ol007l:oookJPGo0000oooonfXOoookJP00
m?oonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o0ooonfX7o`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003doookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`;ooo]Z0ol007l01?oonf[o001o
o`00Ool007l2oookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003WoookJP[o001o
0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?o
oo]Z0ol007l8oookJPGo0000oooonfXOoookJP00iooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o
1_oonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o2?oonfX7o`000?oo
oo]Z7OoonfX00??ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l01?oonf[o001o
o`00Ool007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00??ooo]Z0ol007l3oookJP?o001o
1_oonfX3o`00O`?ooo]Z0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00??ooo]Z0ol0
07l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooo
nfX00??ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool0
07l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX00??ooo]Z0ol007l3oookJP?o001o1_oonfX3
o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooo
nfX00?Cooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP?o001o00Cooo]Zo`00Ool007oo001o
0_oonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXOoookJP00m?oonfX7o`00O`Sooo]Z1ol0
07l3oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX00?Gooo]Z1Ol007l:oookJPGo001o1OoonfX5
o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0
003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooook
JQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z
003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooook
JQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z
1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0
003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooook
JQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z
003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooook
JQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z
1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003o
oookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoo
oo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003o
oookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQko
oo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0
003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooook
JQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z
003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooook
JQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z
1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003eoookJPGo001o1?oonfX3
o`00O`?ooo]Z1Ol007l5oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX00?Cooo]Z1ol007l3oook
JP?o001o0_oonfX7o`00O`?ooo]Z1ol007l9oookJPGo0000oooonfXOoookJP00m?oonfX3o`00O`04
oookJ_l007oo001oo`00O`?ooo]Z0ol007l2oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3
o`00O`;ooo]Z0ol007l8oookJPGo0000oooonfXOoookJP00iooonfX:o`00O`;ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o2?oonfX5
o`000?oooo]Z7ooonfX00>Oooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oook
JP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Sooo]Z1ol0003ooookJQgooo]Z003coook
JP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l2oook
JP?o001o2?oonfX5o`000?oooo]Z7ooonfX00??ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?o
oo]Z0ol007l00ooonf[o001oo`00O`06o`00O`Wooo]Z1Ol0003ooookJQoooo]Z003coookJP?o001o
0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o00Gooo]Zo`00Ool007oo001ooookJP03o`00O`[o
oo]Z1Ol0003ooookJQoooo]Z003coookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
00Cooo]Zo`00Ool007oo001o3_oonfX5o`000?oooo]Z7ooonfX00??ooo]Z0ol007l3oookJP?o001o
1_oonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l>oookJPGo0000oooonfXOoookJP00
m?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003doookJPOo001o2?oonfX7o`00O`?o
oo]Z1ol007l9oookJPGo0000oooonfXOoookJP00mOoonfX5o`00O`[ooo]Z1Ol007l6oookJPCo001o
2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z
7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z7ooonfX00?Gooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`Sooo]Z0ol007l9oookJPGo
0000oooonfXOoookJP00m?oonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o1ooonfX3o`00O`Wooo]Z
1Ol0003ooookJQoooo]Z003doookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`;ooo]Z
0ol007l01?oonf[o001oo`00Ool007l7oookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX00>Oooo]Z
2_l007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o00?ooo]Zo`00Ool007l0
1ol007l8oookJPGo0000oooonfXOoookJP00iooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o1_oo
nfX3o`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`07o`00O`Sooo]Z1ol0003ooookJQgooo]Z003c
oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o00?ooo]Zo`00Ool007l00ooonfX3
o`00O`Wooo]Z1Ol0003ooookJQoooo]Z003coookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oook
JP?o001o0_oonfX2o`00O`;ooo]Z0ol007l9oookJPGo0000oooonfXOoookJP00looonfX3o`00O`?o
oo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`;ooo]Z0ol007l01?oonf[o001oo`00Ool007l9oook
JPGo0000oooonfXOoookJP00looonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`?o
oo]Z0_l007l01?oonf[o001oo`00Ool007l9oookJPGo0000oooonfXOoookJP00looonfX3o`00O`?o
oo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Cooo]Z1Ol007l9oookJPGo0000oooonfXOoookJP00
m?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0ol007l01?oonf[o001oo`00Ool007l5oook
JPGo001o2OoonfX5o`000?oooo]Z7ooonfX00?Cooo]Z1ol007l8oookJPOo001o1_oonfX4o`00O`Wo
oo]Z1Ol0003ooookJQoooo]Z003eoookJPGo001o2_oonfX5o`00O`Sooo]Z0ol007l9oookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00mOoonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o
0ooonfX9o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003doookJPOo001o0ooonfX3o`00O`;ooo]Z1ol0
07l2oookJPWo001o2?oonfX5o`000?oooo]Z7ooonfX00?Cooo]Z0ol007l01?oonf[o001oo`00Ool0
07l3oookJP?o001o0_oonfX3o`00O`04oookJ_l007oo001oo`00O`;ooo]Z1?l007l=oookJPGo0000
oooonfXOoookJP00iooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol0
07l2oookJPCo001o3?oonfX5o`000?oooo]Z7ooonfX00>Oooo]Z2_l007l2oookJP?o001o0ooonfX3
o`00O`Kooo]Z0ol007l3oookJP?o001o0ooonfX5o`00O`[ooo]Z1ol0003ooookJQgooo]Z003coook
JP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1OoonfX4o`00O`Wooo]Z1Ol0003ooook
JQoooo]Z003coookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`Wo
oo]Z1Ol0003ooookJQoooo]Z003coookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003coookJP?o001o0ooonfX3o`00O`Kooo]Z0ol0
07l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z
003coookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o
0ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z003doookJP?o001o00Cooo]Zo`00Ool007oo001o
2?oonfX3o`00O`04oookJ_l007oo001oo`00O`;ooo]Z1?l007l2oookJP?o001o2?oonfX5o`000?oo
oo]Z7ooonfX00?Cooo]Z1ol007l8oookJPOo001o0ooonfX7o`00O`Wooo]Z1Ol0003ooookJQoooo]Z
003eoookJPGo001o2_oonfX5o`00O`Gooo]Z1Ol007l:oookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooo
nfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoook
JPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000
oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXO
oookJP005ooonfX3o`00Og[ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00OgGooo]Z1Ol0001ioook
JPGo001o1?oonfX3o`00O`?ooo]Z1Ol007mloookJP?o001o4_oonfX001Oooo]Z0ol007mioookJPOo
001o0ooonfX3o`00O`;ooo]Z1ol007mdoookJPGo0000N?oonfX7o`00O`?ooo]Z0ol007l2oookJPOo
001oNooonfX3o`00Oa;ooo]Z000GoookJP?o001oNOoonfX3o`00O`04oookJ_l007oo001oo`00O`?o
oo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00OgCooo]Z1Ol0001hoook
JP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Z
o`00Ool007oo001oNooonfX3o`00Oa;ooo]Z0007oookJP[o001o1_oonfX3o`00Ofcooo]Z2_l007l2
oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001oLooonfX5o`0007Oooo]Z0ol007l3
oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007mjoookJP?o001o4_oonfX000Oooo]Z2_l007l6oook
JP?o001oK?oonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Og?ooo]Z1Ol0001goook
JP?o001o0ooonfX3o`00O`cooo]Z0ol007mjoookJP?o001o4_oonfX001Oooo]Z0ol007mhoookJP?o
001o0ooonfX3o`00O`cooo]Z0ol007mcoookJPGo0000MooonfX3o`00O`?ooo]Z0ol007l<oookJP?o
001oN_oonfX3o`00Oa;ooo]Z000GoookJP?o001oN?oonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o
0_oonfX4o`00Og?ooo]Z1Ol0001goookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o
N_oonfX3o`00Oa;ooo]Z000GoookJP?o001oN?oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001oM?oo
nfX5o`0007Oooo]Z0ol007l3oookJP?o001o1ooonfX7o`00Og_ooo]Z0ol007lBoookJP005ooonfX3
o`00OgSooo]Z0ol007l3oookJP?o001o1ooonfX6o`00OgGooo]Z1Ol0001goookJP?o001o0ooonfX3
o`00O`Oooo]Z1_l007mloookJP?o001o4_oonfX001Cooo]Z1_l007mhoookJP?o001o0ooonfX3o`00
O`Oooo]Z0_l007mioookJPGo0000MooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001oOOoonfX6o`00
Oa;ooo]Z000DoookJPKo001oNOoonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007mioook
JPGo0000N?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007mmoookJPKo001o4_oonfX0
01Kooo]Z1?l007mioookJPOo001o2OoonfX7o`00Og?ooo]Z1Ol0001hoookJPOo001o2OoonfX7o`00
OgWooo]Z1?l007lBoookJP005ooonfX3o`00Og[ooo]Z1Ol007l:oookJPOo001oLooonfX5o`0007Wo
oo]Z1Ol007l:oookJPOo001oN_oonfX3o`00Oa;ooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z
003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooook
JQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z000>oookJ_oo06Ko
ool0I_lTo`1Voa3ooo]Z0002oookJPco0000ool0I_ooo`1VobCo06Ko3Ol00003oookJP000_oonfX<
o`000?oo06Koool0I_lTo`1Vo`go00000ooonfX000;ooo]Z3?l0003oo`1Voooo06Ko9?l0I_l=o`00
00?ooo]Z0002oookJPco0000ool0I_ooo`1VobCo06Ko3Ol00003oookJP000_oonfX<o`000?oo06Ko
ool0I_lTo`1Vo`go00000ooonfX000kooo]Zool0I_ooo`1VobCo06Ko4?oonfX000kooo]Zool0I_oo
o`1VobCo06Ko4?oonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00001\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.06829, -0.10335, \
0.00371579, 0.000300614}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Reduce[{LambdaPlus\  < 0, LambdaMinus < 0}]\)], "Input"],

Cell[BoxData[
    \(\[Beta] > 0 && 0 < \[Gamma] \[LessEqual] \[Beta]\^2\/4\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(AnnoteNegRealRoots\  = 
      Graphics[Text[
          StyleForm["\<Negative Roots\>", FontColor \[Rule] Hue[ .6]], {1.0, 
            0.025}, {1, 0}]]\)], "Input"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[ComplexPlot, AnnotePosRealRoots, AnnoteMixedRealRoots, 
      AnnoteNegRealRoots]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.182888 1.68173 [
[.02381 .17039 -13.4688 -20 ]
[.02381 .17039 13.4688 0 ]
[.2619 .17039 -20.9688 -20 ]
[.2619 .17039 20.9688 0 ]
[.7381 .17039 -14.5 -20 ]
[.7381 .17039 14.5 0 ]
[.97619 .17039 -7 -20 ]
[.97619 .17039 7 0 ]
[1.025 .18289 0 -10 ]
[1.025 .18289 15.9375 10 ]
[.4875 .01472 -41.9375 -10 ]
[.4875 .01472 0 10 ]
[.4875 .0988 -51.9375 -10 ]
[.4875 .0988 0 10 ]
[.4875 .26697 -39 -10 ]
[.4875 .26697 0 10 ]
[.4875 .35106 -29 -10 ]
[.4875 .35106 0 10 ]
[.4875 .43515 -39 -10 ]
[.4875 .43515 0 10 ]
[.4875 .51923 -29 -10 ]
[.4875 .51923 0 10 ]
[.4875 .60332 -39 -10 ]
[.4875 .60332 0 10 ]
[.5 .64303 -7.28125 0 ]
[.5 .64303 7.28125 20 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .18289 m
.02381 .18914 L
s
gsave
.02381 .17039 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .18289 m
.2619 .18914 L
s
gsave
.2619 .17039 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .18289 m
.7381 .18914 L
s
gsave
.7381 .17039 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .18289 m
.97619 .18914 L
s
gsave
.97619 .17039 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .18289 m
.07143 .18664 L
s
.11905 .18289 m
.11905 .18664 L
s
.16667 .18289 m
.16667 .18664 L
s
.21429 .18289 m
.21429 .18664 L
s
.30952 .18289 m
.30952 .18664 L
s
.35714 .18289 m
.35714 .18664 L
s
.40476 .18289 m
.40476 .18664 L
s
.45238 .18289 m
.45238 .18664 L
s
.54762 .18289 m
.54762 .18664 L
s
.59524 .18289 m
.59524 .18664 L
s
.64286 .18289 m
.64286 .18664 L
s
.69048 .18289 m
.69048 .18664 L
s
.78571 .18289 m
.78571 .18664 L
s
.83333 .18289 m
.83333 .18664 L
s
.88095 .18289 m
.88095 .18664 L
s
.92857 .18289 m
.92857 .18664 L
s
.01 w
0 .18289 m
1 .18289 L
s
gsave
1.025 .18289 -61 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
%%BeginResource: font Helvetica-Bold-MISO
%%BeginFont: Helvetica-Bold-MISO
/Helvetica-Bold /Helvetica-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
0.000 0.000 rmoveto
64.750 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(b) show
74.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.5 .01472 m
.50625 .01472 L
s
gsave
.4875 .01472 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.1) show
1.000 setlinewidth
grestore
.5 .0988 m
.50625 .0988 L
s
gsave
.4875 .0988 -112.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.05) show
1.000 setlinewidth
grestore
.5 .26697 m
.50625 .26697 L
s
gsave
.4875 .26697 -100 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.05) show
1.000 setlinewidth
grestore
.5 .35106 m
.50625 .35106 L
s
gsave
.4875 .35106 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.1) show
1.000 setlinewidth
grestore
.5 .43515 m
.50625 .43515 L
s
gsave
.4875 .43515 -100 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.15) show
1.000 setlinewidth
grestore
.5 .51923 m
.50625 .51923 L
s
gsave
.4875 .51923 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.5 .60332 m
.50625 .60332 L
s
gsave
.4875 .60332 -100 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .03153 m
.50375 .03153 L
s
.5 .04835 m
.50375 .04835 L
s
.5 .06517 m
.50375 .06517 L
s
.5 .08198 m
.50375 .08198 L
s
.5 .11562 m
.50375 .11562 L
s
.5 .13244 m
.50375 .13244 L
s
.5 .14925 m
.50375 .14925 L
s
.5 .16607 m
.50375 .16607 L
s
.5 .1997 m
.50375 .1997 L
s
.5 .21652 m
.50375 .21652 L
s
.5 .23334 m
.50375 .23334 L
s
.5 .25016 m
.50375 .25016 L
s
.5 .28379 m
.50375 .28379 L
s
.5 .30061 m
.50375 .30061 L
s
.5 .31743 m
.50375 .31743 L
s
.5 .33424 m
.50375 .33424 L
s
.5 .36788 m
.50375 .36788 L
s
.5 .38469 m
.50375 .38469 L
s
.5 .40151 m
.50375 .40151 L
s
.5 .41833 m
.50375 .41833 L
s
.5 .45196 m
.50375 .45196 L
s
.5 .46878 m
.50375 .46878 L
s
.5 .4856 m
.50375 .4856 L
s
.5 .50242 m
.50375 .50242 L
s
.5 .53605 m
.50375 .53605 L
s
.5 .55287 m
.50375 .55287 L
s
.5 .56968 m
.50375 .56968 L
s
.5 .5865 m
.50375 .5865 L
s
.01 w
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -68.2812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
%%BeginResource: font Helvetica-Bold-MISO
%%BeginFont: Helvetica-Bold-MISO
/Helvetica-Bold /Helvetica-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
0.000 0.000 rmoveto
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(g) show
73.562 19.000 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .60332 m
.06244 .53786 L
.10458 .47279 L
.14415 .41767 L
.18221 .37014 L
.22272 .32544 L
.26171 .28817 L
.30316 .25473 L
.34309 .22854 L
.3815 .20892 L
.40095 .20108 L
.42237 .19406 L
.44268 .18898 L
.45178 .1872 L
.46172 .18561 L
.4671 .18489 L
.4721 .18433 L
.47727 .18385 L
.48196 .18349 L
.48658 .18322 L
.4887 .18312 L
.49093 .18304 L
.49332 .18297 L
.49438 .18295 L
.49552 .18292 L
.49675 .18291 L
.49789 .1829 L
.49859 .18289 L
.49925 .18289 L
.50049 .18289 L
.50163 .18289 L
.50286 .1829 L
.50401 .18292 L
.50508 .18294 L
.50754 .18299 L
.51014 .18308 L
.51268 .18319 L
.51504 .18331 L
.5204 .18366 L
.5293 .18448 L
.53882 .18568 L
.54906 .18735 L
.56016 .1896 L
.58032 .19485 L
.60019 .2015 L
.62123 .21014 L
.65912 .22983 L
.69946 .25665 L
.73829 .28816 L
.77956 .32779 L
Mistroke
.81932 .37195 L
.85757 .41994 L
.89827 .47698 L
.93745 .53769 L
.97619 .60332 L
Mfstroke
gsave
.61905 .60332 -61 -62 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 66 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
0.000 0.000 rmoveto
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(Complex) show
63.000 38.000 moveto
(Congugate) show
63.000 57.000 moveto
(Roots) show
113.750 57.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.85714 .26697 -109.844 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
0.000 0.000 rmoveto
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(Real) show
105.938 19.000 moveto
(Roots) show
156.688 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
1 0 0 r
.015 w
.5 .18289 m
.5 .18341 L
.5 .18388 L
.5 .18442 L
.5 .18494 L
.5 .18542 L
.5 .18586 L
.5 .18634 L
.5 .18685 L
.5 .18736 L
.5 .18792 L
.5 .18844 L
.5 .18892 L
.5 .18947 L
.5 .18979 L
.5 .19008 L
.5 .19062 L
.5 .19119 L
.5 .19148 L
.5 .19178 L
.5 .19233 L
.5 .19263 L
.5 .19291 L
.5 .19322 L
.5 .19355 L
.5 .19384 L
.5 .19415 L
.5 .19472 L
.5 .19527 L
.5 .19578 L
.5 .19628 L
.5 .19674 L
.5 .19725 L
.5 .1978 L
.5 .19834 L
.5 .19892 L
.5 .19941 L
.5 .19994 L
.5 .20026 L
.5 .20055 L
.5 .20086 L
.5 .2012 L
.5 .20176 L
.5 .20208 L
.5 .20238 L
.5 .20294 L
.5 .20345 L
.5 .20374 L
.5 .20404 L
.5 .2046 L
Mistroke
.5 .20494 L
.5 .20526 L
.5 .20554 L
.5 .20585 L
.5 .20619 L
.5 .20655 L
.5 .20685 L
.5 .20718 L
.5 .2075 L
.5 .20778 L
.5 .20811 L
.5 .20842 L
.5 .20898 L
.5 .20929 L
.5 .20958 L
.5 .21009 L
.5 .21065 L
.5 .21117 L
.5 .21165 L
.5 .21218 L
.5 .21276 L
.5 .21305 L
.5 .21337 L
.5 .21393 L
.5 .21424 L
.5 .21453 L
.5 .21484 L
.5 .21517 L
.5 .21573 L
.5 .21605 L
.5 .21635 L
.5 .2169 L
.5 .21741 L
.5 .21799 L
.5 .21854 L
.5 .21905 L
.5 .21959 L
.5 .2201 L
.5 .22057 L
.5 .22108 L
.5 .22165 L
.5 .22194 L
.5 .22225 L
.5 .2228 L
.5 .2231 L
.5 .22338 L
.5 .22369 L
.5 .22402 L
.5 .22456 L
.5 .22488 L
Mistroke
.5 .22517 L
.5 .22571 L
.5 .22621 L
.5 .22678 L
.5 .22732 L
.5 .22783 L
.5 .2283 L
.5 .22883 L
.5 .22934 L
.5 .22981 L
.5 .23024 L
.5 .23071 L
.5 .23121 L
.5 .23171 L
.5 .23226 L
.5 .23277 L
.5 .23323 L
.5 .23378 L
.5 .23409 L
.5 .23437 L
.5 .23489 L
.5 .23545 L
.5 .23595 L
.5 .2365 L
.5 .23708 L
.5 .23761 L
.5 .23811 L
.5 .23857 L
.5 .23909 L
.5 .23959 L
.5 .24013 L
.5 .24071 L
.5 .24119 L
.5 .24173 L
.5 .24231 L
.5 .24264 L
.5 .24293 L
.5 .24351 L
.5 .24405 L
.5 .24456 L
.5 .24502 L
.5 .24556 L
.5 .24606 L
.5 .24652 L
.5 .24695 L
.5 .24742 L
.5 .24792 L
.5 .24842 L
.5 .24895 L
.5 .24946 L
Mistroke
.5 .24992 L
.5 .25047 L
.5 .25077 L
.5 .25105 L
.5 .25157 L
.5 .25212 L
.5 .25266 L
.5 .25324 L
.5 .25378 L
.5 .25429 L
.5 .2548 L
.5 .25525 L
.5 .25578 L
.5 .25628 L
.5 .25682 L
.5 .25739 L
.5 .25788 L
.5 .25842 L
.5 .259 L
.5 .25933 L
.5 .25962 L
.5 .2602 L
.5 .26074 L
.5 .26121 L
.5 .26172 L
.5 .26225 L
.5 .26275 L
.5 .26322 L
.5 .26365 L
.5 .26412 L
.5 .26461 L
.5 .26512 L
.5 .26565 L
.5 .26616 L
.5 .26662 L
.5 .26716 L
.5 .26747 L
.5 .26775 L
.5 .26827 L
.5 .26882 L
.5 .26935 L
.5 .26994 L
.5 .27049 L
.5 .271 L
.5 .2715 L
.5 .27196 L
.5 .27249 L
.5 .27298 L
.5 .27353 L
.5 .2741 L
Mistroke
.5 .2746 L
.5 .27513 L
.5 .27572 L
.5 .27604 L
.5 .27634 L
.5 .27691 L
.5 .27746 L
.5 .27792 L
.5 .27843 L
.5 .27897 L
.5 .27947 L
.5 .27994 L
.5 .28037 L
.5 .28084 L
.5 .28133 L
.5 .28184 L
.5 .28237 L
.5 .28288 L
.5 .28334 L
.5 .28389 L
.5 .28419 L
.5 .28447 L
.5 .28499 L
.5 .28554 L
.5 .28608 L
.5 .28666 L
.5 .28721 L
.5 .28772 L
.5 .28818 L
.5 .28869 L
.5 .28922 L
.5 .28972 L
.5 .29026 L
.5 .29084 L
.5 .29133 L
.5 .29187 L
.5 .29245 L
.5 .29278 L
.5 .29307 L
.5 .29365 L
.5 .2942 L
.5 .29466 L
.5 .29517 L
.5 .29571 L
.5 .29621 L
.5 .29668 L
.5 .29711 L
.5 .2976 L
.5 .29807 L
.5 .29858 L
Mistroke
.5 .29912 L
.5 .29963 L
.5 .30009 L
.5 .30063 L
.5 .30094 L
.5 .30122 L
.5 .30174 L
.5 .30228 L
.5 .30282 L
.5 .30313 L
.5 .30341 L
.5 .30393 L
.5 .30447 L
.5 .30496 L
.5 .30542 L
.5 .30593 L
.5 .30647 L
.5 .30701 L
.5 .30732 L
.5 .30761 L
.5 .30819 L
.5 .30852 L
.5 .30881 L
.5 .30934 L
.5 .30991 L
.5 .31046 L
.5 .31096 L
.5 .31142 L
.5 .31192 L
.5 .3124 L
.5 .31283 L
.5 .31333 L
.5 .31389 L
.5 .31441 L
.5 .31489 L
.5 .31543 L
.5 .31595 L
.5 .31641 L
.5 .3169 L
.5 .31745 L
.5 .31802 L
.5 .31851 L
.5 .31905 L
.5 .31963 L
.5 .32016 L
.5 .32044 L
.5 .32075 L
.5 .32107 L
.5 .32137 L
.5 .32192 L
Mistroke
.5 .32243 L
.5 .32301 L
.5 .32357 L
.5 .32406 L
.5 .32459 L
.5 .32508 L
.5 .32554 L
.5 .32607 L
.5 .32664 L
.5 .32718 L
.5 .32768 L
.5 .32822 L
.5 .32879 L
.5 .32933 L
.5 .32982 L
.5 .3304 L
.5 .33073 L
.5 .33103 L
.5 .33158 L
.5 .33186 L
.5 .33217 L
.5 .33247 L
.5 .33279 L
.5 .33335 L
.5 .33367 L
.5 .33396 L
.5 .33428 L
.5 .33462 L
.5 .33492 L
.5 .33524 L
.5 .33555 L
.5 .33583 L
.5 .33636 L
.5 .33692 L
.5 .33746 L
.5 .33804 L
.5 .33859 L
.5 .3391 L
.5 .3396 L
.5 .34006 L
.5 .34059 L
.5 .34108 L
.5 .34163 L
.5 .3422 L
.5 .34269 L
.5 .34323 L
.5 .34381 L
.5 .34414 L
.5 .34443 L
.5 .34501 L
Mistroke
.5 .34556 L
.5 .34602 L
.5 .34653 L
.5 .34707 L
.5 .34757 L
.5 .34803 L
.5 .34846 L
.5 .34893 L
.5 .34943 L
.5 .34993 L
.5 .35047 L
.5 .35098 L
.5 .35144 L
.5 .35198 L
.5 .35229 L
.5 .35257 L
.5 .35309 L
.5 .35364 L
.5 .35417 L
.5 .35476 L
.5 .35531 L
.5 .35582 L
.5 .35632 L
.5 .35678 L
.5 .35731 L
.5 .35781 L
.5 .35836 L
.5 .35893 L
.5 .35942 L
.5 .35996 L
.5 .36054 L
.5 .36087 L
.5 .36117 L
.5 .36174 L
.5 .36229 L
.5 .36275 L
.5 .36327 L
.5 .3638 L
.5 .3643 L
.5 .36477 L
.5 .3652 L
.5 .36569 L
.5 .36616 L
.5 .36667 L
.5 .36721 L
.5 .36772 L
.5 .36818 L
.5 .36872 L
.5 .36903 L
.5 .36931 L
Mistroke
.5 .36983 L
.5 .37037 L
.5 .37091 L
.5 .37122 L
.5 .3715 L
.5 .37201 L
.5 .37256 L
.5 .37305 L
.5 .37351 L
.5 .37401 L
.5 .37456 L
.5 .3751 L
.5 .37541 L
.5 .3757 L
.5 .37628 L
.5 .3766 L
.5 .3769 L
.5 .37743 L
.5 .378 L
.5 .37854 L
.5 .37904 L
.5 .37951 L
.5 .38001 L
.5 .38048 L
.5 .38091 L
.5 .38142 L
.5 .38197 L
.5 .38249 L
.5 .38297 L
.5 .38352 L
.5 .38403 L
.5 .38449 L
.5 .38499 L
.5 .38553 L
.5 .38611 L
.5 .3866 L
.5 .38714 L
.5 .38771 L
.5 .38825 L
.5 .38853 L
.5 .38883 L
.5 .38915 L
.5 .38946 L
.5 .39001 L
.5 .39051 L
.5 .39107 L
.5 .39165 L
.5 .39214 L
.5 .39267 L
.5 .39317 L
Mistroke
.5 .39362 L
.5 .39415 L
.5 .39472 L
.5 .39526 L
.5 .39576 L
.5 .3963 L
.5 .39687 L
.5 .39741 L
.5 .3979 L
.5 .39848 L
.5 .39881 L
.5 .39911 L
.5 .39966 L
.5 .39994 L
.5 .40025 L
.5 .40055 L
.5 .40087 L
.5 .40143 L
.5 .40174 L
.5 .40204 L
.5 .40236 L
.5 .4027 L
.5 .403 L
.5 .40332 L
.5 .40362 L
.5 .40391 L
.5 .40444 L
.5 .405 L
.5 .40553 L
.5 .40612 L
.5 .40666 L
.5 .40717 L
.5 .40768 L
.5 .40813 L
.5 .40866 L
.5 .40916 L
.5 .4097 L
.5 .41028 L
.5 .41077 L
.5 .41131 L
.5 .41189 L
.5 .41221 L
.5 .41251 L
.5 .41308 L
.5 .41363 L
.5 .41409 L
.5 .41461 L
.5 .41514 L
.5 .41564 L
.5 .41611 L
Mistroke
.5 .41654 L
.5 .41701 L
.5 .4175 L
.5 .41801 L
.5 .41854 L
.5 .41905 L
.5 .41951 L
.5 .42005 L
.5 .42036 L
.5 .42064 L
.5 .42116 L
.5 .42171 L
.5 .42225 L
.5 .42283 L
.5 .42338 L
.5 .42389 L
.5 .4244 L
.5 .42485 L
.5 .42538 L
.5 .42588 L
.5 .42643 L
.5 .427 L
.5 .42749 L
.5 .42803 L
.5 .42861 L
.5 .42894 L
.5 .42924 L
.5 .42981 L
.5 .43036 L
.5 .43082 L
.5 .43133 L
.5 .43187 L
.5 .43237 L
.5 .43284 L
.5 .43327 L
.5 .43376 L
.5 .43423 L
.5 .43474 L
.5 .43528 L
.5 .43578 L
.5 .43625 L
.5 .43679 L
.5 .43709 L
.5 .43738 L
.5 .43789 L
.5 .43844 L
.5 .43898 L
.5 .43928 L
.5 .43957 L
.5 .44008 L
Mistroke
.5 .44063 L
.5 .44112 L
.5 .44158 L
.5 .44208 L
.5 .44262 L
.5 .44317 L
.5 .44348 L
.5 .44376 L
.5 .44434 L
.5 .44467 L
.5 .44496 L
.5 .44549 L
.5 .44606 L
.5 .44661 L
.5 .44711 L
.5 .44757 L
.5 .44807 L
.5 .44855 L
.5 .44898 L
.5 .44948 L
.5 .45003 L
.5 .45055 L
.5 .45104 L
.5 .45158 L
.5 .45209 L
.5 .45255 L
.5 .45305 L
.5 .4536 L
.5 .45417 L
.5 .45466 L
.5 .4552 L
.5 .45578 L
.5 .45631 L
.5 .45659 L
.5 .45689 L
.5 .45722 L
.5 .45752 L
.5 .45807 L
.5 .45857 L
.5 .45913 L
.5 .45971 L
.5 .4602 L
.5 .46073 L
.5 .46122 L
.5 .46168 L
.5 .46221 L
.5 .46278 L
.5 .46332 L
.5 .46382 L
.5 .46436 L
Mistroke
.5 .46493 L
.5 .46547 L
.5 .46596 L
.5 .46654 L
.5 .46686 L
.5 .46717 L
.5 .46772 L
.5 .468 L
.5 .46831 L
.5 .46861 L
.5 .46892 L
.5 .46949 L
.5 .4698 L
.5 .47009 L
.5 .47042 L
.5 .47076 L
.5 .47106 L
.5 .47138 L
.5 .47168 L
.5 .47196 L
.5 .47249 L
.5 .47306 L
.5 .47359 L
.5 .47417 L
.5 .47472 L
.5 .47523 L
.5 .47573 L
.5 .47619 L
.5 .47672 L
.5 .47721 L
.5 .47776 L
.5 .47833 L
.5 .47882 L
.5 .47936 L
.5 .47994 L
.5 .48027 L
.5 .48056 L
.5 .48114 L
.5 .48168 L
.5 .48215 L
.5 .48266 L
.5 .48319 L
.5 .48369 L
.5 .48416 L
.5 .48459 L
.5 .48506 L
.5 .48555 L
.5 .48606 L
.5 .48659 L
.5 .4871 L
Mistroke
.5 .48756 L
.5 .48811 L
.5 .48841 L
.5 .48869 L
.5 .48921 L
.5 .48976 L
.5 .4903 L
.5 .49088 L
.5 .49143 L
.5 .49194 L
.5 .49245 L
.5 .4929 L
.5 .49343 L
.5 .49393 L
.5 .49447 L
.5 .49505 L
.5 .49554 L
.5 .49608 L
.5 .49666 L
.5 .49699 L
.5 .49728 L
.5 .49786 L
.5 .4984 L
.5 .49887 L
.5 .49938 L
.5 .49992 L
.5 .50042 L
.5 .50089 L
.5 .50132 L
.5 .50179 L
.5 .50228 L
.5 .50278 L
.5 .50332 L
.5 .50383 L
.5 .50429 L
.5 .50483 L
.5 .50514 L
.5 .50542 L
.5 .50594 L
.5 .50649 L
.5 .50703 L
.5 .50733 L
.5 .50761 L
.5 .50813 L
.5 .50867 L
.5 .50916 L
.5 .50962 L
.5 .51012 L
.5 .51067 L
.5 .51121 L
Mistroke
.5 .51152 L
.5 .51181 L
.5 .51238 L
.5 .51271 L
.5 .513 L
.5 .51353 L
.5 .51411 L
.5 .51465 L
.5 .51515 L
.5 .51561 L
.5 .51611 L
.5 .51659 L
.5 .51702 L
.5 .51752 L
.5 .51807 L
.5 .51859 L
.5 .51908 L
.5 .51962 L
.5 .52013 L
.5 .52059 L
.5 .52109 L
.5 .52164 L
.5 .52221 L
.5 .5227 L
.5 .52324 L
.5 .52382 L
.5 .52435 L
.5 .52463 L
.5 .52493 L
.5 .52526 L
.5 .52556 L
.5 .52611 L
.5 .52661 L
.5 .52717 L
.5 .52775 L
.5 .52824 L
.5 .52877 L
.5 .52926 L
.5 .52971 L
.5 .53024 L
.5 .53082 L
.5 .53136 L
.5 .53186 L
.5 .53239 L
.5 .53296 L
.5 .5335 L
.5 .534 L
.5 .53457 L
.5 .5349 L
.5 .5352 L
Mistroke
.5 .53576 L
.5 .53607 L
.5 .53635 L
.5 .53665 L
.5 .53696 L
.5 .53752 L
.5 .53784 L
.5 .53813 L
.5 .53845 L
.5 .53879 L
.5 .53909 L
.5 .53941 L
.5 .53972 L
.5 .54 L
.5 .54053 L
.5 .54109 L
.5 .54163 L
.5 .54221 L
.5 .54275 L
.5 .54326 L
.5 .54377 L
.5 .54422 L
.5 .54475 L
.5 .54525 L
.5 .54579 L
.5 .54636 L
.5 .54685 L
.5 .54739 L
.5 .54797 L
.5 .5483 L
.5 .54859 L
.5 .54917 L
.5 .54972 L
.5 .55018 L
.5 .55069 L
.5 .55122 L
.5 .55172 L
.5 .55219 L
.5 .55262 L
.5 .55309 L
.5 .55358 L
.5 .55409 L
.5 .55462 L
.5 .55513 L
.5 .55559 L
.5 .55614 L
.5 .55644 L
.5 .55672 L
.5 .55724 L
.5 .55779 L
Mistroke
.5 .55833 L
.5 .55891 L
.5 .55946 L
.5 .55997 L
.5 .56047 L
.5 .56093 L
.5 .56146 L
.5 .56196 L
.5 .5625 L
.5 .56308 L
.5 .56357 L
.5 .56411 L
.5 .56469 L
.5 .56501 L
.5 .56531 L
.5 .56589 L
.5 .56643 L
.5 .5669 L
.5 .56741 L
.5 .56794 L
.5 .56844 L
.5 .56891 L
.5 .56934 L
.5 .56981 L
.5 .5703 L
.5 .57081 L
.5 .57135 L
.5 .57186 L
.5 .57232 L
.5 .57286 L
.5 .57317 L
.5 .57345 L
.5 .57397 L
.5 .57451 L
.5 .57505 L
.5 .57535 L
.5 .57563 L
.5 .57615 L
.5 .5767 L
.5 .57718 L
.5 .57764 L
.5 .57815 L
.5 .57869 L
.5 .57923 L
.5 .57954 L
.5 .57983 L
.5 .58041 L
.5 .58073 L
.5 .58103 L
.5 .58155 L
Mistroke
.5 .58213 L
.5 .58267 L
.5 .58317 L
.5 .58363 L
.5 .58413 L
.5 .58461 L
.5 .58504 L
.5 .58554 L
.5 .58609 L
.5 .58661 L
.5 .5871 L
.5 .58764 L
.5 .58815 L
.5 .58861 L
.5 .58911 L
.5 .58966 L
.5 .59023 L
.5 .59072 L
.5 .59126 L
.5 .59165 L
.5 .59201 L
.5 .5924 L
.5 .59282 L
.5 .59319 L
.5 .59353 L
.5 .5939 L
.5 .5943 L
.5 .59464 L
.5 .59501 L
.5 .59539 L
.5 .59575 L
.5 .59609 L
.5 .59639 L
.5 .59675 L
.5 .59708 L
.5 .59744 L
.5 .59784 L
.5 .59825 L
.5 .59864 L
.5 .599 L
.5 .59933 L
.5 .59971 L
.5 .60007 L
.5 .60046 L
.5 .60088 L
.5 .60127 L
.5 .60163 L
.5 .60205 L
.5 .6025 L
.5 .60293 L
Mistroke
.5 .60332 L
Mfstroke
0 g
gsave
.2619 .43515 -61 -62 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 66 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(Positive) show
63.000 38.000 moveto
(Real) show
63.000 57.000 moveto
(Part) show
97.938 57.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.7381 .43515 -139.812 -62 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 66 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(Negative) show
63.000 38.000 moveto
(Real) show
63.000 57.000 moveto
(Part) show
97.938 57.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.02381 .22493 -61 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.400 1.000 setrgbcolor
0.000 0.000 rmoveto
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.400 1.000 setrgbcolor
(Positive) show
136.875 19.000 moveto
(Roots) show
187.625 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.400 1.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .4 1 r
.02381 .18289 m
.02499 .18289 L
.02605 .18289 L
.02729 .18289 L
.02846 .18289 L
.02954 .18289 L
.03053 .18289 L
.03163 .18289 L
.03279 .18289 L
.03395 .18289 L
.0352 .18289 L
.03638 .18289 L
.03746 .18289 L
.03873 .18289 L
.03944 .18289 L
.04011 .18289 L
.04132 .18289 L
.04262 .18289 L
.04327 .18289 L
.04396 .18289 L
.04519 .18289 L
.04588 .18289 L
.04652 .18289 L
.04722 .18289 L
.04797 .18289 L
.04862 .18289 L
.04933 .18289 L
.05061 .18289 L
.05186 .18289 L
.05302 .18289 L
.05414 .18289 L
.05519 .18289 L
.05634 .18289 L
.05759 .18289 L
.05882 .18289 L
.06012 .18289 L
.06123 .18289 L
.06244 .18289 L
.06315 .18289 L
.06381 .18289 L
.06453 .18289 L
.06529 .18289 L
.06657 .18289 L
.06729 .18289 L
.06797 .18289 L
.06924 .18289 L
.0704 .18289 L
.07103 .18289 L
.07173 .18289 L
.073 .18289 L
Mistroke
.07376 .18289 L
.07448 .18289 L
.07513 .18289 L
.07583 .18289 L
.0766 .18289 L
.0774 .18289 L
.07809 .18289 L
.07885 .18289 L
.07956 .18289 L
.0802 .18289 L
.08095 .18289 L
.08166 .18289 L
.08291 .18289 L
.08362 .18289 L
.08427 .18289 L
.08544 .18289 L
.08669 .18289 L
.08787 .18289 L
.08896 .18289 L
.09016 .18289 L
.09148 .18289 L
.09214 .18289 L
.09285 .18289 L
.09413 .18289 L
.09483 .18289 L
.09548 .18289 L
.09619 .18289 L
.09695 .18289 L
.09821 .18289 L
.09893 .18289 L
.09961 .18289 L
.10086 .18289 L
.10201 .18289 L
.10333 .18289 L
.10458 .18289 L
.10572 .18289 L
.10694 .18289 L
.1081 .18289 L
.10916 .18289 L
.11033 .18289 L
.11162 .18289 L
.11227 .18289 L
.11297 .18289 L
.11422 .18289 L
.11491 .18289 L
.11554 .18289 L
.11624 .18289 L
.11698 .18289 L
.11822 .18289 L
.11892 .18289 L
Mistroke
.11958 .18289 L
.12081 .18289 L
.12194 .18289 L
.12323 .18289 L
.12446 .18289 L
.12562 .18289 L
.12668 .18289 L
.12789 .18289 L
.12903 .18289 L
.13009 .18289 L
.13107 .18289 L
.13214 .18289 L
.13327 .18289 L
.13441 .18289 L
.13564 .18289 L
.1368 .18289 L
.13785 .18289 L
.13909 .18289 L
.13979 .18289 L
.14043 .18289 L
.14162 .18289 L
.14288 .18289 L
.14402 .18289 L
.14526 .18289 L
.14656 .18289 L
.14777 .18289 L
.14891 .18289 L
.14994 .18289 L
.15113 .18289 L
.15226 .18289 L
.15348 .18289 L
.15478 .18289 L
.15589 .18289 L
.15711 .18289 L
.15842 .18289 L
.15915 .18289 L
.15982 .18289 L
.16113 .18289 L
.16236 .18289 L
.16352 .18289 L
.16456 .18289 L
.16577 .18289 L
.1669 .18289 L
.16796 .18289 L
.16893 .18289 L
.16999 .18289 L
.17111 .18289 L
.17225 .18289 L
.17347 .18289 L
.17462 .18289 L
Mistroke
.17566 .18289 L
.17689 .18289 L
.17758 .18289 L
.17823 .18289 L
.1794 .18289 L
.18065 .18289 L
.18185 .18289 L
.18316 .18289 L
.18441 .18289 L
.18556 .18289 L
.1867 .18289 L
.18773 .18289 L
.18893 .18289 L
.19005 .18289 L
.19128 .18289 L
.19258 .18289 L
.19369 .18289 L
.19491 .18289 L
.19623 .18289 L
.19696 .18289 L
.19763 .18289 L
.19894 .18289 L
.20017 .18289 L
.20122 .18289 L
.20238 .18289 L
.20359 .18289 L
.20472 .18289 L
.20578 .18289 L
.20675 .18289 L
.20781 .18289 L
.20894 .18289 L
.21008 .18289 L
.21129 .18289 L
.21244 .18289 L
.21349 .18289 L
.21472 .18289 L
.21541 .18289 L
.21605 .18289 L
.21723 .18289 L
.21847 .18289 L
.21968 .18289 L
.221 .18289 L
.22224 .18289 L
.2234 .18289 L
.22454 .18289 L
.22558 .18289 L
.22677 .18289 L
.2279 .18289 L
.22914 .18289 L
.23044 .18289 L
Mistroke
.23155 .18289 L
.23277 .18289 L
.23409 .18289 L
.23482 .18289 L
.2355 .18289 L
.2368 .18289 L
.23804 .18289 L
.23909 .18289 L
.24025 .18289 L
.24146 .18289 L
.2426 .18289 L
.24365 .18289 L
.24462 .18289 L
.24569 .18289 L
.24681 .18289 L
.24795 .18289 L
.24917 .18289 L
.25032 .18289 L
.25137 .18289 L
.2526 .18289 L
.25329 .18289 L
.25393 .18289 L
.2551 .18289 L
.25635 .18289 L
.25756 .18289 L
.25888 .18289 L
.26013 .18289 L
.26129 .18289 L
.26233 .18289 L
.26348 .18289 L
.26467 .18289 L
.2658 .18289 L
.26704 .18289 L
.26835 .18289 L
.26946 .18289 L
.27068 .18289 L
.272 .18289 L
.27274 .18289 L
.27341 .18289 L
.27472 .18289 L
.27595 .18289 L
.27701 .18289 L
.27817 .18289 L
.27938 .18289 L
.28052 .18289 L
.28158 .18289 L
.28255 .18289 L
.28367 .18289 L
.28474 .18289 L
.28588 .18289 L
Mistroke
.2871 .18289 L
.28825 .18289 L
.2893 .18289 L
.29053 .18289 L
.29122 .18289 L
.29186 .18289 L
.29303 .18289 L
.29427 .18289 L
.29549 .18289 L
.29618 .18289 L
.29682 .18289 L
.29799 .18289 L
.29923 .18289 L
.30034 .18289 L
.30138 .18289 L
.30252 .18289 L
.30375 .18289 L
.30499 .18289 L
.30569 .18289 L
.30634 .18289 L
.30765 .18289 L
.30839 .18289 L
.30906 .18289 L
.31026 .18289 L
.31156 .18289 L
.31278 .18289 L
.31392 .18289 L
.31497 .18289 L
.31611 .18289 L
.31718 .18289 L
.31816 .18289 L
.3193 .18289 L
.32055 .18289 L
.32173 .18289 L
.32282 .18289 L
.32406 .18289 L
.32522 .18289 L
.32626 .18289 L
.32739 .18289 L
.32862 .18289 L
.32992 .18289 L
.33103 .18289 L
.33225 .18289 L
.33356 .18289 L
.33477 .18289 L
.33541 .18289 L
.3361 .18289 L
.33683 .18289 L
.33751 .18289 L
.33876 .18289 L
Mistroke
.33991 .18289 L
.34123 .18289 L
.34249 .18289 L
.3436 .18289 L
.3448 .18289 L
.34592 .18289 L
.34694 .18289 L
.34814 .18289 L
.34945 .18289 L
.35067 .18289 L
.35181 .18289 L
.35302 .18289 L
.35431 .18289 L
.35554 .18289 L
.35665 .18289 L
.35796 .18289 L
.3587 .18289 L
.35939 .18289 L
.36064 .18289 L
.36128 .18289 L
.36198 .18289 L
.36266 .18289 L
.36337 .18289 L
.36465 .18289 L
.36536 .18289 L
.36602 .18289 L
.36675 .18289 L
.36753 .18289 L
.3682 .18289 L
.36893 .18289 L
.36962 .18289 L
.37026 .18289 L
.37146 .18289 L
.37274 .18289 L
.37394 .18289 L
.37526 .18289 L
.37651 .18289 L
.37766 .18289 L
.3788 .18289 L
.37984 .18289 L
.38103 .18289 L
.38216 .18289 L
.38339 .18289 L
.3847 .18289 L
.38581 .18289 L
.38703 .18289 L
.38834 .18289 L
.38908 .18289 L
.38975 .18289 L
.39106 .18289 L
Mistroke
.39229 .18289 L
.39334 .18289 L
.3945 .18289 L
.39571 .18289 L
.39685 .18289 L
.39791 .18289 L
.39888 .18289 L
.39994 .18289 L
.40106 .18289 L
.40221 .18289 L
.40342 .18289 L
.40457 .18289 L
.40562 .18289 L
.40685 .18289 L
.40754 .18289 L
.40818 .18289 L
.40936 .18289 L
.4106 .18289 L
.41181 .18289 L
.41313 .18289 L
.41438 .18289 L
.41554 .18289 L
.41669 .18289 L
.41772 .18289 L
.41892 .18289 L
.42005 .18289 L
.42129 .18289 L
.42259 .18289 L
.42371 .18289 L
.42493 .18289 L
.42624 .18289 L
.42698 .18289 L
.42765 .18289 L
.42896 .18289 L
.43019 .18289 L
.43125 .18289 L
.43241 .18289 L
.43362 .18289 L
.43476 .18289 L
.43582 .18289 L
.43679 .18289 L
.43791 .18289 L
.43898 .18289 L
.44012 .18289 L
.44134 .18289 L
.44249 .18289 L
.44354 .18289 L
.44477 .18289 L
.44546 .18289 L
.4461 .18289 L
Mistroke
.44727 .18289 L
.44851 .18289 L
.44973 .18289 L
.45042 .18289 L
.45106 .18289 L
.45223 .18289 L
.45347 .18289 L
.45458 .18289 L
.45562 .18289 L
.45676 .18289 L
.45799 .18289 L
.45922 .18289 L
.45992 .18289 L
.46057 .18289 L
.46188 .18289 L
.46262 .18289 L
.46329 .18289 L
.46449 .18289 L
.46579 .18289 L
.46702 .18289 L
.46815 .18289 L
.4692 .18289 L
.47034 .18289 L
.47141 .18289 L
.47239 .18289 L
.47353 .18289 L
.47478 .18289 L
.47596 .18289 L
.47705 .18289 L
.47829 .18289 L
.47945 .18289 L
.48049 .18289 L
.48162 .18289 L
.48285 .18289 L
.48415 .18289 L
.48526 .18289 L
.48648 .18289 L
.48779 .18289 L
.489 .18289 L
.48963 .18289 L
.49033 .18289 L
.49105 .18289 L
.49174 .18289 L
.49299 .18289 L
.49413 .18289 L
.49539 .18289 L
.49671 .18289 L
.49783 .18289 L
.49902 .18289 L
.50014 .18289 L
Mistroke
.50116 .18289 L
.50236 .18289 L
.50366 .18289 L
.50489 .18289 L
.50603 .18289 L
.50723 .18289 L
.50853 .18289 L
.50975 .18289 L
.51087 .18289 L
.51218 .18289 L
.51292 .18289 L
.51361 .18289 L
.51486 .18289 L
.5155 .18289 L
.5162 .18289 L
.51687 .18289 L
.51759 .18289 L
.51886 .18289 L
.51958 .18289 L
.52024 .18289 L
.52096 .18289 L
.52174 .18289 L
.52241 .18289 L
.52314 .18289 L
.52383 .18289 L
.52447 .18289 L
.52568 .18289 L
.52695 .18289 L
.52816 .18289 L
.52947 .18289 L
.53072 .18289 L
.53187 .18289 L
.53301 .18289 L
.53405 .18289 L
.53525 .18289 L
.53637 .18289 L
.5376 .18289 L
.53891 .18289 L
.54002 .18289 L
.54124 .18289 L
.54255 .18289 L
.54329 .18289 L
.54396 .18289 L
.54526 .18289 L
.5465 .18289 L
.54755 .18289 L
.54871 .18289 L
.54992 .18289 L
.55105 .18289 L
.55211 .18289 L
Mistroke
.55308 .18289 L
.55415 .18289 L
.55527 .18289 L
.55641 .18289 L
.55763 .18289 L
.55878 .18289 L
.55982 .18289 L
.56105 .18289 L
.56175 .18289 L
.56238 .18289 L
.56356 .18289 L
.5648 .18289 L
.56601 .18289 L
.56734 .18289 L
.56858 .18289 L
.56974 .18289 L
.57088 .18289 L
.57192 .18289 L
.57312 .18289 L
.57425 .18289 L
.57548 .18289 L
.57679 .18289 L
.5779 .18289 L
.57912 .18289 L
.58044 .18289 L
.58118 .18289 L
.58185 .18289 L
.58315 .18289 L
.58439 .18289 L
.58544 .18289 L
.5866 .18289 L
.58782 .18289 L
.58895 .18289 L
.59001 .18289 L
.59098 .18289 L
.5921 .18289 L
.59317 .18289 L
.59431 .18289 L
.59553 .18289 L
.59668 .18289 L
.59773 .18289 L
.59896 .18289 L
.59965 .18289 L
.60029 .18289 L
.60146 .18289 L
.60271 .18289 L
.60392 .18289 L
.60461 .18289 L
.60525 .18289 L
.60642 .18289 L
Mistroke
.60766 .18289 L
.60876 .18289 L
.6098 .18289 L
.61094 .18289 L
.61217 .18289 L
.61341 .18289 L
.6141 .18289 L
.61475 .18289 L
.61607 .18289 L
.6168 .18289 L
.61747 .18289 L
.61867 .18289 L
.61997 .18289 L
.6212 .18289 L
.62233 .18289 L
.62339 .18289 L
.62452 .18289 L
.62559 .18289 L
.62657 .18289 L
.62771 .18289 L
.62896 .18289 L
.63014 .18289 L
.63123 .18289 L
.63247 .18289 L
.63363 .18289 L
.63467 .18289 L
.6358 .18289 L
.63703 .18289 L
.63833 .18289 L
.63944 .18289 L
.64066 .18289 L
.64197 .18289 L
.64318 .18289 L
.64381 .18289 L
.6445 .18289 L
.64523 .18289 L
.64591 .18289 L
.64716 .18289 L
.64831 .18289 L
.64956 .18289 L
.65088 .18289 L
.652 .18289 L
.65319 .18289 L
.65431 .18289 L
.65533 .18289 L
.65653 .18289 L
.65784 .18289 L
.65906 .18289 L
.6602 .18289 L
.6614 .18289 L
Mistroke
.6627 .18289 L
.66392 .18289 L
.66504 .18289 L
.66635 .18289 L
.66709 .18289 L
.66777 .18289 L
.66903 .18289 L
.66966 .18289 L
.67036 .18289 L
.67104 .18289 L
.67175 .18289 L
.67303 .18289 L
.67374 .18289 L
.6744 .18289 L
.67513 .18289 L
.67591 .18289 L
.67658 .18289 L
.67731 .18289 L
.678 .18289 L
.67864 .18289 L
.67984 .18289 L
.68112 .18289 L
.68232 .18289 L
.68364 .18289 L
.68488 .18289 L
.68603 .18289 L
.68718 .18289 L
.68821 .18289 L
.68941 .18289 L
.69053 .18289 L
.69176 .18289 L
.69307 .18289 L
.69418 .18289 L
.6954 .18289 L
.69671 .18289 L
.69745 .18289 L
.69812 .18289 L
.69942 .18289 L
.70066 .18289 L
.70171 .18289 L
.70286 .18289 L
.70407 .18289 L
.70521 .18289 L
.70627 .18289 L
.70724 .18289 L
.7083 .18289 L
.70942 .18289 L
.71056 .18289 L
.71178 .18289 L
.71293 .18289 L
Mistroke
.71398 .18289 L
.71521 .18289 L
.7159 .18289 L
.71654 .18289 L
.71771 .18289 L
.71896 .18289 L
.72017 .18289 L
.72149 .18289 L
.72273 .18289 L
.72389 .18289 L
.72503 .18289 L
.72607 .18289 L
.72727 .18289 L
.7284 .18289 L
.72963 .18289 L
.73094 .18289 L
.73205 .18289 L
.73327 .18289 L
.73458 .18289 L
.73532 .18289 L
.73599 .18289 L
.7373 .18289 L
.73853 .18289 L
.73959 .18289 L
.74075 .18289 L
.74196 .18289 L
.7431 .18289 L
.74416 .18289 L
.74513 .18289 L
.74619 .18289 L
.74731 .18289 L
.74846 .18289 L
.74967 .18289 L
.75083 .18289 L
.75187 .18289 L
.7531 .18289 L
.75379 .18289 L
.75443 .18289 L
.75561 .18289 L
.75685 .18289 L
.75806 .18289 L
.75875 .18289 L
.75939 .18289 L
.76055 .18289 L
.7618 .18289 L
.7629 .18289 L
.76394 .18289 L
.76508 .18289 L
.76631 .18289 L
.76754 .18289 L
Mistroke
.76824 .18289 L
.76889 .18289 L
.7702 .18289 L
.77094 .18289 L
.77161 .18289 L
.7728 .18289 L
.7741 .18289 L
.77533 .18289 L
.77646 .18289 L
.77752 .18289 L
.77865 .18289 L
.77972 .18289 L
.7807 .18289 L
.78184 .18289 L
.78309 .18289 L
.78427 .18289 L
.78536 .18289 L
.7866 .18289 L
.78776 .18289 L
.7888 .18289 L
.78993 .18289 L
.79116 .18289 L
.79246 .18289 L
.79357 .18289 L
.79479 .18289 L
.7961 .18289 L
.7973 .18289 L
.79793 .18289 L
.79863 .18289 L
.79936 .18289 L
.80004 .18289 L
.80129 .18289 L
.80243 .18289 L
.80369 .18289 L
.80501 .18289 L
.80612 .18289 L
.80731 .18289 L
.80843 .18289 L
.80945 .18289 L
.81066 .18289 L
.81196 .18289 L
.81318 .18289 L
.81432 .18289 L
.81552 .18289 L
.81682 .18289 L
.81804 .18289 L
.81916 .18289 L
.82047 .18289 L
.8212 .18289 L
.82189 .18289 L
Mistroke
.82315 .18289 L
.82385 .18289 L
.82448 .18289 L
.82516 .18289 L
.82587 .18289 L
.82715 .18289 L
.82786 .18289 L
.82852 .18289 L
.82925 .18289 L
.83002 .18289 L
.8307 .18289 L
.83143 .18289 L
.83212 .18289 L
.83275 .18289 L
.83396 .18289 L
.83524 .18289 L
.83644 .18289 L
.83775 .18289 L
.839 .18289 L
.84015 .18289 L
.84129 .18289 L
.84232 .18289 L
.84352 .18289 L
.84464 .18289 L
.84587 .18289 L
.84718 .18289 L
.84829 .18289 L
.8495 .18289 L
.85082 .18289 L
.85155 .18289 L
.85222 .18289 L
.85353 .18289 L
.85476 .18289 L
.85581 .18289 L
.85697 .18289 L
.85818 .18289 L
.85932 .18289 L
.86037 .18289 L
.86134 .18289 L
.86241 .18289 L
.86353 .18289 L
.86467 .18289 L
.86589 .18289 L
.86704 .18289 L
.86808 .18289 L
.86931 .18289 L
.87 .18289 L
.87064 .18289 L
.87182 .18289 L
.87306 .18289 L
Mistroke
.87427 .18289 L
.87559 .18289 L
.87684 .18289 L
.87799 .18289 L
.87914 .18289 L
.88017 .18289 L
.88137 .18289 L
.88249 .18289 L
.88373 .18289 L
.88503 .18289 L
.88615 .18289 L
.88737 .18289 L
.88868 .18289 L
.88942 .18289 L
.89009 .18289 L
.89139 .18289 L
.89263 .18289 L
.89368 .18289 L
.89484 .18289 L
.89605 .18289 L
.89719 .18289 L
.89825 .18289 L
.89922 .18289 L
.90028 .18289 L
.90141 .18289 L
.90255 .18289 L
.90377 .18289 L
.90492 .18289 L
.90596 .18289 L
.90719 .18289 L
.90789 .18289 L
.90852 .18289 L
.9097 .18289 L
.91094 .18289 L
.91216 .18289 L
.91284 .18289 L
.91348 .18289 L
.91464 .18289 L
.91589 .18289 L
.91699 .18289 L
.91803 .18289 L
.91917 .18289 L
.9204 .18289 L
.92163 .18289 L
.92233 .18289 L
.92297 .18289 L
.92429 .18289 L
.92502 .18289 L
.92569 .18289 L
.92689 .18289 L
Mistroke
.92819 .18289 L
.92941 .18289 L
.93055 .18289 L
.9316 .18289 L
.93273 .18289 L
.9338 .18289 L
.93478 .18289 L
.93592 .18289 L
.93717 .18289 L
.93835 .18289 L
.93944 .18289 L
.94068 .18289 L
.94184 .18289 L
.94288 .18289 L
.94401 .18289 L
.94524 .18289 L
.94654 .18289 L
.94765 .18289 L
.94887 .18289 L
.94975 .18289 L
.95057 .18289 L
.95146 .18289 L
.95241 .18289 L
.95324 .18289 L
.95401 .18289 L
.95486 .18289 L
.95577 .18289 L
.95653 .18289 L
.95737 .18289 L
.95824 .18289 L
.95905 .18289 L
.95981 .18289 L
.9605 .18289 L
.9613 .18289 L
.96206 .18289 L
.96287 .18289 L
.96377 .18289 L
.96471 .18289 L
.96559 .18289 L
.96641 .18289 L
.96716 .18289 L
.96802 .18289 L
.96884 .18289 L
.96972 .18289 L
.97067 .18289 L
.97155 .18289 L
.97236 .18289 L
.97331 .18289 L
.97433 .18289 L
.9753 .18289 L
Mistroke
.97619 .18289 L
Mfstroke
0 g
gsave
.59524 .01472 -61 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.400 1.000 setrgbcolor
0.000 0.000 rmoveto
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.400 1.000 setrgbcolor
(Mixed) show
118.875 19.000 moveto
(Real) show
161.812 19.000 moveto
(Roots) show
212.562 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.400 1.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .22493 -195.562 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.400 1.000 setrgbcolor
0.000 0.000 rmoveto
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.400 1.000 setrgbcolor
(Negative) show
142.812 19.000 moveto
(Roots) show
193.562 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.400 1.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonfXA
oookJPGo0000oooonfX/oookJP00oooonfXAoookJPGo0000oooonfX/oookJP00oooonfXAoookJPGo
0000oooonfX/oookJP00oooonfXAoookJPGo0000oooonfX/oookJP00oooonfXAoookJPGo0000oooo
nfX/oookJP00oooonfXAoookJPGo0000oooonfX/oookJP00l_oonfX5o`00O`Cooo]Z0ol007l5oook
JP?o001o2_oonfX5o`00037ooo]Z0ol0I_l2oookJP?o06Ko0_oonfX3o`1Vo`;ooo]Z0ol0I_l2oook
JP?o06Ko0ooonfX3o`1Vo`Cooo]Z1Ol0I_l6oookJP?o06Ko00Cooo]Zo`1Vool0I_oo06Ko1OoonfX3
o`1Vo`Gooo]Z0ol0I_l4oookJPGo06Ko1OoonfX4o`1Vo`05oookJ_l0I_oo06Koo`1VoooonfX00ol0
I_l6oookJP?o06Ko1OoonfX3o`1Vo`Gooo]Z1?l0I_l8oookJPCo06Ko1ooonfX4o`1Vo`Cooo]Z1Ol0
I_mSoookJP00lOoonfX7o`00O`?ooo]Z0ol007l5oookJP?o001o2_oonfX5o`00037ooo]Z0ol0I_l2
oookJP?o06Ko0_oonfX3o`1Vo`;ooo]Z0ol0I_l3oookJP?o06Ko00Cooo]Zo`1Vool0I_oo06Ko1?oo
nfX7o`1Vo`Cooo]Z2?l0I_l5oookJP?o06Ko1OoonfX3o`1Vo`?ooo]Z1ol0I_l3oookJPSo06Ko0_oo
nfX3o`1Vo`Kooo]Z0ol0I_l5oookJP?o06Ko0ooonfX8o`1Vo`Cooo]Z2?l0I_l4oookJPGo06Ko0_oo
nfX8o`1Vof;ooo]Z003aoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Gooo]Z0ol0
07l:oookJPGo0000<OoonfX3o`1Vo`;ooo]Z0ol0I_l2oookJP?o06Ko0_oonfX3o`1Vo`?ooo]Z0ol0
I_l01?oonf[o06Koo`1Vool0I_l3oookJPCo06Ko0_oonfX3o`1Vo`;ooo]Z1?l0I_l00ooonf[o06Ko
o`1Vo`02o`1Vo`Gooo]Z0ol0I_l5oookJP?o06Ko0_oonfX4o`1Vo`;ooo]Z0ol0I_l2oookJP?o06Ko
0_oonfX3o`1Vo`;ooo]Z0ol0I_l6oookJP?o06Ko1OoonfX3o`1Vo`?ooo]Z0ol0I_l2oookJP?o06Ko
1?oonfX3o`1Vo`;ooo]Z0ol0I_l4oookJP?o06Ko1?oonfX3o`1Vo`?ooo]Z0ol0I_mQoookJP00i?oo
nfX:o`00O`;ooo]Z0ol007l3oookJP?o001o2_oonfX3o`00O`[ooo]Z1Ol0000aoookJP?o06Ko0_oo
nfX00ol0I_oooo]Zo`1Vo`02oookJP?o06Ko0_oonfX3o`1Vo`Cooo]Z1Ol0I_l4oookJP?o06Ko2?oo
nfX3o`1Vo`?ooo]Z0ol0I_l5oookJP?o06Ko1OoonfX3o`1Vo`;ooo]Z0ol0I_l8oookJP?o06Ko0_oo
nfX3o`1Vo`;ooo]Z0ol0I_l6oookJP?o06Ko1OoonfX3o`1Vo`;ooo]Z0ol0I_l4oookJP?o06Ko0_oo
nfX3o`1Vo`Cooo]Z0ol0I_l3oookJP?o06Ko2OoonfX4o`1Vof7ooo]Z003ToookJP[o001o0_oonfX3
o`00O`?ooo]Z0ol007l:oookJP?o001o2_oonfX6o`00033ooo]Z0ol0I_l01?oonf[o06Koo`1Voooo
nfX2o`1Vo`04oookJ_l0I_oo06Koo`1Vo`;ooo]Z0ol0I_l5oookJP?o06Ko1OoonfX9o`1Vo`;ooo]Z
0ol0I_l3oookJP?o06Ko1OoonfX3o`1Vo`Gooo]Z0ol0I_l2oookJPWo06Ko0_oonfX4o`1Vo`04oook
J_l0I_oo06Koo`1Vo`;ooo]Z0ol0I_l6oookJP?o06Ko1OoonfX3o`1Vo`;ooo]Z0ol0I_l4oookJP?o
06Ko0_oonfX3o`1Vo`Cooo]Z0ol0I_l3oookJP?o06Ko1_oonfX7o`1Vof7ooo]Z003`oookJP?o001o
0ooonfX3o`00O`[ooo]Z0ol007l:oookJPGo0000<OoonfX3o`1Vo`04oookJ_l0I_oo06KooookJP;o
06Ko00Cooo]Zo`1Vool0I_oo06Ko0_oonfX3o`1Vo`Gooo]Z0ol0I_l5oookJPWo06Ko0_oonfX3o`1V
o`?ooo]Z0ol0I_l5oookJP[o06Ko0ooonfX9o`1Vo`?ooo]Z1ol0I_l2oookJP?o06Ko1_oonfX:o`1V
o`?ooo]Z0ol0I_l4oookJP?o06Ko0_oonfX3o`1Vo`Cooo]Z0ol0I_l3oookJP?o06Ko1?oonfX7o`1V
of?ooo]Z003`oookJP?o001o0ooonfX3o`00O`[ooo]Z0ol007l:oookJPGo0000<OoonfX3o`1Vo`04
oookJ_l0I_oo06KooookJP;o06Ko00Cooo]Zo`1Vool0I_oo06Ko0_oonfX3o`1Vo`Cooo]Z1Ol0I_l4
oookJP?o06Ko0ooonfX3o`1Vo`;ooo]Z0ol0I_l3oookJP?o06Ko1OoonfX:o`1Vo`?ooo]Z0ol0I_l3
oookJP?o06Ko1ooonfX3o`1Vo`;ooo]Z0ol0I_l6oookJP[o06Ko0ooonfX3o`1Vo`Cooo]Z0ol0I_l2
oookJP?o06Ko1?oonfX3o`1Vo`?ooo]Z0ol0I_l4oookJPCo06KoI_oonfX00?3ooo]Z0ol007l3oook
JP?o001o2_oonfX3o`00O`[ooo]Z1Ol0000aoookJP?o06Ko00?ooo]Zo`1VoooonfX00_oonfX00ol0
I_oooo]Zo`1Vo`02o`1Vo`;ooo]Z0ol0I_l3oookJP?o06Ko00Cooo]Zo`1Vool0I_oo06Ko0ooonfX3
o`1Vo`?ooo]Z0ol0I_l2oookJPCo06Ko00?ooo]Zo`1Vool0I_l00_l0I_l5oookJP?o06Ko1OoonfX3
o`1Vo`;ooo]Z0ol0I_l3oookJP?o06Ko0_oonfX3o`1Vo`;ooo]Z0ol0I_l2oookJP?o06Ko1_oonfX3
o`1Vo`Gooo]Z0ol0I_l3oookJP?o06Ko0_oonfX3o`1Vo`Cooo]Z0ol0I_l2oookJP?o06Ko1?oonfX3
o`1Vo`Cooo]Z0ol0I_l3oookJP?o06KoHOoonfX00?3ooo]Z0ol007l3oookJP?o001o2_oonfX3o`00
O`[ooo]Z1Ol0000aoookJPGo06Ko0ooonfX5o`1Vo`;ooo]Z0ol0I_l3oookJP?o06Ko00Cooo]Zo`1V
ool0I_oo06Ko1?oonfX7o`1Vo`Cooo]Z2?l0I_l5oookJP?o06Ko1OoonfX3o`1Vo`?ooo]Z1ol0I_l3
oookJPSo06Ko0_oonfX3o`1Vo`Kooo]Z0ol0I_l5oookJP?o06Ko0ooonfX8o`1Vo`Cooo]Z2?l0I_l3
oookJPKo06Ko0ooonfX7o`1Vof;ooo]Z003`oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l:oook
JPGo0000<OoonfX5o`1Vo`?ooo]Z1Ol0I_l2oookJP?o06Ko0_oonfX3o`1Vo`?ooo]Z0ol0I_l4oook
JPGo06Ko1_oonfX3o`1Vo`04oookJ_l0I_oo06Koo`1Vo`Gooo]Z0ol0I_l5oookJP?o06Ko1?oonfX5
o`1Vo`Kooo]Z1?l0I_l4oookJP?o06Ko1_oonfX3o`1Vo`Gooo]Z0ol0I_l5oookJPCo06Ko2?oonfX4
o`1Vo`Gooo]Z1_l0I_l4oookJPGo06KoHooonfX00?7ooo]Z0ol007l01?oonf[o001oo`00Ool007l8
oookJPKo001o2_oonfX5o`00037ooo]Z1Ol0I_l3oookJPGo06Ko8ooonfX3o`1Vo`Gooo]Z0ol0I_l5
oookJP?o06Ko5ooonfX3o`1Vo`Kooo]Z0ol0I_l5oookJP?o06Ko6ooonfX3o`1Vofkooo]Z003aoook
JPOo001o2_oonfX4o`00O`[ooo]Z1Ol0000aoookJPCo06Ko1OoonfX4o`1Vo`;ooo]Z0ol0I_lNoook
JP?o06Ko1OoonfX:o`1VoaSooo]Z0ol0I_l6oookJP[o06Ko7?oonfX3o`1Vofkooo]Z003boookJPGo
001o3?oonfX3o`00O`[ooo]Z1Ol0000aoookJPCo06Ko1OoonfX4o`1Vo`;ooo]Z0ol0I_lNoookJP?o
06Ko1OoonfX9o`1VoaWooo]Z0ol0I_l6oookJPWo06KoS_oonfX00?oooo]Z4OoonfX5o`000?oooo]Z
;?oonfX00?oooo]Z4OoonfX5o`000?oooo]Z;?oonfX00?oooo]Z4OoonfX5o`000?oooo]Z;?oonfX0
0?oooo]Z4OoonfX5o`000?oooo]Z;?oonfX00?oooo]Z4OoonfX5o`000?oooo]Z;?oonfX00?oooo]Z
4OoonfX5o`000?oooo]Z;?oonfX00?oooo]Z4OoonfX5o`000?oooo]Z;?oonfX00?oooo]Z4OoonfX5
o`000?oooo]Z;?oonfX00?oooo]Z4OoonfX5o`000?oooo]Z;?oonfX00?oooo]Z4OoonfX5o`000?oo
oo]Z;?oonfX00?oooo]Z4OoonfX5o`000?oooo]Z;?oonfX00?oooo]Z4OoonfX5o`000?oooo]Z;?oo
nfX00?oooo]Z4OoonfX5o`000?oooo]Z;?oonfX00?oooo]Z4OoonfX5o`000?oooo]Z;?oonfX00?oo
oo]Z4OoonfX5o`000?oooo]Z;?oonfX00?oooo]Z4OoonfX5o`000?oooo]Z;?oonfX00?oooo]Z4Ooo
nfX5o`000?oooo]Z;?oonfX00?oooo]Z4OoonfX5o`000?oooo]Z;?oonfX00?oooo]Z4OoonfX5o`00
0?oooo]Z;?oonfX00?oooo]Z4OoonfX5o`000?oooo]Z;?oonfX00?oooo]Z4OoonfX5o`000?oooo]Z
;?oonfX00?oooo]Z4OoonfX5o`000?oooo]Z;?oonfX00?oooo]Z4OoonfX5o`000?oooo]Z;?oonfX0
0?oooo]Z4OoonfX5o`000?oooo]Z;?oonfX00?oooo]Z4OoonfX5o`000?oooo]Z;?oonfX00?oooo]Z
4OoonfX5o`000?oooo]Z;?oonfX00?oooo]Z4OoonfX5o`000?oooo]Z;?oonfX00?oooo]Z4OoonfX5
o`000?oooo]Z;?oonfX00?oooo]Z4OoonfX5o`000?oooo]Z;?oonfX00?oooo]Z4OoonfX5o`000?oo
oo]Z;?oonfX00>Sooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`Gooo]Z1Ol007l:oookJPGo0000
oooonfX/oookJP00iooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o0ooonfX7o`00O`Wooo]Z1Ol0
003ooookJRcooo]Z003WoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`;ooo]Z0ol0
07l01?oonf[o001oo`00Ool007l2oookJPCo001o00Cooo]Zo`00Ool007oo001o2OoonfX5o`000?oo
oo]Z;?oonfX00=[ooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Sooo]Z1Ol0003ooookJRcooo]Z003JoookJP[o001o
0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z0ol007l8oookJPKo0000
oooonfX[oookJP00i_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z0ol0
07l8oookJPGo0000oooonfX/oookJP00i_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3
o`00O`;ooo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Z;?oonfX00>Kooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z;?oonfX00>Ko
oo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l2oookJPKo001o2_oonfX5o`000?oo
oo]Z;?oonfX00>Kooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l2oookJP;o001o
3_oonfX5o`000?oooo]Z;?oonfX00>Oooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP?o001o
00Cooo]Zo`00Ool007oo001o0ooonfX2o`00O`kooo]Z1Ol0003ooookJRcooo]Z003WoookJPOo001o
2?oonfX7o`00O`Cooo]Z1ol007l8oookJPGo0000oooonfX/oookJP00j?oonfX5o`00O`[ooo]Z1Ol0
07l5oookJPOo001o2?oonfX5o`000?oooo]Z;?oonfX00?oooo]Z4OoonfX5o`000?oooo]Z;?oonfX0
0?oooo]Z4OoonfX5o`000?oooo]Z;?oonfX00?oooo]Z4OoonfX5o`000?oooo]Z;?oonfX00?oooo]Z
4OoonfX5o`000?oooo]Z;?oonfX00?oooo]Z4OoonfX5o`000?oooo]Z;?oonfX00?oooo]Z4OoonfX5
o`000?oooo]Z;?oonfX00?oooo]Z4OoonfX5o`000?oooo]Z;?oonfX00?oooo]Z4OoonfX5o`000?oo
oo]Z;?oonfX00?oooo]Z4OoonfX5o`000?oooo]Z;?oonfX00?oooo]Z4OoonfX5o`000?oooo]Z;?oo
nfX00?oooo]Z4OoonfX5o`000?oooo]Z;?oonfX00?oooo]Z4OoonfX5o`000?oooo]Z;?oonfX00?oo
oo]Z4OoonfX5o`000?oooo]Z;?oonfX00?oooo]Z4OoonfX5o`000?oooo]Z;?oonfX0027ooo]Z0ol0
07m_oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007mYoookJPGo0000KOoonfX5o`00O`Cooo]Z0ol0
07l3oookJPGo001oLOoonfX3o`00OcKooo]Z000QoookJP?o001oK_oonfX7o`00O`?ooo]Z0ol007l2
oookJPOo001oJ?oonfX5o`0006cooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Og3ooo]Z0ol007lf
oookJP008OoonfX3o`00Ofkooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Z
o`00Ool007l00_l007l01?oonf[o001oo`00Ool007mXoookJPGo0000K?oonfX3o`00O`04oookJ_l0
07oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00Og3o
oo]Z0ol007lfoookJP004OoonfX:o`00O`Kooo]Z0ol007mQoookJP[o001o0_oonfX3o`00O`?ooo]Z
0ol007l6oookJP?o001o0ooonfX3o`00OfOooo]Z1Ol0001[oookJP?o001o0ooonfX3o`00O`Kooo]Z
0ol007l3oookJP?o001oKooonfX3o`00OcKooo]Z000AoookJP[o001o1_oonfX3o`00Of7ooo]Z2_l0
07l2oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007mWoookJPGo0000JooonfX3o`00O`?ooo]Z0ol0
07l<oookJP?o001oKooonfX3o`00OcKooo]Z000QoookJP?o001oKOoonfX3o`00O`?ooo]Z0ol007l<
oookJP?o001oIooonfX5o`0006_ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ofoooo]Z0ol007lf
oookJP008OoonfX3o`00Ofgooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007mWoook
JPGo0000JooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00Ofoooo]Z0ol007lfoook
JP008OoonfX3o`00Ofgooo]Z0ol007l3oookJP?o001o1ooonfX7o`00OfSooo]Z1Ol0001[oookJP?o
001o0ooonfX3o`00O`Oooo]Z1ol007m`oookJP?o001o=_oonfX0027ooo]Z0ol007m]oookJP?o001o
0ooonfX3o`00O`Oooo]Z1_l007mYoookJPGo0000JooonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o
LOoonfX3o`00OcKooo]Z000NoookJPKo001oKOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001oKOoo
nfX5o`0006_ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00Og;ooo]Z1_l007lfoookJP007_oonfX6
o`00Ofkooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP;o001oKOoonfX5o`0006cooo]Z0ol0
07l01?oonf[o001oo`00Ool007l8oookJP;o001oL_oonfX6o`00OcKooo]Z000PoookJPCo001oK_oo
nfX7o`00O`Wooo]Z1ol007mWoookJPGo0000K?oonfX7o`00O`Wooo]Z1ol007m^oookJPCo001o=_oo
nfX0027ooo]Z0ol007m_oookJPGo001o2_oonfX7o`00OfOooo]Z1Ol0001]oookJPGo001o2_oonfX7
o`00Ofoooo]Z0ol007lfoookJP00oooonfXAoookJPGo0000oooonfX?oookJP04odA2NOl007oo001o
okZhKaWooo]Z003ooookJQ7ooo]Z1Ol0003ooookJPoooo]Z00Cok^Y[o`00Ool007ooA49i6OoonfX0
0?oooo]Z4OoonfX5o`000?oooo]Z4?oonfX01?mgMGGo001oo`00OooMfF`HoookJP00oooonfXAoook
JPGo0000oooonfX@oookJP04omgIK?l007oo001oohN5LaSooo]Z003ooookJQ7ooo]Z1Ol0003ooook
JQ7ooo]Z00Co411mo`00Oolb<W[oEE=g0_l007l00omEDgOok^Y[oookJP0BoookJP006Ooonf[oo`1V
ooCo06Ko6OoonfX02Om4@WWo001oo`00Oom4@WWooo]Zoc8bN_l007oo8B5lonkZJ`0BoookJP003Ooo
nfX<o`000?oo06Kom?l0I_l;o`0000kooo]Z00KoQhEco`00Ool007ooMgEeoookJ_nYYg42o`00O`03
ogMeMOoonf[ooo]Z013ooo]Z000=oookJPco0000ool0I_odo`1Vo`_o00003_oonfX01_o<b6ko001o
o`00OomVI7Kooo]ZonkZJ`;o001o00?o411moookJ_oonfX04?oonfX000gooo]Z3?l0003oo`1VooCo
06Ko2ol0000?oookJP;o001o00?o<S9joookJ_oonfX00ol007lBoookJP003OoonfX<o`000?oo06Ko
m?l0I_l;o`0000oooo]Z00?oA49io`00Ool007l00_oonfX2o`00O`03oa0@OOoonf[ooo]Z013ooo]Z
000=oookJPco0000ool0I_odo`1Vo`_o00003ooonfX01On7QG?o001oo`00Oonj^6ooQhEc00;o001o
00?oQhEcoookJ_oonfX04?oonfX001Wooo]Zool0I_odo`1Voa[ooo]Z00?oc<Q^o`00Ool007l00ol0
07l00olQ8Gcok^Y[oookJP0AoookJP00j?oonfX@o`0001Oooo]Z1ooo000HoookJPgo0000k?oonfX2
o`00O`06odA2NOoonf[ok^Y[ob4QO?l007ooc<Q^4OoonfX00>Gooo]Z3_l0000LoookJPOoo`007Ooo
nfX<o`000>Sooo]Z00?oA49io`00Ool007l00_oonfX00ooMfFco001ooc8bNP0AoookJP00h_oonfX<
o`00027ooo]Z1ooo000PoookJPgo0000i?oonfX01?nj^6oo001oo`00Oonj^6l2oookJP;o001o4Ooo
nfX00=oooo]Z2ol0000UoookJPOoo`008ooonfX=o`000>;ooo]Z00OoMgEeo`00OolQ8Gcok^Y[okZh
Kol007oo411m017ooo]Z003MoookJP[o0000:?oonfX7ool002Oooo]Z3?l0003PoookJP06ojVWLOlb
<W[o001oo`00Oom4@WWoc<Q^4OoonfX00=[ooo]Z2_l0000[oookJPOoo`00:ooonfX:o`000?Gooo]Z
003HoookJPWo0000;_oonfX7ool002kooo]Z2_l0003boookJP00eOoonfX:o`00033ooo]Z1ooo000a
oookJPWo0000l?oonfX00=?ooo]Z2Ol0000coookJPOoo`00<ooonfX9o`000>kooo]Z003AoookJPWo
0000=OoonfX7ool003Kooo]Z2?l00019oookJPGo06KoW_oonfX00<oooo]Z2?l0000hoookJPOoo`00
>?oonfX8o`0004Kooo]Z1ol0I_nMoookJP00cOoonfX8o`0003[ooo]Z1ooo000joookJPSo0000@ooo
nfX3o`1Vo`?ooo]Z0ol0I_nLoookJP00booonfX8o`0003cooo]Z1ooo000loookJPSo0000AooonfX3
o`1Voicooo]Z000OoookJP?o06Ko3?oonfX4o`1Vo`Oooo]Z1Ol0I_l4oookJP?o06Ko1?oonfX4o`1V
o`;ooo]Z0ol0I_l4oookJPGo06Ko1OoonfX5o`1Vo`Cooo]Z0ol0I_l5oookJP?o06Ko1OoonfX4o`1V
o`Sooo]Z1?l0I_l7oookJPCo06Ko1?oonfX5o`1Vobcooo]Z2?l0000noookJPOoo`00?_oonfX8o`00
02Sooo]Z0ol0I_l4oookJP?o06Ko1?oonfX5o`1Vo`Kooo]Z0ol0I_l01?oonf[o06Koo`1Vool0I_l3
oookJPCo06Ko00Cooo]Zo`1Vool0I_oo06Ko0ooonfX4o`1Vo`;ooo]Z0ol0I_l4oookJPGo06Ko1Ooo
nfX5o`1Vo`Kooo]Z0ol0I_l5oookJP?o06Ko1OoonfX4o`1Vo`Sooo]Z1?l0I_l7oookJPCo06Ko1?oo
nfX5o`1VocSooo]Z000OoookJP?o06Ko2_oonfX8o`1Vo`?ooo]Z2?l0I_l3oookJP?o06Ko0ooonfX5
o`1Vo`;ooo]Z0ol0I_l4oookJPGo06Ko1?oonfX7o`1Vo`?ooo]Z0ol0I_l5oookJP?o06Ko0ooonfX8
o`1Vo`Cooo]Z2?l0I_l4oookJPGo06Ko0_oonfX8o`1VobWooo]Z2?l00010oookJPOoo`00@?oonfX7
o`0002Oooo]Z0ol0I_l3oookJPCo06Ko0ooonfX7o`1Vo`Cooo]Z2?l0I_l2oookJPSo06Ko0ooonfX5
o`1Vo`;ooo]Z0ol0I_l4oookJPGo06Ko1?oonfX7o`1Vo`Gooo]Z0ol0I_l5oookJP?o06Ko0ooonfX8
o`1Vo`Cooo]Z2?l0I_l4oookJPGo06Ko0_oonfX8o`1VocOooo]Z000OoookJP?o06Ko2_oonfX3o`1V
o`;ooo]Z0ol0I_l3oookJP?o06Ko0ooonfX3o`1Vo`;ooo]Z0ol0I_l3oookJP?o06Ko1?oonfX3o`1V
o`?ooo]Z1ol0I_l2oookJPCo06Ko0_oonfX3o`1Vo`;ooo]Z0ol0I_l5oookJP?o06Ko0ooonfX3o`1V
o`;ooo]Z0ol0I_l4oookJP?o06Ko0_oonfX3o`1Vo`Cooo]Z0ol0I_l4oookJP?o06Ko0ooonfX3o`1V
obKooo]Z2?l00012oookJPOoo`00@_oonfX7o`0002Gooo]Z0ol0I_l3oookJPCo06Ko0_oonfX4o`1V
o`;ooo]Z0ol0I_l2oookJPCo06Ko00?ooo]Zo`1Vool0I_l00_l0I_l2oookJP?o06Ko0_oonfX3o`1V
o`?ooo]Z0ol0I_l4oookJP?o06Ko0ooonfX7o`1Vo`;ooo]Z1?l0I_l2oookJP?o06Ko1?oonfX3o`1V
o`Gooo]Z0ol0I_l3oookJP?o06Ko0_oonfX3o`1Vo`Cooo]Z0ol0I_l2oookJP?o06Ko1?oonfX3o`1V
o`Cooo]Z0ol0I_l3oookJP?o06Ko=_oonfX001oooo]Z0ol0I_l9oookJP?o06Ko1?oonfX3o`1Vo`Oo
oo]Z1?l0I_l2oookJP?o06Ko0ooonfX3o`1Vo`Cooo]Z0ol0I_l3oookJP?o06Ko00Cooo]Zo`1Vool0
I_oo06Ko0_oonfX3o`1Vo`Sooo]Z0ol0I_l5oookJP?o06Ko0_oonfX3o`1Vo`Cooo]Z0ol0I_l2oook
JP?o06Ko1?oonfX3o`1Vo`?ooo]Z0ol0I_l9oookJPCo06Ko9?oonfX8o`0004Cooo]Z1ooo0014oook
JPOo00008ooonfX3o`1Vo`;ooo]Z1Ol0I_l2oookJP?o06Ko2?oonfX3o`1Vo`?ooo]Z0ol0I_l2oook
JP?o06Ko0_oonfX3o`1Vo`?ooo]Z0ol0I_l4oookJP?o06Ko0ooonfX3o`1Vo`04oookJ_l0I_oo06Ko
o`1Vo`;ooo]Z0ol0I_l:oookJP?o06Ko1OoonfX3o`1Vo`;ooo]Z0ol0I_l4oookJP?o06Ko0_oonfX3
o`1Vo`Cooo]Z0ol0I_l3oookJP?o06Ko2OoonfX4o`1VocKooo]Z000OoookJP?o06Ko2OoonfX3o`1V
o`Cooo]Z0ol0I_l4oookJPOo06Ko0_oonfX3o`1Vo`?ooo]Z0ol0I_l4oookJP?o06Ko0ooonfX3o`1V
o`04oookJ_l0I_oo06Koo`1Vo`;ooo]Z2Ol0I_l2oookJP?o06Ko1OoonfX3o`1Vo`;ooo]Z0ol0I_l4
oookJP?o06Ko0_oonfX3o`1Vo`Cooo]Z0ol0I_l3oookJP?o06Ko1_oonfX7o`1Vob;ooo]Z2?l00016
oookJPOoo`00AOoonfX8o`00027ooo]Z0ol0I_l2oookJPGo06Ko0_oonfX9o`1Vo`;ooo]Z0ol0I_l3
oookJP?o06Ko0_oonfX4o`1Vo`04oookJ_l0I_oo06Koo`1Vo`?ooo]Z0ol0I_l4oookJP?o06Ko0ooo
nfX3o`1Vo`04oookJ_l0I_oo06Koo`1Vo`;ooo]Z2Ol0I_l4oookJP?o06Ko1OoonfX3o`1Vo`;ooo]Z
0ol0I_l4oookJP?o06Ko0_oonfX3o`1Vo`Cooo]Z0ol0I_l3oookJP?o06Ko1_oonfX7o`1VocKooo]Z
000OoookJPSo06Ko1?oonfX3o`1Vo`Cooo]Z0ol0I_l2oookJPOo06Ko1?oonfX3o`1Vo`?ooo]Z0ol0
I_l4oookJP?o06Ko0ooonfX3o`1Vo`04oookJ_l0I_oo06Koo`1Vo`;ooo]Z2Ol0I_l2oookJP[o06Ko
0ooonfX3o`1Vo`Cooo]Z0ol0I_l2oookJP?o06Ko1?oonfX3o`1Vo`?ooo]Z0ol0I_l4oookJPOo06Ko
8_oonfX8o`0004Sooo]Z1ooo0017oookJPSo00007ooonfX3o`1Vo`03oookJ_l0I_oo06Ko00Co06Ko
0_oonfX9o`1Vo`;ooo]Z0ol0I_l3oookJP?o06Ko0ooonfX7o`1Vo`?ooo]Z0ol0I_l4oookJP?o06Ko
0ooonfX3o`1Vo`04oookJ_l0I_oo06Koo`1Vo`;ooo]Z2Ol0I_l4oookJP[o06Ko0ooonfX3o`1Vo`Co
oo]Z0ol0I_l2oookJP?o06Ko1?oonfX3o`1Vo`?ooo]Z0ol0I_l4oookJPOo06Ko>?oonfX001oooo]Z
2Ol0I_l3oookJP?o06Ko1?oonfX3o`1Vo`;ooo]Z1?l0I_l7oookJP?o06Ko0ooonfX3o`1Vo`Cooo]Z
0ol0I_l2oookJP?o06Ko0ooonfX3o`1Vo`04oookJ_l0I_oo06Koo`1Vo`?ooo]Z0ol0I_l2oookJP[o
06Ko0ooonfX3o`1Vo`Cooo]Z0ol0I_l2oookJP?o06Ko1?oonfX3o`1Vo`?ooo]Z0ol0I_l4oookJPCo
06Ko9?oonfX7o`0004[ooo]Z1ooo0019oookJPSo00007OoonfX3o`1Vo`04oookJ_l0I_oo06Kooook
JP?o06Ko0_oonfX3o`1Vo`?ooo]Z0ol0I_l2oookJP?o06Ko0ooonfX3o`1Vo`Oooo]Z0ol0I_l3oook
JP?o06Ko1?oonfX3o`1Vo`;ooo]Z0ol0I_l3oookJP?o06Ko00Cooo]Zo`1Vool0I_oo06Ko0ooonfX3
o`1Vo`Cooo]Z2_l0I_l3oookJP?o06Ko1?oonfX3o`1Vo`;ooo]Z0ol0I_l4oookJP?o06Ko0ooonfX3
o`1Vo`Cooo]Z1?l0I_lkoookJP007ooonfX3o`1Vo`?ooo]Z1?l0I_l3oookJP?o06Ko0_oonfX3o`1V
o`?ooo]Z0ol0I_l3oookJP?o06Ko0_oonfX3o`1Vo`?ooo]Z0ol0I_l4oookJP?o06Ko0_oonfX3o`1V
o`?ooo]Z0ol0I_l01?oonf[o06Koo`1Vool0I_l3oookJP?o06Ko0_oonfX3o`1Vo`Gooo]Z0ol0I_l3
oookJP?o06Ko0_oonfX3o`1Vo`Cooo]Z0ol0I_l2oookJP?o06Ko1?oonfX3o`1Vo`Cooo]Z0ol0I_l3
oookJP?o06Ko7OoonfX7o`0004cooo]Z1ooo001;oookJPOo00007?oonfX6o`1Vo`04oookJ_l0I_oo
06Koo`1Vo`;ooo]Z0ol0I_l3oookJP?o06Ko0_oonfX4o`1Vo`03oookJ_l0I_oo06Ko00;o06Ko0_oo
nfX3o`1Vo`;ooo]Z0ol0I_l3oookJP?o06Ko1?oonfX3o`1Vo`;ooo]Z0ol0I_l3oookJP?o06Ko00Co
oo]Zo`1Vool0I_oo06Ko0ooonfX3o`1Vo`Cooo]Z0ol0I_l5oookJP?o06Ko0ooonfX3o`1Vo`;ooo]Z
0ol0I_l4oookJP?o06Ko0_oonfX3o`1Vo`Cooo]Z0ol0I_l4oookJP?o06Ko0ooonfX3o`1VocKooo]Z
000OoookJP?o06Ko1?oonfX3o`1Vo`?ooo]Z2?l0I_l4oookJPOo06Ko0ooonfX3o`1Vo`;ooo]Z1_l0
I_l2oookJP?o06Ko0_oonfX3o`1Vo`?ooo]Z0ol0I_l2oookJPOo06Ko0ooonfX3o`1Vo`Gooo]Z0ol0
I_l3oookJPSo06Ko1?oonfX8o`1Vo`?ooo]Z1_l0I_l3oookJPOo06Ko7OoonfX6o`0004kooo]Z1ooo
001=oookJPOo00006_oonfX5o`1Vo`;ooo]Z0ol0I_l3oookJPOo06Ko1?oonfX8o`1Vo`;ooo]Z2?l0
I_l2oookJPKo06Ko0_oonfX3o`1Vo`;ooo]Z0ol0I_l3oookJP?o06Ko0_oonfX7o`1Vo`Gooo]Z0ol0
I_l5oookJP?o06Ko0ooonfX8o`1Vo`Cooo]Z2?l0I_l3oookJPKo06Ko0ooonfX7o`1VocOooo]Z000O
oookJP?o06Ko1?oonfX3o`1Vo`Gooo]Z1?l0I_l7oookJPGo06Ko1?oonfX3o`1Vo`;ooo]Z1_l0I_l2
oookJP?o06Ko00Cooo]Zo`1Vool0I_oo06Ko1OoonfX3o`1Vo`;ooo]Z1Ol0I_l4oookJP?o06Ko1Ooo
nfX3o`1Vo`Gooo]Z1?l0I_l8oookJPCo06Ko1OoonfX6o`1Vo`Cooo]Z1Ol0I_lLoookJPOo0000Cooo
nfX7ool004oooo]Z1_l0000IoookJPGo06Ko0_oonfX3o`1Vo`Cooo]Z1Ol0I_l6oookJP?o06Ko00Co
oo]Zo`1Vool0I_oo06Ko1?oonfX4o`1Vo`Cooo]Z1_l0I_l2oookJP?o06Ko00Cooo]Zo`1Vool0I_oo
06Ko1OoonfX3o`1Vo`;ooo]Z1Ol0I_l6oookJP?o06Ko1OoonfX3o`1Vo`Gooo]Z1?l0I_l8oookJPCo
06Ko1OoonfX6o`1Vo`Cooo]Z1Ol0I_lhoookJP007ooonfX3o`1Vo`?ooo]Z1?l0I_lOoookJP?o06Ko
7_oonfX3o`1Vo`Gooo]Z0ol0I_lKoookJP?o06Ko9_oonfX6o`00057ooo]Z1ooo001@oookJPOo0000
5ooonfX4o`1Vo`?ooo]Z0ol0I_lSoookJP?o06Ko8?oonfX3o`1Vo`Gooo]Z0ol0I_lKoookJP?o06Ko
@ooonfX001oooo]Z2Ol0I_lJoookJP?o06Ko0ooonfX3o`1Vo`Cooo]Z0ol0I_lGoookJP[o06Ko7?oo
nfX3o`1VobCooo]Z1ol0001BoookJPOoo`00D_oonfX6o`0001Kooo]Z1?l0I_l3oookJP?o06Ko8ooo
nfX3o`1Vo`Cooo]Z0ol0I_lIoookJP[o06Ko7?oonfX3o`1Vod?ooo]Z000OoookJPSo06Ko6ooonfX3
o`1Vo`[ooo]Z0ol0I_lGoookJPWo06Ko@ooonfX6o`0005Cooo]Z1ooo001CoookJPOo00005?oonfX3
o`1Vo`Cooo]Z0ol0I_lZoookJP?o06Ko6OoonfX9o`1Vof?ooo]Z002coookJPOo0000EOoonfX7ool0
05Gooo]Z1_l0003?oookJP00/_oonfX6o`0005Oooo]Z1ooo001FoookJPOo0000cOoonfX00;3ooo]Z
1ol0001HoookJPOoo`00F?oonfX6o`000<cooo]Z002_oookJPKo0000F_oonfX7ool005Wooo]Z1ol0
003:oookJP00[OoonfX7o`0005_ooo]Z1ooo001KoookJPKo0000bOoonfX00:cooo]Z1_l0001Moook
JPOoo`00G?oonfX7o`000<Oooo]Z002ZoookJPOo0000G_oonfX7ool005kooo]Z1_l00036oookJP00
ZOoonfX6o`00063ooo]Z1ooo001OoookJPOo0000a?oonfX00:Sooo]Z1_l0001QoookJPOoo`00HOoo
nfX6o`000<?ooo]Z002WoookJPGo0000??oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o1OoonfX5
o`00O`Wooo]Z1ooo001RoookJPKo00007ooonfX3o`00O`Gooo]Z0ol007l4oookJPGo001o1OoonfX4
o`00O`05oookJ_l007oo001oo`00OooonfX00ol007l6oookJP?o001o1OoonfX3o`00O`Gooo]Z1?l0
07l8oookJPCo001o1ooonfX4o`00O`Cooo]Z1Ol007m4oookJP00YOoonfX6o`0003cooo]Z1ol007l3
oookJP?o001o0_oonfX7o`00O`?ooo]Z1ol007l8oookJPOoo`00I?oonfX5o`0001kooo]Z0ol007l5
oookJP?o001o0ooonfX7o`00O`?ooo]Z2?l007l2oookJP?o001o1_oonfX3o`00O`Gooo]Z0ol007l3
oookJPSo001o1?oonfX8o`00O`Cooo]Z1Ol007l2oookJPSo001o@ooonfX00:Cooo]Z1_l0000moook
JP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`;ooo]Z0ol007l01?oonf[o001oo`00Ool0
07l2oookJPCo001o00Cooo]Zo`00Ool007oo001o2?oonfX7ool006Gooo]Z1_l0000LoookJP?o001o
1OoonfX3o`00O`;ooo]Z1?l007l2oookJP?o001o0_oonfX3o`00O`;ooo]Z0ol007l2oookJP?o001o
1_oonfX3o`00O`Gooo]Z0ol007l3oookJP?o001o0_oonfX3o`00O`Cooo]Z0ol007l2oookJP?o001o
1?oonfX3o`00O`Cooo]Z0ol007l3oookJP?o001o@_oonfX00:?ooo]Z1_l0000moookJP?o001o0ooo
nfX3o`00O`Kooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Oooo]Z
1ooo001VoookJPKo00006ooonfX3o`00O`Gooo]Z0ol007l2oookJP?o001o2?oonfX3o`00O`;ooo]Z
0ol007l2oookJP?o001o1_oonfX3o`00O`Gooo]Z0ol007l2oookJP?o001o1?oonfX3o`00O`;ooo]Z
0ol007l4oookJP?o001o0ooonfX3o`00O`Wooo]Z1?l007m2oookJP00X_oonfX5o`0003oooo]Z0ol0
07l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7oookJP?o001o1ooonfX7ool006Oooo]Z1_l0
000JoookJP?o001o1OoonfX3o`00O`;ooo]Z2Ol007l2oookJPCo001o00Cooo]Zo`00Ool007oo001o
0_oonfX3o`00O`Kooo]Z0ol007l5oookJP?o001o0_oonfX3o`00O`Cooo]Z0ol007l2oookJP?o001o
1?oonfX3o`00O`?ooo]Z0ol007l6oookJPOo001o@_oonfX00:3ooo]Z1_l00010oookJP?o001o0ooo
nfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1ooonfX3o`00O`Oooo]Z1ooo001YoookJPGo00006Ooo
nfX:o`00O`?ooo]Z2Ol007l3oookJPOo001o0_oonfX3o`00O`Kooo]Z2_l007l3oookJP?o001o1?oo
nfX3o`00O`;ooo]Z0ol007l4oookJP?o001o0ooonfX3o`00O`Cooo]Z1ol007m4oookJP00WooonfX6
o`00047ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l2oookJP;o001o0_oonfX4
o`00O`Oooo]Z1ooo001ZoookJPKo00005ooonfX:o`00O`?ooo]Z0ol007l3oookJP?o001o1ooonfX3
o`00O`;ooo]Z0ol007l6oookJP[o001o0ooonfX3o`00O`Cooo]Z0ol007l2oookJP?o001o1?oonfX3
o`00O`?ooo]Z0ol007l4oookJPCo001oAooonfX009kooo]Z1_l00012oookJP?o001o0ooonfX3o`00
O`Kooo]Z0ol007l3oookJP?o001o0_oonfX7o`00O`Sooo]Z1ooo001[oookJPKo00005_oonfX3o`00
O`Gooo]Z0ol007l2oookJP?o001o0ooonfX3o`00O`;ooo]Z0ol007l2oookJP?o001o0_oonfX3o`00
O`Kooo]Z0ol007l5oookJP?o001o0ooonfX3o`00O`;ooo]Z0ol007l4oookJP?o001o0_oonfX3o`00
O`Cooo]Z0ol007l4oookJP?o001o0ooonfX3o`00Od;ooo]Z002MoookJPGo0000A?oonfX3o`00O`?o
oo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`;ooo]Z1_l007l9oookJPOoo`00K?oonfX6o`0001Go
oo]Z0ol007l5oookJP?o001o0ooonfX7o`00O`?ooo]Z2?l007l2oookJP?o001o1_oonfX3o`00O`Go
oo]Z0ol007l3oookJPSo001o1?oonfX8o`00O`?ooo]Z1_l007l3oookJPOo001o@ooonfX009cooo]Z
1Ol00015oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o0_oonfX2o`00O`gooo]Z
1ooo001^oookJPGo00005?oonfX3o`00O`Gooo]Z0ol007l4oookJPGo001o1_oonfX4o`00O`Cooo]Z
0ol007l6oookJP?o001o1OoonfX3o`00O`Gooo]Z1?l007l8oookJPCo001o1OoonfX6o`00O`Cooo]Z
1Ol007m4oookJP00V_oonfX6o`0004Oooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP?o001o
00Cooo]Zo`00Ool007oo001o0ooonfX2o`00O`gooo]Z1ooo001_oookJPKo00004_oonfX3o`00O`Go
oo]Z0ol007lGoookJP?o001o1_oonfX3o`00O`Gooo]Z0ol007lKoookJP?o001oCooonfX009Wooo]Z
1_l00018oookJPOo001o2?oonfX7o`00O`Cooo]Z1ol007l7oookJPOoo`00L?oonfX6o`00017ooo]Z
2_l007lHoookJP?o001o1_oonfX:o`00Oacooo]Z0ol007m?oookJP00V?oonfX6o`0004[ooo]Z1Ol0
07l:oookJPGo001o1OoonfX7o`00O`Oooo]Z1ooo001aoookJPKo00004?oonfX9o`00OaWooo]Z0ol0
07l6oookJPWo001oKooonfX009Oooo]Z1Ol0001coookJPOoo`00LooonfX5o`000;;ooo]Z002Eoook
JPKo0000M?oonfX7ool007Cooo]Z1Ol0002aoookJP00U?oonfX6o`0007Gooo]Z1ooo001eoookJPGo
0000/?oonfX009?ooo]Z1_l0001foookJPOoo`00M_oonfX5o`000:oooo]Z002BoookJPGo0000N?oo
nfX7ool007Oooo]Z1Ol0002^oookJP00TOoonfX5o`0007Wooo]Z1ooo001hoookJPGo0000[OoonfX0
093ooo]Z1Ol0001joookJPOoo`00NOoonfX5o`000:cooo]Z002?oookJPGo0000NooonfX7ool007[o
oo]Z1Ol0002[oookJP00S_oonfX5o`0007cooo]Z1ooo001koookJPGo0000Z_oonfX008gooo]Z1Ol0
001moookJPOoo`00O?oonfX5o`000:Wooo]Z002<oookJPGo0000O_oonfX7ool007gooo]Z1Ol0002X
oookJP00RooonfX5o`0007oooo]Z1ooo001noookJPGo0000YooonfX008[ooo]Z1Ol00020oookJPOo
o`00OooonfX5o`000:Kooo]Z0029oookJPGo0000POoonfX7ool0083ooo]Z1Ol0002UoookJP00R?oo
nfX5o`0008;ooo]Z1ooo0021oookJPGo0000Y?oonfX008Oooo]Z1Ol00023oookJPOoo`00P_oonfX5
o`000:?ooo]Z0026oookJPGo0000Q?oonfX7ool008?ooo]Z1Ol0002RoookJP00QOoonfX5o`0008Go
oo]Z1ooo0024oookJPGo0000XOoonfX008Cooo]Z1Ol00026oookJPOoo`00QOoonfX5o`000:3ooo]Z
0023oookJPGo0000QooonfX7ool008Kooo]Z1Ol0002OoookJP00P_oonfX5o`0008Sooo]Z1ooo0027
oookJPGo0000W_oonfX008;ooo]Z1?l00029oookJPOoo`00R?oonfX5o`0009gooo]Z0021oookJPCo
0000R_oonfX7ool008Wooo]Z1Ol0002LoookJP00P?oonfX5o`0008[ooo]Z1ooo002:oookJPCo0000
W?oonfX007oooo]Z1Ol0002;oookJPOoo`00RooonfX4o`0009_ooo]Z001noookJPGo0000S?oonfX7
ool008_ooo]Z1Ol0002JoookJP00OOoonfX5o`0001Sooo]Z0ooo000:oookJPCoo`0000Gooo]Zool0
0?oo003oo`00oookJP03ool000Kooo]Z1?oo001BoookJPOoo`00:ooonfX3ool000[ooo]Z1?oo0000
1Ooonf[oo`00ool00?oo003ooo]Z00?oo`001_oonfX4ool003kooo]Z1Ol0002IoookJP00O?oonfX5
o`0001Wooo]Z0ooo0009oookJPSoo`000_oonfX3ool000Gooo]Z1Ooo001BoookJPOoo`00:ooonfX3
ool000Wooo]Z2?oo0002oookJP?oo`001OoonfX5ool003oooo]Z1Ol0002HoookJP00NooonfX5o`00
01[ooo]Z0ooo0009oookJP?oo`000_oonfX3ool000;ooo]Z0ooo0005oookJP?oo`00E?oonfX7ool0
02_ooo]Z0ooo0009oookJP?oo`000_oonfX3ool000;ooo]Z0ooo0005oookJP?oo`00@_oonfX5o`00
09Oooo]Z001joookJPGo00006ooonfX3ool000Wooo]Z0ooo0002oookJP?oo`000_oonfX3ool000Go
oo]Z0ooo001DoookJPOoo`00:ooonfX3ool000Wooo]Z0ooo0002oookJP?oo`000_oonfX3ool000Go
oo]Z0ooo0013oookJPGo0000U_oonfX007Wooo]Z1Ol0000LoookJP?oo`002OoonfX4ool00004oook
J_oo003oo`00ool000;ooo]Z0ooo0005oookJP?oo`00E?oonfX7ool002_ooo]Z0ooo0009oookJPCo
o`0000Cooo]Zool00?oo003oo`000_oonfX3ool000Gooo]Z0ooo0014oookJPGo0000UOoonfX007So
oo]Z1Ol0000MoookJPSoo`001OoonfX7ool000;ooo]Z0ooo0005oookJP?oo`00=ooonfX5o`00O`Co
oo]Z0ol007l5oookJP?o001o2OoonfX7ool002_ooo]Z2?oo0005oookJPOoo`000_oonfX3ool000Go
oo]Z0ooo0015oookJPGo0000U?oonfX007Oooo]Z1Ol0000NoookJPWoo`002?oonfX3ool000;ooo]Z
1?oo0004oookJP?oo`00=_oonfX7o`00O`?ooo]Z0ol007l5oookJP?o001o2OoonfX7ool002_ooo]Z
2Ooo0008oookJP?oo`000_oonfX4ool000Cooo]Z0ooo0016oookJPGo0000TooonfX007Oooo]Z1?l0
000OoookJP?oo`000ooonfX4ool000;ooo]Z0ooo0002oookJP?oo`000_oonfX6ool000;ooo]Z0ooo
000foookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Gooo]Z0ol007l9oookJPOoo`00
:ooonfX3ool000?ooo]Z1?oo0002oookJP?oo`000_oonfX3ool000;ooo]Z1_oo0002oookJP?oo`00
AooonfX5o`0009;ooo]Z001foookJPCo00008?oonfX3ool000Cooo]Z0ooo0002oookJPSoo`000_oo
nfX6ool00003oookJ_oo003oo`0000Coo`00<ooonfX3o`00O`?ooo]Z0ol007l:oookJP?o001o2Ooo
nfX7ool002_ooo]Z0ooo0004oookJP?oo`000_oonfX8ool000;ooo]Z1_oo00000ooonf[oo`00ool0
0004ool004Kooo]Z1Ol0002AoookJP00MOoonfX5o`00023ooo]Z0ooo0004oookJP?oo`001?oonfX4
ool000Cooo]Z0ooo00001?oonf[oo`00ool00?oonfX6ool003?ooo]Z0ol007l3oookJP?o001o2_oo
nfX3o`00O`Wooo]Z1ooo000[oookJP?oo`001?oonfX3ool000Cooo]Z1?oo0004oookJP?oo`0000Co
oo]Zool00?oo003ooo]Z1_oo0017oookJPGo0000T?oonfX007Cooo]Z1Ol0000QoookJP?oo`000ooo
nfX4ool001Cooo]Z0ooo000eoookJP?o001o0ooonfX3o`00O`[ooo]Z0ol007l9oookJPOoo`00:ooo
nfX3ool000?ooo]Z1?oo000DoookJP?oo`00B_oonfX5o`0008oooo]Z001coookJPGo00008_oonfX9
ool001Gooo]Z0ooo000eoookJP?o001o0ooonfX3o`00O`[ooo]Z0ol007l9oookJPOoo`00:ooonfX9
ool001Gooo]Z0ooo001;oookJPGo0000S_oonfX007;ooo]Z1Ol0000SoookJPSoo`00C_oonfX3o`00
O`?ooo]Z0ol007l:oookJP?o001o2OoonfX7ool002_ooo]Z2?oo001UoookJPGo0000SOoonfX0077o
oo]Z1Ol0001joookJP?o001o0ooonfX3o`00O`[ooo]Z0ol007l9oookJPOoo`00VOoonfX5o`0008co
oo]Z001`oookJPGo0000NooonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o2OoonfX7ool009[ooo]Z
1Ol0002;oookJP00KooonfX5o`0007gooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPKo001o
2OoonfX7ool009_ooo]Z1Ol0002:oookJP00K_oonfX5o`0007kooo]Z1ol007l:oookJPCo001o2Ooo
nfX7ool009cooo]Z1Ol00029oookJP00KOoonfX5o`00083ooo]Z1Ol007l<oookJP?o001o2OoonfX7
ool009gooo]Z1Ol00028oookJP00KOoonfX4o`0009kooo]Z1ooo002NoookJPGo0000QooonfX006co
oo]Z1?l0000ZoookJP?oo`001OoonfX3ool000Cooo]Z1Ooo0005oookJPCoo`0000Gooo]Zool00?oo
003oo`00oookJP03ool0053ooo]Z1ooo000[oookJP?oo`001OoonfX3ool000Cooo]Z1Ooo0005oook
JPCoo`0000Gooo]Zool00?oo003oo`00oookJP03ool004oooo]Z1?l00027oookJP00JooonfX5o`00
02[ooo]Z0ooo0005oookJP?oo`000ooonfX7ool000?ooo]Z2?oo0002oookJP?oo`00D?oonfX7ool0
02_ooo]Z0ooo0005oookJP?oo`000ooonfX7ool000?ooo]Z2?oo0002oookJP?oo`00D?oonfX4o`00
08Kooo]Z001ZoookJPGo0000:ooonfX3ool000Gooo]Z0ooo0002oookJPCoo`000_oonfX3ool000;o
oo]Z0ooo0002oookJP?oo`000_oonfX3ool0053ooo]Z1ooo000[oookJP?oo`001OoonfX3ool000;o
oo]Z1?oo0002oookJP?oo`000_oonfX3ool000;ooo]Z0ooo0002oookJP?oo`00D?oonfX5o`0008Go
oo]Z001YoookJPGo0000;?oonfX3ool000Gooo]Z0ooo0002oookJP?oo`002?oonfX3ool000;ooo]Z
0ooo0002oookJP?oo`00D?oonfX7ool002_ooo]Z0ooo0005oookJP?oo`000_oonfX3ool000Sooo]Z
0ooo0002oookJP?oo`000_oonfX3ool0057ooo]Z1Ol00024oookJP00JOoonfX4o`0002gooo]Z0ooo
0005oookJP?oo`000_oonfX9ool000;ooo]Z1?oo00001?oonf[oo`00ool00?oo0002oookJP?oo`00
D?oonfX7ool002_ooo]Z0ooo0005oookJP?oo`000_oonfX9ool000;ooo]Z1?oo00001?oonf[oo`00
ool00?oo0002oookJP?oo`00D_oonfX5o`0008?ooo]Z001XoookJPCo0000;_oonfX:ool000?ooo]Z
2Ooo0003oookJPOoo`000_oonfX3ool0053ooo]Z1ooo000[oookJP[oo`000ooonfX9ool000?ooo]Z
1ooo0002oookJP?oo`00DooonfX4o`0008?ooo]Z001WoookJPGo0000;_oonfX:ool000?ooo]Z0ooo
0003oookJP?oo`001ooonfX3ool000;ooo]Z0ooo001@oookJPOoo`00:ooonfX:ool000?ooo]Z0ooo
0003oookJP?oo`001ooonfX3ool000;ooo]Z0ooo001DoookJPCo0000P_oonfX006Kooo]Z1Ol0000_
oookJP?oo`001OoonfX3ool000;ooo]Z0ooo0003oookJP?oo`000_oonfX3ool000;ooo]Z0ooo0002
oookJP?oo`00D?oonfX7ool002_ooo]Z0ooo0005oookJP?oo`000_oonfX3ool000?ooo]Z0ooo0002
oookJP?oo`000_oonfX3ool000;ooo]Z0ooo001DoookJPGo0000POoonfX006Gooo]Z1Ol0000`oook
JP?oo`001OoonfX3ool000?ooo]Z1ooo0003oookJPSoo`000_oonfX3ool0053ooo]Z1ooo000[oook
JP?oo`001OoonfX3ool000?ooo]Z1ooo0003oookJPSoo`000_oonfX3ool005Gooo]Z1Ol00020oook
JP00IOoonfX4o`00037ooo]Z0ooo0005oookJP?oo`001?oonfX5ool000Kooo]Z1?oo0004oookJP?o
o`00D?oonfX7ool002_ooo]Z0ooo0005oookJP?oo`001?oonfX5ool000Kooo]Z1?oo0004oookJP?o
o`00E_oonfX5o`0007oooo]Z001ToookJPCo0000<_oonfX3ool000Gooo]Z0ooo000GoookJP?oo`00
D?oonfX7ool002_ooo]Z0ooo0005oookJP?oo`005ooonfX3ool005Oooo]Z1?l0001ooookJP00Hooo
nfX5o`0003;ooo]Z2_oo000HoookJP?oo`00D?oonfX7ool002_ooo]Z2_oo000HoookJP?oo`00F?oo
nfX4o`0007kooo]Z001RoookJPGo0000<ooonfX9ool001Wooo]Z0ooo001@oookJPOoo`00:ooonfX9
ool001Wooo]Z0ooo001HoookJPGo0000OOoonfX0067ooo]Z1Ol0002YoookJPOoo`00ZOoonfX5o`00
07cooo]Z001QoookJPCo0000Z_oonfX7ool00:[ooo]Z1Ol0001koookJP00H?oonfX4o`000:_ooo]Z
1ooo0014oookJPGoo`00H_oonfX4o`0007_ooo]Z001OoookJPGo0000ZooonfX7ool004?ooo]Z1ooo
001RoookJPCo0000N_oonfX005kooo]Z1Ol0002/oookJPOoo`00@_oonfX3ool000?ooo]Z0ooo001Q
oookJPGo0000NOoonfX005gooo]Z1Ol0002]oookJPOoo`00B?oonfX3ool006;ooo]Z1Ol0001hoook
JP00GOoonfX4o`0003Wooo]Z0ooo000<oookJPCoo`001ooonfX5ool000Cooo]Z0ooo0004oookJPCo
o`000_oonfX3ool000Cooo]Z1Ooo0005oookJPGoo`00;ooonfX7ool002_ooo]Z0ooo0004oookJP?o
o`001?oonfX5ool000Kooo]Z0ooo00001?oonf[oo`00ool00?oo0003oookJPCoo`0000Cooo]Zool0
0?oo003oo`000ooonfX4ool000;ooo]Z0ooo0004oookJPGoo`001OoonfX5ool003Wooo]Z1Ol0001g
oookJP00G?oonfX4o`0003[ooo]Z0ooo000:oookJPSoo`000ooonfX8ool000?ooo]Z0ooo0003oook
JPGoo`000_oonfX3ool000Cooo]Z1Ooo0004oookJPOoo`00;_oonfX7ool002_ooo]Z0ooo0003oook
JPCoo`000ooonfX7ool000Cooo]Z2?oo0002oookJPSoo`000ooonfX5ool000;ooo]Z0ooo0004oook
JPGoo`001?oonfX7ool003Wooo]Z1?l0001goookJP00FooonfX5o`0003[ooo]Z0ooo000:oookJP?o
o`000_oonfX3ool000?ooo]Z0ooo0003oookJP?oo`000_oonfX3ool000?ooo]Z0ooo0004oookJP?o
o`000ooonfX7ool000;ooo]Z1?oo0002oookJP?oo`00;OoonfX7ool002_ooo]Z0ooo0003oookJPCo
o`000_oonfX4ool000;ooo]Z0ooo0002oookJPCoo`0000?ooo]Zool00?oo00000_oo0002oookJP?o
o`000_oonfX3ool000?ooo]Z0ooo0004oookJP?oo`000ooonfX7ool000;ooo]Z1?oo0002oookJP?o
o`00>OoonfX4o`0007Kooo]Z001JoookJPGo0000>ooonfX3ool000Wooo]Z0ooo0004oookJP?oo`00
1ooonfX4ool000;ooo]Z0ooo0003oookJP?oo`001?oonfX3ool000?ooo]Z0ooo00001?oonf[oo`00
ool00?oo0002oookJP?oo`00<ooonfX7ool002_ooo]Z0ooo0002oookJPGoo`000_oonfX3ool000So
oo]Z0ooo0003oookJP?oo`000_oonfX3ool000;ooo]Z0ooo0003oookJP?oo`001?oonfX3ool000?o
oo]Z0ooo00001?oonf[oo`00ool00?oo0002oookJP?oo`00?ooonfX5o`0007Gooo]Z001IoookJPGo
0000??oonfX3ool000Wooo]Z0ooo0004oookJP?oo`001?oonfX7ool000;ooo]Z0ooo0003oookJP?o
o`001?oonfX3ool000?ooo]Z0ooo00001?oonf[oo`00ool00?oo0002oookJPWoo`00;OoonfX7ool0
02_ooo]Z0ooo0002oookJPGoo`000_oonfX9ool000;ooo]Z0ooo0003oookJP?oo`000_oonfX4ool0
0004oookJ_oo003oo`00ool000?ooo]Z0ooo0004oookJP?oo`000ooonfX3ool00004oookJ_oo003o
o`00ool000;ooo]Z2Ooo000joookJPGo0000M?oonfX005Wooo]Z1?l0000moookJPSoo`001?oonfX3
ool000Cooo]Z0ooo0002oookJPOoo`001?oonfX3ool000?ooo]Z0ooo0004oookJP?oo`000ooonfX3
ool00004oookJ_oo003oo`00ool000;ooo]Z2Ooo000]oookJPOoo`00:ooonfX3ool00003oookJ_oo
003oo`0000Coo`000_oonfX9ool000;ooo]Z0ooo0003oookJP?oo`000ooonfX7ool000?ooo]Z0ooo
0004oookJP?oo`000ooonfX3ool00004oookJ_oo003oo`00ool000;ooo]Z2Ooo000koookJPGo0000
LooonfX005Sooo]Z1?l0000noookJPWoo`000ooonfX3ool000Cooo]Z0ooo0002oookJPCoo`001ooo
nfX3ool000?ooo]Z0ooo0004oookJP?oo`000_oonfX3ool000?ooo]Z0ooo00001?oonf[oo`00ool0
0?oo0003oookJP?oo`00;OoonfX7ool002_ooo]Z0ooo00001?oonf[oo`00ool00?oonfX3ool000;o
oo]Z0ooo0003oookJP?oo`000_oonfX3ool000?ooo]Z0ooo0007oookJP?oo`000ooonfX3ool000Co
oo]Z0ooo0002oookJP?oo`000ooonfX3ool00004oookJ_oo003oo`00ool000?ooo]Z0ooo000loook
JPCo0000LooonfX005Oooo]Z1Ol0000noookJP?oo`000ooonfX4ool000?ooo]Z0ooo0002oookJP?o
o`000ooonfX3ool000?ooo]Z0ooo0002oookJP?oo`000ooonfX3ool000Cooo]Z0ooo0002oookJP?o
o`000ooonfX3ool00004oookJ_oo003oo`00ool000?ooo]Z0ooo000]oookJPOoo`00:ooonfX6ool0
0004oookJ_oo003oo`00ool000;ooo]Z0ooo0003oookJP?oo`000_oonfX4ool00003oookJ_oo003o
o`0000;oo`000_oonfX3ool000;ooo]Z0ooo0003oookJP?oo`001?oonfX3ool000;ooo]Z0ooo0003
oookJP?oo`0000Cooo]Zool00?oo003oo`000ooonfX3ool003gooo]Z1?l0001boookJP00E_oonfX5
o`0003oooo]Z0ooo0004oookJP?oo`000ooonfX8ool000Cooo]Z1ooo0003oookJP?oo`000_oonfX6
ool000;ooo]Z0ooo0002oookJP?oo`000ooonfX3ool000;ooo]Z1ooo000^oookJPOoo`00:ooonfX5
ool000;ooo]Z0ooo0003oookJPOoo`001?oonfX8ool000;ooo]Z2?oo0002oookJPKoo`000_oonfX3
ool000;ooo]Z0ooo0003oookJP?oo`000_oonfX7ool003kooo]Z1Ol0001aoookJP00E_oonfX4o`00
043ooo]Z0ooo0004oookJP?oo`001OoonfX4ool000Oooo]Z1Ooo0004oookJP?oo`000_oonfX6ool0
00;ooo]Z0ooo00001?oonf[oo`00ool00?oo0005oookJP?oo`000_oonfX5ool002oooo]Z1ooo000[
oookJPGoo`000_oonfX3ool000Cooo]Z1Ooo0006oookJP?oo`0000Cooo]Zool00?oo003oo`001?oo
nfX4ool000Cooo]Z1_oo0002oookJP?oo`0000Cooo]Zool00?oo003oo`001OoonfX3ool000;ooo]Z
1Ooo0010oookJPCo0000LOoonfX005Gooo]Z1?l00011oookJP?oo`000ooonfX4ool001oooo]Z0ooo
000RoookJPGo001o1?oonfX3o`00O`Gooo]Z0ol007l5oookJPGo001o2OoonfX7ool002_ooo]Z1?oo
0003oookJP?oo`008ooonfX3ool005_ooo]Z1?l0001`oookJP00E?oonfX5o`00047ooo]Z2Ooo000J
oookJP?oo`000ooonfX3ool000Cooo]Z0ooo000JoookJPOo001o0ooonfX3o`00O`Gooo]Z0ol007l4
oookJPOo001o2?oonfX7ool002_ooo]Z1?oo0003oookJP?oo`008ooonfX3ool000Cooo]Z0ooo001D
oookJPGo0000KooonfX005Cooo]Z1?l00012oookJPSoo`006ooonfX3ool000[ooo]Z0ooo000Joook
JP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Gooo]Z0ol007l3oookJPCo001o00Cooo]Z
o`00Ool007oo001o2?oonfX7ool002_ooo]Z0ooo0004oookJP?oo`00:_oonfX3ool005Gooo]Z1Ol0
001^oookJP00DooonfX4o`0008oooo]Z0ol007l3oookJP?o001o2_oonfX3o`00O`?ooo]Z0ol007l3
oookJP?o001o1ooonfX7ool00;Sooo]Z1?l0001^oookJP00D_oonfX5o`0008oooo]Z0ol007l3oook
JP?o001o2_oonfX3o`00O`Wooo]Z0ol007l7oookJPOoo`00^OoonfX4o`0006gooo]Z001AoookJPGo
0000T?oonfX3o`00O`?ooo]Z0ol007l:oookJP?o001o2OoonfX3o`00O`Oooo]Z1ooo002ioookJPGo
0000K?oonfX0057ooo]Z1?l0002AoookJP?o001o0ooonfX3o`00O`[ooo]Z0ol007l4oookJP;o001o
0_oonfX4o`00O`Oooo]Z1ooo002joookJPCo0000K?oonfX0053ooo]Z1?l0002BoookJP?o001o0ooo
nfX3o`00O`[ooo]Z0ol007l4oookJPOo001o2?oonfX7ool00;_ooo]Z1?l0001[oookJP00CooonfX5
o`0009;ooo]Z0ol007l3oookJP?o001o2_oonfX3o`00O`Cooo]Z1_l007l9oookJPOoo`00^ooonfX5
o`0006[ooo]Z001>oookJPGo0000TooonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o1?oonfX2o`00
O`gooo]Z1ooo002loookJPCo0000J_oonfX004kooo]Z1?l0002EoookJP?o001o00Cooo]Zo`00Ool0
07oo001o2?oonfX6o`00O`Cooo]Z0_l007l=oookJPOoo`00_OoonfX4o`0006Wooo]Z001=oookJPCo
0000U_oonfX7o`00O`[ooo]Z1?l007l5oookJPOo001o1ooonfX7ool00;gooo]Z1Ol0001XoookJP00
C?oonfX5o`0009Oooo]Z1Ol007l<oookJP?o001o1OoonfX7o`00O`Oooo]Z1ooo002noookJPGo0000
IooonfX004cooo]Z1?l0002ooookJPOoo`00_ooonfX4o`0006Oooo]Z001;oookJPCo0000`?oonfX7
ool00<3ooo]Z1?l0001VoookJP00B_oonfX5o`000<3ooo]Z1ooo0030oookJPGo0000IOoonfX004Wo
oo]Z1Ol00031oookJPOoo`00`OoonfX4o`0006Gooo]Z0019oookJPCo0000`_oonfX7ool00<;ooo]Z
1?l0001ToookJP00B?oonfX4o`000<?ooo]Z1ooo0032oookJPGo0000HooonfX004Oooo]Z1Ol00033
oookJPOoo`00`ooonfX4o`0006?ooo]Z0017oookJPCo0000a?oonfX7ool00<Cooo]Z1?l0001Roook
JP00A_oonfX4o`000<Gooo]Z1ooo0034oookJPGo0000HOoonfX004Gooo]Z1Ol00035oookJPOoo`00
aOoonfX5o`00063ooo]Z0014oookJPGo0000a_oonfX7ool00<Kooo]Z1?l0001PoookJP00A?oonfX4
o`000<Oooo]Z1ooo0037oookJPCo0000GooonfX004?ooo]Z1?l00038oookJPOoo`00aooonfX5o`00
05kooo]Z0012oookJPGo0000b?oonfX7ool00<Sooo]Z1?l0001NoookJP00@_oonfX4o`000<Wooo]Z
1ooo0039oookJPCo0000GOoonfX0047ooo]Z1?l0003:oookJPOoo`00bOoonfX5o`0005cooo]Z0010
oookJPGo0000b_oonfX7ool00<[ooo]Z1?l0001LoookJP00@?oonfX4o`000<_ooo]Z1ooo003;oook
JPCo0000FooonfX003oooo]Z1?l0003<oookJPOoo`00booonfX5o`0005[ooo]Z000ooookJPCo0000
c?oonfX7ool00<cooo]Z1?l0001JoookJP00?_oonfX4o`000<gooo]Z1ooo003=oookJPCo0000FOoo
nfX003gooo]Z1Ol0003=oookJPOoo`00cOoonfX4o`0005Wooo]Z000moookJPCo0000c_oonfX7ool0
0<kooo]Z1?l0001HoookJP00??oonfX4o`000<oooo]Z1ooo003>oookJPGo0000EooonfX003_ooo]Z
1Ol0003?oookJPOoo`00cooonfX4o`0005Oooo]Z000koookJPCo0000d?oonfX7ool00=3ooo]Z1?l0
001FoookJP00>_oonfX4o`000=7ooo]Z1ooo000loookJP?o001o1OoonfX3o`00O`Gooo]Z1?l007l8
oookJPCo001o1ooonfX4o`00O`Cooo]Z1Ol007mPoookJPGo0000EOoonfX003Wooo]Z1Ol0003Aoook
JPOoo`00??oonfX3o`00O`Gooo]Z0ol007l3oookJPSo001o1?oonfX8o`00O`Cooo]Z1Ol007l2oook
JPSo001oH?oonfX4o`0005Gooo]Z000ioookJPCo0000d_oonfX7ool003cooo]Z0ol007l5oookJP?o
001o0ooonfX3o`00O`;ooo]Z0ol007l4oookJP?o001o0_oonfX3o`00O`Cooo]Z0ol007l4oookJP?o
001o0ooonfX3o`00Of3ooo]Z1?l0001DoookJP00>?oonfX4o`000=?ooo]Z1ooo000loookJP?o001o
1OoonfX3o`00O`;ooo]Z0ol007l4oookJP?o001o0_oonfX3o`00O`Cooo]Z0ol007l3oookJP?o001o
2OoonfX4o`00Of3ooo]Z1Ol0001CoookJP00>?oonfX4o`000=?ooo]Z1ooo000loookJP?o001o1Ooo
nfX3o`00O`;ooo]Z0ol007l4oookJP?o001o0_oonfX3o`00O`Cooo]Z0ol007l3oookJP?o001o1_oo
nfX7o`00Of7ooo]Z1?l0001CoookJP00=ooonfX4o`000;Oooo]Z1Ol007l4oookJP?o001o00?ooo]Z
o`00Ool007l01ol007l7oookJPOoo`00??oonfX:o`00O`?ooo]Z0ol007l4oookJP?o001o0_oonfX3
o`00O`Cooo]Z0ol007l3oookJP?o001o1?oonfX7o`00OfCooo]Z1?l0001BoookJP00=_oonfX5o`00
0;Kooo]Z1ol007l3oookJP?o001o00?ooo]Zo`00Ool007l01ol007l7oookJPOoo`00??oonfX:o`00
O`?ooo]Z0ol007l4oookJP?o001o0_oonfX3o`00O`Cooo]Z0ol007l3oookJP?o001o1?oonfX4o`00
OfOooo]Z1Ol0001AoookJP00=_oonfX4o`000;Oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00?ooo]Zo`00Ool007l00_l007l<oookJPOoo`00??oonfX3o`00O`Gooo]Z0ol007l3oook
JP?o001o0_oonfX3o`00O`Cooo]Z0ol007l2oookJP?o001o1?oonfX3o`00O`Cooo]Z0ol007l3oook
JP?o001oHooonfX4o`00057ooo]Z000eoookJPCo0000]ooonfX3o`00O`?ooo]Z0ol007l7oookJPCo
001o2ooonfX7ool003cooo]Z0ol007l5oookJP?o001o0ooonfX8o`00O`Cooo]Z2?l007l3oookJPKo
001o0ooonfX7o`00OfGooo]Z1?l0001@oookJP00=?oonfX5o`000;Oooo]Z0ol007l3oookJP?o001o
2?oonfX5o`00O`Wooo]Z1ooo000loookJP?o001o1OoonfX3o`00O`Gooo]Z1?l007l8oookJPCo001o
1OoonfX6o`00O`Cooo]Z1Ol007mVoookJPGo0000CooonfX003Cooo]Z1?l0002hoookJP?o001o0ooo
nfX3o`00O`[ooo]Z1?l007l8oookJPOoo`00??oonfX3o`00O`Gooo]Z0ol007lKoookJP?o001oL_oo
nfX4o`0004oooo]Z000coookJPCo0000^OoonfX3o`00O`?ooo]Z0ol007l;oookJP?o001o2?oonfX7
ool003cooo]Z2_l007lLoookJP?o001oLooonfX4o`0004kooo]Z000boookJPGo0000^OoonfX3o`00
O`?ooo]Z0ol007l<oookJP?o001o1ooonfX7ool003cooo]Z2Ol007nCoookJPCo0000C_oonfX003;o
oo]Z1?l0002joookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1ooonfX7ool00=Wo
oo]Z1?l0001=oookJP00<OoonfX4o`000;_ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z
0ol007l7oookJPOoo`00fOoonfX5o`0004cooo]Z000aoookJPCo0000_?oonfX3o`00O`04oookJ_l0
07oo001oo`00O`Oooo]Z1?l007l2oookJP?o001o1ooonfX7ool006;ooo]Z1Ol007lAoookJPGo001o
GOoonfX4o`0004cooo]Z000`oookJPCo0000_OoonfX7o`00O`Sooo]Z1ol007l8oookJPOoo`00HOoo
nfX7o`00O`oooo]Z1ol007mMoookJPCo0000BooonfX002oooo]Z1Ol0002noookJPGo001o2_oonfX5
o`00O`Wooo]Z1ooo001PoookJP?o001o0ooonfX3o`00O`gooo]Z0ol007l3oookJP?o001oG?oonfX5
o`0004[ooo]Z000_oookJPCo0000g?oonfX7ool006Kooo]Z0ol007lCoookJP?o001oGOoonfX4o`00
04[ooo]Z000^oookJPCo0000gOoonfX7ool003oooo]Z1Ol007l8oookJPCo001o1OoonfX3o`00O`?o
oo]Z0ol007l4oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX4o`00O`04oookJ_l007oo001o
o`00O`Cooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJPCo001o00Cooo]Zo`00Ool007oo001o
0ooonfX4o`00O`Cooo]Z1Ol007m3oookJPCo0000BOoonfX002kooo]Z1?l0003MoookJPOoo`00?_oo
nfX7o`00O`Gooo]Z2?l007l3oookJP?o001o0ooonfX3o`00O`?ooo]Z2?l007l2oookJPWo001o0ooo
nfX8o`00O`;ooo]Z2?l007l3oookJPGo001o0ooonfX7o`00Od;ooo]Z1?l00019oookJP00;OoonfX4
o`000=kooo]Z1ooo000moookJP?o001o0ooonfX3o`00O`Cooo]Z0ol007l2oookJP?o001o0ooonfX3
o`00O`?ooo]Z0ol007l2oookJPCo001o00?ooo]Zo`00Ool007l00_l007l2oookJP?o001o0_oonfX4
o`00O`;ooo]Z1?l007l00ooonf[o001oo`00O`02o`00O`;ooo]Z0ol007l2oookJP?o001o0ooonfX3
o`00O`Cooo]Z1?l007l2oookJP?o001o@_oonfX4o`0004Sooo]Z000/oookJPGo0000g_oonfX7ool0
03gooo]Z0ol007l4oookJP?o001o0_oonfX3o`00O`Cooo]Z0ol007l2oookJP?o001o0ooonfX3o`00
O`;ooo]Z0ol007l3oookJP?o001o0_oonfX3o`00O`?ooo]Z0ol007l2oookJP?o001o0ooonfX3o`00
O`;ooo]Z0ol007l2oookJP?o001o0ooonfX3o`00O`Cooo]Z0ol007m8oookJPGo0000AooonfX002co
oo]Z1?l0003OoookJPOoo`00??oonfX3o`00O`Gooo]Z0ol007l2oookJP?o001o1?oonfX3o`00O`;o
oo]Z0ol007l3oookJP?o001o0_oonfX3o`00O`?ooo]Z0ol007l2oookJP?o001o0ooonfX3o`00O`;o
oo]Z0ol007l3oookJP?o001o0_oonfX4o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l4oook
JPWo001o@ooonfX4o`0004Oooo]Z000[oookJPCo0000h?oonfX7ool003cooo]Z0ol007l:oookJP?o
001o1?oonfX3o`00O`;ooo]Z0ol007l3oookJP?o001o0_oonfX3o`00O`?ooo]Z0ol007l2oookJP?o
001o0ooonfX3o`00O`;ooo]Z0ol007l3oookJP?o001o0ooonfX7o`00O`?ooo]Z0ol007l4oookJPWo
001oA?oonfX4o`0004Kooo]Z000[oookJPCo0000h?oonfX7ool003cooo]Z0ol007l:oookJP?o001o
1?oonfX3o`00O`;ooo]Z0ol007l3oookJP?o001o0_oonfX3o`00O`?ooo]Z0ol007l2oookJP?o001o
0ooonfX3o`00O`;ooo]Z0ol007l3oookJP?o001o1ooonfX3o`00O`?ooo]Z0ol007l4oookJP?o001o
0ooonfX3o`00OdCooo]Z1?l00016oookJP00:_oonfX4o`000>7ooo]Z1ooo000loookJP?o001o2ooo
nfX3o`00O`;ooo]Z0ol007l3oookJPCo001o0_oonfX3o`00O`;ooo]Z1?l007l00ooonf[o001oo`00
O`02o`00O`;ooo]Z0ol007l3oookJP?o001o0_oonfX4o`00O`03oookJ_l007oo001o00;o001o0_oo
nfX3o`00O`;ooo]Z0ol007l3oookJP?o001o1?oonfX3o`00O`?ooo]Z0ol007m5oookJPCo0000AOoo
nfX002Wooo]Z1Ol0003QoookJPOoo`00??oonfX3o`00O`Gooo]Z0ol007l3oookJPSo001o0ooonfX9
o`00O`?ooo]Z2?l007l2oookJP?o001o0ooonfX3o`00O`?ooo]Z2?l007l2oookJPSo001o0_oonfX6
o`00O`?ooo]Z1ol007m6oookJPGo0000A?oonfX002Wooo]Z1?l0003RoookJPOoo`00?OoonfX3o`00
O`Cooo]Z0ol007l5oookJPCo001o1OoonfX3o`00O`03oookJ_l007oo001o00;o001o1OoonfX3o`00
O`04oookJ_l007oo001oo`00O`;ooo]Z0ol007l3oookJP?o001o1?oonfX3o`00O`04oookJ_l007oo
001oo`00O`Cooo]Z1?l007l4oookJPKo001o1?oonfX5o`00OdSooo]Z1?l00014oookJP00:?oonfX4
o`000>?ooo]Z1ooo000moookJP?o001o0ooonfX3o`00OdKooo]Z0ol007mDoookJPCo0000@ooonfX0
02Sooo]Z1?l0003SoookJPOoo`00?_oonfX8o`00OdKooo]Z0ol007mDoookJPCo0000@ooonfX002Oo
oo]Z1?l0003ToookJPOoo`00?ooonfX5o`00Oj3ooo]Z1?l00012oookJP009_oonfX5o`000>Cooo]Z
1ooo003ToookJPGo0000@OoonfX002Kooo]Z1?l0003UoookJPOoo`00iOoonfX4o`00047ooo]Z000U
oookJPCo0000i_oonfX7ool006Kooo]Z0ol007mmoookJPCo0000@?oonfX002Gooo]Z1?l0003Voook
JPOoo`00I_oonfX3o`00Oggooo]Z1?l00010oookJP009?oonfX4o`000>Oooo]Z1ooo001VoookJP?o
001oO_oonfX4o`0003oooo]Z000ToookJPCo0000iooonfX7ool006Kooo]Z0ol007mnoookJPCo0000
?ooonfX002?ooo]Z1?l0003XoookJPOoo`00?ooonfX5o`00O`Sooo]Z1?l007l5oookJP?o001o0ooo
nfX3o`00O`?ooo]Z0ol007l2oookJP?o001o00Cooo]Zo`00Ool007oo001o1?oonfX3o`00O`Cooo]Z
1Ol007l4oookJP?o001o0ooonfX3o`00Oekooo]Z1?l0000noookJP008_oonfX5o`000>Sooo]Z1ooo
000noookJPOo001o1OoonfX8o`00O`?ooo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`;ooo]Z2?l0
07l3oookJP?o001o0ooonfX7o`00O`Cooo]Z0ol007l01?oonf[o001oo`00Ool007mOoookJPGo0000
?OoonfX002;ooo]Z1?l0003YoookJPOoo`00?OoonfX3o`00O`?ooo]Z0ol007l4oookJP?o001o0_oo
nfX3o`00O`?ooo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`;ooo]Z1?l007l00ooonf[o001oo`00
O`02o`00O`;ooo]Z0ol007l2oookJPCo001o0_oonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00
Ool007mPoookJPCo0000?OoonfX0027ooo]Z1?l0003ZoookJPOoo`00?OoonfX3o`00O`Cooo]Z0ol0
07l2oookJP?o001o1?oonfX3o`00O`;ooo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`;ooo]Z0ol0
07l3oookJP?o001o0_oonfX3o`00O`;ooo]Z0ol007l:oookJPGo001oH_oonfX4o`0003cooo]Z000Q
oookJPCo0000j_oonfX7ool003cooo]Z0ol007l5oookJP?o001o0_oonfX3o`00O`Cooo]Z0ol007l2
oookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l2oookJP?o001o0ooonfX3o`00O`;ooo]Z0ol007l2
oookJPWo001o1OoonfX3o`00Of?ooo]Z1?l0000loookJP008?oonfX4o`000>_ooo]Z1ooo000loook
JP?o001o2_oonfX3o`00O`Cooo]Z0ol007l2oookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l2oook
JP?o001o0ooonfX3o`00O`;ooo]Z0ol007l2oookJPWo001o1OoonfX3o`00OfCooo]Z1?l0000koook
JP007ooonfX5o`000>_ooo]Z1ooo000loookJP?o001o2_oonfX3o`00O`Cooo]Z0ol007l2oookJP?o
001o0ooonfX3o`00O`?ooo]Z0ol007l2oookJP?o001o0ooonfX3o`00O`;ooo]Z0ol007l2oookJP?o
001o0ooonfX3o`00O`Cooo]Z1Ol007mSoookJPGo0000>_oonfX001oooo]Z1?l0003/oookJPOoo`00
??oonfX3o`00O`_ooo]Z0ol007l2oookJP?o001o0ooonfX4o`00O`;ooo]Z1?l007l2oookJP?o001o
0_oonfX4o`00O`03oookJ_l007oo001o00;o001o0_oonfX3o`00O`;ooo]Z0ol007l3oookJP?o001o
0ooonfX3o`00O`04oookJ_l007oo001oo`00Of?ooo]Z1?l0000joookJP007_oonfX4o`000>gooo]Z
1ooo000loookJP?o001o1OoonfX3o`00O`?ooo]Z2?l007l3oookJPoo001o0_oonfX8o`00O`?ooo]Z
0ol007l3oookJPOo001o1?oonfX3o`00O`04oookJ_l007oo001oo`00OfCooo]Z1?l0000ioookJP00
7_oonfX4o`000>gooo]Z1ooo000moookJP?o001o1?oonfX3o`00O`Gooo]Z1?l007l5oookJP?o001o
00?ooo]Zo`00Ool007l00_l007l2oookJPCo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`Co
oo]Z0ol007l4oookJPGo001o1?oonfX3o`00O`?ooo]Z0ol007mSoookJPCo0000>OoonfX001gooo]Z
1?l00037oookJPGo001o1?oonfX3o`00O`03oookJ_l007oo001o00Oo001o0ooonfX5o`00O`Wooo]Z
1ooo000moookJP?o001o0ooonfX3o`00Ob_ooo]Z0ol007mjoookJPCo0000>?oonfX001cooo]Z1Ol0
0036oookJPOo001o0ooonfX3o`00O`03oookJ_l007oo001o00Oo001o0_oonfX7o`00O`Sooo]Z1ooo
000noookJPSo001o:ooonfX3o`00Og[ooo]Z1Ol0000goookJP007?oonfX4o`000<Oooo]Z0ol007l0
1?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l6oookJPCo001o00Co
oo]Zo`00Ool007oo001o2?oonfX7ool003oooo]Z1Ol007l]oookJP?o001oNooonfX4o`0003Oooo]Z
000KoookJPCo0000aooonfX3o`00O`?ooo]Z0ol007l7oookJPCo001o1OoonfX3o`00O`?ooo]Z0ol0
07l7oookJPOoo`00l?oonfX4o`0003Kooo]Z000KoookJPCo0000aooonfX3o`00O`?ooo]Z0ol007l8
oookJPGo001o2OoonfX3o`00O`Oooo]Z1ooo003`oookJPCo0000=_oonfX001_ooo]Z0ol00038oook
JP?o001o0ooonfX3o`00O`[ooo]Z1?l007l8oookJP?o001o1ooonfX7ool00?7ooo]Z0ol0000foook
JP00i_oonfX3o`00O`?ooo]Z0ol007l;oookJP?o001o0ooonfX2o`00O`;ooo]Z1?l007l7oookJPOo
o`00oooonfX[oookJP00i_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o0_oonfX7o`00O`Sooo]Z
1ooo003ooookJR_ooo]Z003VoookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o0_oo
nfX6o`00O`[ooo]Z1Ol0003ooookJRcooo]Z003VoookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3
oookJP?o001o0_oonfX2o`00O`kooo]Z1Ol0003ooookJRcooo]Z003WoookJP?o001o00Cooo]Zo`00
Ool007oo001o1ooonfX4o`00O`;ooo]Z0ol007l2oookJP;o001o3_oonfX5o`000?oooo]Z;?oonfX0
0>Oooo]Z1ol007l8oookJPOo001o1?oonfX7o`00O`Sooo]Z1Ol0003ooookJRcooo]Z003XoookJPGo
001o2_oonfX5o`00O`Gooo]Z1ol007l8oookJPGo0000oooonfX/oookJP00oooonfXAoookJPGo0000
oooonfX/oookJP00oooonfXAoookJPGo0000oooonfX/oookJP00oooonf[ooookJT;ooo]Z003ooook
J_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oo
nfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]Z
oooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]Z3ooonfX00ol@
47go001oojVWL@3ooookJS3ooo]Z003ooookJPoooo]Z00?o<S9jo`00Ool007l0oooonfX`oookJP00
oooonfX?oookJP04olc8K_l007oo001ookZhKooooo]Z;ooonfX00?oooo]Z4?oonfX00onHUW;o001o
ohN5L`3ooookJRoooo]Z003ooookJQ7ooo]Z00?oMgEeoc8bN_oonfX0oooonfX^oookJP00oooonfXB
oookJP03o`00OonHUW;ooo]Z0?oooo]Z;OoonfX00?oooo]Z4_oonfX00olQ8Gco411moiRFLP3ooook
JRgooo]Z003ooookJQ;ooo]Z00Co001ookZhKol007ooc<Q^oooonfX/oookJP00oooonfXAoookJP06
olc8K_l007oooo]ZoeECMol@47gok^Y[oooonfX[oookJP00oooonfX>oookJP09o`00Oon7QG?ooo]Z
ogMeMOl007oooo]ZomgIK?l007ooIVAf0?oooo]Z:ooonfX00?oooo]Z3_oonfX01On7QG?o001oo`00
Ool007oo<S9j00;ooo]Z00?oEE=go`00OooMfF`0oooonfXZoookJP00oooonfX?oookJP04ohN5Lol0
07oo411molc8KP;ooo]Z00?ogMU/oc8bN_m4@WT0oooonfXZoookJP00oooonf[ooookJT;ooo]Z003o
oookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z
@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.11476, -0.111725, \
0.00406308, 0.00115048}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["Determination of Specific Solution using Boundary Values", "Subtitle"],

Cell[TextData[{
  "Second order ODEs require that ",
  StyleBox["two",
    FontWeight->"Bold"],
  " conditions  be specified to generate a particular solution."
}], "Text",
  CellTags->"mmtag:21:second_order_odes__using_boundary_values"],

Cell["\<\
Example of y(0) = 0 and y(L)=1
The general solution will have the form:\
\>", "Subsubtitle"],

Cell[CellGroupData[{

Cell[BoxData[
    \(GeneralSolution[x_]\  := \ 
      CPlus\ Exp[LambdaPlus\ x]\  + \ CMinus\ Exp[LambdaMinus\ x]\)], "Input"],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(CPlus\\)\\\" is similar to existing symbol \
\\\"\\!\\(Plus\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(CMinus\\)\\\" is similar to existing symbol \
\\\"\\!\\(Minus\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"]
}, Open  ]],

Cell[TextData[{
  "Apply the two boundary conditions and solve the resulting equations for \
constants ",
  StyleBox["CPlus",
    FontWeight->"Bold"],
  " and ",
  StyleBox["CMinus",
    FontWeight->"Bold"],
  ":"
}], "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolutionOne\  = \ 
      Solve[{GeneralSolution[0] == 0, GeneralSolution[L] == 1}, {CPlus, 
          CMinus}]\)], "Input"],

Cell[BoxData[
    \({{CPlus \[Rule] \(-\(1\/\(\[ExponentialE]\^\(1\/2\ L\ \((\(-\[Beta]\) - \
\@\(\[Beta]\^2 - 4\ \[Gamma]\))\)\) - \[ExponentialE]\^\(1\/2\ L\ \((\(-\
\[Beta]\) + \@\(\[Beta]\^2 - 4\ \[Gamma]\))\)\)\)\)\), 
        CMinus \[Rule] 
          1\/\(\[ExponentialE]\^\(1\/2\ L\ \((\(-\[Beta]\) - \@\(\[Beta]\^2 - \
4\ \[Gamma]\))\)\) - \[ExponentialE]\^\(1\/2\ L\ \((\(-\[Beta]\) + \
\@\(\[Beta]\^2 - 4\ \[Gamma]\))\)\)\)}}\)], "Output"]
}, Open  ]],

Cell["Write the resulting solution:", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SpecificSolutionOne\  = \ 
      Simplify[GeneralSolution[x] /. Flatten[SolutionOne]]\)], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(1\/2\ \((L - x)\)\ \((\[Beta] + \@\(\[Beta]\^2 - 4\
\ \[Gamma]\))\)\)\ \((\(-1\) + \[ExponentialE]\^\(x\ \@\(\[Beta]\^2 - 4\ \
\[Gamma]\)\))\)\)\/\(\(-1\) + \[ExponentialE]\^\(L\ \@\(\[Beta]\^2 - 4\ \
\[Gamma]\)\)\)\)], "Output"]
}, Open  ]],

Cell["\<\
Second example with different form of boundary condition:  y(0) = 1 \
and y'(0)=0\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DGen\  = \ D[GeneralSolution[x], x]\)], "Input"],

Cell[BoxData[
    \(1\/2\ CMinus\ \[ExponentialE]\^\(1\/2\ x\ \((\(-\[Beta]\) - \@\(\[Beta]\
\^2 - 4\ \[Gamma]\))\)\)\ \((\(-\[Beta]\) - \@\(\[Beta]\^2 - 4\ \[Gamma]\))\) \
+ 1\/2\ CPlus\ \[ExponentialE]\^\(1\/2\ x\ \((\(-\[Beta]\) + \@\(\[Beta]\^2 - \
4\ \[Gamma]\))\)\)\ \((\(-\[Beta]\) + \@\(\[Beta]\^2 - 4\ \[Gamma]\))\)\)], \
"Output"]
}, Open  ]],

Cell["Now the constants CPlus and CMinus are found by solving:", \
"Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolutionTwo\  = \ 
      Solve[{GeneralSolution[0] \[Equal] 
            1, \((DGen /. x \[Rule] 0)\) \[Equal] 0}, {CPlus, 
          CMinus}]\)], "Input"],

Cell[BoxData[
    \({{CPlus \[Rule] 1\/2 + \[Beta]\/\(2\ \@\(\[Beta]\^2 - 4\ \[Gamma]\)\), 
        CMinus \[Rule] \(-\(\(\[Beta] - \@\(\[Beta]\^2 - 4\ \[Gamma]\)\)\/\(2\
\ \@\(\[Beta]\^2 - 4\ \[Gamma]\)\)\)\)}}\)], "Output"],

Cell[BoxData[
    \({{CPlus \[Rule] 1\/2 + \[Beta]\/\(2\ \@\(\[Beta]\^2 - 4\ \[Gamma]\)\), 
        CMinus \[Rule] \(-\(\(\[Beta] - \@\(\[Beta]\^2 - 4\ \[Gamma]\)\)\/\(2\
\ \@\(\[Beta]\^2 - 4\ \[Gamma]\)\)\)\)}}\)], "Input"]
}, Open  ]],

Cell["And the new solution is:", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SpecificSolutionTwo\  = \ 
      Simplify[GeneralSolution[x] /. Flatten[SolutionTwo]]\)], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-\(1\/2\)\)\ x\ \((\[Beta] + \@\(\[Beta]\^2 - 4\ \
\[Gamma]\))\)\)\ \((\((\(-1\) + \[ExponentialE]\^\(x\ \@\(\[Beta]\^2 - 4\ \
\[Gamma]\)\))\)\ \[Beta] + \((1 + \[ExponentialE]\^\(x\ \@\(\[Beta]\^2 - 4\ \
\[Gamma]\)\))\)\ \@\(\[Beta]\^2 - 4\ \[Gamma]\))\)\)\/\(2\ \@\(\[Beta]\^2 - 4\
\ \[Gamma]\)\)\)], "Output"]
}, Open  ]],

Cell["\<\
Example of Higher-Order equation and Visualization of Solutions:
The Beam Equation\
\>", "Subtitle",
  CellTags->{
  "mmtag:21:beam_theory", "mmtag:21:fourth_order_odes__beam_theory"}],

Cell["Visualizing Beam Deflections:", "Text"],

Cell["\<\
Set up the ODE solution (we will specify a unit beam stiffness) EI \
= 1\
\>", "Text"],

Cell[BoxData[
    \(BeamEquation[y_\ , x_\ , \ w_, \ BC1_\ , \ BC2_]\  := \ 
      DSolve[Flatten[{\(y''''\)[x]\  == \ w[x], \ BC1, \ BC2}], y[x], x] // 
        Flatten\)], "Input",
  CellTags->"mmtag:21:beam_equation"],

Cell["Set up some typical boundary conditions:", "Text",
  CellTags->{
  "mmtag:21:beam_boundary_conditions", 
    "mmtag:21:boundary_conditions__for_beams"}],

Cell[BoxData[{
    \(Clamped[y_\ , \ x_\ , \ position_, \ 
        slope_]\  := \ {y[x]\  == \ position, \ \(y'\)[x]\  == \ 
          slope}\), "\[IndentingNewLine]", 
    \(PointLoad[y_, \ x_, \ position_, \ 
        moment_]\  := \ {y[x] \[Equal] \ position, \ \(y''\)[x]\  \[Equal] \ 
          moment}\), "\[IndentingNewLine]", 
    \(FreeEnd[y_\ , \ 
        x_]\  := \ {\(y''\)[x] \[Equal] 0, \ \(y'''\)[x] \[Equal] 
          0}\)}], "Input"],

Cell[BoxData[
    \(noload[x_]\  := \ 0\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BeamEquation[y, x, noload, Clamped[y, 0, 0, 0], 
      PointLoad[y, 1, \(- .1\), 0]]\)], "Input",
  CellTags->"mmtag:21:beams__general_solutions_for_deflection"],

Cell[BoxData[
    \({y[x] \[Rule] \(\(0.`\)\(\[InvisibleSpace]\)\) + 0.`\ x - 0.15`\ x\^2 + 
          0.05`\ x\^3}\)], "Output"]
}, Open  ]],

Cell["Clamped Beam, loaded at the end", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Plot", "[", 
      RowBox[{
        RowBox[{"Evaluate", "[", "\[IndentingNewLine]", 
          
          StyleBox[\(y[x] /. 
              BeamEquation[y, x, noload, Clamped[y, 0, 0, 0], 
                PointLoad[y, 1, \(- .25\), 0]]\),
            FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", "]"}], 
        ",", \({x, 0, 1}\), ",", \(PlotRange \[Rule] {\(-0.5\), 0.5}\), 
        ",", \(AspectRatio \[Rule] 1\)}], "]"}]], "Input",
  CellTags->{
  "mmtag:21:beams__clamped_and_loaded", 
    "mmtag:21:beams__clamped_both_ends_with_point_load"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.5 1 [
[.21429 .4875 -14.5 -20 ]
[.21429 .4875 14.5 0 ]
[.40476 .4875 -14.5 -20 ]
[.40476 .4875 14.5 0 ]
[.59524 .4875 -14.5 -20 ]
[.59524 .4875 14.5 0 ]
[.78571 .4875 -14.5 -20 ]
[.78571 .4875 14.5 0 ]
[.97619 .4875 -7 -20 ]
[.97619 .4875 7 0 ]
[.01131 .1 -41.9375 -10 ]
[.01131 .1 0 10 ]
[.01131 .3 -41.9375 -10 ]
[.01131 .3 0 10 ]
[.01131 .7 -29 -10 ]
[.01131 .7 0 10 ]
[.01131 .9 -29 -10 ]
[.01131 .9 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 1.005 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .5 m
.21429 .50625 L
s
gsave
.21429 .4875 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.40476 .5 m
.40476 .50625 L
s
gsave
.40476 .4875 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.59524 .5 m
.59524 .50625 L
s
gsave
.59524 .4875 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.78571 .5 m
.78571 .50625 L
s
gsave
.78571 .4875 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.97619 .5 m
.97619 .50625 L
s
gsave
.97619 .4875 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .5 m
.07143 .50375 L
s
.11905 .5 m
.11905 .50375 L
s
.16667 .5 m
.16667 .50375 L
s
.2619 .5 m
.2619 .50375 L
s
.30952 .5 m
.30952 .50375 L
s
.35714 .5 m
.35714 .50375 L
s
.45238 .5 m
.45238 .50375 L
s
.5 .5 m
.5 .50375 L
s
.54762 .5 m
.54762 .50375 L
s
.64286 .5 m
.64286 .50375 L
s
.69048 .5 m
.69048 .50375 L
s
.7381 .5 m
.7381 .50375 L
s
.83333 .5 m
.83333 .50375 L
s
.88095 .5 m
.88095 .50375 L
s
.92857 .5 m
.92857 .50375 L
s
.01 w
0 .5 m
1 .5 L
s
.25 Mabswid
.02381 .1 m
.03006 .1 L
s
gsave
.01131 .1 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.02381 .3 m
.03006 .3 L
s
gsave
.01131 .3 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.02381 .7 m
.03006 .7 L
s
gsave
.01131 .7 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.02381 .9 m
.03006 .9 L
s
gsave
.01131 .9 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .15 m
.02756 .15 L
s
.02381 .2 m
.02756 .2 L
s
.02381 .25 m
.02756 .25 L
s
.02381 .35 m
.02756 .35 L
s
.02381 .4 m
.02756 .4 L
s
.02381 .45 m
.02756 .45 L
s
.02381 .55 m
.02756 .55 L
s
.02381 .6 m
.02756 .6 L
s
.02381 .65 m
.02756 .65 L
s
.02381 .75 m
.02756 .75 L
s
.02381 .8 m
.02756 .8 L
s
.02381 .85 m
.02756 .85 L
s
.02381 .05 m
.02756 .05 L
s
.02381 .95 m
.02756 .95 L
s
.01 w
.02381 0 m
.02381 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.0075 w
.02381 .5 m
.02499 .5 L
.02605 .5 L
.02729 .49999 L
.02846 .49999 L
.03053 .49998 L
.03279 .49997 L
.03527 .49995 L
.0379 .49992 L
.04262 .49985 L
.04749 .49977 L
.05205 .49967 L
.06244 .49939 L
.07305 .49902 L
.08274 .49859 L
.10458 .49738 L
.14429 .49425 L
.18248 .49017 L
.22313 .48472 L
.26226 .47846 L
.30384 .47076 L
.34391 .46238 L
.38246 .4535 L
.42346 .4432 L
.46295 .43253 L
.50092 .4216 L
.54134 .40932 L
.58025 .39692 L
.62161 .38316 L
.66146 .36941 L
.69979 .35578 L
.74057 .34088 L
.77984 .32622 L
.81759 .31187 L
.85779 .29638 L
.89648 .28131 L
.93762 .26518 L
.97619 .25 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 576},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900002@2000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oo
oo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX0
0?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]Zoooo
nfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00
;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5
o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oo
oo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Zoooo
nfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oook
JP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oo
nfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`00
0?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Z
oooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?
oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00
;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5
o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oo
oo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Zoooo
nfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oook
JP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oo
nfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`00
0?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Z
oooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?
oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00
;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5
o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oo
oo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Zoooo
nfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oook
JP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP004Ooo
nfX5o`00O`Cooo]Z0ol007l6oookJP?o001o2?oonfX5o`000?oooo]ZoooonfX?oookJP004?oonfX7
o`00O`?ooo]Z0ol007l6oookJP?o001o2?oonfX5o`000?oooo]ZoooonfX?oookJP004?oonfX3o`00
O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l6oookJP?o001o2?oonfX5o`000?oooo]ZoooonfX?
oookJP000ooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX9o`00O`Oooo]Z1Ol0003ooook
J_oooo]Z3ooonfX000?ooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z2Ol007l7oookJPOo
0000oooonf[ooookJPgooo]Z000?oookJP?o001o0ooonfX3o`00O`Kooo]Z0_l007l3oookJP?o001o
2?oonfX5o`000?oooo]ZoooonfX?oookJP003ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oo
nfX3o`00O`Sooo]Z1Ol0003ooookJ_oooo]Z3ooonfX000oooo]Z0ol007l3oookJP?o001o1ooonfX3
o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol0003ooookJ_oooo]Z3ooonfX000oooo]Z0ol007l3
oookJP?o001o2?oonfX2o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX000oooo]Z0ol007l3oookJP?o001o2OoonfX5o`00O`Sooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
013ooo]Z0ol007l01?oonf[o001oo`00Ool007l:oookJPGo001o2?oonfX5o`000?oooo]ZoooonfX?
oookJP004?oonfX7o`00O`_ooo]Z1?l007l8oookJPGo0000oooonf[ooookJPoooo]Z000AoookJPGo
001o3OoonfX3o`00O`Sooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002ko
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0
003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooook
J_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002ko
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0
003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooook
J_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002ko
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0
003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooook
J_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_[ooo]Z1Ol0
000?oookJP00;_oonfX5o`000?oooo]ZmooonfX8o`0000oooo]Z000^oookJPGo0000oooonf[doook
JP_o00003ooonfX002kooo]Z1Ol0003ooookJ_;ooo]Z3Ol0000?oookJP00;_oonfX5o`000?oooo]Z
kooonfX>o`00017ooo]Z000^oookJPGo0000oooonf[]oookJPgo00005?oonfX002kooo]Z1Ol0003o
oookJ^[ooo]Z3Ol0000GoookJP00;_oonfX5o`000?oooo]ZiooonfX>o`0001Wooo]Z000^oookJPGo
0000oooonf[UoookJPgo00007?oonfX002kooo]Z1Ol0003ooookJ^;ooo]Z3_l0000NoookJP00;_oo
nfX5o`000?oooo]Zh?oonfX=o`00027ooo]Z000^oookJPGo0000oooonf[MoookJPgo00009?oonfX0
02kooo]Z1Ol0003ooookJ]_ooo]Z3Ol0000VoookJP00;_oonfX5o`000?oooo]ZfOoonfX<o`0002Wo
oo]Z000^oookJPGo0000oooonf[FoookJPgo0000:ooonfX002kooo]Z1Ol0003ooookJ]Cooo]Z3?l0
000^oookJP00;_oonfX5o`000?oooo]ZdOoonfX=o`00033ooo]Z000^oookJPGo0000oooonf[?oook
JPgo0000<_oonfX002kooo]Z1Ol0003ooookJ/cooo]Z3Ol0000eoookJP00;_oonfX5o`000?oooo]Z
b_oonfX=o`0003Oooo]Z000^oookJPGo0000oooonf[7oookJPgo0000>_oonfX002kooo]Z1Ol0003o
oookJ/Gooo]Z3Ol0000loookJP00;_oonfX5o`000?oooo]Z`_oonfX=o`0003oooo]Z000^oookJPGo
0000oooonf[0oookJPgo0000@OoonfX0017ooo]Z1Ol007l4oookJP?o001o00?ooo]Zo`00Ool007l0
1ol007l7oookJPGo0000oooonfZmoookJPgo0000A?oonfX0013ooo]Z1ol007l3oookJP?o001o00?o
oo]Zo`00Ool007l01ol007l7oookJPGo0000oooonfZkoookJPgo0000A_oonfX0013ooo]Z0ol007l0
1?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l<oookJPGo0000oooo
nfZhoookJPgo0000BOoonfX000?ooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Oooo]Z1?l007l;
oookJPGo0000oooonfZeoookJPko0000BooonfX000?ooo]Z2_l007l2oookJP?o001o0ooonfX3o`00
O`Sooo]Z1Ol007l9oookJPOo0000oooonfZ`oookJPko0000C_oonfX000oooo]Z0ol007l3oookJP?o
001o2_oonfX4o`00O`Sooo]Z1Ol0003ooookJ[3ooo]Z3_l0001@oookJP003ooonfX3o`00O`?ooo]Z
0ol007l;oookJP?o001o2?oonfX5o`000?oooo]Z[OoonfX>o`0005?ooo]Z000?oookJP?o001o0ooo
nfX3o`00O`cooo]Z0ol007l7oookJPGo0000oooonfZZoookJPko0000E_oonfX000oooo]Z0ol007l3
oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000oooonfZWoookJPko0000FOoonfX0
00oooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000oooonfZUoook
JPko0000FooonfX0013ooo]Z0ol007l01?oonf[o001oo`00Ool007l7oookJPCo001o0_oonfX3o`00
O`Oooo]Z1Ol0003ooookJZ;ooo]Z3_l0001NoookJP004?oonfX7o`00O`Sooo]Z1ol007l8oookJPGo
0000oooonfZPoookJPgo0000HOoonfX0017ooo]Z1Ol007l:oookJPGo001o2OoonfX5o`000?oooo]Z
WOoonfX=o`0006Cooo]Z000^oookJPGo0000oooonfZKoookJPgo0000I_oonfX002kooo]Z1Ol0003o
oookJYSooo]Z3Ol0001YoookJP00;_oonfX5o`000?oooo]ZU_oonfX=o`0006_ooo]Z000^oookJPGo
0000oooonfZCoookJPgo0000K_oonfX002kooo]Z1Ol0003ooookJY7ooo]Z3Ol0001`oookJP00;_oo
nfX5o`000?oooo]ZS_oonfX=o`0007?ooo]Z000^oookJPGo0000oooonfZ;oookJPko0000MOoonfX0
02kooo]Z1Ol0003ooookJXWooo]Z3Ol0001hoookJP00;_oonfX5o`000?oooo]ZQ_oonfX>o`0007[o
oo]Z000^oookJPGo0000oooonfZ4oookJPgo0000OOoonfX002kooo]Z1Ol0003ooookJX7ooo]Z3Ol0
0020oookJP00;_oonfX5o`000?oooo]ZO_oonfX>o`0008;ooo]Z000^oookJPGo0000oooonfYloook
JPgo0000QOoonfX002kooo]Z1Ol0003ooookJWWooo]Z3_l00027oookJP00;_oonfX5o`000?oooo]Z
M_oonfX>o`0008[ooo]Z000^oookJPGo0000oooonfYcoookJPko0000SOoonfX002kooo]Z1Ol0003o
oookJW7ooo]Z3_l0002?oookJP00;_oonfX5o`000?oooo]ZK_oonfX>o`0009;ooo]Z000^oookJPGo
0000oooonfY[oookJPko0000UOoonfX002kooo]Z1Ol0003ooookJVSooo]Z3_l0002HoookJP00;_oo
nfX5o`000?oooo]ZI_oonfX>o`0009[ooo]Z000^oookJPGo0000oooonfYSoookJPko0000WOoonfX0
02kooo]Z1Ol0003ooookJV3ooo]Z3_l0002PoookJP00;_oonfX5o`000?oooo]ZGOoonfX>o`000:?o
oo]Z000^oookJPGo0000oooonfYJoookJPoo0000YOoonfX002kooo]Z1Ol0003ooookJUOooo]Z3ol0
002XoookJP00;_oonfX5o`000?oooo]ZE?oonfX?o`000:_ooo]Z000^oookJPGo0000oooonfYAoook
JPoo0000[_oonfX002kooo]Z1Ol0003ooookJTkooo]Z3ol0002aoookJP00;_oonfX5o`000?oooo]Z
BooonfX?o`000;Cooo]Z000^oookJPGo0000oooonfY8oookJPoo0000]ooonfX002kooo]Z1Ol0003o
oookJTGooo]Z3ol0002joookJP00;_oonfX5o`000?oooo]Z@_oonfX?o`000;gooo]Z000^oookJPGo
0000oooonfXooookJPoo0000`?oonfX002kooo]Z1Ol0003ooookJScooo]Z3ol00033oookJP00;_oo
nfX5o`000?oooo]Z>OoonfX?o`000<Kooo]Z000^oookJPGo0000oooonfXfoookJPoo0000bOoonfX0
02kooo]Z1Ol0003ooookJS?ooo]Z3ol0003<oookJP00;_oonfX5o`000?oooo]Z<OoonfX>o`000<oo
oo]Z000^oookJPGo0000oooonfX^oookJPko0000d_oonfX002kooo]Z1Ol0003ooookJR_ooo]Z3_l0
003EoookJP00;_oonfX5o`000?oooo]Z:?oonfX>o`000=Sooo]Z000^oookJPGo0000oooonfXUoook
JPoo0000f_oonfX002kooo]Z1Ol0003ooookJR;ooo]Z3ol0003MoookJP00;_oonfX5o`000?oooo]Z
7_oonfX@o`000>3ooo]Z000^oookJPGo0000oooonfXKoookJQ3o0000hooonfX002kooo]Z1Ol0003o
oookJQOooo]Z4Ol0003VoookJP00;_oonfX5o`000?oooo]Z5?oonfXAo`000>Wooo]Z000^oookJPGo
0000oooonfX@oookJQ7o0000kOoonfX002kooo]Z1Ol0003ooookJPgooo]Z4Ol0003`oookJP00;_oo
nfX5o`000?oooo]Z2_oonfX@o`000?Cooo]Z000^oookJPGo0000oooonfX7oookJQ3o0000mooonfX0
02kooo]Z1Ol0003ooookJPCooo]Z3ol0003koookJP00;_oonfX5o`000?oooo]Z0OoonfX?o`000?ko
oo]Z000^oookJPGo0000oOoonfX?o`000?oooo]Z0_oonfX002kooo]Z1Ol0003ioookJQ3o0000oooo
nfX5oookJP00;_oonfX5o`000?Kooo]Z4?l0003ooookJPSooo]Z000^oookJPGo0000looonfX@o`00
0?oooo]Z2ooonfX002kooo]Z1Ol0003_oookJQ7o0000oooonfX>oookJP00;_oonfX5o`000>cooo]Z
4?l0003ooookJQ;ooo]Z000^oookJPGo0000jOoonfX@o`000?oooo]Z5OoonfX002kooo]Z1Ol0003U
oookJQ7o0000oooonfXHoookJP00;_oonfX5o`000>;ooo]Z4?l0003ooookJQcooo]Z000^oookJPGo
0000g_oonfXAo`000?oooo]Z7ooonfX002kooo]Z1Ol0003KoookJQ7o0000oooonfXRoookJP00;_oo
nfX5o`000=Oooo]Z4Ol0003ooookJRKooo]Z000^oookJPGo0000e?oonfXAo`000?oooo]Z:OoonfX0
02kooo]Z1Ol0003@oookJQ7o0000oooonfX]oookJP00;_oonfX5o`000<_ooo]Z4ol0003ooookJS3o
oo]Z000^oookJPGo0000aooonfXCo`000?oooo]Z=?oonfX002kooo]Z1Ol00033oookJQCo0000oooo
nfXgoookJP00;_oonfX5o`000;kooo]Z5Ol0003ooookJS_ooo]Z000^oookJPGo0000^_oonfXDo`00
0?oooo]Z@?oonfX002kooo]Z1Ol0002foookJQCo0000oooonfY4oookJP00;_oonfX5o`000;7ooo]Z
5Ol0003ooookJTSooo]Z000^oookJPGo0000[OoonfXDo`000?oooo]ZCOoonfX002kooo]Z1Ol0002Y
oookJQCo0000oooonfYAoookJP00;_oonfX5o`0005Wooo]Z1Ol007l4oookJP?o001o00?ooo]Zo`00
Ool007l01ol007leoookJQGo00001_oonfX5o`00O`Cooo]Z0ol007l6oookJP?o001oDOoonfX5o`00
O`Cooo]Z0ol007l3oookJPGo001oD_oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001oG?oonfX3o`00
O`oooo]Z000^oookJPGo0000F?oonfX7o`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`07o`00Oc3o
oo]Z5Ol0000:oookJPOo001o0ooonfX3o`00O`Kooo]Z0ol007m@oookJPOo001o0ooonfX3o`00O`;o
oo]Z1ol007m@oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007mKoookJP?o001o3ooonfX002kooo]Z
1Ol0001HoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o
001o;ooonfXGo`0000kooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1_oonfX3o`00
Oe3ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o0_oonfX3o`00O`;ooo]Z0ol007m?
oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z
0ol007mJoookJP?o001o3ooonfX002kooo]Z1Ol0001GoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0
07lYoookJQSo00004OoonfX3o`00O`?ooo]Z0ol007l6oookJPWo001oC_oonfX3o`00O`?ooo]Z0ol0
07l6oookJP?o001o0ooonfX3o`00Odkooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol0
07mJoookJP?o001o3ooonfX002kooo]Z1Ol0001GoookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol007lQ
oookJQWo00005_oonfX3o`00O`?ooo]Z0ol007l6oookJPWo001oC_oonfX3o`00O`?ooo]Z0ol007l6
oookJP?o001o0ooonfX3o`00Odkooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007mJ
oookJP?o001o3ooonfX002kooo]Z1Ol0001GoookJP?o001o0ooonfX3o`00O`[ooo]Z1?l007lKoook
JQWo00006ooonfX3o`00O`?ooo]Z0ol007l6oookJP;o001o0ooonfX3o`00Odoooo]Z0ol007l3oook
JP?o001o1_oonfX4o`00O`;ooo]Z0ol007m>oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oook
JP?o001oF_oonfX3o`00O`oooo]Z000^oookJPGo0000EooonfX3o`00O`?ooo]Z0ol007l;oookJP?o
001o5OoonfXIo`00027ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z0ol007m?oookJP?o
001o0ooonfX3o`00O`Kooo]Z2?l007m?oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007mKoookJP?o
001o3ooonfX002kooo]Z1Ol0001GoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l?oookJQWo0000
9_oonfX3o`00O`?ooo]Z0ol007l7oookJP?o001o00Cooo]Zo`00Ool007oo001oCooonfX3o`00O`?o
oo]Z0ol007l6oookJP?o001o00Cooo]Zo`00Ool007oo001oD?oonfX3o`00O`?ooo]Z0ol007l7oook
JPOo001oFooonfX3o`00O`oooo]Z000^oookJPGo0000EooonfX3o`00O`?ooo]Z0ol007l6oookJP?o
001o0ooonfX3o`00O`Wooo]Z6Ol0000/oookJP?o001o0ooonfX3o`00O`Sooo]Z0_l007l01?oonf[o
001oo`00Ool007m?oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007mDoookJP?o001o0ooonfX3o`00
O`Kooo]Z0ol007l3oookJP?o001oF_oonfX3o`00O`oooo]Z000^oookJPGo0000EooonfX3o`00O`?o
oo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Cooo]Z6Ol0000aoookJP?o001o0ooonfX3o`00O`Wo
oo]Z1Ol007m?oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007mDoookJP?o001o0ooonfX3o`00O`Ko
oo]Z0ol007l3oookJP?o001oEooonfX6o`00O`oooo]Z000^oookJPGo0000F?oonfX3o`00O`04oook
J_l007oo001oo`00O`Oooo]Z1?l007l2oookJP;o001o6?l0000hoookJP?o001o00Cooo]Zo`00Ool0
07oo001o2_oonfX5o`00Oe3ooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP?o001o0_oonfX3
o`00Odoooo]Z0ol007l01?oonf[o001oo`00Ool007l7oookJP?o001o0ooonfX3o`00OeOooo]Z1_l0
07l?oookJP00;_oonfX5o`0005Sooo]Z1ol007l8oookJP;o001o6?l0000moookJPOo001o2ooonfX4
o`00Oe3ooo]Z1ol007l8oookJPOo001oD?oonfX7o`00O`Sooo]Z1ol007mJoookJPCo001o3ooonfX0
02kooo]Z1Ol0001IoookJPGo001o1?oonfXIo`0004Cooo]Z1Ol007l=oookJP?o001oDOoonfX5o`00
O`_ooo]Z1?l007mBoookJPGo001o2_oonfX5o`00Oecooo]Z0ol007l?oookJP00;_oonfX5o`0005_o
oo]Z6ol0003ooookJYSooo]Z000^oookJPGo0000E?oonfXMo`000?oooo]ZWOoonfX002kooo]Z1Ol0
001;oookJR7o0000oooonfZRoookJP00;_oonfX5o`00047ooo]Z9?l0003ooookJZWooo]Z000^oook
JPGo0000=ooonfXWo`000?oooo]Z/?oonfX002kooo]Z1Ol0000/oookJR_o0000oooonfZgoookJP00
8Ooonf[oo`000?oo00008?l00001oookJP008Ooonf[oo`000?oo00008?l00001oookJP008Ooonf[o
o`000?oo00008?l00001oookJP008Ooonf[oo`000?oo00008?l00001oookJP008Ooonf[oo`000?oo
00008?l00001oookJP00;_oonfX5o`0006?ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]Z
oookJP1SoookJP03o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Z
oookJP0>oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?
oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00
;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5
o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oo
oo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Zoooo
nfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oook
JP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oo
nfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`00
0?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Z
oooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?
oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00
;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5
o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oo
oo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Zoooo
nfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oook
JP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oo
nfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`00
0?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Z
oooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?
oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00
;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5
o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oo
oo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Zoooo
nfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oook
JP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oo
nfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`00
0?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Z
oooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?
oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00
;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5
o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oo
oo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Zoooo
nfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oook
JP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oo
nfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`00
0?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Z
oooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?
oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00
;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5
o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oo
oo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Zoooo
nfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oook
JP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oo
nfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`00
0?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP004OoonfX5o`00O`Cooo]Z
0ol007l00ooonf[o001oo`00O`07o`00O`Oooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0013ooo]Z1ol0
07l3oookJP?o001o00?ooo]Zo`00Ool007l01ol007l7oookJPGo0000oooonf[ooookJPoooo]Z000@
oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o3?oo
nfX5o`000?oooo]ZoooonfX?oookJP003ooonfX3o`00O`?ooo]Z0ol007l7oookJPCo001o2ooonfX5
o`000?oooo]ZoooonfX?oookJP003ooonfX3o`00O`?ooo]Z0ol007l8oookJPGo001o2OoonfX7o`00
0?oooo]ZoooonfX=oookJP003ooonfX3o`00O`?ooo]Z0ol007l:oookJPCo001o2?oonfX5o`000?oo
oo]ZoooonfX?oookJP003ooonfX3o`00O`?ooo]Z0ol007l;oookJP?o001o2?oonfX5o`000?oooo]Z
oooonfX?oookJP003ooonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX5o`000?oooo]Zoooo
nfX?oookJP003ooonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX000oooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7oook
JPGo0000oooonf[ooookJPoooo]Z000@oookJP?o001o00Cooo]Zo`00Ool007oo001o1ooonfX4o`00
O`;ooo]Z0ol007l7oookJPGo0000oooonf[ooookJPoooo]Z000@oookJPOo001o2?oonfX7o`00O`So
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX0017ooo]Z1Ol007l:oookJPGo001o2OoonfX5o`000?oooo]Z
oooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?
oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00
;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5
o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oo
oo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Zoooo
nfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oook
JP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oo
nfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`00
0?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Z
oooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?
oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00
;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5
o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oo
oo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Zoooo
nfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oook
JP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oo
nfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`00
0?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Z
oooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?
oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00
;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5
o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oo
oo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Zoooo
nfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oook
JP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oo
nfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`00
0?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Z
oooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?
oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00
;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5
o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oo
oo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Zoooo
nfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oook
JP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oo
nfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`00
0?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Z
oooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?
oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00
;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5
o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oo
oo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Zoooo
nfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oook
JP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP004Ooo
nfX5o`00O`Cooo]Z0ol007l6oookJP?o001o2?oonfX5o`000?oooo]ZoooonfX?oookJP004?oonfX7
o`00O`?ooo]Z0ol007l6oookJP?o001o2?oonfX5o`000?oooo]ZoooonfX?oookJP004?oonfX3o`00
O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l6oookJP?o001o2?oonfX5o`000?oooo]ZoooonfX?
oookJP003ooonfX3o`00O`?ooo]Z0ol007l6oookJPWo001o1ooonfX5o`000?oooo]ZoooonfX?oook
JP003ooonfX3o`00O`?ooo]Z0ol007l6oookJPWo001o1ooonfX7o`000?oooo]ZoooonfX=oookJP00
3ooonfX3o`00O`?ooo]Z0ol007l6oookJP;o001o0ooonfX3o`00O`Sooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX000oooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z0ol007l8oookJPGo0000oooo
nf[ooookJPoooo]Z000?oookJP?o001o0ooonfX3o`00O`Oooo]Z0ol007l01?oonf[o001oo`00Ool0
07l8oookJPGo0000oooonf[ooookJPoooo]Z000?oookJP?o001o0ooonfX3o`00O`Sooo]Z0_l007l0
1?oonf[o001oo`00Ool007l8oookJPGo0000oooonf[ooookJPoooo]Z000?oookJP?o001o0ooonfX3
o`00O`Wooo]Z1Ol007l8oookJPGo0000oooonf[ooookJPoooo]Z000@oookJP?o001o00Cooo]Zo`00
Ool007oo001o2_oonfX5o`00O`Sooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0013ooo]Z1ol007l;oook
JPCo001o2?oonfX5o`000?oooo]ZoooonfX?oookJP004OoonfX5o`00O`gooo]Z0ol007l8oookJPGo
0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooo
nf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooook
JPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z
000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oook
JPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000
oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[o
oookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoo
oo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^
oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo
0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooo
nf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooook
JPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z
000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oook
JPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000
oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[o
oookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoo
oo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^
oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo
0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooo
nf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooook
JPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z
000^oookJPGo0000oooonf[ooookJPoooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oook
JP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oo
oo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX0
0?oooo]ZoooonfY2oookJP00\
\>"],
  ImageRangeCache->{{{0, 575}, {575, 0}} -> {-0.0952157, -0.535939, \
0.00195734, 0.00186413}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["Clamped Beam, Free end, unit applied load", "Text"],

Cell[BoxData[
    \(unitload[x_]\  := \ 1\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Plot", "[", 
      RowBox[{
        RowBox[{"Evaluate", "[", "\[IndentingNewLine]", 
          
          StyleBox[\(y[x] /. 
              BeamEquation[y, x, unitload, Clamped[y, 0, 0, 0], 
                FreeEnd[y, 1]]\),
            FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", "]"}], 
        ",", \({x, 0, 1}\), ",", \(PlotRange \[Rule] {\(-0.5\), 0.5}\), 
        ",", \(AspectRatio \[Rule] 1\)}], "]"}]], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.5 1 [
[.21429 .4875 -14.5 -20 ]
[.21429 .4875 14.5 0 ]
[.40476 .4875 -14.5 -20 ]
[.40476 .4875 14.5 0 ]
[.59524 .4875 -14.5 -20 ]
[.59524 .4875 14.5 0 ]
[.78571 .4875 -14.5 -20 ]
[.78571 .4875 14.5 0 ]
[.97619 .4875 -7 -20 ]
[.97619 .4875 7 0 ]
[.01131 .1 -41.9375 -10 ]
[.01131 .1 0 10 ]
[.01131 .3 -41.9375 -10 ]
[.01131 .3 0 10 ]
[.01131 .7 -29 -10 ]
[.01131 .7 0 10 ]
[.01131 .9 -29 -10 ]
[.01131 .9 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 1.005 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .5 m
.21429 .50625 L
s
gsave
.21429 .4875 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.40476 .5 m
.40476 .50625 L
s
gsave
.40476 .4875 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.59524 .5 m
.59524 .50625 L
s
gsave
.59524 .4875 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.78571 .5 m
.78571 .50625 L
s
gsave
.78571 .4875 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.97619 .5 m
.97619 .50625 L
s
gsave
.97619 .4875 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .5 m
.07143 .50375 L
s
.11905 .5 m
.11905 .50375 L
s
.16667 .5 m
.16667 .50375 L
s
.2619 .5 m
.2619 .50375 L
s
.30952 .5 m
.30952 .50375 L
s
.35714 .5 m
.35714 .50375 L
s
.45238 .5 m
.45238 .50375 L
s
.5 .5 m
.5 .50375 L
s
.54762 .5 m
.54762 .50375 L
s
.64286 .5 m
.64286 .50375 L
s
.69048 .5 m
.69048 .50375 L
s
.7381 .5 m
.7381 .50375 L
s
.83333 .5 m
.83333 .50375 L
s
.88095 .5 m
.88095 .50375 L
s
.92857 .5 m
.92857 .50375 L
s
.01 w
0 .5 m
1 .5 L
s
.25 Mabswid
.02381 .1 m
.03006 .1 L
s
gsave
.01131 .1 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.02381 .3 m
.03006 .3 L
s
gsave
.01131 .3 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.02381 .7 m
.03006 .7 L
s
gsave
.01131 .7 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.02381 .9 m
.03006 .9 L
s
gsave
.01131 .9 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .15 m
.02756 .15 L
s
.02381 .2 m
.02756 .2 L
s
.02381 .25 m
.02756 .25 L
s
.02381 .35 m
.02756 .35 L
s
.02381 .4 m
.02756 .4 L
s
.02381 .45 m
.02756 .45 L
s
.02381 .55 m
.02756 .55 L
s
.02381 .6 m
.02756 .6 L
s
.02381 .65 m
.02756 .65 L
s
.02381 .75 m
.02756 .75 L
s
.02381 .8 m
.02756 .8 L
s
.02381 .85 m
.02756 .85 L
s
.02381 .05 m
.02756 .05 L
s
.02381 .95 m
.02756 .95 L
s
.01 w
.02381 0 m
.02381 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.0075 w
.02381 .5 m
.02499 .5 L
.02605 .5 L
.02729 .5 L
.02846 .50001 L
.03053 .50001 L
.03279 .50002 L
.03527 .50004 L
.0379 .50005 L
.04262 .5001 L
.05205 .50022 L
.06244 .5004 L
.07293 .50064 L
.0842 .50096 L
.10458 .5017 L
.1458 .50376 L
.18551 .50643 L
.22371 .50955 L
.26435 .51343 L
.30348 .51765 L
.34506 .52259 L
.38513 .52775 L
.42368 .53303 L
.46468 .53895 L
.50417 .54491 L
.54214 .55084 L
.58257 .55733 L
.62148 .56373 L
.66284 .57065 L
.70268 .57742 L
.74101 .584 L
.78179 .59105 L
.82106 .59788 L
.85881 .60447 L
.89901 .6115 L
.9377 .61826 L
.97619 .625 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 576},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900002@2000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oo
oo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX0
0?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]Zoooo
nfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00
;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5
o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oo
oo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Zoooo
nfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oook
JP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oo
nfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`00
0?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Z
oooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?
oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00
;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5
o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oo
oo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Zoooo
nfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oook
JP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oo
nfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`00
0?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Z
oooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?
oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00
;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5
o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oo
oo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Zoooo
nfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oook
JP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP004Ooo
nfX5o`00O`Cooo]Z0ol007l6oookJP?o001o2?oonfX5o`000?oooo]ZoooonfX?oookJP004?oonfX7
o`00O`?ooo]Z0ol007l6oookJP?o001o2?oonfX5o`000?oooo]ZoooonfX?oookJP004?oonfX3o`00
O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l6oookJP?o001o2?oonfX5o`000?oooo]ZoooonfX?
oookJP000ooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX9o`00O`Oooo]Z1Ol0003ooook
J_oooo]Z3ooonfX000?ooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z2Ol007l7oookJPOo
0000oooonf[ooookJPgooo]Z000?oookJP?o001o0ooonfX3o`00O`Kooo]Z0_l007l3oookJP?o001o
2?oonfX5o`000?oooo]ZoooonfX?oookJP003ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oo
nfX3o`00O`Sooo]Z1Ol0003ooookJ_oooo]Z3ooonfX000oooo]Z0ol007l3oookJP?o001o1ooonfX3
o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol0003ooookJ_oooo]Z3ooonfX000oooo]Z0ol007l3
oookJP?o001o2?oonfX2o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX000oooo]Z0ol007l3oookJP?o001o2OoonfX5o`00O`Sooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
013ooo]Z0ol007l01?oonf[o001oo`00Ool007l:oookJPGo001o2?oonfX5o`000?oooo]ZoooonfX?
oookJP004?oonfX7o`00O`_ooo]Z1?l007l8oookJPGo0000oooonf[ooookJPoooo]Z000AoookJPGo
001o3OoonfX3o`00O`Sooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002ko
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0
003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooook
J_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002ko
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0
003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooook
J_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002ko
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0
003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooook
J_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002ko
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0
003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooook
J_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002ko
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX0017ooo]Z1Ol007l4oookJP?o001o00?ooo]Zo`00Ool007l0
1ol007l7oookJPGo0000oooonf[ooookJPoooo]Z000@oookJPOo001o0ooonfX3o`00O`03oookJ_l0
07oo001o00Oo001o1ooonfX5o`000?oooo]ZoooonfX?oookJP004?oonfX3o`00O`04oookJ_l007oo
001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`cooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX000?ooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Oooo]Z1?l007l;oookJPGo0000oooonf[o
oookJPoooo]Z0003oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l8oookJPGo001o2OoonfX7o`00
0?oooo]ZoooonfX=oookJP003ooonfX3o`00O`?ooo]Z0ol007l:oookJPCo001o2?oonfX5o`000?oo
oo]ZoooonfX?oookJP003ooonfX3o`00O`?ooo]Z0ol007l;oookJP?o001o2?oonfX5o`000?oooo]Z
oooonfX?oookJP003ooonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX5o`000?oooo]Zoooo
nfX?oookJP003ooonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX000oooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7oook
JPGo0000oooonf[ooookJPoooo]Z000@oookJP?o001o00Cooo]Zo`00Ool007oo001o1ooonfX4o`00
O`;ooo]Z0ol007l7oookJPGo0000oooonf[ooookJPoooo]Z000@oookJPOo001o2?oonfX7o`00O`So
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX0017ooo]Z1Ol007l:oookJPGo001o2OoonfX5o`000?oooo]Z
oooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?
oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00
;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5
o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oo
oo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Zoooo
nfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oook
JP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oo
nfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`00
0?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Z
oooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?
oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00
;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5
o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oo
oo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Zoooo
nfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oook
JP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oo
nfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`00
0?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Z
oooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?
oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00
;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5
o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oo
oo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Zoooo
nfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oook
JP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oo
nfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`00
0?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Z
oooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?
oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00
;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5
o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oo
oo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Zoooo
nfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oook
JP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oo
nfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`00
05Wooo]Z1Ol007l4oookJP?o001o00?ooo]Zo`00Ool007l01ol007m@oookJPGo001o1?oonfX3o`00
O`Kooo]Z0ol007mAoookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007mBoookJPGo001o1?oonfX3o`00
O`?ooo]Z1Ol007mLoookJP?o001o3ooonfX002kooo]Z1Ol0001HoookJPOo001o0ooonfX3o`00O`03
oookJ_l007oo001o00Oo001oCooonfX7o`00O`?ooo]Z0ol007l6oookJP?o001oD?oonfX7o`00O`?o
oo]Z0ol007l2oookJPOo001oD?oonfX7o`00O`?ooo]Z0ol007l2oookJPOo001oFooonfX3o`00O`oo
oo]Z000^oookJPGo0000F?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o
001oo`00O`02o`00OeCooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1_oonfX3o`00
Oe3ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o0_oonfX3o`00O`;ooo]Z0ol007m?
oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z
0ol007mJoookJP?o001o3ooonfX002kooo]Z1Ol0001GoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0
07mBoookJP?o001o0ooonfX3o`00O`Kooo]Z2Ol007m>oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol0
07l3oookJP?o001oC_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00Oe[ooo]Z0ol0
07l?oookJP00;_oonfX5o`0005Oooo]Z0ol007l3oookJP?o001o2?oonfX5o`00Oe3ooo]Z0ol007l3
oookJP?o001o1_oonfX9o`00Odkooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007m>
oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001oF_oonfX3o`00O`oooo]Z000^oook
JPGo0000EooonfX3o`00O`?ooo]Z0ol007l:oookJPCo001oCooonfX3o`00O`?ooo]Z0ol007l6oook
JP;o001o0ooonfX3o`00Odoooo]Z0ol007l3oookJP?o001o1_oonfX4o`00O`;ooo]Z0ol007m>oook
JP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001oF_oonfX3o`00O`oooo]Z000^oookJPGo
0000EooonfX3o`00O`?ooo]Z0ol007l;oookJP?o001oCooonfX3o`00O`?ooo]Z0ol007l7oookJP;o
001o0_oonfX3o`00Odoooo]Z0ol007l3oookJP?o001o1_oonfX8o`00Odoooo]Z0ol007l3oookJP?o
001o1ooonfX7o`00Oe_ooo]Z0ol007l?oookJP00;_oonfX5o`0005Oooo]Z0ol007l3oookJP?o001o
3?oonfX3o`00Odkooo]Z0ol007l3oookJP?o001o1ooonfX3o`00O`04oookJ_l007oo001oo`00Odoo
oo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`04oookJ_l007oo001oo`00Oe3ooo]Z0ol007l3oook
JP?o001o1ooonfX7o`00Oe_ooo]Z0ol007l?oookJP00;_oonfX5o`0005Oooo]Z0ol007l3oookJP?o
001o1_oonfX3o`00O`?ooo]Z0ol007m>oookJP?o001o0ooonfX3o`00O`Sooo]Z0_l007l01?oonf[o
001oo`00Ool007m?oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007mDoookJP?o001o0ooonfX3o`00
O`Kooo]Z0ol007l3oookJP?o001oF_oonfX3o`00O`oooo]Z000^oookJPGo0000EooonfX3o`00O`?o
oo]Z0ol007l6oookJP?o001o0ooonfX3o`00Odkooo]Z0ol007l3oookJP?o001o2OoonfX5o`00Odoo
oo]Z0ol007l3oookJP?o001o1_oonfX3o`00OeCooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?o
oo]Z0ol007mGoookJPKo001o3ooonfX002kooo]Z1Ol0001HoookJP?o001o00Cooo]Zo`00Ool007oo
001o1ooonfX4o`00O`;ooo]Z0ol007m?oookJP?o001o00Cooo]Zo`00Ool007oo001o2_oonfX5o`00
Oe3ooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP?o001o0_oonfX3o`00Odoooo]Z0ol007l0
1?oonf[o001oo`00Ool007l7oookJP?o001o0ooonfX3o`00OeOooo]Z1_l007l?oookJP00;_oonfX5
o`0005Sooo]Z1ol007l8oookJPOo001oD?oonfX7o`00O`_ooo]Z1?l007m@oookJPOo001o2?oonfX7
o`00Oe3ooo]Z1ol007l8oookJPOo001oF_oonfX4o`00O`oooo]Z000^oookJPGo0000FOoonfX5o`00
O`[ooo]Z1Ol007mBoookJPGo001o3OoonfX3o`00Oe7ooo]Z1Ol007l;oookJPCo001oD_oonfX5o`00
O`[ooo]Z1Ol007mLoookJP?o001o3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX0027ooo]Zool0003oo`00023o00000OoonfX0027ooo]Zool0003oo`00023o00000Ooo
nfX0027ooo]Zool0003oo`00023o00000OoonfX0027ooo]Zool0003oo`00023o00000OoonfX0027o
oo]Zool0003oo`00023o00000OoonfX002kooo]Z1Ol0000JoookJT_o0000IOoonfX00ol0003ooo]Z
oookJP1SoookJP03o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Z
oookJP0>oookJP00;_oonfX5o`0003?ooo]Z?Ol0003ooookJYkooo]Z000^oookJPGo0000BOoonfXb
o`000?oooo]ZTooonfX002kooo]Z1Ol0001HoookJRgo0000oooonfZ9oookJP00;_oonfX5o`0006;o
oo]Z;_l0003ooookJWkooo]Z000^oookJPGo0000KOoonfX/o`000?oooo]ZMOoonfX002kooo]Z1Ol0
001hoookJRSo0000oooonfY^oookJP00;_oonfX5o`0008;ooo]Z9Ol0003ooookJVOooo]Z000^oook
JPGo0000SOoonfXRo`000?oooo]ZGooonfX002kooo]Z1Ol0002FoookJR3o0000oooonfYHoookJP00
;_oonfX5o`0009gooo]Z8?l0003ooookJU7ooo]Z000^oookJPGo0000Y?oonfXQo`000?oooo]ZBOoo
nfX002kooo]Z1Ol0002/oookJR3o0000oooonfY2oookJP00;_oonfX5o`000;?ooo]Z8?l0003ooook
JS_ooo]Z000^oookJPGo0000^_oonfXPo`000?oooo]Z=?oonfX002kooo]Z1Ol00032oookJQoo0000
oooonfX]oookJP00;_oonfX5o`000<Wooo]Z7ol0003ooookJRKooo]Z000^oookJPGo0000d?oonfXP
o`000?oooo]Z7_oonfX002kooo]Z1Ol0003GoookJR3o0000oooonfXGoookJP00;_oonfX5o`000=ko
oo]Z8?l0003ooookJQ3ooo]Z000^oookJPGo0000iOoonfXOo`000?oooo]Z2_oonfX002kooo]Z1Ol0
003]oookJQko0000oooonfX3oookJP00;_oonfX5o`000?Cooo]Z7_l0003koookJP00;_oonfX5o`00
0?_ooo]Z7Ol0003eoookJP00;_oonfX5o`000?oooo]Z0_oonfXLo`000?3ooo]Z000^oookJPGo0000
oooonfX9oookJQ_o0000j_oonfX002kooo]Z1Ol0003ooookJQ3ooo]Z6Ol0003UoookJP00;_oonfX5
o`000?oooo]Z5_oonfXJo`000=kooo]Z000^oookJPGo0000oooonfXKoookJQco0000eooonfX002ko
oo]Z1Ol0003ooookJR7ooo]Z7Ol0003@oookJP00;_oonfX5o`000?oooo]Z9_oonfXNo`000<[ooo]Z
000^oookJPGo0000oooonfX]oookJQco0000aOoonfX002kooo]Z1Ol0003ooookJSCooo]Z6ol0002o
oookJP00;_oonfX5o`000?oooo]Z>ooonfXIo`000;[ooo]Z000^oookJPGo0000oooonfY1oookJQWo
0000]?oonfX002kooo]Z1Ol0003ooookJTKooo]Z6Ol0002_oookJP00;_oonfX5o`000?oooo]ZC?oo
nfXHo`000:[ooo]Z000^oookJPGo0000oooonfYAoookJQSo0000YOoonfX002kooo]Z1Ol0003ooook
JUOooo]Z6Ol0002NoookJP00;_oonfX5o`000?oooo]ZG?oonfXKo`0009Oooo]Z000^oookJPGo0000
oooonfYQoookJQgo0000T?oonfX002kooo]Z1Ol0003ooookJVKooo]Z7_l0002:oookJP00;_oonfX5
o`000?oooo]ZKOoonfXLo`0008Gooo]Z000^oookJPGo0000oooonfYdoookJQ_o0000OooonfX002ko
oo]Z1Ol0003ooookJW_ooo]Z6Ol0001joookJP00;_oonfX5o`000?oooo]ZPOoonfXIo`0007Cooo]Z
000^oookJPGo0000oooonfZ6oookJQWo0000KooonfX002kooo]Z1Ol0003ooookJXcooo]Z6?l0001Z
oookJP00;_oonfX5o`000?oooo]ZTOoonfXHo`0006Gooo]Z000^oookJPGo0000oooonfZGoookJQSo
0000GooonfX002kooo]Z1Ol0003ooookJYcooo]Z6_l0001HoookJP00;_oonfX5o`000?oooo]ZXOoo
nfXLo`00057ooo]Z000^oookJPGo0000oooonfZVoookJQgo0000BooonfX002kooo]Z1Ol0003ooook
JZcooo]Z7?l00016oookJP00;_oonfX5o`000?oooo]Z/ooonfXKo`00043ooo]Z000^oookJPGo0000
oooonfZjoookJQWo0000>ooonfX002kooo]Z1Ol0003ooookJ/3ooo]Z6Ol0000eoookJP00;_oonfX5
o`000?oooo]ZaOoonfXKo`0002kooo]Z000^oookJPGo0000oooonf[;oookJQco00009ooonfX002ko
oo]Z1Ol0003ooookJ]3ooo]Z7Ol0000QoookJP00;_oonfX5o`000?oooo]Ze_oonfXLo`0001cooo]Z
000^oookJPGo0000oooonf[MoookJQ[o00005ooonfX002kooo]Z1Ol0003ooookJ^Cooo]Z6?l0000B
oookJP00;_oonfX5o`000?oooo]Zj_oonfXEo`0000oooo]Z000^oookJPGo0000oooonf[_oookJQ3o
00003ooonfX002kooo]Z1Ol0003ooookJ_Cooo]Z2ol0000?oookJP00;_oonfX5o`000?oooo]ZnOoo
nfX6o`0000oooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooook
JPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z
000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oook
JPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000
oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[o
oookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoo
oo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^
oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo
0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooo
nf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooook
JPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z
000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oook
JPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000
oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[o
oookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoo
oo]Z000AoookJPGo001o1?oonfX3o`00O`03oookJ_l007oo001o00Oo001o1ooonfX5o`000?oooo]Z
oooonfX?oookJP004?oonfX7o`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`07o`00O`Oooo]Z1Ol0
003ooookJ_oooo]Z3ooonfX0013ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?o
oo]Zo`00Ool007l00_l007l<oookJPGo0000oooonf[ooookJPoooo]Z000?oookJP?o001o0ooonfX3
o`00O`Oooo]Z1?l007l;oookJPGo0000oooonf[ooookJPoooo]Z000?oookJP?o001o0ooonfX3o`00
O`Sooo]Z1Ol007l9oookJPOo0000oooonf[ooookJPgooo]Z000?oookJP?o001o0ooonfX3o`00O`[o
oo]Z1?l007l8oookJPGo0000oooonf[ooookJPoooo]Z000?oookJP?o001o0ooonfX3o`00O`_ooo]Z
0ol007l8oookJPGo0000oooonf[ooookJPoooo]Z000?oookJP?o001o0ooonfX3o`00O`cooo]Z0ol0
07l7oookJPGo0000oooonf[ooookJPoooo]Z000?oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3
oookJP?o001o1ooonfX5o`000?oooo]ZoooonfX?oookJP003ooonfX3o`00O`?ooo]Z0ol007l6oook
JP?o001o0ooonfX3o`00O`Oooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0013ooo]Z0ol007l01?oonf[o
001oo`00Ool007l7oookJPCo001o0_oonfX3o`00O`Oooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0013o
oo]Z1ol007l8oookJPOo001o2?oonfX5o`000?oooo]ZoooonfX?oookJP004OoonfX5o`00O`[ooo]Z
1Ol007l9oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^
oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo
0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooo
nf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooook
JPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z
000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oook
JPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000
oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[o
oookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoo
oo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^
oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo
0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooo
nf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooook
JPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z
000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oook
JPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000
oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[o
oookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoo
oo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^
oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo
0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooo
nf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooook
JPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z
000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oook
JPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000
oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[o
oookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoo
oo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^
oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo
0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooo
nf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooook
JPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z
000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oook
JPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000
oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[o
oookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoo
oo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^
oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo
0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooo
nf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooook
JPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z
000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oook
JPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000
oooonf[ooookJPoooo]Z000AoookJPGo001o1?oonfX3o`00O`Kooo]Z0ol007l8oookJPGo0000oooo
nf[ooookJPoooo]Z000@oookJPOo001o0ooonfX3o`00O`Kooo]Z0ol007l8oookJPGo0000oooonf[o
oookJPoooo]Z000@oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l8
oookJPGo0000oooonf[ooookJPoooo]Z000?oookJP?o001o0ooonfX3o`00O`Kooo]Z2Ol007l7oook
JPGo0000oooonf[ooookJPoooo]Z000?oookJP?o001o0ooonfX3o`00O`Kooo]Z2Ol007l7oookJPOo
0000oooonf[ooookJPgooo]Z000?oookJP?o001o0ooonfX3o`00O`Kooo]Z0_l007l3oookJP?o001o
2?oonfX5o`000?oooo]ZoooonfX?oookJP003ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oo
nfX3o`00O`Sooo]Z1Ol0003ooookJ_oooo]Z3ooonfX000oooo]Z0ol007l3oookJP?o001o1ooonfX3
o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol0003ooookJ_oooo]Z3ooonfX000oooo]Z0ol007l3
oookJP?o001o2?oonfX2o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX000oooo]Z0ol007l3oookJP?o001o2OoonfX5o`00O`Sooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
013ooo]Z0ol007l01?oonf[o001oo`00Ool007l:oookJPGo001o2?oonfX5o`000?oooo]ZoooonfX?
oookJP004?oonfX7o`00O`_ooo]Z1?l007l8oookJPGo0000oooonf[ooookJPoooo]Z000AoookJPGo
001o3OoonfX3o`00O`Sooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002ko
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0
003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooook
J_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002ko
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0
003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooook
J_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX00?oooo]ZoooonfY2
oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooo
nf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;o
oo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooook
J_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oo
nfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 575}, {575, 0}} -> {-0.0952157, -0.535939, \
0.00195734, 0.00186413}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["Clamped Beam, Point load at end, Point load at Middle", "Text"],

Cell[BoxData[
    \(midload[x_]\  := \ \(-10\) DiracDelta[x\  - \ 1/2]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Plot", "[", 
      RowBox[{
        RowBox[{"Evaluate", "[", "\[IndentingNewLine]", 
          
          StyleBox[\(y[x] /. 
              BeamEquation[y, x, midload, Clamped[y, 0, 0, 0], 
                PointLoad[y, 1, 0, 0]]\),
            FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", "]"}], 
        ",", \({x, 0, 1}\), ",", \(PlotRange \[Rule] {\(-0.5\), 0.5}\), 
        ",", \(AspectRatio \[Rule] 1\)}], "]"}]], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.5 1 [
[.21429 .4875 -14.5 -20 ]
[.21429 .4875 14.5 0 ]
[.40476 .4875 -14.5 -20 ]
[.40476 .4875 14.5 0 ]
[.59524 .4875 -14.5 -20 ]
[.59524 .4875 14.5 0 ]
[.78571 .4875 -14.5 -20 ]
[.78571 .4875 14.5 0 ]
[.97619 .4875 -7 -20 ]
[.97619 .4875 7 0 ]
[.01131 .1 -41.9375 -10 ]
[.01131 .1 0 10 ]
[.01131 .3 -41.9375 -10 ]
[.01131 .3 0 10 ]
[.01131 .7 -29 -10 ]
[.01131 .7 0 10 ]
[.01131 .9 -29 -10 ]
[.01131 .9 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 1.005 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .5 m
.21429 .50625 L
s
gsave
.21429 .4875 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.40476 .5 m
.40476 .50625 L
s
gsave
.40476 .4875 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.59524 .5 m
.59524 .50625 L
s
gsave
.59524 .4875 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.78571 .5 m
.78571 .50625 L
s
gsave
.78571 .4875 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.97619 .5 m
.97619 .50625 L
s
gsave
.97619 .4875 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .5 m
.07143 .50375 L
s
.11905 .5 m
.11905 .50375 L
s
.16667 .5 m
.16667 .50375 L
s
.2619 .5 m
.2619 .50375 L
s
.30952 .5 m
.30952 .50375 L
s
.35714 .5 m
.35714 .50375 L
s
.45238 .5 m
.45238 .50375 L
s
.5 .5 m
.5 .50375 L
s
.54762 .5 m
.54762 .50375 L
s
.64286 .5 m
.64286 .50375 L
s
.69048 .5 m
.69048 .50375 L
s
.7381 .5 m
.7381 .50375 L
s
.83333 .5 m
.83333 .50375 L
s
.88095 .5 m
.88095 .50375 L
s
.92857 .5 m
.92857 .50375 L
s
.01 w
0 .5 m
1 .5 L
s
.25 Mabswid
.02381 .1 m
.03006 .1 L
s
gsave
.01131 .1 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.02381 .3 m
.03006 .3 L
s
gsave
.01131 .3 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.02381 .7 m
.03006 .7 L
s
gsave
.01131 .7 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.02381 .9 m
.03006 .9 L
s
gsave
.01131 .9 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .15 m
.02756 .15 L
s
.02381 .2 m
.02756 .2 L
s
.02381 .25 m
.02756 .25 L
s
.02381 .35 m
.02756 .35 L
s
.02381 .4 m
.02756 .4 L
s
.02381 .45 m
.02756 .45 L
s
.02381 .55 m
.02756 .55 L
s
.02381 .6 m
.02756 .6 L
s
.02381 .65 m
.02756 .65 L
s
.02381 .75 m
.02756 .75 L
s
.02381 .8 m
.02756 .8 L
s
.02381 .85 m
.02756 .85 L
s
.02381 .05 m
.02756 .05 L
s
.02381 .95 m
.02756 .95 L
s
.01 w
.02381 0 m
.02381 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.0075 w
.02381 .5 m
.02499 .5 L
.02605 .49999 L
.02729 .49999 L
.02846 .49998 L
.03053 .49995 L
.03279 .49992 L
.03527 .49987 L
.0379 .4998 L
.04262 .49964 L
.05205 .49921 L
.06244 .49853 L
.07293 .49766 L
.0842 .49652 L
.10458 .49396 L
.1458 .48703 L
.18551 .47858 L
.22371 .46929 L
.26435 .45866 L
.30348 .44817 L
.34506 .43731 L
.38513 .42763 L
.42368 .41954 L
.44323 .41604 L
.46468 .41277 L
.48511 .41026 L
.50417 .40853 L
.51462 .40784 L
.51977 .40756 L
.52452 .40735 L
.52875 .40719 L
.53341 .40705 L
.5381 .40695 L
.54067 .4069 L
.54308 .40687 L
.54426 .40686 L
.54551 .40685 L
.5467 .40684 L
.54777 .40684 L
.54904 .40683 L
.54976 .40683 L
.55042 .40683 L
.55163 .40683 L
.55291 .40684 L
.55414 .40684 L
.55546 .40685 L
.55784 .40687 L
.56067 .40691 L
.56326 .40696 L
.5678 .40706 L
Mistroke
.57275 .40721 L
.58177 .40758 L
.59211 .40813 L
.60148 .40877 L
.62246 .41062 L
.64175 .41282 L
.66258 .41569 L
.70364 .42278 L
.74318 .43117 L
.7812 .44049 L
.82168 .45152 L
.86064 .46302 L
.90205 .47592 L
.94195 .48879 L
.97619 .5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 576},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900002@2000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oo
oo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX0
0?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]Zoooo
nfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00
;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5
o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oo
oo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Zoooo
nfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oook
JP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oo
nfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`00
0?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Z
oooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?
oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00
;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5
o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oo
oo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Zoooo
nfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oook
JP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oo
nfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`00
0?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Z
oooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?
oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00
;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5
o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oo
oo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Zoooo
nfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oook
JP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP004Ooo
nfX5o`00O`Cooo]Z0ol007l6oookJP?o001o2?oonfX5o`000?oooo]ZoooonfX?oookJP004?oonfX7
o`00O`?ooo]Z0ol007l6oookJP?o001o2?oonfX5o`000?oooo]ZoooonfX?oookJP004?oonfX3o`00
O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l6oookJP?o001o2?oonfX5o`000?oooo]ZoooonfX?
oookJP000ooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX9o`00O`Oooo]Z1Ol0003ooook
J_oooo]Z3ooonfX000?ooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z2Ol007l7oookJPOo
0000oooonf[ooookJPgooo]Z000?oookJP?o001o0ooonfX3o`00O`Kooo]Z0_l007l3oookJP?o001o
2?oonfX5o`000?oooo]ZoooonfX?oookJP003ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oo
nfX3o`00O`Sooo]Z1Ol0003ooookJ_oooo]Z3ooonfX000oooo]Z0ol007l3oookJP?o001o1ooonfX3
o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol0003ooookJ_oooo]Z3ooonfX000oooo]Z0ol007l3
oookJP?o001o2?oonfX2o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX000oooo]Z0ol007l3oookJP?o001o2OoonfX5o`00O`Sooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
013ooo]Z0ol007l01?oonf[o001oo`00Ool007l:oookJPGo001o2?oonfX5o`000?oooo]ZoooonfX?
oookJP004?oonfX7o`00O`_ooo]Z1?l007l8oookJPGo0000oooonf[ooookJPoooo]Z000AoookJPGo
001o3OoonfX3o`00O`Sooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002ko
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0
003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooook
J_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002ko
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0
003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooook
J_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002ko
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0
003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooook
J_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002ko
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0
003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooook
J_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002ko
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX0017ooo]Z1Ol007l4oookJP?o001o00?ooo]Zo`00Ool007l0
1ol007l7oookJPGo0000oooonf[ooookJPoooo]Z000@oookJPOo001o0ooonfX3o`00O`03oookJ_l0
07oo001o00Oo001o1ooonfX5o`000?oooo]ZoooonfX?oookJP004?oonfX3o`00O`04oookJ_l007oo
001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`cooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX000?ooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Oooo]Z1?l007l;oookJPGo0000oooonf[o
oookJPoooo]Z0003oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l8oookJPGo001o2OoonfX7o`00
0?oooo]ZoooonfX=oookJP003ooonfX3o`00O`?ooo]Z0ol007l:oookJPCo001o2?oonfX5o`000?oo
oo]ZoooonfX?oookJP003ooonfX3o`00O`?ooo]Z0ol007l;oookJP?o001o2?oonfX5o`000?oooo]Z
oooonfX?oookJP003ooonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX5o`000?oooo]Zoooo
nfX?oookJP003ooonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX000oooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7oook
JPGo0000oooonf[ooookJPoooo]Z000@oookJP?o001o00Cooo]Zo`00Ool007oo001o1ooonfX4o`00
O`;ooo]Z0ol007l7oookJPGo0000oooonf[ooookJPoooo]Z000@oookJPOo001o2?oonfX7o`00O`So
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX0017ooo]Z1Ol007l:oookJPGo001o2OoonfX5o`000?oooo]Z
oooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?
oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00
;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5
o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oo
oo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Zoooo
nfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oook
JP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oo
nfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`00
0?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Z
oooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?
oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00
;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5
o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oo
oo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Zoooo
nfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oook
JP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oo
nfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`00
0?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Z
oooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?
oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00
;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5
o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Z1OoonfXYo`000>3ooo]Z000^oookJPGo
0000n?oonfY3o`000=;ooo]Z000^oookJPGo0000k_oonfYHo`000<Oooo]Z000^oookJPGo0000iOoo
nfYYo`000;oooo]Z000^oookJPGo0000gooonfXXo`0002?ooo]Z:Ol0002joookJP00;_oonfX5o`00
0=[ooo]Z8Ol0000moookJR7o0000]?oonfX002kooo]Z1Ol0003EoookJQco0000D_oonfXKo`000:oo
oo]Z000^oookJPGo0000cooonfXIo`0006?ooo]Z6Ol0002YoookJP00;_oonfX5o`000<[ooo]Z6?l0
001^oookJQWo0000Y?oonfX002kooo]Z1Ol00035oookJQSo0000NOoonfXIo`0009kooo]Z000^oook
JPGo0000`?oonfXHo`0008?ooo]Z6Ol0002IoookJP00;_oonfX5o`000;_ooo]Z5ol0002?oookJQSo
0000U?oonfX002kooo]Z1Ol0002foookJQOo0000VOoonfXHo`0008oooo]Z000^oookJPGo0000/_oo
nfXFo`000:Cooo]Z5ol0002:oookJP00;_oonfX5o`000:kooo]Z5Ol0002^oookJQKo0000Q_oonfX0
02kooo]Z1Ol0002YoookJQGo0000^?oonfXEo`0008;ooo]Z000^oookJPGo0000YOoonfXDo`000<;o
oo]Z5?l0001noookJP00;_oonfX5o`000:7ooo]Z5?l0003;oookJQ?o0000N_oonfX002kooo]Z1Ol0
002NoookJQ?o0000dooonfXCo`0007Kooo]Z000^oookJPGo0000V_oonfXBo`000=cooo]Z4ol0001b
oookJP00;_oonfX5o`0009Kooo]Z4_l0003ToookJQ;o0000KooonfX002kooo]Z1Ol0002CoookJQ7o
0000k?oonfXBo`0006_ooo]Z000^oookJPGo0000SooonfXBo`000??ooo]Z4_l0001WoookJP00;_oo
nfX5o`0008cooo]Z4Ol0003koookJQ7o0000I?oonfX002kooo]Z1Ol00028oookJQ7o0000oooonfX3
oookJQ;o0000H?oonfX002kooo]Z1Ol00025oookJQ7o0000oooonfX:oookJQ7o0000GOoonfX002ko
oo]Z1Ol00021oookJQ7o0000oooonfXBoookJQ7o0000FOoonfX002kooo]Z1Ol0001noookJQ7o0000
oooonfXHoookJQ7o0000E_oonfX002kooo]Z1Ol0001joookJQ7o0000oooonfXPoookJQ7o0000D_oo
nfX002kooo]Z1Ol0001foookJQ;o0000oooonfXVoookJQ7o0000CooonfX002kooo]Z1Ol0001Ioook
JPGo001o1?oonfX3o`00O`03oookJ_l007oo001o00Oo001o1?oonfXAo`0003_ooo]Z1Ol007l4oook
JP?o001o1_oonfX3o`00Oe7ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00Oe;ooo]Z1Ol007l4oook
JP?o001o0ooonfX5o`00Oa;ooo]Z4Ol0000ioookJP?o001o3ooonfX002kooo]Z1Ol0001HoookJPOo
001o0ooonfX3o`00O`03oookJ_l007oo001o00Oo001o4_l0000moookJPOo001o0ooonfX3o`00O`Ko
oo]Z0ol007m@oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007m@oookJPOo001o0ooonfX3o`00O`;o
oo]Z1ol007lDoookJQ7o0000=_oonfX3o`00O`oooo]Z000^oookJPGo0000F?oonfX3o`00O`04oook
J_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`03oookJ_l0003o0000013o
0000@OoonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l6oookJP?o001oD?oonfX3o`00
O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l2oookJP?o001o0_oonfX3o`00Odoooo]Z0ol007l0
1?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00OaOooo]Z
4?l0000coookJP?o001o3ooonfX002kooo]Z1Ol0001GoookJP?o001o0ooonfX3o`00O`Oooo]Z00?o
001oo`000?l000003ol00014oookJP?o001o0ooonfX3o`00O`Kooo]Z2Ol007m>oookJP?o001o0ooo
nfX3o`00O`Kooo]Z0ol007l3oookJP?o001oC_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooo
nfX3o`00Oa[ooo]Z4?l0000`oookJP?o001o3ooonfX002kooo]Z1Ol0001GoookJP?o001o0ooonfX3
o`00O`Cooo]Z4_l00017oookJP?o001o0ooonfX3o`00O`Kooo]Z2Ol007m>oookJP?o001o0ooonfX3
o`00O`Kooo]Z0ol007l3oookJP?o001oC_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3
o`00Oakooo]Z3ol0000]oookJP?o001o3ooonfX002kooo]Z1Ol0001GoookJP?o001o0ooonfX3o`00
Oa;o0000BooonfX3o`00O`?ooo]Z0ol007l6oookJP;o001o0ooonfX3o`00Odoooo]Z0ol007l3oook
JP?o001o1_oonfX4o`00O`;ooo]Z0ol007m>oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oook
JP?o001o8OoonfX?o`0002[ooo]Z0ol007l?oookJP00;_oonfX5o`0005Oooo]Z0ol007l2oookJQ;o
0000CooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX3o`00Odoooo]Z0ol007l3oookJP?o
001o1_oonfX8o`00Odoooo]Z0ol007l3oookJP?o001o1ooonfX7o`00ObGooo]Z3ol0000WoookJP?o
001o3ooonfX002kooo]Z1Ol0001GoookJP03o`00Ool0003o0000017o000000Cooo]Zo`00Ool007oo
001oC_oonfX3o`00O`?ooo]Z0ol007l7oookJP?o001o00Cooo]Zo`00Ool007oo001oCooonfX3o`00
O`?ooo]Z0ol007l6oookJP?o001o00Cooo]Zo`00Ool007oo001oD?oonfX3o`00O`?ooo]Z0ol007l7
oookJPOo001o:?oonfX@o`0002?ooo]Z0ol007l?oookJP00;_oonfX5o`0005Cooo]Z4ol00002o`00
O`?ooo]Z0ol007m>oookJP?o001o0ooonfX3o`00O`Sooo]Z0_l007l01?oonf[o001oo`00Ool007m?
oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007mDoookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3
oookJP?o001o:_oonfX@o`00023ooo]Z0ol007l?oookJP00;_oonfX5o`0004oooo]Z5?l00003oook
JP?o001o0ooonfX3o`00Odkooo]Z0ol007l3oookJP?o001o2OoonfX5o`00Odoooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00OeCooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l]oook
JQ3o00006_oonfX6o`00O`oooo]Z000^oookJPGo0000B_oonfXEo`0000Oooo]Z1?l007l2oookJP?o
001oCooonfX3o`00O`04oookJ_l007oo001oo`00O`[ooo]Z1Ol007m@oookJP?o001o00Cooo]Zo`00
Ool007oo001o2?oonfX3o`00O`;ooo]Z0ol007m?oookJP?o001o00Cooo]Zo`00Ool007oo001o1ooo
nfX3o`00O`?ooo]Z0ol007l`oookJQ3o00005ooonfX6o`00O`oooo]Z000^oookJPGo0000AOoonfXF
o`0000Co001o2?oonfX7o`00Oe3ooo]Z1ol007l;oookJPCo001oD?oonfX7o`00O`Sooo]Z1ol007m@
oookJPOo001o2?oonfX7o`00OcGooo]Z3ol0000FoookJPCo001o3ooonfX002kooo]Z1Ol00010oook
JQOo00000_oonfX5o`00O`[ooo]Z1Ol007mBoookJPGo001o3OoonfX3o`00Oe7ooo]Z1Ol007l;oook
JPCo001oD_oonfX5o`00O`[ooo]Z1Ol007lioookJPoo00005?oonfX3o`00O`oooo]Z000^oookJPGo
0000>_oonfXHo`000?oooo]ZR_oonfX?o`0002?ooo]Z000^oookJPGo0000=?oonfXIo`000?oooo]Z
T_oonfX@o`0001oooo]Z000^oookJPGo0000;ooonfXIo`000?oooo]ZV_oonfX@o`0001cooo]Z000^
oookJPGo0000:OoonfXJo`000?oooo]ZX_oonfX@o`0001Wooo]Z000^oookJPGo00008OoonfXLo`00
0?oooo]ZZooonfX@o`0001Kooo]Z000^oookJPGo00006OoonfXNo`000?oooo]Z]OoonfX?o`0001?o
oo]Z000QoookJ_oo0000ool0000Po`00007ooo]Z000QoookJ_oo0000ool0000Po`00007ooo]Z000Q
oookJ_oo0000ool0000Po`00007ooo]Z000QoookJ_oo0000ool0000Po`00007ooo]Z000QoookJ_oo
0000ool0000Po`00007ooo]Z000^oookJPGo0000HooonfX00ol0003ooo]ZoookJP1ToookJP03o`00
0?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP1SoookJP03o`00
0?oonf[ooo]Z00kooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[o
oookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoo
oo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^
oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo
0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooo
nf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooook
JPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z
000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oook
JPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000
oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[o
oookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoo
oo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^
oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo
0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooo
nf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooook
JPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z
000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oook
JPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000
oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[o
oookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoo
oo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^
oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo
0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooo
nf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooook
JPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z
000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oook
JPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000
oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[o
oookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoo
oo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^
oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo
0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooo
nf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooook
JPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z
000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oook
JPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000
oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[o
oookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoo
oo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^
oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo
0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooo
nf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooook
JPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z
000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oook
JPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000AoookJPGo001o
1?oonfX3o`00O`03oookJ_l007oo001o00Oo001o1ooonfX5o`000?oooo]ZoooonfX?oookJP004?oo
nfX7o`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`07o`00O`Oooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX0013ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l0
07l<oookJPGo0000oooonf[ooookJPoooo]Z000?oookJP?o001o0ooonfX3o`00O`Oooo]Z1?l007l;
oookJPGo0000oooonf[ooookJPoooo]Z000?oookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol007l9oook
JPOo0000oooonf[ooookJPgooo]Z000?oookJP?o001o0ooonfX3o`00O`[ooo]Z1?l007l8oookJPGo
0000oooonf[ooookJPoooo]Z000?oookJP?o001o0ooonfX3o`00O`_ooo]Z0ol007l8oookJPGo0000
oooonf[ooookJPoooo]Z000?oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPGo0000oooo
nf[ooookJPoooo]Z000?oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1ooonfX5
o`000?oooo]ZoooonfX?oookJP003ooonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00
O`Oooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0013ooo]Z0ol007l01?oonf[o001oo`00Ool007l7oook
JPCo001o0_oonfX3o`00O`Oooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0013ooo]Z1ol007l8oookJPOo
001o2?oonfX5o`000?oooo]ZoooonfX?oookJP004OoonfX5o`00O`[ooo]Z1Ol007l9oookJPGo0000
oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[o
oookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoo
oo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^
oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo
0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooo
nf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooook
JPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z
000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oook
JPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000
oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[o
oookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoo
oo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^
oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo
0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooo
nf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooook
JPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z
000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oook
JPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000
oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[o
oookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoo
oo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^
oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo
0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooo
nf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooook
JPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z
000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oook
JPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000
oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[o
oookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoo
oo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^
oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo
0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooo
nf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooook
JPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z
000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oook
JPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000
oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[o
oookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoo
oo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^
oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo
0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooo
nf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooook
JPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z000^oookJPGo0000oooonf[ooookJPoooo]Z
000AoookJPGo001o1?oonfX3o`00O`Kooo]Z0ol007l8oookJPGo0000oooonf[ooookJPoooo]Z000@
oookJPOo001o0ooonfX3o`00O`Kooo]Z0ol007l8oookJPGo0000oooonf[ooookJPoooo]Z000@oook
JP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l8oookJPGo0000oooonf[o
oookJPoooo]Z000?oookJP?o001o0ooonfX3o`00O`Kooo]Z2Ol007l7oookJPGo0000oooonf[ooook
JPoooo]Z000?oookJP?o001o0ooonfX3o`00O`Kooo]Z2Ol007l7oookJPOo0000oooonf[ooookJPgo
oo]Z000?oookJP?o001o0ooonfX3o`00O`Kooo]Z0_l007l3oookJP?o001o2?oonfX5o`000?oooo]Z
oooonfX?oookJP003ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX3o`00O`Sooo]Z1Ol0
003ooookJ_oooo]Z3ooonfX000oooo]Z0ol007l3oookJP?o001o1ooonfX3o`00O`04oookJ_l007oo
001oo`00O`Sooo]Z1Ol0003ooookJ_oooo]Z3ooonfX000oooo]Z0ol007l3oookJP?o001o2?oonfX2
o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol0003ooookJ_oooo]Z3ooonfX000oooo]Z0ol007l3
oookJP?o001o2OoonfX5o`00O`Sooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0013ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l:oookJPGo001o2?oonfX5o`000?oooo]ZoooonfX?oookJP004?oonfX7o`00
O`_ooo]Z1?l007l8oookJPGo0000oooonf[ooookJPoooo]Z000AoookJPGo001o3OoonfX3o`00O`So
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0
003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooook
J_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002ko
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0
003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooook
J_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002ko
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0
003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooook
J_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX00?oooo]ZoooonfY2oookJP00oooonf[ooook
JT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003o
oookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z
@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oo
oo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2
oookJP00oooonf[ooookJT;ooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 575}, {575, 0}} -> {-0.0952157, -0.535939, \
0.00195734, 0.00186413}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["Point Loaded on both ends, loaded in the middle as above", "Text"],

Cell[BoxData[
    \(midload[x_]\  := \ \(-10\) DiracDelta[x\  - \ 1/2]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Plot", "[", 
      RowBox[{
        RowBox[{"Evaluate", "[", "\[IndentingNewLine]", 
          
          StyleBox[\(y[x] /. 
              BeamEquation[y, x, midload, PointLoad[y, 0, 0, 0], 
                PointLoad[y, 1, 0, 0]]\),
            FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", "]"}], 
        ",", \({x, 0, 1}\), ",", \(PlotRange \[Rule] {\(-0.5\), 0.5}\), 
        ",", \(AspectRatio \[Rule] 1\)}], "]"}]], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.5 1 [
[.21429 .4875 -14.5 -20 ]
[.21429 .4875 14.5 0 ]
[.40476 .4875 -14.5 -20 ]
[.40476 .4875 14.5 0 ]
[.59524 .4875 -14.5 -20 ]
[.59524 .4875 14.5 0 ]
[.78571 .4875 -14.5 -20 ]
[.78571 .4875 14.5 0 ]
[.97619 .4875 -7 -20 ]
[.97619 .4875 7 0 ]
[.01131 .1 -41.9375 -10 ]
[.01131 .1 0 10 ]
[.01131 .3 -41.9375 -10 ]
[.01131 .3 0 10 ]
[.01131 .7 -29 -10 ]
[.01131 .7 0 10 ]
[.01131 .9 -29 -10 ]
[.01131 .9 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 1.005 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .5 m
.21429 .50625 L
s
gsave
.21429 .4875 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.40476 .5 m
.40476 .50625 L
s
gsave
.40476 .4875 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.59524 .5 m
.59524 .50625 L
s
gsave
.59524 .4875 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.78571 .5 m
.78571 .50625 L
s
gsave
.78571 .4875 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.97619 .5 m
.97619 .50625 L
s
gsave
.97619 .4875 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .5 m
.07143 .50375 L
s
.11905 .5 m
.11905 .50375 L
s
.16667 .5 m
.16667 .50375 L
s
.2619 .5 m
.2619 .50375 L
s
.30952 .5 m
.30952 .50375 L
s
.35714 .5 m
.35714 .50375 L
s
.45238 .5 m
.45238 .50375 L
s
.5 .5 m
.5 .50375 L
s
.54762 .5 m
.54762 .50375 L
s
.64286 .5 m
.64286 .50375 L
s
.69048 .5 m
.69048 .50375 L
s
.7381 .5 m
.7381 .50375 L
s
.83333 .5 m
.83333 .50375 L
s
.88095 .5 m
.88095 .50375 L
s
.92857 .5 m
.92857 .50375 L
s
.01 w
0 .5 m
1 .5 L
s
.25 Mabswid
.02381 .1 m
.03006 .1 L
s
gsave
.01131 .1 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.02381 .3 m
.03006 .3 L
s
gsave
.01131 .3 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.02381 .7 m
.03006 .7 L
s
gsave
.01131 .7 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.02381 .9 m
.03006 .9 L
s
gsave
.01131 .9 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .15 m
.02756 .15 L
s
.02381 .2 m
.02756 .2 L
s
.02381 .25 m
.02756 .25 L
s
.02381 .35 m
.02756 .35 L
s
.02381 .4 m
.02756 .4 L
s
.02381 .45 m
.02756 .45 L
s
.02381 .55 m
.02756 .55 L
s
.02381 .6 m
.02756 .6 L
s
.02381 .65 m
.02756 .65 L
s
.02381 .75 m
.02756 .75 L
s
.02381 .8 m
.02756 .8 L
s
.02381 .85 m
.02756 .85 L
s
.02381 .05 m
.02756 .05 L
s
.02381 .95 m
.02756 .95 L
s
.01 w
.02381 0 m
.02381 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.0075 w
.02381 .5 m
.06244 .4747 L
.10458 .4475 L
.14415 .42271 L
.18221 .39988 L
.22272 .37706 L
.26171 .35687 L
.30316 .33771 L
.34309 .32187 L
.3815 .30941 L
.40095 .30425 L
.42237 .29952 L
.44268 .29601 L
.46172 .29363 L
.46668 .29316 L
.4721 .29272 L
.47687 .29239 L
.48196 .29211 L
.48456 .29199 L
.487 .2919 L
.48938 .29182 L
.49157 .29176 L
.49365 .29172 L
.49472 .29171 L
.49585 .29169 L
.497 .29168 L
.49806 .29167 L
.49933 .29167 L
.50049 .29167 L
.50167 .29167 L
.50277 .29168 L
.50399 .29169 L
.5053 .29171 L
.50659 .29173 L
.50796 .29175 L
.5104 .29181 L
.51478 .29196 L
.51957 .29219 L
.52477 .2925 L
.53033 .29291 L
.54033 .29385 L
.56168 .29668 L
.58183 .30037 L
.6203 .30993 L
.66122 .32344 L
.70062 .33934 L
.73851 .35697 L
.77885 .37791 L
.81767 .39981 L
.85895 .42461 L
Mistroke
.89871 .4496 L
.93695 .47431 L
.97619 .5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 576},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900002@2000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oo
oo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX0
0?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]Zoooo
nfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00
;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5
o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oo
oo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Zoooo
nfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oook
JP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oo
nfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`00
0?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Z
oooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?
oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00
;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5
o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oo
oo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Zoooo
nfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oook
JP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oo
nfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`00
0?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Z
oooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?
oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00
;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5
o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oo
oo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Zoooo
nfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oook
JP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP004Ooo
nfX5o`00O`Cooo]Z0ol007l6oookJP?o001o2?oonfX5o`000?oooo]ZoooonfX?oookJP004?oonfX7
o`00O`?ooo]Z0ol007l6oookJP?o001o2?oonfX5o`000?oooo]ZoooonfX?oookJP004?oonfX3o`00
O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l6oookJP?o001o2?oonfX5o`000?oooo]ZoooonfX?
oookJP000ooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX9o`00O`Oooo]Z1Ol0003ooook
J_oooo]Z3ooonfX000?ooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z2Ol007l7oookJPOo
0000oooonf[ooookJPgooo]Z000?oookJP?o001o0ooonfX3o`00O`Kooo]Z0_l007l3oookJP?o001o
2?oonfX5o`000?oooo]ZoooonfX?oookJP003ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oo
nfX3o`00O`Sooo]Z1Ol0003ooookJ_oooo]Z3ooonfX000oooo]Z0ol007l3oookJP?o001o1ooonfX3
o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol0003ooookJ_oooo]Z3ooonfX000oooo]Z0ol007l3
oookJP?o001o2?oonfX2o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX000oooo]Z0ol007l3oookJP?o001o2OoonfX5o`00O`Sooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
013ooo]Z0ol007l01?oonf[o001oo`00Ool007l:oookJPGo001o2?oonfX5o`000?oooo]ZoooonfX?
oookJP004?oonfX7o`00O`_ooo]Z1?l007l8oookJPGo0000oooonf[ooookJPoooo]Z000AoookJPGo
001o3OoonfX3o`00O`Sooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002ko
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0
003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooook
J_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002ko
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0
003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooook
J_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002ko
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0
003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooook
J_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002ko
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0
003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooook
J_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003`oookJQSo0000oooonfX6oook
JP00;_oonfX5o`000>Cooo]Z<ol0003foookJP004OoonfX5o`00O`Cooo]Z0ol007l00ooonf[o001o
o`00O`07o`00O`Oooo]Z1Ol0003OoookJSko0000l?oonfX0013ooo]Z1ol007l3oookJP?o001o00?o
oo]Zo`00Ool007l01ol007l7oookJPGo0000eooonfY<o`000>[ooo]Z000@oookJP?o001o00Cooo]Z
o`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o3?oonfX5o`000<oooo]Z9?l0
000BoookJR?o0000iOoonfX000?ooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Oooo]Z1?l007l;
oookJPGo0000booonfXLo`0002gooo]Z6?l0003QoookJP000ooonfX:o`00O`;ooo]Z0ol007l3oook
JP?o001o2?oonfX5o`00O`Wooo]Z1ol00035oookJQ_o0000>?oonfXFo`000=gooo]Z000?oookJP?o
001o0ooonfX3o`00O`[ooo]Z1?l007l8oookJPGo0000`ooonfXGo`0004Kooo]Z5Ol0003HoookJP00
3ooonfX3o`00O`?ooo]Z0ol007l;oookJP?o001o2?oonfX5o`000<3ooo]Z4_l0001CoookJQCo0000
e?oonfX000oooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1Ol0002moookJQ7o0000Fooo
nfXDo`000=3ooo]Z000?oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1ooonfX5
o`000;Wooo]Z4Ol0001SoookJQCo0000c?oonfX000oooo]Z0ol007l3oookJP?o001o1_oonfX3o`00
O`?ooo]Z0ol007l7oookJPGo0000]_oonfX@o`0006cooo]Z4_l00039oookJP004?oonfX3o`00O`04
oookJ_l007oo001oo`00O`Oooo]Z1?l007l2oookJP?o001o1ooonfX5o`000;;ooo]Z4Ol0001coook
JQ7o0000a_oonfX0013ooo]Z1ol007l8oookJPOo001o2?oonfX5o`000:oooo]Z4Ol0001joookJQ3o
0000`ooonfX0017ooo]Z1Ol007l:oookJPGo001o2OoonfX5o`000:_ooo]Z4Ol00022oookJPoo0000
`?oonfX002kooo]Z1Ol0002XoookJQ7o0000R?oonfX?o`000;gooo]Z000^oookJPGo0000YOoonfX@
o`0008oooo]Z3ol0002joookJP00;_oonfX5o`000:;ooo]Z4?l0002EoookJPoo0000]ooonfX002ko
oo]Z1Ol0002PoookJPko0000W?oonfX?o`000;Cooo]Z000^oookJPGo0000W_oonfX=o`000:;ooo]Z
3_l0002boookJP00;_oonfX5o`0009_ooo]Z3Ol0002XoookJPgo0000/?oonfX002kooo]Z1Ol0002I
oookJPco0000[_oonfX=o`000:gooo]Z000^oookJPGo0000UooonfX<o`000;?ooo]Z3?l0002[oook
JP00;_oonfX5o`0009Cooo]Z3Ol0002goookJPco0000ZOoonfX002kooo]Z1Ol0002BoookJPco0000
_?oonfX=o`000:Kooo]Z000^oookJPGo0000T?oonfX<o`000<7ooo]Z3?l0002ToookJP00;_oonfX5
o`0008kooo]Z3?l00035oookJPco0000X_oonfX002kooo]Z1Ol0002;oookJPco0000b_oonfX=o`00
09oooo]Z000^oookJPGo0000ROoonfX<o`000<oooo]Z3?l0002MoookJP00;_oonfX5o`0008Oooo]Z
3?l0003CoookJPco0000VooonfX002kooo]Z1Ol00025oookJPco0000eooonfX=o`0009Sooo]Z000^
oookJPGo0000PooonfX;o`000=gooo]Z3?l0002FoookJP00;_oonfX5o`00083ooo]Z3?l0003Qoook
JPco0000U?oonfX002kooo]Z1Ol0001noookJPco0000iOoonfX=o`00097ooo]Z000^oookJPGo0000
O?oonfX<o`000>[ooo]Z3?l0002?oookJP00;_oonfX5o`0007[ooo]Z3?l0003^oookJPco0000SOoo
nfX002kooo]Z1Ol0001hoookJP_o0000looonfX<o`0008_ooo]Z000^oookJPGo0000M_oonfX;o`00
0?Sooo]Z2_l0002:oookJP00;_oonfX5o`0007Cooo]Z2ol0003loookJP[o0000R?oonfX002kooo]Z
1Ol0001boookJP_o0000oooonfX1oookJP[o0000Q_oonfX002kooo]Z1Ol0001`oookJP_o0000oooo
nfX5oookJP[o0000Q?oonfX002kooo]Z1Ol0001_oookJP[o0000oooonfX8oookJP[o0000PooonfX0
02kooo]Z1Ol0001]oookJP[o0000oooonfX<oookJP[o0000POoonfX002kooo]Z1Ol0001[oookJP[o
0000oooonfX@oookJP[o0000OooonfX002kooo]Z1Ol0001YoookJP[o0000oooonfXDoookJP[o0000
OOoonfX002kooo]Z1Ol0001WoookJP_o0000oooonfXFoookJP[o0000O?oonfX002kooo]Z1Ol0001U
oookJP_o0000oooonfXJoookJP[o0000N_oonfX002kooo]Z1Ol0001SoookJP_o0000oooonfXNoook
JP[o0000N?oonfX002kooo]Z1Ol0001QoookJP_o0000oooonfXRoookJP[o0000M_oonfX002kooo]Z
1Ol0001PoookJP[o0000oooonfXUoookJP_o0000M?oonfX002kooo]Z1Ol0001NoookJP[o0000oooo
nfXYoookJP_o0000L_oonfX002kooo]Z1Ol0001LoookJP[o0000oooonfX]oookJP_o0000L?oonfX0
02kooo]Z1Ol0001JoookJP[o0000oooonfXaoookJP_o0000K_oonfX002kooo]Z1Ol0001HoookJP_o
0000oooonfXdoookJP[o0000KOoonfX002kooo]Z1Ol0001FoookJP_o0000oooonfXhoookJP[o0000
JooonfX002kooo]Z1Ol0001EoookJP[o0000oooonfXloookJP[o0000JOoonfX002kooo]Z1Ol0001C
oookJP[o0000oooonfY0oookJP[o0000IooonfX002kooo]Z1Ol0001AoookJP[o0000oooonfY3oook
JP_o0000IOoonfX002kooo]Z1Ol0001?oookJP[o0000oooonfY7oookJP_o0000HooonfX002kooo]Z
1Ol0001>oookJP[o0000oooonfY:oookJP[o0000H_oonfX002kooo]Z1Ol0001<oookJP[o0000oooo
nfY>oookJP[o0000H?oonfX002kooo]Z1Ol0001;oookJPWo0000oooonfYBoookJP[o0000G_oonfX0
02kooo]Z1Ol00019oookJPWo0000oooonfYFoookJPWo0000GOoonfX002kooo]Z1Ol00018oookJPWo
0000oooonfYHoookJP[o0000FooonfX002kooo]Z1Ol00016oookJPWo0000oooonfYLoookJPWo0000
F_oonfX002kooo]Z1Ol00014oookJP[o0000oooonfYOoookJPWo0000F?oonfX002kooo]Z1Ol00013
oookJPWo0000oooonfYRoookJPWo0000EooonfX002kooo]Z1Ol00011oookJP[o0000oooonfYUoook
JPWo0000EOoonfX002kooo]Z1Ol00010oookJPWo0000oooonfYXoookJP[o0000DooonfX002kooo]Z
1Ol0000noookJPWo0000oooonfY/oookJPWo0000D_oonfX002kooo]Z1Ol0000moookJPWo0000oooo
nfY^oookJP[o0000D?oonfX002kooo]Z1Ol0000koookJPWo0000oooonfYboookJPWo0000CooonfX0
02kooo]Z1Ol0000ioookJP[o0000oooonfYeoookJPWo0000COoonfX002kooo]Z1Ol0000hoookJPWo
0000oooonfYhoookJPWo0000C?oonfX002kooo]Z1Ol0000foookJP[o0000oooonfYkoookJPWo0000
B_oonfX002kooo]Z1Ol0000doookJP[o0000oooonfYnoookJP[o0000B?oonfX002kooo]Z1Ol0000c
oookJPWo0000oooonfZ2oookJPWo0000AooonfX002kooo]Z1Ol0000aoookJP[o0000oooonfZ4oook
JP[o0000AOoonfX002kooo]Z1Ol0000_oookJP[o0000oooonfZ8oookJP[o0000@ooonfX002kooo]Z
1Ol0000^oookJPWo0000oooonfZ<oookJPWo0000@_oonfX002kooo]Z1Ol0000/oookJP[o0000oooo
nfZ>oookJP[o0000@?oonfX002kooo]Z1Ol0000ZoookJP[o0000oooonfZBoookJPWo0000?ooonfX0
02kooo]Z1Ol0000YoookJPWo0000oooonfZFoookJPWo0000?OoonfX002kooo]Z1Ol0000WoookJP[o
0000oooonfZHoookJP[o0000>ooonfX002kooo]Z1Ol0000UoookJP[o0000oooonfZLoookJPWo0000
>_oonfX002kooo]Z1Ol0000ToookJPWo0000oooonfZOoookJP[o0000>?oonfX002kooo]Z1Ol0000R
oookJP[o0000oooonfZRoookJPWo0000=ooonfX002kooo]Z1Ol0000PoookJP[o0000oooonfZVoook
JPWo0000=OoonfX002kooo]Z1Ol0000OoookJPWo0000oooonfZYoookJP[o0000<ooonfX002kooo]Z
1Ol0000MoookJP[o0000oooonfZ/oookJPWo0000<_oonfX002kooo]Z1Ol0000LoookJPWo0000oooo
nfZ_oookJP[o0000<?oonfX002kooo]Z1Ol0000JoookJPWo0000oooonfZcoookJP[o0000;_oonfX0
02kooo]Z1Ol0000IoookJPWo0000=ooonfX5o`00O`Cooo]Z0ol007l00ooonf[o001oo`00O`07o`00
Oe3ooo]Z1Ol007l4oookJP?o001o1_oonfX3o`00Oe7ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00
Oe;ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00OcSooo]Z2Ol0000KoookJP?o001o3ooonfX002ko
oo]Z1Ol0000GoookJPWo0000>?oonfX7o`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`07o`00Odoo
oo]Z1ol007l3oookJP?o001o1_oonfX3o`00Oe3ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Oe3o
oo]Z1ol007l3oookJP?o001o0_oonfX7o`00OcSooo]Z2_l0000IoookJP?o001o3ooonfX002kooo]Z
1Ol0000EoookJP[o0000>OoonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o
001oo`00O`02o`00OeCooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1_oonfX3o`00
Oe3ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o0_oonfX3o`00O`;ooo]Z0ol007m?
oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z
0ol007lioookJPWo00006?oonfX3o`00O`oooo]Z000^oookJPGo00005?oonfX9o`0003[ooo]Z0ol0
07l3oookJP?o001o1ooonfX4o`00Oe;ooo]Z0ol007l3oookJP?o001o1_oonfX9o`00Odkooo]Z0ol0
07l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007m>oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol0
07l3oookJP?o001o>ooonfX9o`0001Kooo]Z0ol007l?oookJP00;_oonfX5o`0001;ooo]Z2_l0000k
oookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol007m@oookJP?o001o0ooonfX3o`00O`Kooo]Z2Ol007m>
oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001oC_oonfX3o`00O`?ooo]Z0ol007l6
oookJP?o001o0ooonfX3o`00Occooo]Z2_l0000DoookJP?o001o3ooonfX002kooo]Z1Ol0000Aoook
JPWo0000?OoonfX3o`00O`?ooo]Z0ol007l:oookJPCo001oCooonfX3o`00O`?ooo]Z0ol007l6oook
JP;o001o0ooonfX3o`00Odoooo]Z0ol007l3oookJP?o001o1_oonfX4o`00O`;ooo]Z0ol007m>oook
JP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o?_oonfX9o`0001?ooo]Z0ol007l?oook
JP00;_oonfX5o`0000oooo]Z2Ol0000ooookJP?o001o0ooonfX3o`00O`_ooo]Z0ol007m?oookJP?o
001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJP?o001oCooonfX3o`00O`?ooo]Z0ol007l6oookJPSo
001oCooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o@?oonfX:o`00017ooo]Z0ol007l?oookJP00
;_oonfX5o`0000kooo]Z2Ol00010oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007m>oookJP?o001o
0ooonfX3o`00O`Oooo]Z0ol007l01?oonf[o001oo`00Ool007m?oookJP?o001o0ooonfX3o`00O`Ko
oo]Z0ol007l01?oonf[o001oo`00Ool007m@oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007m2oook
JPWo00004?oonfX3o`00O`oooo]Z000^oookJPGo00003?oonfX9o`0004;ooo]Z0ol007l3oookJP?o
001o1_oonfX3o`00O`?ooo]Z0ol007m>oookJP?o001o0ooonfX3o`00O`Sooo]Z0_l007l01?oonf[o
001oo`00Ool007m?oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007mDoookJP?o001o0ooonfX3o`00
O`Kooo]Z0ol007l3oookJP?o001o@ooonfX9o`0000kooo]Z0ol007l?oookJP00;_oonfX5o`0000_o
oo]Z2Ol00013oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001oC_oonfX3o`00O`?o
oo]Z0ol007l9oookJPGo001oCooonfX3o`00O`?ooo]Z0ol007l6oookJP?o001oE?oonfX3o`00O`?o
oo]Z0ol007l6oookJP?o001o0ooonfX3o`00OdCooo]Z2Ol0000:oookJPKo001o3ooonfX002kooo]Z
1Ol00009oookJPWo0000A_oonfX3o`00O`04oookJ_l007oo001oo`00O`Oooo]Z1?l007l2oookJP?o
001oCooonfX3o`00O`04oookJ_l007oo001oo`00O`[ooo]Z1Ol007m@oookJP?o001o00Cooo]Zo`00
Ool007oo001o2?oonfX3o`00O`;ooo]Z0ol007m?oookJP?o001o00Cooo]Zo`00Ool007oo001o1ooo
nfX3o`00O`?ooo]Z0ol007m6oookJPWo00002?oonfX6o`00O`oooo]Z000^oookJPGo00002?oonfX9
o`0004Oooo]Z1ol007l8oookJPOo001oD?oonfX7o`00O`_ooo]Z1?l007m@oookJPOo001o2?oonfX7
o`00Oe3ooo]Z1ol007l8oookJPOo001oB?oonfX9o`0000Wooo]Z1?l007l?oookJP00;_oonfX5o`00
00Kooo]Z2Ol0001:oookJPGo001o2_oonfX5o`00Oe;ooo]Z1Ol007l=oookJP?o001oDOoonfX5o`00
O`_ooo]Z1?l007mBoookJPGo001o2_oonfX5o`00Od_ooo]Z2Ol00008oookJP?o001o3ooonfX002ko
oo]Z1Ol00005oookJPWo0000oooonf[NoookJPWo00006OoonfX002kooo]Z1Ol00003oookJPWo0000
oooonf[RoookJPWo00005ooonfX002kooo]Z1Ol00002oookJPWo0000oooonf[ToookJPWo00005_oo
nfX002kooo]Z3_l0003ooookJ^Sooo]Z2Ol0000DoookJP00;_oonfX=o`000?oooo]Zj_oonfX9o`00
01?ooo]Z000^oookJP_o0000oooonf[^oookJPWo00004OoonfX0027ooo]Zool0003oo`00023o0000
0OoonfX0027ooo]Zool0003oo`00023o00000OoonfX0027ooo]Zool0003oo`00023o00000OoonfX0
027ooo]Zool0003oo`00023o00000OoonfX0027ooo]Zool0003oo`00023o00000OoonfX002kooo]Z
1Ol0001SoookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Z
oookJP1SoookJP03o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX03_oonfX002kooo]Z1Ol0
003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooook
J_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002ko
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0
003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooook
J_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002ko
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0
003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooook
J_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002ko
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0
003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooook
J_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002ko
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0
003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooook
J_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002ko
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX0017ooo]Z1Ol007l4oookJP?o001o00?ooo]Zo`00Ool007l0
1ol007l7oookJPGo0000oooonf[ooookJPoooo]Z000@oookJPOo001o0ooonfX3o`00O`03oookJ_l0
07oo001o00Oo001o1ooonfX5o`000?oooo]ZoooonfX?oookJP004?oonfX3o`00O`04oookJ_l007oo
001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`cooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX000oooo]Z0ol007l3oookJP?o001o1ooonfX4o`00O`_ooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
00oooo]Z0ol007l3oookJP?o001o2?oonfX5o`00O`Wooo]Z1ol0003ooookJ_oooo]Z3OoonfX000oo
oo]Z0ol007l3oookJP?o001o2_oonfX4o`00O`Sooo]Z1Ol0003ooookJ_oooo]Z3ooonfX000oooo]Z
0ol007l3oookJP?o001o2ooonfX3o`00O`Sooo]Z1Ol0003ooookJ_oooo]Z3ooonfX000oooo]Z0ol0
07l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1Ol0003ooookJ_oooo]Z3ooonfX000oooo]Z0ol007l3
oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000oooonf[ooookJPoooo]Z000?oook
JP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1ooonfX5o`000?oooo]ZoooonfX?oook
JP004?oonfX3o`00O`04oookJ_l007oo001oo`00O`Oooo]Z1?l007l2oookJP?o001o1ooonfX5o`00
0?oooo]ZoooonfX?oookJP004?oonfX7o`00O`Sooo]Z1ol007l8oookJPGo0000oooonf[ooookJPoo
oo]Z000AoookJPGo001o2_oonfX5o`00O`Wooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0
003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooook
J_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002ko
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0
003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooook
J_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002ko
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0
003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooook
J_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002ko
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0
003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooook
J_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002ko
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0
003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooook
J_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0017ooo]Z1Ol007l4oookJP?o001o1_oo
nfX3o`00O`Sooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0013ooo]Z1ol007l3oookJP?o001o1_oonfX3
o`00O`Sooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0013ooo]Z0ol007l01?oonf[o001oo`00Ool007l3
oookJP?o001o1_oonfX3o`00O`Sooo]Z1Ol0003ooookJ_oooo]Z3ooonfX000oooo]Z0ol007l3oook
JP?o001o1_oonfX9o`00O`Oooo]Z1Ol0003ooookJ_oooo]Z3ooonfX000oooo]Z0ol007l3oookJP?o
001o1_oonfX9o`00O`Oooo]Z1ol0003ooookJ_oooo]Z3OoonfX000oooo]Z0ol007l3oookJP?o001o
1_oonfX2o`00O`?ooo]Z0ol007l8oookJPGo0000oooonf[ooookJPoooo]Z000?oookJP?o001o0ooo
nfX3o`00O`Oooo]Z0_l007l2oookJP?o001o2?oonfX5o`000?oooo]ZoooonfX?oookJP003ooonfX3
o`00O`?ooo]Z0ol007l7oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`000?oooo]Zoooo
nfX?oookJP003ooonfX3o`00O`?ooo]Z0ol007l8oookJP;o001o00Cooo]Zo`00Ool007oo001o2?oo
nfX5o`000?oooo]ZoooonfX?oookJP003ooonfX3o`00O`?ooo]Z0ol007l9oookJPGo001o2?oonfX5
o`000?oooo]ZoooonfX?oookJP004?oonfX3o`00O`04oookJ_l007oo001oo`00O`[ooo]Z1Ol007l8
oookJPGo0000oooonf[ooookJPoooo]Z000@oookJPOo001o2ooonfX4o`00O`Sooo]Z1Ol0003ooook
J_oooo]Z3ooonfX0017ooo]Z1Ol007l=oookJP?o001o2?oonfX5o`000?oooo]ZoooonfX?oookJP00
;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5
o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oo
oo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Zoooo
nfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oook
JP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oo
nfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`00
0?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Z
oooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?
oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00
;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5
o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oo
oo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Zoooo
nfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oook
JP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oo
nfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`00
0?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Z
oooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?
oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00
;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5
o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oo
oo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Zoooo
nfX?oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00
oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooook
JT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003o
oookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z
@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00001
\
\>"],
  ImageRangeCache->{{{0, 575}, {575, 0}} -> {-0.0952157, -0.535939, \
0.00195734, 0.00186413}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
Point Loaded on both ends, with linear distributed load positive at \
left and negative at right\
\>", "Text",
  CellTags->{
  "mmtag:21:beams__point_loads_and_distributed_loads", 
    "mmtag:21:beams__distributed_loads"}],

Cell[BoxData[
    \(testload[x_]\  := 100*\((1/2\  - \ x)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Plot", "[", 
      RowBox[{
        RowBox[{"Evaluate", "[", "\[IndentingNewLine]", 
          
          StyleBox[\(y[x] /. 
              BeamEquation[y, x, testload, PointLoad[y, 0, 0, 0], 
                PointLoad[y, 1, 0, 0]]\),
            FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", "]"}], 
        ",", \({x, 0, 1}\), ",", \(PlotRange \[Rule] {\(-0.5\), 0.5}\), 
        ",", \(AspectRatio \[Rule] 1\)}], "]"}]], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.5 1 [
[.21429 .4875 -14.5 -20 ]
[.21429 .4875 14.5 0 ]
[.40476 .4875 -14.5 -20 ]
[.40476 .4875 14.5 0 ]
[.59524 .4875 -14.5 -20 ]
[.59524 .4875 14.5 0 ]
[.78571 .4875 -14.5 -20 ]
[.78571 .4875 14.5 0 ]
[.97619 .4875 -7 -20 ]
[.97619 .4875 7 0 ]
[.01131 .1 -41.9375 -10 ]
[.01131 .1 0 10 ]
[.01131 .3 -41.9375 -10 ]
[.01131 .3 0 10 ]
[.01131 .7 -29 -10 ]
[.01131 .7 0 10 ]
[.01131 .9 -29 -10 ]
[.01131 .9 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 1.005 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .5 m
.21429 .50625 L
s
gsave
.21429 .4875 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.40476 .5 m
.40476 .50625 L
s
gsave
.40476 .4875 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.59524 .5 m
.59524 .50625 L
s
gsave
.59524 .4875 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.78571 .5 m
.78571 .50625 L
s
gsave
.78571 .4875 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.97619 .5 m
.97619 .50625 L
s
gsave
.97619 .4875 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .5 m
.07143 .50375 L
s
.11905 .5 m
.11905 .50375 L
s
.16667 .5 m
.16667 .50375 L
s
.2619 .5 m
.2619 .50375 L
s
.30952 .5 m
.30952 .50375 L
s
.35714 .5 m
.35714 .50375 L
s
.45238 .5 m
.45238 .50375 L
s
.5 .5 m
.5 .50375 L
s
.54762 .5 m
.54762 .50375 L
s
.64286 .5 m
.64286 .50375 L
s
.69048 .5 m
.69048 .50375 L
s
.7381 .5 m
.7381 .50375 L
s
.83333 .5 m
.83333 .50375 L
s
.88095 .5 m
.88095 .50375 L
s
.92857 .5 m
.92857 .50375 L
s
.01 w
0 .5 m
1 .5 L
s
.25 Mabswid
.02381 .1 m
.03006 .1 L
s
gsave
.01131 .1 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.02381 .3 m
.03006 .3 L
s
gsave
.01131 .3 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.02381 .7 m
.03006 .7 L
s
gsave
.01131 .7 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.02381 .9 m
.03006 .9 L
s
gsave
.01131 .9 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .15 m
.02756 .15 L
s
.02381 .2 m
.02756 .2 L
s
.02381 .25 m
.02756 .25 L
s
.02381 .35 m
.02756 .35 L
s
.02381 .4 m
.02756 .4 L
s
.02381 .45 m
.02756 .45 L
s
.02381 .55 m
.02756 .55 L
s
.02381 .6 m
.02756 .6 L
s
.02381 .65 m
.02756 .65 L
s
.02381 .75 m
.02756 .75 L
s
.02381 .8 m
.02756 .8 L
s
.02381 .85 m
.02756 .85 L
s
.02381 .05 m
.02756 .05 L
s
.02381 .95 m
.02756 .95 L
s
.01 w
.02381 0 m
.02381 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.0075 w
.02381 .5 m
.06244 .50555 L
.10458 .51104 L
.14415 .51525 L
.16408 .51694 L
.18221 .5182 L
.20178 .51924 L
.21254 .51967 L
.22272 .51999 L
.23241 .5202 L
.2373 .52028 L
.24012 .52031 L
.24269 .52034 L
.24504 .52036 L
.24728 .52037 L
.2485 .52037 L
.24964 .52038 L
.25088 .52038 L
.25158 .52038 L
.25221 .52038 L
.25336 .52038 L
.25442 .52038 L
.25558 .52038 L
.2568 .52037 L
.25787 .52037 L
.25887 .52037 L
.26113 .52035 L
.26373 .52033 L
.26614 .5203 L
.27158 .52023 L
.27638 .52014 L
.28148 .52003 L
.2903 .51978 L
.30004 .51943 L
.31939 .51851 L
.34024 .51722 L
.38138 .51382 L
.42101 .50969 L
.45912 .50516 L
.49968 .50004 L
.53872 .49511 L
.58022 .49018 L
.6202 .48603 L
.65867 .48286 L
.67854 .4816 L
.68869 .48107 L
.69959 .48059 L
.70981 .48022 L
.71916 .47996 L
.72365 .47986 L
Mistroke
.72855 .47977 L
.73318 .4797 L
.73747 .47966 L
.73876 .47965 L
.74013 .47964 L
.74131 .47963 L
.74257 .47963 L
.74328 .47963 L
.74392 .47962 L
.74519 .47962 L
.7459 .47962 L
.74667 .47962 L
.7474 .47962 L
.74807 .47962 L
.74926 .47962 L
.75037 .47962 L
.75159 .47963 L
.7529 .47963 L
.75558 .47965 L
.75804 .47967 L
.76237 .47972 L
.76711 .47979 L
.77666 .48 L
.78696 .48031 L
.7963 .48067 L
.81727 .48177 L
.83649 .4831 L
.8573 .48488 L
.89827 .48931 L
.93773 .49448 L
.97567 .49992 L
.97619 .5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 576},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900002@2000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oo
oo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX0
0?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]Zoooo
nfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00
;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5
o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oo
oo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Zoooo
nfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oook
JP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oo
nfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`00
0?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Z
oooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?
oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00
;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5
o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oo
oo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Zoooo
nfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oook
JP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oo
nfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`00
0?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Z
oooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?
oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00
;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5
o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oo
oo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Zoooo
nfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oook
JP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP004Ooo
nfX5o`00O`Cooo]Z0ol007l6oookJP?o001o2?oonfX5o`000?oooo]ZoooonfX?oookJP004?oonfX7
o`00O`?ooo]Z0ol007l6oookJP?o001o2?oonfX5o`000?oooo]ZoooonfX?oookJP004?oonfX3o`00
O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l6oookJP?o001o2?oonfX5o`000?oooo]ZoooonfX?
oookJP000ooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX9o`00O`Oooo]Z1Ol0003ooook
J_oooo]Z3ooonfX000?ooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z2Ol007l7oookJPOo
0000oooonf[ooookJPgooo]Z000?oookJP?o001o0ooonfX3o`00O`Kooo]Z0_l007l3oookJP?o001o
2?oonfX5o`000?oooo]ZoooonfX?oookJP003ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oo
nfX3o`00O`Sooo]Z1Ol0003ooookJ_oooo]Z3ooonfX000oooo]Z0ol007l3oookJP?o001o1ooonfX3
o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol0003ooookJ_oooo]Z3ooonfX000oooo]Z0ol007l3
oookJP?o001o2?oonfX2o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX000oooo]Z0ol007l3oookJP?o001o2OoonfX5o`00O`Sooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
013ooo]Z0ol007l01?oonf[o001oo`00Ool007l:oookJPGo001o2?oonfX5o`000?oooo]ZoooonfX?
oookJP004?oonfX7o`00O`_ooo]Z1?l007l8oookJPGo0000oooonf[ooookJPoooo]Z000AoookJPGo
001o3OoonfX3o`00O`Sooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002ko
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0
003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooook
J_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002ko
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0
003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooook
J_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002ko
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0
003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooook
J_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002ko
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0
003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooook
J_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002ko
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX0017ooo]Z1Ol007l4oookJP?o001o00?ooo]Zo`00Ool007l0
1ol007l7oookJPGo0000oooonf[ooookJPoooo]Z000@oookJPOo001o0ooonfX3o`00O`03oookJ_l0
07oo001o00Oo001o1ooonfX5o`000?oooo]ZoooonfX?oookJP004?oonfX3o`00O`04oookJ_l007oo
001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`cooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX000?ooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Oooo]Z1?l007l;oookJPGo0000oooonf[o
oookJPoooo]Z0003oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l8oookJPGo001o2OoonfX7o`00
0?oooo]ZoooonfX=oookJP003ooonfX3o`00O`?ooo]Z0ol007l:oookJPCo001o2?oonfX5o`000?oo
oo]ZoooonfX?oookJP003ooonfX3o`00O`?ooo]Z0ol007l;oookJP?o001o2?oonfX5o`000?oooo]Z
oooonfX?oookJP003ooonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX5o`000?oooo]Zoooo
nfX?oookJP003ooonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX000oooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7oook
JPGo0000oooonf[ooookJPoooo]Z000@oookJP?o001o00Cooo]Zo`00Ool007oo001o1ooonfX4o`00
O`;ooo]Z0ol007l7oookJPGo0000oooonf[ooookJPoooo]Z000@oookJPOo001o2?oonfX7o`00O`So
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX0017ooo]Z1Ol007l:oookJPGo001o2OoonfX5o`000?oooo]Z
oooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?
oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00
;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5
o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oo
oo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Zoooo
nfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oook
JP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oo
nfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`00
0?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Z
oooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?
oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00
;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5
o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oo
oo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Zoooo
nfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oook
JP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oo
nfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`00
0?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Z
oooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?
oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00
;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5
o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oo
oo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Zoooo
nfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oook
JP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oo
nfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`00
0?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Z
oooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?
oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00
;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5
o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oo
oo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Zoooo
nfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oook
JP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oo
nfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`00
05Wooo]Z1Ol007l4oookJP?o001o00?ooo]Zo`00Ool007l01ol007m@oookJPGo001o1?oonfX3o`00
O`Kooo]Z0ol007mAoookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007mBoookJPGo001o1?oonfX3o`00
O`?ooo]Z1Ol007mLoookJP?o001o3ooonfX002kooo]Z1Ol0001HoookJPOo001o0ooonfX3o`00O`03
oookJ_l007oo001o00Oo001oCooonfX7o`00O`?ooo]Z0ol007l6oookJP?o001oD?oonfX7o`00O`?o
oo]Z0ol007l2oookJPOo001oD?oonfX7o`00O`?ooo]Z0ol007l2oookJPOo001oFooonfX3o`00O`oo
oo]Z000^oookJPGo0000F?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o
001oo`00O`02o`00OeCooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1_oonfX3o`00
Oe3ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o0_oonfX3o`00O`;ooo]Z0ol007m?
oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z
0ol007mJoookJP?o001o3ooonfX002kooo]Z1Ol0001GoookJP?o001o0ooonfX3o`00O`Oooo]Z1?l0
07mBoookJP?o001o0ooonfX3o`00O`Kooo]Z2Ol007m>oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol0
07l3oookJP?o001oC_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00Oe[ooo]Z0ol0
07l?oookJP00;_oonfX5o`0005Oooo]Z0ol007l3oookJP?o001o2?oonfX5o`00Oe3ooo]Z0ol007l3
oookJP?o001o1_oonfX9o`00Odkooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007m>
oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001oF_oonfX3o`00O`oooo]Z000^oook
JPGo0000EooonfX3o`00O`?ooo]Z0ol007l:oookJPCo001oCooonfX3o`00O`?ooo]Z0ol007l6oook
JP;o001o0ooonfX3o`00Odoooo]Z0ol007l3oookJP?o001o1_oonfX4o`00O`;ooo]Z0ol007m>oook
JP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001oF_oonfX3o`00O`oooo]Z000^oookJPGo
0000EooonfX3o`00O`?ooo]Z0ol007l;oookJP?o001oCooonfX3o`00O`?ooo]Z0ol007l7oookJP;o
001o0_oonfX3o`00Odoooo]Z0ol007l3oookJP?o001o1_oonfX8o`00Odoooo]Z0ol007l3oookJP?o
001o1ooonfX7o`00Oe_ooo]Z0ol007l?oookJP00;_oonfX5o`0005Oooo]Z0ol007l3oookJP?o001o
3?oonfX3o`00Odkooo]Z0ol007l3oookJP?o001o1ooonfX3o`00O`04oookJ_l007oo001oo`00Odoo
oo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`04oookJ_l007oo001oo`00Oe3ooo]Z0ol007l3oook
JP?o001o1ooonfX7o`00Oe_ooo]Z0ol007l?oookJP00;_oonfX5o`0005Oooo]Z0ol007l3oookJP?o
001o1_oonfX3o`00O`?ooo]Z0ol007m>oookJP?o001o0ooonfX3o`00O`Sooo]Z0_l007l01?oonf[o
001oo`00Ool007m?oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007mDoookJP?o001o0ooonfX3o`00
O`Kooo]Z0ol007l3oookJP?o001oF_oonfX3o`00O`oooo]Z000^oookJPGo0000EooonfX3o`00O`?o
oo]Z0ol007l6oookJP?o001o0ooonfX3o`00Odkooo]Z0ol007l3oookJP?o001o2OoonfX5o`00Odoo
oo]Z0ol007l3oookJP?o001o1_oonfX3o`00OcCooo]Z<ol00002oookJP?o001oEooonfX6o`00O`oo
oo]Z000^oookJPGo0000F?oonfX3o`00O`04oookJ_l007oo001oo`00O`Oooo]Z1?l007l2oookJP?o
001oCooonfX3o`00O`04oookJ_l007oo001oo`00O`[ooo]Z1Ol007m@oookJP?o001o00Cooo]Zo`00
Ool007oo001o2?oonfX3o`00O`;ooo]Z0ol007lJoookJUWo0000B_oonfX6o`00O`oooo]Z000^oook
JPGo0000F?oonfX7o`00O`Sooo]Z1ol007m@oookJPOo001o2ooonfX4o`00Oe3ooo]Z1ol007l8oook
JPOo001o4OoonfY^o`00047ooo]Z1?l007l?oookJP00;_oonfX5o`0005Wooo]Z1Ol007l:oookJPGo
001oD_oonfX5o`00O`gooo]Z0ol007mAoookJPGo001o2ooonfX4o`00O`Oooo]ZQ?l0000goookJP?o
001o3ooonfX002kooo]Z1Ol0003ooookJSOooo]Z=_l0000]oookJSKo0000?_oonfX002kooo]Z1Ol0
003ooookJRcooo]Z;Ol0001CoookJRgo0000=OoonfX002kooo]Z1Ol0003ooookJR7ooo]Z;_l0001X
oookJRWo0000;_oonfX002kooo]Z1Ol0003ooookJQKooo]Z;_l0001noookJRGo00009ooonfX002ko
oo]Z1Ol0003ooookJPgooo]Z;Ol0002CoookJR7o00008?oonfX002kooo]Z1Ol0003ooookJPKooo]Z
:Ol0002WoookJQoo00006OoonfX0027ooo]Zool0003oo`00023o00000OoonfX0027ooo]Zool0003o
o`00023o00000OoonfX0027ooo]Zool0003oo`00023o00000OoonfX0027ooo]Zool0003oo`00023o
00000OoonfX0027ooo]Zool0003oo`00023o00000OoonfX002kooo]Z9?l00014oookJP03o`000?oo
nf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX02?oonfXUo`0003Kooo]Z00?o0000oookJ_oonfX0Hooo
nfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z00kooo]Z000^oookJPGo00001ooonfXO
o`000:Gooo]Z:?l0003ooookJQ_ooo]Z000^oookJPGo00003_oonfXRo`00093ooo]Z;?l0003ooook
JR;ooo]Z000^oookJPGo00005OoonfXVo`0007_ooo]Z;Ol0003ooookJR_ooo]Z000^oookJPGo0000
7?oonfXYo`0006Kooo]Z;Ol0003ooookJSKooo]Z000^oookJPGo00008ooonfX/o`00057ooo]Z;_l0
003ooookJT3ooo]Z000^oookJPGo0000;OoonfXeo`0002_ooo]Z=_l0003ooookJT_ooo]Z000^oook
JPGo0000>?oonfZ1o`000?oooo]ZEOoonfX002kooo]Z1Ol00012oookJVco0000oooonfYPoookJP00
;_oonfX5o`0004cooo]ZEol0003ooookJV_ooo]Z000^oookJPGo0000GooonfXao`000?oooo]ZO_oo
nfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002ko
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0
003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooook
J_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002ko
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0
003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooook
J_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002ko
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0
003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooook
J_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002ko
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0
003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooook
J_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002ko
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0
003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooook
J_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX0017ooo]Z1Ol007l4oookJP?o001o00?ooo]Zo`00Ool007l01ol007l7oookJPGo0000oooo
nf[ooookJPoooo]Z000@oookJPOo001o0ooonfX3o`00O`03oookJ_l007oo001o00Oo001o1ooonfX5
o`000?oooo]ZoooonfX?oookJP004?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l0
0ooonf[o001oo`00O`02o`00O`cooo]Z1Ol0003ooookJ_oooo]Z3ooonfX000oooo]Z0ol007l3oook
JP?o001o1ooonfX4o`00O`_ooo]Z1Ol0003ooookJ_oooo]Z3ooonfX000oooo]Z0ol007l3oookJP?o
001o2?oonfX5o`00O`Wooo]Z1ol0003ooookJ_oooo]Z3OoonfX000oooo]Z0ol007l3oookJP?o001o
2_oonfX4o`00O`Sooo]Z1Ol0003ooookJ_oooo]Z3ooonfX000oooo]Z0ol007l3oookJP?o001o2ooo
nfX3o`00O`Sooo]Z1Ol0003ooookJ_oooo]Z3ooonfX000oooo]Z0ol007l3oookJP?o001o3?oonfX3
o`00O`Oooo]Z1Ol0003ooookJ_oooo]Z3ooonfX000oooo]Z0ol007l3oookJP?o001o1_oonfX3o`00
O`?ooo]Z0ol007l7oookJPGo0000oooonf[ooookJPoooo]Z000?oookJP?o001o0ooonfX3o`00O`Ko
oo]Z0ol007l3oookJP?o001o1ooonfX5o`000?oooo]ZoooonfX?oookJP004?oonfX3o`00O`04oook
J_l007oo001oo`00O`Oooo]Z1?l007l2oookJP?o001o1ooonfX5o`000?oooo]ZoooonfX?oookJP00
4?oonfX7o`00O`Sooo]Z1ol007l8oookJPGo0000oooonf[ooookJPoooo]Z000AoookJPGo001o2_oo
nfX5o`00O`Wooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002ko
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0
003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooook
J_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002ko
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0
003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooook
J_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002ko
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0
003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooook
J_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002ko
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0
003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooook
J_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002ko
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0
003ooookJ_oooo]Z3ooonfX0017ooo]Z1Ol007l4oookJP?o001o1_oonfX3o`00O`Sooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX0013ooo]Z1ol007l3oookJP?o001o1_oonfX3o`00O`Sooo]Z1Ol0003ooook
J_oooo]Z3ooonfX0013ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1_oonfX3o`00
O`Sooo]Z1Ol0003ooookJ_oooo]Z3ooonfX000oooo]Z0ol007l3oookJP?o001o1_oonfX9o`00O`Oo
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX000oooo]Z0ol007l3oookJP?o001o1_oonfX9o`00O`Oooo]Z
1ol0003ooookJ_oooo]Z3OoonfX000oooo]Z0ol007l3oookJP?o001o1_oonfX2o`00O`?ooo]Z0ol0
07l8oookJPGo0000oooonf[ooookJPoooo]Z000?oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2
oookJP?o001o2?oonfX5o`000?oooo]ZoooonfX?oookJP003ooonfX3o`00O`?ooo]Z0ol007l7oook
JP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`000?oooo]ZoooonfX?oookJP003ooonfX3o`00
O`?ooo]Z0ol007l8oookJP;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`000?oooo]ZoooonfX?
oookJP003ooonfX3o`00O`?ooo]Z0ol007l9oookJPGo001o2?oonfX5o`000?oooo]ZoooonfX?oook
JP004?oonfX3o`00O`04oookJ_l007oo001oo`00O`[ooo]Z1Ol007l8oookJPGo0000oooonf[ooook
JPoooo]Z000@oookJPOo001o2ooonfX4o`00O`Sooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0017ooo]Z
1Ol007l=oookJP?o001o2?oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Zoooo
nfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oook
JP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oo
nfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`00
0?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Z
oooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?
oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00
;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5
o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oo
oo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Zoooo
nfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oook
JP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oo
nfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`00
0?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Z
oooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?
oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00
;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5
o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oo
oo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Zoooo
nfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oook
JP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oo
nfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00oooonf[ooook
JT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003o
oookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z
@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oo
oo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2
oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00001\
\>"],
  ImageRangeCache->{{{0, 575}, {575, 0}} -> {-0.0952157, -0.535939, \
0.00195734, 0.00186413}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["Clamped on both ends, with a \"box\" placed at x = 3/4", "Text"],

Cell[BoxData[
    \(boxload[
        x_]\  := \(-100\)*\((UnitStep[x - \((3/4 - 1/8)\)]\  - \ 
            UnitStep[x - \((3/4 + 1/8)\)])\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[boxload[x], {x, 0, 1}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.603319 0.00588604 [
[.21429 .59082 -14.5 -20 ]
[.21429 .59082 14.5 0 ]
[.40476 .59082 -14.5 -20 ]
[.40476 .59082 14.5 0 ]
[.59524 .59082 -14.5 -20 ]
[.59524 .59082 14.5 0 ]
[.78571 .59082 -14.5 -20 ]
[.78571 .59082 14.5 0 ]
[.97619 .59082 -7 -20 ]
[.97619 .59082 7 0 ]
[.01131 .01472 -46.9375 -10 ]
[.01131 .01472 0 10 ]
[.01131 .13244 -36.9375 -10 ]
[.01131 .13244 0 10 ]
[.01131 .25016 -36.9375 -10 ]
[.01131 .25016 0 10 ]
[.01131 .36788 -36.9375 -10 ]
[.01131 .36788 0 10 ]
[.01131 .4856 -36.9375 -10 ]
[.01131 .4856 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .60332 m
.21429 .60957 L
s
gsave
.21429 .59082 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.40476 .60332 m
.40476 .60957 L
s
gsave
.40476 .59082 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.59524 .60332 m
.59524 .60957 L
s
gsave
.59524 .59082 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.78571 .60332 m
.78571 .60957 L
s
gsave
.78571 .59082 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.97619 .60332 m
.97619 .60957 L
s
gsave
.97619 .59082 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .60332 m
.07143 .60707 L
s
.11905 .60332 m
.11905 .60707 L
s
.16667 .60332 m
.16667 .60707 L
s
.2619 .60332 m
.2619 .60707 L
s
.30952 .60332 m
.30952 .60707 L
s
.35714 .60332 m
.35714 .60707 L
s
.45238 .60332 m
.45238 .60707 L
s
.5 .60332 m
.5 .60707 L
s
.54762 .60332 m
.54762 .60707 L
s
.64286 .60332 m
.64286 .60707 L
s
.69048 .60332 m
.69048 .60707 L
s
.7381 .60332 m
.7381 .60707 L
s
.83333 .60332 m
.83333 .60707 L
s
.88095 .60332 m
.88095 .60707 L
s
.92857 .60332 m
.92857 .60707 L
s
.01 w
0 .60332 m
1 .60332 L
s
.25 Mabswid
.02381 .01472 m
.03006 .01472 L
s
gsave
.01131 .01472 -107.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.02381 .13244 m
.03006 .13244 L
s
gsave
.01131 .13244 -97.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(80) show
1.000 setlinewidth
grestore
.02381 .25016 m
.03006 .25016 L
s
gsave
.01131 .25016 -97.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(60) show
1.000 setlinewidth
grestore
.02381 .36788 m
.03006 .36788 L
s
gsave
.01131 .36788 -97.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(40) show
1.000 setlinewidth
grestore
.02381 .4856 m
.03006 .4856 L
s
gsave
.01131 .4856 -97.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .16187 m
.02756 .16187 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .45617 m
.02756 .45617 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.01 w
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .60332 m
.02499 .60332 L
.02605 .60332 L
.02729 .60332 L
.02846 .60332 L
.02954 .60332 L
.03053 .60332 L
.03163 .60332 L
.03279 .60332 L
.03395 .60332 L
.0352 .60332 L
.03638 .60332 L
.03746 .60332 L
.03873 .60332 L
.03944 .60332 L
.04011 .60332 L
.04132 .60332 L
.04262 .60332 L
.04327 .60332 L
.04396 .60332 L
.04519 .60332 L
.04588 .60332 L
.04652 .60332 L
.04722 .60332 L
.04797 .60332 L
.04862 .60332 L
.04933 .60332 L
.05061 .60332 L
.05186 .60332 L
.05302 .60332 L
.05414 .60332 L
.05519 .60332 L
.05634 .60332 L
.05759 .60332 L
.05882 .60332 L
.06012 .60332 L
.06123 .60332 L
.06244 .60332 L
.06315 .60332 L
.06381 .60332 L
.06453 .60332 L
.06529 .60332 L
.06657 .60332 L
.06729 .60332 L
.06797 .60332 L
.06924 .60332 L
.0704 .60332 L
.07103 .60332 L
.07173 .60332 L
.073 .60332 L
Mistroke
.07376 .60332 L
.07448 .60332 L
.07513 .60332 L
.07583 .60332 L
.0766 .60332 L
.0774 .60332 L
.07809 .60332 L
.07885 .60332 L
.07956 .60332 L
.0802 .60332 L
.08095 .60332 L
.08166 .60332 L
.08291 .60332 L
.08362 .60332 L
.08427 .60332 L
.08544 .60332 L
.08669 .60332 L
.08787 .60332 L
.08896 .60332 L
.09016 .60332 L
.09148 .60332 L
.09214 .60332 L
.09285 .60332 L
.09413 .60332 L
.09483 .60332 L
.09548 .60332 L
.09619 .60332 L
.09695 .60332 L
.09821 .60332 L
.09893 .60332 L
.09961 .60332 L
.10086 .60332 L
.10201 .60332 L
.10333 .60332 L
.10458 .60332 L
.10572 .60332 L
.10694 .60332 L
.1081 .60332 L
.10916 .60332 L
.11033 .60332 L
.11162 .60332 L
.11227 .60332 L
.11297 .60332 L
.11422 .60332 L
.11491 .60332 L
.11554 .60332 L
.11624 .60332 L
.11698 .60332 L
.11822 .60332 L
.11892 .60332 L
Mistroke
.11958 .60332 L
.12081 .60332 L
.12194 .60332 L
.12323 .60332 L
.12446 .60332 L
.12562 .60332 L
.12668 .60332 L
.12789 .60332 L
.12903 .60332 L
.13009 .60332 L
.13107 .60332 L
.13214 .60332 L
.13327 .60332 L
.13441 .60332 L
.13564 .60332 L
.1368 .60332 L
.13785 .60332 L
.13909 .60332 L
.13979 .60332 L
.14043 .60332 L
.14162 .60332 L
.14288 .60332 L
.14402 .60332 L
.14526 .60332 L
.14656 .60332 L
.14777 .60332 L
.14891 .60332 L
.14994 .60332 L
.15113 .60332 L
.15226 .60332 L
.15348 .60332 L
.15478 .60332 L
.15589 .60332 L
.15711 .60332 L
.15842 .60332 L
.15915 .60332 L
.15982 .60332 L
.16113 .60332 L
.16236 .60332 L
.16352 .60332 L
.16456 .60332 L
.16577 .60332 L
.1669 .60332 L
.16796 .60332 L
.16893 .60332 L
.16999 .60332 L
.17111 .60332 L
.17225 .60332 L
.17347 .60332 L
.17462 .60332 L
Mistroke
.17566 .60332 L
.17689 .60332 L
.17758 .60332 L
.17823 .60332 L
.1794 .60332 L
.18065 .60332 L
.18185 .60332 L
.18316 .60332 L
.18441 .60332 L
.18556 .60332 L
.1867 .60332 L
.18773 .60332 L
.18893 .60332 L
.19005 .60332 L
.19128 .60332 L
.19258 .60332 L
.19369 .60332 L
.19491 .60332 L
.19623 .60332 L
.19696 .60332 L
.19763 .60332 L
.19894 .60332 L
.20017 .60332 L
.20122 .60332 L
.20238 .60332 L
.20359 .60332 L
.20472 .60332 L
.20578 .60332 L
.20675 .60332 L
.20781 .60332 L
.20894 .60332 L
.21008 .60332 L
.21129 .60332 L
.21244 .60332 L
.21349 .60332 L
.21472 .60332 L
.21541 .60332 L
.21605 .60332 L
.21723 .60332 L
.21847 .60332 L
.21968 .60332 L
.221 .60332 L
.22224 .60332 L
.2234 .60332 L
.22454 .60332 L
.22558 .60332 L
.22677 .60332 L
.2279 .60332 L
.22914 .60332 L
.23044 .60332 L
Mistroke
.23155 .60332 L
.23277 .60332 L
.23409 .60332 L
.23482 .60332 L
.2355 .60332 L
.2368 .60332 L
.23804 .60332 L
.23909 .60332 L
.24025 .60332 L
.24146 .60332 L
.2426 .60332 L
.24365 .60332 L
.24462 .60332 L
.24569 .60332 L
.24681 .60332 L
.24795 .60332 L
.24917 .60332 L
.25032 .60332 L
.25137 .60332 L
.2526 .60332 L
.25329 .60332 L
.25393 .60332 L
.2551 .60332 L
.25635 .60332 L
.25756 .60332 L
.25888 .60332 L
.26013 .60332 L
.26129 .60332 L
.26233 .60332 L
.26348 .60332 L
.26467 .60332 L
.2658 .60332 L
.26704 .60332 L
.26835 .60332 L
.26946 .60332 L
.27068 .60332 L
.272 .60332 L
.27274 .60332 L
.27341 .60332 L
.27472 .60332 L
.27595 .60332 L
.27701 .60332 L
.27817 .60332 L
.27938 .60332 L
.28052 .60332 L
.28158 .60332 L
.28255 .60332 L
.28367 .60332 L
.28474 .60332 L
.28588 .60332 L
Mistroke
.2871 .60332 L
.28825 .60332 L
.2893 .60332 L
.29053 .60332 L
.29122 .60332 L
.29186 .60332 L
.29303 .60332 L
.29427 .60332 L
.29549 .60332 L
.29618 .60332 L
.29682 .60332 L
.29799 .60332 L
.29923 .60332 L
.30034 .60332 L
.30138 .60332 L
.30252 .60332 L
.30375 .60332 L
.30499 .60332 L
.30569 .60332 L
.30634 .60332 L
.30765 .60332 L
.30839 .60332 L
.30906 .60332 L
.31026 .60332 L
.31156 .60332 L
.31278 .60332 L
.31392 .60332 L
.31497 .60332 L
.31611 .60332 L
.31718 .60332 L
.31816 .60332 L
.3193 .60332 L
.32055 .60332 L
.32173 .60332 L
.32282 .60332 L
.32406 .60332 L
.32522 .60332 L
.32626 .60332 L
.32739 .60332 L
.32862 .60332 L
.32992 .60332 L
.33103 .60332 L
.33225 .60332 L
.33356 .60332 L
.33477 .60332 L
.33541 .60332 L
.3361 .60332 L
.33683 .60332 L
.33751 .60332 L
.33876 .60332 L
Mistroke
.33991 .60332 L
.34123 .60332 L
.34249 .60332 L
.3436 .60332 L
.3448 .60332 L
.34592 .60332 L
.34694 .60332 L
.34814 .60332 L
.34945 .60332 L
.35067 .60332 L
.35181 .60332 L
.35302 .60332 L
.35431 .60332 L
.35554 .60332 L
.35665 .60332 L
.35796 .60332 L
.3587 .60332 L
.35939 .60332 L
.36064 .60332 L
.36128 .60332 L
.36198 .60332 L
.36266 .60332 L
.36337 .60332 L
.36465 .60332 L
.36536 .60332 L
.36602 .60332 L
.36675 .60332 L
.36753 .60332 L
.3682 .60332 L
.36893 .60332 L
.36962 .60332 L
.37026 .60332 L
.37146 .60332 L
.37274 .60332 L
.37394 .60332 L
.37526 .60332 L
.37651 .60332 L
.37766 .60332 L
.3788 .60332 L
.37984 .60332 L
.38103 .60332 L
.38216 .60332 L
.38339 .60332 L
.3847 .60332 L
.38581 .60332 L
.38703 .60332 L
.38834 .60332 L
.38908 .60332 L
.38975 .60332 L
.39106 .60332 L
Mistroke
.39229 .60332 L
.39334 .60332 L
.3945 .60332 L
.39571 .60332 L
.39685 .60332 L
.39791 .60332 L
.39888 .60332 L
.39994 .60332 L
.40106 .60332 L
.40221 .60332 L
.40342 .60332 L
.40457 .60332 L
.40562 .60332 L
.40685 .60332 L
.40754 .60332 L
.40818 .60332 L
.40936 .60332 L
.4106 .60332 L
.41181 .60332 L
.41313 .60332 L
.41438 .60332 L
.41554 .60332 L
.41669 .60332 L
.41772 .60332 L
.41892 .60332 L
.42005 .60332 L
.42129 .60332 L
.42259 .60332 L
.42371 .60332 L
.42493 .60332 L
.42624 .60332 L
.42698 .60332 L
.42765 .60332 L
.42896 .60332 L
.43019 .60332 L
.43125 .60332 L
.43241 .60332 L
.43362 .60332 L
.43476 .60332 L
.43582 .60332 L
.43679 .60332 L
.43791 .60332 L
.43898 .60332 L
.44012 .60332 L
.44134 .60332 L
.44249 .60332 L
.44354 .60332 L
.44477 .60332 L
.44546 .60332 L
.4461 .60332 L
Mistroke
.44727 .60332 L
.44851 .60332 L
.44973 .60332 L
.45042 .60332 L
.45106 .60332 L
.45223 .60332 L
.45347 .60332 L
.45458 .60332 L
.45562 .60332 L
.45676 .60332 L
.45799 .60332 L
.45922 .60332 L
.45992 .60332 L
.46057 .60332 L
.46188 .60332 L
.46262 .60332 L
.46329 .60332 L
.46449 .60332 L
.46579 .60332 L
.46702 .60332 L
.46815 .60332 L
.4692 .60332 L
.47034 .60332 L
.47141 .60332 L
.47239 .60332 L
.47353 .60332 L
.47478 .60332 L
.47596 .60332 L
.47705 .60332 L
.47829 .60332 L
.47945 .60332 L
.48049 .60332 L
.48162 .60332 L
.48285 .60332 L
.48415 .60332 L
.48526 .60332 L
.48648 .60332 L
.48779 .60332 L
.489 .60332 L
.48963 .60332 L
.49033 .60332 L
.49105 .60332 L
.49174 .60332 L
.49299 .60332 L
.49413 .60332 L
.49539 .60332 L
.49671 .60332 L
.49783 .60332 L
.49902 .60332 L
.50014 .60332 L
Mistroke
.50116 .60332 L
.50236 .60332 L
.50366 .60332 L
.50489 .60332 L
.50603 .60332 L
.50723 .60332 L
.50853 .60332 L
.50975 .60332 L
.51087 .60332 L
.51218 .60332 L
.51292 .60332 L
.51361 .60332 L
.51486 .60332 L
.5155 .60332 L
.5162 .60332 L
.51687 .60332 L
.51759 .60332 L
.51886 .60332 L
.51958 .60332 L
.52024 .60332 L
.52096 .60332 L
.52174 .60332 L
.52241 .60332 L
.52314 .60332 L
.52383 .60332 L
.52447 .60332 L
.52568 .60332 L
.52695 .60332 L
.52816 .60332 L
.52947 .60332 L
.53072 .60332 L
.53187 .60332 L
.53301 .60332 L
.53405 .60332 L
.53525 .60332 L
.53637 .60332 L
.5376 .60332 L
.53891 .60332 L
.54002 .60332 L
.54124 .60332 L
.54255 .60332 L
.54329 .60332 L
.54396 .60332 L
.54526 .60332 L
.5465 .60332 L
.54755 .60332 L
.54871 .60332 L
.54992 .60332 L
.55105 .60332 L
.55211 .60332 L
Mistroke
.55308 .60332 L
.55415 .60332 L
.55527 .60332 L
.55641 .60332 L
.55763 .60332 L
.55878 .60332 L
.55982 .60332 L
.56105 .60332 L
.56175 .60332 L
.56238 .60332 L
.56356 .60332 L
.5648 .60332 L
.56601 .60332 L
.56734 .60332 L
.56858 .60332 L
.56974 .60332 L
.57088 .60332 L
.57192 .60332 L
.57312 .60332 L
.57425 .60332 L
.57548 .60332 L
.57679 .60332 L
.5779 .60332 L
.57912 .60332 L
.58044 .60332 L
.58118 .60332 L
.58185 .60332 L
.58315 .60332 L
.58439 .60332 L
.58544 .60332 L
.5866 .60332 L
.58782 .60332 L
.58895 .60332 L
.59001 .60332 L
.59098 .60332 L
.5921 .60332 L
.59317 .60332 L
.59431 .60332 L
.59553 .60332 L
.59668 .60332 L
.59773 .60332 L
.59896 .60332 L
.59965 .60332 L
.60029 .60332 L
.60146 .60332 L
.60271 .60332 L
.60392 .60332 L
.60461 .60332 L
.60525 .60332 L
.60642 .60332 L
Mistroke
.60766 .60332 L
.60876 .60332 L
.6098 .60332 L
.61094 .60332 L
.61217 .60332 L
.61341 .60332 L
.6141 .60332 L
.61475 .60332 L
.61607 .60332 L
.6168 .60332 L
.61747 .60332 L
.61867 .60332 L
.61997 .01472 L
.6212 .01472 L
.62233 .01472 L
.64066 .01472 L
.68005 .01472 L
.71792 .01472 L
.75824 .01472 L
.79705 .01472 L
.81678 .01472 L
.8272 .01472 L
.83831 .01472 L
.84388 .01472 L
.84912 .01472 L
.85383 .01472 L
.85512 .01472 L
.85583 .01472 L
.85649 .01472 L
.85765 .60332 L
.85892 .60332 L
.86011 .60332 L
.86141 .60332 L
.86263 .60332 L
.86376 .60332 L
.86477 .60332 L
.86589 .60332 L
.86706 .60332 L
.86816 .60332 L
.86937 .60332 L
.87064 .60332 L
.87173 .60332 L
.87292 .60332 L
.87421 .60332 L
.87493 .60332 L
.87558 .60332 L
.87685 .60332 L
.87805 .60332 L
.87921 .60332 L
.88045 .60332 L
Mistroke
.88162 .60332 L
.88269 .60332 L
.88394 .60332 L
.88465 .60332 L
.88531 .60332 L
.88651 .60332 L
.88779 .60332 L
.889 .60332 L
.89031 .60332 L
.89155 .60332 L
.89268 .60332 L
.89394 .60332 L
.89465 .60332 L
.89531 .60332 L
.89602 .60332 L
.89666 .60332 L
.89739 .60332 L
.89809 .60332 L
.89915 .60332 L
.90032 .60332 L
.90155 .60332 L
.90269 .60332 L
.90376 .60332 L
.90474 .60332 L
.90587 .60332 L
.90694 .60332 L
.9081 .60332 L
.90932 .60332 L
.91048 .60332 L
.91154 .60332 L
.91278 .60332 L
.91348 .60332 L
.91412 .60332 L
.9153 .60332 L
.91655 .60332 L
.91777 .60332 L
.91846 .60332 L
.9191 .60332 L
.92027 .60332 L
.92151 .60332 L
.92262 .60332 L
.92366 .60332 L
.9248 .60332 L
.92603 .60332 L
.92726 .60332 L
.92796 .60332 L
.92861 .60332 L
.92993 .60332 L
.93066 .60332 L
.93133 .60332 L
Mistroke
.93253 .60332 L
.93383 .60332 L
.93506 .60332 L
.93619 .60332 L
.93725 .60332 L
.93838 .60332 L
.93945 .60332 L
.94043 .60332 L
.94158 .60332 L
.94283 .60332 L
.944 .60332 L
.9451 .60332 L
.94633 .60332 L
.94749 .60332 L
.94854 .60332 L
.94966 .60332 L
.9509 .60332 L
.9522 .60332 L
.95331 .60332 L
.95453 .60332 L
.95523 .60332 L
.95587 .60332 L
.95659 .60332 L
.95734 .60332 L
.95861 .60332 L
.95933 .60332 L
.96 .60332 L
.96126 .60332 L
.9624 .60332 L
.96366 .60332 L
.9643 .60332 L
.96499 .60332 L
.96575 .60332 L
.96646 .60332 L
.9671 .60332 L
.9678 .60332 L
.96856 .60332 L
.96936 .60332 L
.97004 .60332 L
.9708 .60332 L
.9715 .60332 L
.97214 .60332 L
.97288 .60332 L
.97358 .60332 L
.97483 .60332 L
.97554 .60332 L
.97619 .60332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oo
oo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX0
03?ooo]Z1Ol0003ooookJ_oooo]Z2_oonfX003?ooo]Z1Ol0003ooookJ_oooo]Z2_oonfX003?ooo]Z
1Ol0003ooookJ_oooo]Z2_oonfX003?ooo]Z1Ol0003ooookJ_oooo]Z2_oonfX003?ooo]Z1Ol0003o
oookJ_oooo]Z2_oonfX003?ooo]Z1Ol0003ooookJ_oooo]Z2_oonfX001?ooo]Z0ol007l5oookJPGo
001o1OoonfX5o`00O`Wooo]Z1Ol0003ooookJ_oooo]Z2_oonfX001?ooo]Z0ol007l4oookJPOo001o
0ooonfX7o`00O`Sooo]Z1Ol0003ooookJ_oooo]Z2_oonfX001?ooo]Z0ol007l4oookJP?o001o00Co
oo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol0003ooookJ_oo
oo]Z2_oonfX000?ooo]Z2_l007l6oookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l01?oonf[o001o
o`00Ool007l3oookJP?o001o1ooonfX5o`000?oooo]Z>_oonfZ1o`0004kooo]Z0003oookJP[o001o
1_oonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Oo
oo]Z1_l0003ooookJSWooo]ZPOl0001>oookJP004ooonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o
00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Oooo]Z1Ol0003ooookJS[ooo]ZPOl0001>oookJP00
4ooonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Oo
oo]Z1Ol0003ooookJS[ooo]Z0ol0001koookJP?o0000C_oonfX001?ooo]Z0ol007l3oookJP?o001o
0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l7oookJPGo0000oooonfXjoookJP?o
0000NooonfX3o`0004kooo]Z000CoookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l01?oonf[o001o
o`00Ool007l3oookJP?o001o1ooonfX5o`000?oooo]Z>_oonfX3o`0007_ooo]Z0ol0001>oookJP00
4?oonfX6o`00O`?ooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Oo
oo]Z1Ol0003ooookJS[ooo]Z0ol0001koookJP?o0000C_oonfX0013ooo]Z1_l007l4oookJP?o001o
00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol0003ooook
JS[ooo]Z0ol0001koookJP?o0000C_oonfX001;ooo]Z1?l007l4oookJPOo001o0ooonfX7o`00O`So
oo]Z1Ol0003ooookJS[ooo]Z0ol0001koookJP?o0000C_oonfX001?ooo]Z0ol007l5oookJPGo001o
1OoonfX5o`00O`Wooo]Z1Ol0003ooookJS[ooo]Z0ol0001koookJP?o0000C_oonfX003?ooo]Z1Ol0
003ooookJS[ooo]Z0ol0001koookJP?o0000C_oonfX003?ooo]Z1Ol0003ooookJS[ooo]Z0ol0001k
oookJP?o0000C_oonfX003?ooo]Z1Ol0003ooookJS[ooo]Z0ol0001koookJP?o0000C_oonfX003?o
oo]Z1Ol0003ooookJS[ooo]Z0ol0001koookJP?o0000C_oonfX003?ooo]Z1Ol0003ooookJS[ooo]Z
0ol0001koookJP?o0000C_oonfX003?ooo]Z1Ol0003ooookJS[ooo]Z0ol0001koookJP?o0000C_oo
nfX003?ooo]Z1Ol0003ooookJS[ooo]Z0ol0001koookJP?o0000C_oonfX003?ooo]Z1Ol0003ooook
JS[ooo]Z0ol0001koookJP?o0000C_oonfX003?ooo]Z1Ol0003ooookJS[ooo]Z0ol0001koookJP?o
0000C_oonfX003?ooo]Z1Ol0003ooookJS[ooo]Z0ol0001koookJP?o0000C_oonfX003?ooo]Z1Ol0
003ooookJS[ooo]Z0ol0001koookJP?o0000C_oonfX003?ooo]Z1Ol0003ooookJS[ooo]Z0ol0001k
oookJP?o0000C_oonfX003?ooo]Z1Ol0003ooookJS[ooo]Z0ol0001koookJP?o0000C_oonfX003?o
oo]Z1Ol0003ooookJS[ooo]Z0ol0001koookJP?o0000C_oonfX003?ooo]Z1Ol0003ooookJS[ooo]Z
0ol0001koookJP?o0000C_oonfX003?ooo]Z1Ol0003ooookJS[ooo]Z0ol0001koookJP?o0000C_oo
nfX003?ooo]Z1Ol0003ooookJS[ooo]Z0ol0001koookJP?o0000C_oonfX003?ooo]Z1Ol0003ooook
JS[ooo]Z0ol0001koookJP?o0000C_oonfX003?ooo]Z1Ol0003ooookJS[ooo]Z0ol0001koookJP?o
0000C_oonfX003?ooo]Z1Ol0003ooookJS[ooo]Z0ol0001koookJP?o0000C_oonfX003?ooo]Z1Ol0
003ooookJS[ooo]Z0ol0001koookJP?o0000C_oonfX003?ooo]Z1Ol0003ooookJS[ooo]Z0ol0001k
oookJP?o0000C_oonfX003?ooo]Z1Ol0003ooookJS[ooo]Z0ol0001koookJP?o0000C_oonfX003?o
oo]Z1Ol0003ooookJS[ooo]Z0ol0001koookJP?o0000C_oonfX003?ooo]Z1Ol0003ooookJS[ooo]Z
0ol0001koookJP?o0000C_oonfX003?ooo]Z1Ol0003ooookJS[ooo]Z0ol0001koookJP?o0000C_oo
nfX003?ooo]Z1Ol0003ooookJS[ooo]Z0ol0001koookJP?o0000C_oonfX003?ooo]Z1Ol0003ooook
JS[ooo]Z0ol0001koookJP?o0000C_oonfX003?ooo]Z1Ol0003ooookJS[ooo]Z0ol0001koookJP?o
0000C_oonfX003?ooo]Z1Ol0003ooookJS[ooo]Z0ol0001koookJP?o0000C_oonfX003?ooo]Z1Ol0
003ooookJS[ooo]Z0ol0001koookJP?o0000C_oonfX003?ooo]Z1Ol0003ooookJS[ooo]Z0ol0001k
oookJP?o0000C_oonfX003?ooo]Z1Ol0003ooookJS[ooo]Z0ol0001koookJP?o0000C_oonfX003?o
oo]Z1Ol0003ooookJS[ooo]Z0ol0001koookJP?o0000C_oonfX003?ooo]Z1Ol0003ooookJS[ooo]Z
0ol0001koookJP?o0000C_oonfX003?ooo]Z1Ol0003ooookJS[ooo]Z0ol0001koookJP?o0000C_oo
nfX003?ooo]Z1Ol0003ooookJS[ooo]Z0ol0001koookJP?o0000C_oonfX003?ooo]Z1Ol0003ooook
JS[ooo]Z0ol0001koookJP?o0000C_oonfX003?ooo]Z1Ol0003ooookJS[ooo]Z0ol0001koookJP?o
0000C_oonfX003?ooo]Z1Ol0003ooookJS[ooo]Z0ol0001koookJP?o0000C_oonfX003?ooo]Z1Ol0
003ooookJS[ooo]Z0ol0001koookJP?o0000C_oonfX003?ooo]Z1Ol0003ooookJS[ooo]Z0ol0001k
oookJP?o0000C_oonfX003?ooo]Z1Ol0003ooookJS[ooo]Z0ol0001koookJP?o0000C_oonfX003?o
oo]Z1Ol0003ooookJS[ooo]Z0ol0001koookJP?o0000C_oonfX003?ooo]Z1Ol0003ooookJS[ooo]Z
0ol0001koookJP?o0000C_oonfX003?ooo]Z1Ol0003ooookJS[ooo]Z0ol0001koookJP?o0000C_oo
nfX003?ooo]Z1Ol0003ooookJS[ooo]Z0ol0001koookJP?o0000C_oonfX003?ooo]Z1Ol0003ooook
JS[ooo]Z0ol0001koookJP?o0000C_oonfX003?ooo]Z1Ol0003ooookJS[ooo]Z0ol0001koookJP?o
0000C_oonfX001_ooo]Z1Ol007l5oookJPGo001o2OoonfX5o`000?oooo]Z>_oonfX3o`0007_ooo]Z
0ol0001>oookJP006_oonfX7o`00O`?ooo]Z1ol007l8oookJPGo0000oooonfXjoookJP?o0000Nooo
nfX3o`0004kooo]Z000IoookJP?o001o0ooonfX3o`00O`;ooo]Z0ol007l01?oonf[o001oo`00Ool0
07l8oookJPGo0000oooonfXjoookJP?o0000NooonfX3o`0004kooo]Z000=oookJP[o001o0_oonfX3
o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1ooonfX5o`000?oooo]Z>_oo
nfX3o`0007_ooo]Z0ol0001>oookJP003OoonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o00Cooo]Z
o`00Ool007oo001o0ooonfX3o`00O`Oooo]Z1_l0003ooookJSWooo]Z0ol0001koookJP?o0000C_oo
nfX001Wooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Oooo]Z1Ol0
003ooookJS[ooo]Z0ol0001koookJP?o0000C_oonfX001[ooo]Z1ol007l2oookJP?o001o0ooonfX3
o`00O`Oooo]Z1Ol0003ooookJS[ooo]Z0ol0001koookJP?o0000C_oonfX001[ooo]Z1ol007l2oook
JP?o001o0ooonfX3o`00O`Oooo]Z1Ol0003ooookJS[ooo]Z0ol0001koookJP?o0000C_oonfX001Wo
oo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Oooo]Z1Ol0003ooook
JS[ooo]Z0ol0001koookJP?o0000C_oonfX001Wooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool0
07oo001o0ooonfX3o`00O`Oooo]Z1Ol0003ooookJS[ooo]Z0ol0001koookJP?o0000C_oonfX001Wo
oo]Z0ol007l3oookJP?o001o0_oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol0003ooook
JS[ooo]Z0ol0001koookJP?o0000C_oonfX001[ooo]Z1ol007l3oookJPOo001o2?oonfX5o`000?oo
oo]Z>_oonfX3o`0007_ooo]Z0ol0001>oookJP006ooonfX5o`00O`Gooo]Z1Ol007l9oookJPGo0000
oooonfXjoookJP?o0000NooonfX3o`0004kooo]Z000coookJPGo0000oooonfXjoookJP?o0000Nooo
nfX3o`0004kooo]Z000coookJPGo0000oooonfXjoookJP?o0000NooonfX3o`0004kooo]Z000coook
JPGo0000oooonfXjoookJP?o0000NooonfX3o`0004kooo]Z000coookJPGo0000oooonfXjoookJP?o
0000NooonfX3o`0004kooo]Z000coookJPGo0000oooonfXjoookJP?o0000NooonfX3o`0004kooo]Z
000coookJPGo0000oooonfXjoookJP?o0000NooonfX3o`0004kooo]Z000coookJPGo0000oooonfXj
oookJP?o0000NooonfX3o`0004kooo]Z000coookJPGo0000oooonfXjoookJP?o0000NooonfX3o`00
04kooo]Z000coookJPGo0000oooonfXjoookJP?o0000NooonfX3o`0004kooo]Z000coookJPGo0000
oooonfXjoookJP?o0000NooonfX3o`0004kooo]Z000coookJPGo0000oooonfXjoookJP?o0000Nooo
nfX3o`0004kooo]Z000coookJPGo0000oooonfXjoookJP?o0000NooonfX3o`0004kooo]Z000coook
JPGo0000oooonfXjoookJP?o0000NooonfX3o`0004kooo]Z000coookJPGo0000oooonfXjoookJP?o
0000NooonfX3o`0004kooo]Z000coookJPGo0000oooonfXjoookJP?o0000NooonfX3o`0004kooo]Z
000coookJPGo0000oooonfXjoookJP?o0000NooonfX3o`0004kooo]Z000coookJPGo0000oooonfXj
oookJP?o0000NooonfX3o`0004kooo]Z000coookJPGo0000oooonfXjoookJP?o0000NooonfX3o`00
04kooo]Z000coookJPGo0000oooonfXjoookJP?o0000NooonfX3o`0004kooo]Z000coookJPGo0000
oooonfXjoookJP?o0000NooonfX3o`0004kooo]Z000coookJPGo0000oooonfXjoookJP?o0000Nooo
nfX3o`0004kooo]Z000coookJPGo0000oooonfXjoookJP?o0000NooonfX3o`0004kooo]Z000coook
JPGo0000oooonfXjoookJP?o0000NooonfX3o`0004kooo]Z000coookJPGo0000oooonfXjoookJP?o
0000NooonfX3o`0004kooo]Z000coookJPGo0000oooonfXjoookJP?o0000NooonfX3o`0004kooo]Z
000coookJPGo0000oooonfXjoookJP?o0000NooonfX3o`0004kooo]Z000coookJPGo0000oooonfXj
oookJP?o0000NooonfX3o`0004kooo]Z000coookJPGo0000oooonfXjoookJP?o0000NooonfX3o`00
04kooo]Z000coookJPGo0000oooonfXjoookJP?o0000NooonfX3o`0004kooo]Z000coookJPGo0000
oooonfXjoookJP?o0000NooonfX3o`0004kooo]Z000coookJPGo0000oooonfXjoookJP?o0000Nooo
nfX3o`0004kooo]Z000coookJPGo0000oooonfXjoookJP?o0000NooonfX3o`0004kooo]Z000coook
JPGo0000oooonfXjoookJP?o0000NooonfX3o`0004kooo]Z000coookJPGo0000oooonfXjoookJP?o
0000NooonfX3o`0004kooo]Z000coookJPGo0000oooonfXjoookJP?o0000NooonfX3o`0004kooo]Z
000coookJPGo0000oooonfXjoookJP?o0000NooonfX3o`0004kooo]Z000coookJPGo0000oooonfXj
oookJP?o0000NooonfX3o`0004kooo]Z000coookJPGo0000oooonfXjoookJP?o0000NooonfX3o`00
04kooo]Z000coookJPGo0000oooonfXjoookJP?o0000NooonfX3o`0004kooo]Z000coookJPGo0000
oooonfXjoookJP?o0000NooonfX3o`0004kooo]Z000coookJPGo0000oooonfXjoookJP?o0000Nooo
nfX3o`0004kooo]Z000coookJPGo0000oooonfXjoookJP?o0000NooonfX3o`0004kooo]Z000coook
JPGo0000oooonfXjoookJP?o0000NooonfX3o`0004kooo]Z000coookJPGo0000oooonfXjoookJP?o
0000NooonfX3o`0004kooo]Z000coookJPGo0000oooonfXjoookJP?o0000NooonfX3o`0004kooo]Z
000coookJPGo0000oooonfXjoookJP?o0000NooonfX3o`0004kooo]Z000coookJPGo0000oooonfXj
oookJP?o0000NooonfX3o`0004kooo]Z000coookJPGo0000oooonfXjoookJP?o0000NooonfX3o`00
04kooo]Z000coookJPGo0000oooonfXjoookJP?o0000NooonfX3o`0004kooo]Z000coookJPGo0000
oooonfXjoookJP?o0000NooonfX3o`0004kooo]Z000KoookJPGo001o1OoonfX5o`00O`Wooo]Z1Ol0
003ooookJS[ooo]Z0ol0001koookJP?o0000C_oonfX001[ooo]Z1ol007l3oookJPOo001o2?oonfX5
o`000?oooo]Z>_oonfX3o`0007_ooo]Z0ol0001>oookJP006_oonfX3o`00O`;ooo]Z0ol007l2oook
JP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`000?oooo]Z>_oonfX3o`0007_ooo]Z0ol0001>
oookJP003OoonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3
o`00O`Oooo]Z1Ol0003ooookJS[ooo]Z0ol0001koookJP?o0000C_oonfX000gooo]Z2_l007l2oook
JP?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l7oookJPKo0000oooonfXi
oookJP?o0000NooonfX3o`0004kooo]Z000IoookJPCo001o0_oonfX3o`00O`04oookJ_l007oo001o
o`00O`?ooo]Z0ol007l7oookJPGo0000oooonfXjoookJP?o0000NooonfX3o`0004kooo]Z000Ioook
JPSo001o0_oonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000oooonfXjoookJP?o0000NooonfX3o`00
04kooo]Z000IoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`?ooo]Z0ol007l7oook
JPGo0000oooonfXjoookJP?o0000NooonfX3o`0004kooo]Z000IoookJP?o001o1ooonfX3o`00O`?o
oo]Z0ol007l7oookJPGo0000oooonfXjoookJP?o0000NooonfX3o`0004kooo]Z000IoookJP?o001o
1ooonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000oooonfXjoookJP?o0000NooonfX3o`0004kooo]Z
000JoookJP?o001o0_oonfX3o`00O`;ooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo0000
oooonfXjoookJP?o0000NooonfX3o`0004kooo]Z000JoookJPOo001o0ooonfX7o`00O`Sooo]Z1Ol0
003ooookJS[ooo]Z0ol0001koookJP?o0000C_oonfX001cooo]Z1?l007l5oookJPGo001o2OoonfX5
o`000?oooo]Z>_oonfX3o`0007_ooo]Z0ol0001>oookJP00<ooonfX5o`000?oooo]Z>_oonfX3o`00
07_ooo]Z0ol0001>oookJP00<ooonfX5o`000?oooo]Z>_oonfX3o`0007_ooo]Z0ol0001>oookJP00
<ooonfX5o`000?oooo]Z>_oonfX3o`0007_ooo]Z0ol0001>oookJP00<ooonfX5o`000?oooo]Z>_oo
nfX3o`0007_ooo]Z0ol0001>oookJP00<ooonfX5o`000?oooo]Z>_oonfX3o`0007_ooo]Z0ol0001>
oookJP00<ooonfX5o`000?oooo]Z>_oonfX3o`0007_ooo]Z0ol0001>oookJP00<ooonfX5o`000?oo
oo]Z>_oonfX3o`0007_ooo]Z0ol0001>oookJP00<ooonfX5o`000?oooo]Z>_oonfX3o`0007_ooo]Z
0ol0001>oookJP00<ooonfX5o`000?oooo]Z>_oonfX3o`0007_ooo]Z0ol0001>oookJP00<ooonfX5
o`000?oooo]Z>_oonfX3o`0007_ooo]Z0ol0001>oookJP00<ooonfX5o`000?oooo]Z>_oonfX3o`00
07_ooo]Z0ol0001>oookJP00<ooonfX5o`000?oooo]Z>_oonfX3o`0007_ooo]Z0ol0001>oookJP00
<ooonfX5o`000?oooo]Z>_oonfX3o`0007_ooo]Z0ol0001>oookJP00<ooonfX5o`000?oooo]Z>_oo
nfX3o`0007_ooo]Z0ol0001>oookJP00<ooonfX5o`000?oooo]Z>_oonfX3o`0007_ooo]Z0ol0001>
oookJP00<ooonfX5o`000?oooo]Z>_oonfX3o`0007_ooo]Z0ol0001>oookJP00<ooonfX5o`000?oo
oo]Z>_oonfX3o`0007_ooo]Z0ol0001>oookJP00<ooonfX5o`000?oooo]Z>_oonfX3o`0007_ooo]Z
0ol0001>oookJP00<ooonfX5o`000?oooo]Z>_oonfX3o`0007_ooo]Z0ol0001>oookJP00<ooonfX5
o`000?oooo]Z>_oonfX3o`0007_ooo]Z0ol0001>oookJP00<ooonfX5o`000?oooo]Z>_oonfX3o`00
07_ooo]Z0ol0001>oookJP00<ooonfX5o`000?oooo]Z>_oonfX3o`0007_ooo]Z0ol0001>oookJP00
<ooonfX5o`000?oooo]Z>OoonfX4o`0007_ooo]Z0ol0001>oookJP00<ooonfX5o`000?oooo]Z>Ooo
nfX4o`0007_ooo]Z0ol0001>oookJP00<ooonfX5o`000?oooo]Z>OoonfX3o`0007cooo]Z0ol0001>
oookJP00<ooonfX5o`000?oooo]Z>OoonfX3o`0007cooo]Z0ol0001>oookJP00<ooonfX5o`000?oo
oo]Z>OoonfX3o`0007cooo]Z0ol0001>oookJP00<ooonfX5o`000?oooo]Z>OoonfX3o`0007cooo]Z
0ol0001>oookJP00<ooonfX5o`000?oooo]Z>OoonfX3o`0007cooo]Z0ol0001>oookJP00<ooonfX5
o`000?oooo]Z>OoonfX3o`0007cooo]Z0ol0001>oookJP00<ooonfX5o`000?oooo]Z>OoonfX3o`00
07cooo]Z0ol0001>oookJP00<ooonfX5o`000?oooo]Z>OoonfX3o`0007cooo]Z0ol0001>oookJP00
<ooonfX5o`000?oooo]Z>OoonfX3o`0007cooo]Z0ol0001>oookJP00<ooonfX5o`000?oooo]Z>Ooo
nfX3o`0007cooo]Z0ol0001>oookJP00<ooonfX5o`000?oooo]Z>OoonfX3o`0007cooo]Z0ol0001>
oookJP00<ooonfX5o`000?oooo]Z>OoonfX3o`0007cooo]Z0ol0001>oookJP00<ooonfX5o`000?oo
oo]Z>OoonfX3o`0007cooo]Z0ol0001>oookJP00<ooonfX5o`000?oooo]Z>OoonfX3o`0007cooo]Z
0ol0001>oookJP00<ooonfX5o`000?oooo]Z>OoonfX3o`0007cooo]Z0ol0001>oookJP00<ooonfX5
o`000?oooo]Z>OoonfX3o`0007cooo]Z0ol0001>oookJP00<ooonfX5o`000?oooo]Z>OoonfX3o`00
07cooo]Z0ol0001>oookJP00<ooonfX5o`000?oooo]Z>OoonfX3o`0007cooo]Z0ol0001>oookJP00
<ooonfX5o`000?oooo]Z>OoonfX3o`0007cooo]Z0ol0001>oookJP00<ooonfX5o`000?oooo]Z>Ooo
nfX3o`0007cooo]Z0ol0001>oookJP00<ooonfX5o`000?oooo]Z>OoonfX3o`0007cooo]Z0ol0001>
oookJP00<ooonfX5o`000?oooo]Z>OoonfX3o`0007cooo]Z0ol0001>oookJP00<ooonfX5o`000?oo
oo]Z>OoonfX3o`0007cooo]Z0ol0001>oookJP00<ooonfX5o`000?oooo]Z>OoonfX3o`0007cooo]Z
0ol0001>oookJP00<ooonfX5o`000?oooo]Z>OoonfX3o`0007cooo]Z0ol0001>oookJP007_oonfX3
o`00O`Cooo]Z1Ol007l9oookJPGo0000oooonfXioookJP?o0000O?oonfX3o`0004kooo]Z000Noook
JP?o001o0ooonfX7o`00O`Sooo]Z1Ol0003ooookJSWooo]Z0ol0001loookJP?o0000C_oonfX001ko
oo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`000?oooo]Z>OoonfX3o`00
07cooo]Z0ol0001>oookJP003OoonfX:o`00O`;ooo]Z2Ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o1ooonfX5o`000?oooo]Z>OoonfX3o`0007cooo]Z0ol0001>oookJP003OoonfX:o`00O`;o
oo]Z2Ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1ooonfX6o`000?oooo]Z>?oonfX3o`00
07cooo]Z0ol0001>oookJP006OoonfX2o`00O`?ooo]Z0ol007l2oookJP?o001o0ooonfX3o`00O`Oo
oo]Z1Ol0003ooookJSWooo]Z0ol0001loookJP?o0000C_oonfX001[ooo]Z0_l007l2oookJP?o001o
0_oonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000oooonfXioookJP?o0000O?oonfX3o`0004kooo]Z
000JoookJP?o001o00Cooo]Zo`00Ool007oo001o0_oonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000
oooonfXioookJP?o0000O?oonfX3o`0004kooo]Z000KoookJP;o001o00Cooo]Zo`00Ool007oo001o
0_oonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000oooonfXioookJP?o0000O?oonfX3o`0004kooo]Z
000LoookJPGo001o0_oonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000oooonfXioookJP?o0000O?oo
nfX3o`0004kooo]Z000LoookJPGo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol0
003ooookJSWooo]Z0ol0001loookJP?o0000C_oonfX001gooo]Z1?l007l3oookJPOo001o2?oonfX5
o`000?oooo]Z>OoonfX3o`0007cooo]Z0ol0001>oookJP007_oonfX3o`00O`Cooo]Z1Ol007l9oook
JPGo0000oooonfXioookJP?o0000O?oonfX3o`0004kooo]Z000coookJPGo0000oooonfXioookJP?o
0000O?oonfX3o`0004kooo]Z000coookJPGo0000oooonfXioookJP?o0000O?oonfX3o`0004kooo]Z
000coookJPGo0000oooonfXioookJP?o0000O?oonfX3o`0004kooo]Z000coookJPGo0000oooonfXi
oookJP?o0000O?oonfX3o`0004kooo]Z000coookJPGo0000oooonfXioookJP?o0000O?oonfX3o`00
04kooo]Z000coookJPGo0000oooonfXioookJP?o0000O?oonfX3o`0004kooo]Z000coookJPGo0000
oooonfXioookJP?o0000O?oonfX3o`0004kooo]Z000coookJPGo0000oooonfXioookJP?o0000O?oo
nfX3o`0004kooo]Z000coookJPGo0000oooonfXioookJP?o0000O?oonfX3o`0004kooo]Z000coook
JPGo0000oooonfXioookJP?o0000O?oonfX3o`0004kooo]Z000coookJPGo0000oooonfXioookJP?o
0000O?oonfX3o`0004kooo]Z000coookJPGo0000oooonfXioookJP?o0000O?oonfX3o`0004kooo]Z
000coookJPGo0000oooonfXioookJP?o0000O?oonfX3o`0004kooo]Z000coookJPGo0000oooonfXi
oookJP?o0000O?oonfX3o`0004kooo]Z000coookJPGo0000oooonfXioookJP?o0000O?oonfX3o`00
04kooo]Z000coookJPGo0000oooonfXioookJP?o0000O?oonfX3o`0004kooo]Z000coookJPGo0000
oooonfXioookJP?o0000O?oonfX3o`0004kooo]Z000coookJPGo0000oooonfXioookJP?o0000O?oo
nfX3o`0004kooo]Z000coookJPGo0000oooonfXioookJP?o0000O?oonfX3o`0004kooo]Z000coook
JPGo0000oooonfXioookJP?o0000O?oonfX3o`0004kooo]Z000coookJPGo0000oooonfXioookJP?o
0000O?oonfX3o`0004kooo]Z000coookJPGo0000oooonfXioookJP?o0000O?oonfX3o`0004kooo]Z
000coookJPGo0000oooonfXioookJP?o0000O?oonfX3o`0004kooo]Z000coookJPGo0000oooonfXi
oookJP?o0000O?oonfX3o`0004kooo]Z000coookJPGo0000oooonfXioookJP?o0000O?oonfX3o`00
04kooo]Z000coookJPGo0000oooonfXioookJP?o0000O?oonfX3o`0004kooo]Z000coookJPGo0000
oooonfXioookJP?o0000O?oonfX3o`0004kooo]Z000coookJPGo0000oooonfXioookJP?o0000O?oo
nfX3o`0004kooo]Z000coookJPGo0000oooonfXioookJP?o0000O?oonfX3o`0004kooo]Z000coook
JPGo0000oooonfXioookJP?o0000O?oonfX3o`0004kooo]Z000coookJPGo0000oooonfXioookJP?o
0000O?oonfX3o`0004kooo]Z000coookJPGo0000oooonfXioookJP?o0000O?oonfX3o`0004kooo]Z
000coookJPGo0000oooonfXioookJP?o0000O?oonfX3o`0004kooo]Z000coookJPGo0000oooonfXi
oookJP?o0000O?oonfX3o`0004kooo]Z000coookJPGo0000oooonfXioookJP?o0000O?oonfX3o`00
04kooo]Z000coookJPGo0000oooonfXioookJP?o0000O?oonfX3o`0004kooo]Z000coookJPGo0000
oooonfXioookJP?o0000O?oonfX3o`0004kooo]Z000coookJPGo0000oooonfXioookJP?o0000O?oo
nfX3o`0004kooo]Z000coookJPGo0000oooonfXioookJP?o0000O?oonfX3o`0004kooo]Z000coook
JPGo0000oooonfXioookJP?o0000O?oonfX3o`0004kooo]Z000coookJPGo0000oooonfXioookJP?o
0000O?oonfX3o`0004kooo]Z000coookJPGo0000oooonfXioookJP?o0000O?oonfX3o`0004kooo]Z
000coookJPGo0000oooonfXioookJP?o0000O?oonfX3o`0004kooo]Z000coookJPGo0000oooonfXi
oookJP?o0000O?oonfX3o`0004kooo]Z000coookJPGo0000oooonfXioookJP?o0000O?oonfX3o`00
04kooo]Z000coookJPGo0000oooonfXioookJP?o0000O?oonfX3o`0004kooo]Z000coookJPGo0000
oooonfXioookJP?o0000O?oonfX3o`0004kooo]Z000coookJPGo0000oooonfXioookJP?o0000O?oo
nfX3o`0004kooo]Z000coookJPGo0000oooonfXioookJP?o0000O?oonfX3o`0004kooo]Z000coook
JPGo0000oooonfXioookJP?o0000O?oonfX3o`0004kooo]Z000IoookJPWo001o0ooonfX5o`00O`Wo
oo]Z1Ol0003ooookJSWooo]Z0ol0001loookJP?o0000C_oonfX001Wooo]Z2Ol007l2oookJPOo001o
2?oonfX5o`000?oooo]Z>OoonfX3o`0007cooo]Z0ol0001>oookJP006OoonfX4o`00O`Oooo]Z0ol0
07l01?oonf[o001oo`00Ool007l8oookJPGo0000oooonfXioookJP?o0000O?oonfX3o`0004kooo]Z
000=oookJP[o001o0ooonfX4o`00O`Gooo]Z0ol007l3oookJP?o001o1ooonfX5o`000?oooo]Z>Ooo
nfX3o`0007cooo]Z0ol0001>oookJP003OoonfX:o`00O`Cooo]Z1Ol007l3oookJP?o001o0ooonfX3
o`00O`Oooo]Z1_l0003ooookJSSooo]Z0ol0001loookJP?o0000C_oonfX001gooo]Z1?l007l2oook
JP?o001o0ooonfX3o`00O`Oooo]Z1Ol0003ooookJSWooo]Z0ol0001loookJP?o0000C_oonfX001ko
oo]Z0ol007l2oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0003ooookJSWooo]Z0ol0001loookJP?o
0000C_oonfX001oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1ooonfX5o`000?oo
oo]Z>OoonfX3o`0007cooo]Z0ol0001>oookJP006OoonfX3o`00O`?ooo]Z0ol007l01?oonf[o001o
o`00Ool007l3oookJP?o001o1ooonfX5o`000?oooo]Z>OoonfX3o`0007cooo]Z0ol0001>oookJP00
6OoonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1ooonfX5o`000?oo
oo]Z>OoonfX3o`0007cooo]Z0ol0001>oookJP006OoonfX4o`00O`;ooo]Z0ol007l2oookJP?o001o
00Cooo]Zo`00Ool007oo001o2?oonfX5o`000?oooo]Z>OoonfX3o`0007cooo]Z0ol0001>oookJP00
6_oonfX7o`00O`?ooo]Z1ol007l8oookJPGo0000oooonfXioookJP?o0000O?oonfX3o`0004kooo]Z
000KoookJPGo001o1OoonfX5o`00O`Wooo]Z1Ol0003ooookJSWooo]Z0ol0001loookJP?o0000C_oo
nfX003?ooo]Z1Ol0003ooookJSWooo]Z0ol0001loookJP?o0000C_oonfX003?ooo]Z1Ol0003ooook
JSWooo]Z0ol0001loookJP?o0000C_oonfX003?ooo]Z1Ol0003ooookJSWooo]Z0ol0001loookJP?o
0000C_oonfX003?ooo]Z1Ol0003ooookJSWooo]Z0ol0001loookJP?o0000C_oonfX003?ooo]Z1Ol0
003ooookJSWooo]Z0ol0001loookJP?o0000C_oonfX003?ooo]Z1Ol0003ooookJSWooo]Z0ol0001l
oookJP?o0000C_oonfX003?ooo]Z1Ol0003ooookJSWooo]Z0ol0001loookJP?o0000C_oonfX003?o
oo]Z1Ol0003ooookJSWooo]Z0ol0001loookJP?o0000C_oonfX003?ooo]Z1Ol0003ooookJSWooo]Z
0ol0001loookJP?o0000C_oonfX003?ooo]Z1Ol0003ooookJSWooo]Z0ol0001loookJP?o0000C_oo
nfX003?ooo]Z1Ol0003ooookJSWooo]Z0ol0001loookJP?o0000C_oonfX003?ooo]Z1Ol0003ooook
JSWooo]Z0ol0001loookJP?o0000C_oonfX003?ooo]Z1Ol0003ooookJSWooo]Z0ol0001loookJP?o
0000C_oonfX003?ooo]Z1Ol0003ooookJSWooo]Z0ol0001loookJP?o0000C_oonfX003?ooo]Z1Ol0
003ooookJSWooo]Z0ol0001loookJP?o0000C_oonfX003?ooo]Z1Ol0003ooookJSWooo]Z0ol0001l
oookJP?o0000C_oonfX003?ooo]Z1Ol0003ooookJSWooo]Z0ol0001loookJP?o0000C_oonfX003?o
oo]Z1Ol0003ooookJSWooo]Z0ol0001loookJP?o0000C_oonfX003?ooo]Z1Ol0003ooookJSWooo]Z
0ol0001loookJP?o0000C_oonfX003?ooo]Z1Ol0003ooookJSWooo]Z0ol0001loookJP?o0000C_oo
nfX003?ooo]Z1Ol0003ooookJSWooo]Z0ol0001loookJP?o0000C_oonfX003?ooo]Z1Ol0003ooook
JSWooo]Z0ol0001loookJP?o0000C_oonfX003?ooo]Z1Ol0003ooookJSWooo]Z0ol0001loookJP?o
0000C_oonfX003?ooo]Z1Ol0003ooookJSWooo]Z0ol0001loookJP?o0000C_oonfX003?ooo]Z1Ol0
003ooookJSWooo]Z0ol0001loookJP?o0000C_oonfX003?ooo]Z1Ol0003ooookJSWooo]Z0ol0001l
oookJP?o0000C_oonfX003?ooo]Z1Ol0003ooookJSWooo]Z0ol0001loookJP?o0000C_oonfX003?o
oo]Z1Ol0003ooookJSWooo]Z0ol0001loookJP?o0000C_oonfX003?ooo]Z1Ol0003ooookJSWooo]Z
0ol0001loookJP?o0000C_oonfX003?ooo]Z1Ol0003ooookJSWooo]Z0ol0001loookJP?o0000C_oo
nfX003?ooo]Z1Ol0003ooookJSWooo]Z0ol0001loookJP?o0000C_oonfX003?ooo]Z1Ol0003ooook
JSWooo]Z0ol0001loookJP?o0000C_oonfX003?ooo]Z1Ol0003ooookJSWooo]Z0ol0001loookJP?o
0000C_oonfX003?ooo]Z1Ol0001HoookJPGo001o1?oonfX3o`00O`03oookJ_l007oo001o00Oo001o
CooonfX5o`00O`Cooo]Z0ol007l6oookJP?o001oD?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o
0_oonfX3o`0004cooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00Oacooo]Z0ol0000loookJP?o001o
3ooonfX003?ooo]Z1Ol0001GoookJPOo001o0ooonfX3o`00O`03oookJ_l007oo001o00Oo001oC_oo
nfX7o`00O`?ooo]Z0ol007l6oookJP?o001oCooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o00Co
oo]Zo`000?l0003o0000BooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o6ooonfX3o`0003cooo]Z
0ol007l?oookJP00<ooonfX5o`0005Oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o
00?ooo]Zo`00Ool007l00_l007mCoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Ko
oo]Z0ol007m?oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`;ooo]Z0ol007l2oook
JP?o001o0ol0001;oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo
001oo`00O`?ooo]Z0ol007lJoookJP?o0000??oonfX3o`00O`oooo]Z000coookJPGo0000E_oonfX3
o`00O`?ooo]Z0ol007l7oookJPCo001oDOoonfX3o`00O`?ooo]Z0ol007l6oookJPWo001oCOoonfX3
o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`?o0000B_oonfX3o`00O`?ooo]Z0ol007l6
oookJP?o001o0ooonfX3o`00Oa[ooo]Z0ol0000loookJP?o001o3ooonfX003?ooo]Z1Ol0001Foook
JP?o001o0ooonfX3o`00O`Sooo]Z1Ol007m?oookJP?o001o0ooonfX3o`00O`Kooo]Z2Ol007m=oook
JP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o0ol0001:oookJP?o001o0ooonfX3o`00
O`Kooo]Z0ol007l3oookJP?o001o6_oonfX3o`0003cooo]Z0ol007l?oookJP00<ooonfX5o`0005Ko
oo]Z0ol007l3oookJP?o001o2_oonfX4o`00Odkooo]Z0ol007l3oookJP?o001o1_oonfX2o`00O`?o
oo]Z0ol007m>oookJP?o001o0ooonfX3o`00O`Kooo]Z1?l007l2oookJP?o001o0ol0001:oookJP?o
001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o6_oonfX3o`0003cooo]Z0ol007l?oookJP00
<ooonfX5o`0005Kooo]Z0ol007l3oookJP?o001o2ooonfX3o`00Odkooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00O`;ooo]Z0ol007m>oookJP?o001o0ooonfX3o`00O`Kooo]Z2?l007l01?oonf[o0000
o`000?l0001:oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007lKoookJP?o0000??oonfX3o`00O`oo
oo]Z000coookJPGo0000E_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001oCOoonfX3o`00O`?ooo]Z
0ol007l7oookJP?o001o00Cooo]Zo`00Ool007oo001oC_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o
001o00Cooo]Zo`00Ool007oo001o0_oonfX3o`0004[ooo]Z0ol007l3oookJP?o001o1ooonfX7o`00
Oa_ooo]Z0ol0000loookJP?o001o3ooonfX003?ooo]Z1Ol0001FoookJP?o001o0ooonfX3o`00O`Ko
oo]Z0ol007l3oookJP?o001oCOoonfX3o`00O`?ooo]Z0ol007l8oookJP;o001o00Cooo]Zo`00Ool0
07oo001oC_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o1_oonfX3o`0004[ooo]Z0ol007l3oook
JP?o001o1_oonfX3o`00O`?ooo]Z0ol007lJoookJP?o0000??oonfX3o`00O`oooo]Z000coookJPGo
0000E_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00Odgooo]Z0ol007l3oookJP?o
001o2OoonfX5o`00Odkooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`Kooo]Z0ol0001:oookJP?o
001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o6_oonfX3o`0003Wooo]Z1_l007l?oookJP00
<ooonfX5o`0005Oooo]Z0ol007l01?oonf[o001oo`00Ool007l7oookJPCo001o0_oonfX3o`00Odko
oo]Z0ol007l01?oonf[o001oo`00Ool007l:oookJPGo001oCooonfX3o`00O`04oookJ_l007oo001o
o`00O`Sooo]Z0ol007l2oookJP?o001o0ol0001;oookJP?o001o00Cooo]Zo`00Ool007oo001o1ooo
nfX3o`00O`?ooo]Z0ol007lJoookJP?o0000>OoonfX6o`00O`oooo]Z000coookJPGo0000EooonfX7
o`00O`Sooo]Z1ol007m?oookJPOo001o2ooonfX4o`00Odoooo]Z1ol007l8oookJPOo001o00Cooo]Z
o`000?l0003o0000BooonfX7o`00O`Sooo]Z1ol007lKoookJP?o0000>ooonfX4o`00O`oooo]Z000c
oookJPGo0000F?oonfX5o`00O`[ooo]Z1Ol007mAoookJPGo001o3OoonfX3o`00Oe3ooo]Z1Ol007l;
oookJPCo001o0_oonfX3o`0004cooo]Z1Ol007l:oookJPGo001o7?oonfX3o`0003cooo]Z0ol007l?
oookJP00<ooonfX5o`000?oooo]Z>OoonfX3o`0007cooo]Z0ol0001>oookJP00<ooonfX5o`000?oo
oo]Z>OoonfX3o`0007cooo]Z0ol0001>oookJP00<ooonfX5o`000?oooo]Z>OoonfX3o`0007cooo]Z
0ol0001>oookJP00<ooonfX5o`000?oooo]Z>OoonfX3o`0007cooo]Z0ol0001>oookJP00<ooonfX5
o`000?oooo]Z>OoonfX3o`0007cooo]Z0ol0001>oookJP009_oonf[oo`000?oo00006ol00001oook
JP009_oonf[oo`000?oo00006ol00001oookJP009_oonf[oo`000?oo00006ol00001oookJP009_oo
nf[oo`000?oo00006ol00001oookJP009_oonf[oo`000?oo00006ol00001oookJP00<ooonfX5o`00
06;ooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP1RoookJP03o`000?oonf[ooo]Z
06;ooo]Z00?o0000oookJ_oonfX0H_oonfX00ol0003ooo]ZoookJP0>oookJP00<ooonfX5o`0006;o
oo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP1RoookJP03o`000?oonf[ooo]Z06;o
oo]Z00?o0000oookJ_oonfX0H_oonfX00ol0003ooo]ZoookJP0>oookJP00<ooonfX5o`000?oooo]Z
oooonfX:oookJP00<ooonfX5o`000?oooo]ZoooonfX:oookJP00<ooonfX5o`000?oooo]ZoooonfX:
oookJP00<ooonfX5o`000?oooo]ZoooonfX:oookJP00<ooonfX5o`000?oooo]ZoooonfX:oookJP00
<ooonfX5o`000?oooo]ZoooonfX:oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX0
0?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]Zoooo
nfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00
oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00001\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-0.105872, -106.738, \
0.00197587, 0.319703}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Plot", "[", 
      RowBox[{
        RowBox[{"Evaluate", "[", "\[IndentingNewLine]", 
          
          StyleBox[\(y[x] /. 
              BeamEquation[y, x, boxload, Clamped[y, 0, 0, 0], 
                Clamped[y, 1, 0, 0]]\),
            FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", "]"}], 
        ",", \({x, 0, 1}\), ",", \(PlotRange \[Rule] {\(-0.5\), 0.5}\), 
        ",", \(AspectRatio \[Rule] 1\)}], "]"}]], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.5 1 [
[.21429 .4875 -14.5 -20 ]
[.21429 .4875 14.5 0 ]
[.40476 .4875 -14.5 -20 ]
[.40476 .4875 14.5 0 ]
[.59524 .4875 -14.5 -20 ]
[.59524 .4875 14.5 0 ]
[.78571 .4875 -14.5 -20 ]
[.78571 .4875 14.5 0 ]
[.97619 .4875 -7 -20 ]
[.97619 .4875 7 0 ]
[.01131 .1 -41.9375 -10 ]
[.01131 .1 0 10 ]
[.01131 .3 -41.9375 -10 ]
[.01131 .3 0 10 ]
[.01131 .7 -29 -10 ]
[.01131 .7 0 10 ]
[.01131 .9 -29 -10 ]
[.01131 .9 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 1.005 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .5 m
.21429 .50625 L
s
gsave
.21429 .4875 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.40476 .5 m
.40476 .50625 L
s
gsave
.40476 .4875 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.59524 .5 m
.59524 .50625 L
s
gsave
.59524 .4875 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.78571 .5 m
.78571 .50625 L
s
gsave
.78571 .4875 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.97619 .5 m
.97619 .50625 L
s
gsave
.97619 .4875 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .5 m
.07143 .50375 L
s
.11905 .5 m
.11905 .50375 L
s
.16667 .5 m
.16667 .50375 L
s
.2619 .5 m
.2619 .50375 L
s
.30952 .5 m
.30952 .50375 L
s
.35714 .5 m
.35714 .50375 L
s
.45238 .5 m
.45238 .50375 L
s
.5 .5 m
.5 .50375 L
s
.54762 .5 m
.54762 .50375 L
s
.64286 .5 m
.64286 .50375 L
s
.69048 .5 m
.69048 .50375 L
s
.7381 .5 m
.7381 .50375 L
s
.83333 .5 m
.83333 .50375 L
s
.88095 .5 m
.88095 .50375 L
s
.92857 .5 m
.92857 .50375 L
s
.01 w
0 .5 m
1 .5 L
s
.25 Mabswid
.02381 .1 m
.03006 .1 L
s
gsave
.01131 .1 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.02381 .3 m
.03006 .3 L
s
gsave
.01131 .3 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.02381 .7 m
.03006 .7 L
s
gsave
.01131 .7 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.02381 .9 m
.03006 .9 L
s
gsave
.01131 .9 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .15 m
.02756 .15 L
s
.02381 .2 m
.02756 .2 L
s
.02381 .25 m
.02756 .25 L
s
.02381 .35 m
.02756 .35 L
s
.02381 .4 m
.02756 .4 L
s
.02381 .45 m
.02756 .45 L
s
.02381 .55 m
.02756 .55 L
s
.02381 .6 m
.02756 .6 L
s
.02381 .65 m
.02756 .65 L
s
.02381 .75 m
.02756 .75 L
s
.02381 .8 m
.02756 .8 L
s
.02381 .85 m
.02756 .85 L
s
.02381 .05 m
.02756 .05 L
s
.02381 .95 m
.02756 .95 L
s
.01 w
.02381 0 m
.02381 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.0075 w
.02381 .5 m
.02499 .5 L
.02605 .5 L
.02729 .49999 L
.02846 .49999 L
.03053 .49997 L
.03279 .49995 L
.03527 .49991 L
.0379 .49987 L
.04262 .49977 L
.05205 .49949 L
.06244 .49905 L
.07293 .49849 L
.0842 .49775 L
.10458 .49609 L
.1458 .49156 L
.18551 .48599 L
.22371 .47979 L
.26435 .4726 L
.30348 .46538 L
.34506 .45772 L
.38513 .45065 L
.42368 .44444 L
.46468 .43876 L
.48511 .4364 L
.50417 .43451 L
.52367 .43294 L
.54214 .43182 L
.55189 .43139 L
.55703 .4312 L
.56249 .43104 L
.56708 .43093 L
.56951 .43088 L
.57213 .43084 L
.57453 .43081 L
.57673 .43079 L
.57884 .43077 L
.57989 .43077 L
.58105 .43076 L
.58237 .43076 L
.58359 .43076 L
.58422 .43076 L
.58492 .43076 L
.58565 .43077 L
.58634 .43077 L
.58759 .43077 L
.58874 .43078 L
.59133 .43081 L
.59362 .43083 L
.59612 .43087 L
Mistroke
.60066 .43097 L
.60593 .43111 L
.61153 .43131 L
.62161 .43179 L
.63192 .43243 L
.64306 .43331 L
.66325 .43541 L
.68322 .43812 L
.7043 .44165 L
.74233 .44961 L
.7828 .45988 L
.82176 .47076 L
.86318 .48221 L
.88391 .48743 L
.90307 .4917 L
.92133 .4951 L
.93102 .4966 L
.94146 .49794 L
.95081 .49888 L
.95491 .4992 L
.95938 .4995 L
.96363 .49972 L
.96758 .49987 L
.96976 .49992 L
.97174 .49996 L
.97284 .49998 L
.97403 .49999 L
.97516 .5 L
.97619 .5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 576},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900002@2000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oo
oo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX0
0?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]Zoooo
nfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00
;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5
o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oo
oo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Zoooo
nfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oook
JP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oo
nfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`00
0?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Z
oooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?
oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00
;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5
o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oo
oo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Zoooo
nfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oook
JP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oo
nfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`00
0?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Z
oooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?
oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00
;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5
o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oo
oo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Zoooo
nfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oook
JP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP004Ooo
nfX5o`00O`Cooo]Z0ol007l6oookJP?o001o2?oonfX5o`000?oooo]ZoooonfX?oookJP004?oonfX7
o`00O`?ooo]Z0ol007l6oookJP?o001o2?oonfX5o`000?oooo]ZoooonfX?oookJP004?oonfX3o`00
O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l6oookJP?o001o2?oonfX5o`000?oooo]ZoooonfX?
oookJP000ooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX9o`00O`Oooo]Z1Ol0003ooook
J_oooo]Z3ooonfX000?ooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z2Ol007l7oookJPOo
0000oooonf[ooookJPgooo]Z000?oookJP?o001o0ooonfX3o`00O`Kooo]Z0_l007l3oookJP?o001o
2?oonfX5o`000?oooo]ZoooonfX?oookJP003ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oo
nfX3o`00O`Sooo]Z1Ol0003ooookJ_oooo]Z3ooonfX000oooo]Z0ol007l3oookJP?o001o1ooonfX3
o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol0003ooookJ_oooo]Z3ooonfX000oooo]Z0ol007l3
oookJP?o001o2?oonfX2o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX000oooo]Z0ol007l3oookJP?o001o2OoonfX5o`00O`Sooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
013ooo]Z0ol007l01?oonf[o001oo`00Ool007l:oookJPGo001o2?oonfX5o`000?oooo]ZoooonfX?
oookJP004?oonfX7o`00O`_ooo]Z1?l007l8oookJPGo0000oooonf[ooookJPoooo]Z000AoookJPGo
001o3OoonfX3o`00O`Sooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002ko
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0
003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooook
J_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002ko
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0
003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooook
J_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002ko
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0
003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooook
J_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002ko
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0
003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooook
J_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002ko
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX0017ooo]Z1Ol007l4oookJP?o001o00?ooo]Zo`00Ool007l0
1ol007l7oookJPGo0000oooonf[ooookJPoooo]Z000@oookJPOo001o0ooonfX3o`00O`03oookJ_l0
07oo001o00Oo001o1ooonfX5o`000?oooo]ZoooonfX?oookJP004?oonfX3o`00O`04oookJ_l007oo
001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`cooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX000?ooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Oooo]Z1?l007l;oookJPGo0000oooonf[o
oookJPoooo]Z0003oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l8oookJPGo001o2OoonfX7o`00
0?oooo]ZoooonfX=oookJP003ooonfX3o`00O`?ooo]Z0ol007l:oookJPCo001o2?oonfX5o`000?oo
oo]ZoooonfX?oookJP003ooonfX3o`00O`?ooo]Z0ol007l;oookJP?o001o2?oonfX5o`000?oooo]Z
oooonfX?oookJP003ooonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX5o`000?oooo]Zoooo
nfX?oookJP003ooonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX000oooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7oook
JPGo0000oooonf[ooookJPoooo]Z000@oookJP?o001o00Cooo]Zo`00Ool007oo001o1ooonfX4o`00
O`;ooo]Z0ol007l7oookJPGo0000oooonf[ooookJPoooo]Z000@oookJPOo001o2?oonfX7o`00O`So
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX0017ooo]Z1Ol007l:oookJPGo001o2OoonfX5o`000?oooo]Z
oooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?
oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00
;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5
o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oo
oo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Zoooo
nfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oook
JP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oo
nfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`00
0?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Z
oooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?
oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00
;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5
o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oo
oo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Zoooo
nfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oook
JP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oo
nfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`00
0?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Z
oooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?
oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00
;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5
o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oo
oo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Zoooo
nfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oook
JP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oo
nfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`00
0?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Z
oooonfX?oookJP00;_oonfX5o`000?oooo]Z3OoonfXgo`000<[ooo]Z000^oookJPGo0000oooonfX3
oookJToo0000_?oonfX002kooo]Z1Ol0003hoookJV7o0000]?oonfX002kooo]Z1Ol0003^oookJW3o
0000[ooonfX002kooo]Z1Ol0003ToookJR_o0000<OoonfXTo`000:Wooo]Z000^oookJPGo0000gOoo
nfXXo`0004Wooo]Z6ol0002ToookJP00;_oonfX5o`000=Kooo]Z9Ol0001KoookJQWo0000W_oonfX0
02kooo]Z1Ol0003?oookJR;o0000J_oonfXIo`0009Wooo]Z000^oookJPGo0000b_oonfXMo`0007[o
oo]Z6?l0002DoookJP00;_oonfX5o`000<Gooo]Z6ol00026oookJQSo0000SooonfX002kooo]Z1Ol0
0030oookJQWo0000TooonfXGo`0008[ooo]Z000^oookJPGo0000^OoonfXIo`0009oooo]Z5_l00026
oookJP00;_oonfX5o`000;;ooo]Z6ol0002YoookJQKo0000POoonfX002kooo]Z1Ol0002[oookJQgo
0000/ooonfXEo`0007gooo]Z000^oookJPGo0000Y?oonfXOo`000;gooo]Z5?l0001ioookJP00;_oo
nfX5o`0009oooo]Z7Ol00038oookJQCo0000MOoonfX002kooo]Z1Ol0002IoookJQco0000e?oonfXB
o`0007;ooo]Z000^oookJPGo0000FOoonfX5o`00O`Cooo]Z0ol007l00ooonf[o001oo`00O`07o`00
ObGooo]Z6_l0000AoookJPGo001o1?oonfX3o`00O`Kooo]Z0ol007mAoookJPGo001o1?oonfX3o`00
O`?ooo]Z1Ol007mBoookJP;o001o4_l0001LoookJP?o001o3ooonfX002kooo]Z1Ol0001HoookJPOo
001o0ooonfX3o`00O`03oookJ_l007oo001o00Oo001o7ooonfXIo`0001Oooo]Z1ol007l3oookJP?o
001o1_oonfX3o`00Oe3ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Oe3ooo]Z1ol007lAo`0005Wo
oo]Z0ol007l?oookJP00;_oonfX5o`0005Sooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o
001o00?ooo]Zo`00Ool007l00_l007lOoookJQWo00007?oonfX3o`00O`04oookJ_l007oo001oo`00
O`?ooo]Z0ol007l6oookJP?o001oD?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l2
oookJP?o001o0_oonfX3o`00Odoooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP03o`00Ool0
003o000000oo0000EOoonfX3o`00O`oooo]Z000^oookJPGo0000EooonfX3o`00O`?ooo]Z0ol007l7
oookJPCo001o6OoonfXHo`00027ooo]Z0ol007l3oookJP?o001o1_oonfX9o`00Odkooo]Z0ol007l3
oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007m>oookJP?o001o0ooonfX3o`00O`Kooo]Z4Ol0001B
oookJP?o001o3ooonfX002kooo]Z1Ol0001GoookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol007lBoook
JQSo00009_oonfX3o`00O`?ooo]Z0ol007l6oookJPWo001oC_oonfX3o`00O`?ooo]Z0ol007l6oook
JP?o001o0ooonfX3o`00Odkooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`03oookJ_l0003o0000
00oo0000C_oonfX3o`00O`oooo]Z000^oookJPGo0000EooonfX3o`00O`?ooo]Z0ol007l:oookJPCo
001o2ooonfXHo`0002cooo]Z0ol007l3oookJP?o001o1_oonfX2o`00O`?ooo]Z0ol007m?oookJP?o
001o0ooonfX3o`00O`Kooo]Z1?l007l2oookJP?o001oC_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o
001o0ooonfX00ol007oo0000o`00000@o`0004[ooo]Z0ol007l?oookJP00;_oonfX5o`0005Oooo]Z
0ol007l3oookJP?o001o2ooonfX3o`00O`Kooo]Z6?l0000aoookJP?o001o0ooonfX3o`00O`Oooo]Z
0_l007l2oookJP?o001oCooonfX3o`00O`?ooo]Z0ol007l6oookJPSo001oCooonfX3o`00O`?ooo]Z
0ol007l7oookJPOo001o0ooonfXAo`0004Oooo]Z0ol007l?oookJP00;_oonfX5o`0005Oooo]Z0ol0
07l3oookJP?o001o3?oonfX2o`00OaWo0000=_oonfX3o`00O`?ooo]Z0ol007l7oookJP?o001o00Co
oo]Zo`00Ool007oo001oCooonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o00Cooo]Zo`00Ool007oo
001oD?oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o1_oonfXBo`0004?ooo]Z0ol007l?oookJP00
;_oonfX5o`0005Oooo]Z0ol007l3oookJP?o001o1_oonfX3o`00OaWo0000>ooonfX3o`00O`?ooo]Z
0ol007l8oookJP;o001o00Cooo]Zo`00Ool007oo001oCooonfX3o`00O`?ooo]Z0ol007l6oookJP?o
001oE?oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Wooo]Z4_l0000ooookJP?o
001o3ooonfX002kooo]Z1Ol0001GoookJP?o001o0ooonfX3o`00O`?ooo]Z6Ol00011oookJP?o001o
0ooonfX3o`00O`Wooo]Z1Ol007m?oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007mDoookJP?o001o
0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o3OoonfXAo`0003Wooo]Z1_l007l?oookJP00;_oo
nfX5o`0005Sooo]Z0ol007l00ooonf[o0000o`00000Io`0004Oooo]Z0ol007l01?oonf[o001oo`00
Ool007l:oookJPGo001oD?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0ol007l2oookJP?o
001oCooonfX3o`00O`04oookJ_l007oo001oo`00O`Oooo]Z0ol007l3oookJP?o001o4?oonfXBo`00
03Gooo]Z1_l007l?oookJP00;_oonfX5o`0005Gooo]Z7?l0001=oookJPOo001o2ooonfX4o`00Oe3o
oo]Z1ol007l8oookJPOo001oD?oonfX7o`00O`Sooo]Z1ol007lEoookJQ;o0000<ooonfX4o`00O`oo
oo]Z000^oookJPGo0000CooonfXMo`000003o`00Oooonf[ooo]Z053ooo]Z1Ol007l=oookJP?o001o
DOoonfX5o`00O`_ooo]Z1?l007mBoookJPGo001o2_oonfX5o`00Oa[ooo]Z4_l0000`oookJP?o001o
3ooonfX002kooo]Z1Ol00018oookJQko0000oooonfYGoookJQ?o0000?_oonfX002kooo]Z1Ol00011
oookJQko0000oooonfYRoookJQ;o0000>ooonfX002kooo]Z1Ol0000ioookJQoo0000oooonfY]oook
JQ7o0000>?oonfX002kooo]Z1Ol0000aoookJR7o0000oooonfYgoookJQCo0000<OoonfX002kooo]Z
1Ol0000ZoookJR7o0000oooonfZ2oookJQSo0000:OoonfX002kooo]Z1Ol0000QoookJR?o0000oooo
nfZ<oookJQ[o00009?oonfX0027ooo]Zool0003oo`00023o00000OoonfX0027ooo]Zool0003oo`00
023o00000OoonfX0027ooo]Zool0003oo`00023o00000OoonfX0027ooo]Zool0003oo`00023o0000
0OoonfX0027ooo]Zool0003oo`00023o00000OoonfX002kooo]Z1Ol0001SoookJP03o`000?oonf[o
oo]Z06Cooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[o
oo]Z06?ooo]Z00?o0000oookJ_oonfX03_oonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002ko
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0
003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooook
J_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002ko
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0
003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooook
J_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002ko
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0
003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooook
J_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002ko
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0
003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooook
J_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002ko
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0
003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooook
J_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX0017ooo]Z1Ol007l4oookJP?o001o00?ooo]Zo`00Ool007l01ol007l7oookJPGo0000oooonf[o
oookJPoooo]Z000@oookJPOo001o0ooonfX3o`00O`03oookJ_l007oo001o00Oo001o1ooonfX5o`00
0?oooo]ZoooonfX?oookJP004?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooo
nf[o001oo`00O`02o`00O`cooo]Z1Ol0003ooookJ_oooo]Z3ooonfX000oooo]Z0ol007l3oookJP?o
001o1ooonfX4o`00O`_ooo]Z1Ol0003ooookJ_oooo]Z3ooonfX000oooo]Z0ol007l3oookJP?o001o
2?oonfX5o`00O`Wooo]Z1ol0003ooookJ_oooo]Z3OoonfX000oooo]Z0ol007l3oookJP?o001o2_oo
nfX4o`00O`Sooo]Z1Ol0003ooookJ_oooo]Z3ooonfX000oooo]Z0ol007l3oookJP?o001o2ooonfX3
o`00O`Sooo]Z1Ol0003ooookJ_oooo]Z3ooonfX000oooo]Z0ol007l3oookJP?o001o3?oonfX3o`00
O`Oooo]Z1Ol0003ooookJ_oooo]Z3ooonfX000oooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?o
oo]Z0ol007l7oookJPGo0000oooonf[ooookJPoooo]Z000?oookJP?o001o0ooonfX3o`00O`Kooo]Z
0ol007l3oookJP?o001o1ooonfX5o`000?oooo]ZoooonfX?oookJP004?oonfX3o`00O`04oookJ_l0
07oo001oo`00O`Oooo]Z1?l007l2oookJP?o001o1ooonfX5o`000?oooo]ZoooonfX?oookJP004?oo
nfX7o`00O`Sooo]Z1ol007l8oookJPGo0000oooonf[ooookJPoooo]Z000AoookJPGo001o2_oonfX5
o`00O`Wooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002ko
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0
003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooook
J_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002ko
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0
003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooook
J_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002ko
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0
003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooook
J_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002ko
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0
003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooook
J_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooo
nfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002ko
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0
003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooook
J_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z
3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003o
oookJ_oooo]Z3ooonfX0017ooo]Z1Ol007l4oookJP?o001o1_oonfX3o`00O`Sooo]Z1Ol0003ooook
J_oooo]Z3ooonfX0013ooo]Z1ol007l3oookJP?o001o1_oonfX3o`00O`Sooo]Z1Ol0003ooookJ_oo
oo]Z3ooonfX0013ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1_oonfX3o`00O`So
oo]Z1Ol0003ooookJ_oooo]Z3ooonfX000oooo]Z0ol007l3oookJP?o001o1_oonfX9o`00O`Oooo]Z
1Ol0003ooookJ_oooo]Z3ooonfX000oooo]Z0ol007l3oookJP?o001o1_oonfX9o`00O`Oooo]Z1ol0
003ooookJ_oooo]Z3OoonfX000oooo]Z0ol007l3oookJP?o001o1_oonfX2o`00O`?ooo]Z0ol007l8
oookJPGo0000oooonf[ooookJPoooo]Z000?oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oook
JP?o001o2?oonfX5o`000?oooo]ZoooonfX?oookJP003ooonfX3o`00O`?ooo]Z0ol007l7oookJP?o
001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`000?oooo]ZoooonfX?oookJP003ooonfX3o`00O`?o
oo]Z0ol007l8oookJP;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`000?oooo]ZoooonfX?oook
JP003ooonfX3o`00O`?ooo]Z0ol007l9oookJPGo001o2?oonfX5o`000?oooo]ZoooonfX?oookJP00
4?oonfX3o`00O`04oookJ_l007oo001oo`00O`[ooo]Z1Ol007l8oookJPGo0000oooonf[ooookJPoo
oo]Z000@oookJPOo001o2ooonfX4o`00O`Sooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0017ooo]Z1Ol0
07l=oookJP?o001o2?oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?
oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00
;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5
o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oo
oo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Zoooo
nfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oook
JP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oo
nfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`00
0?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Z
oooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?
oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00
;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5
o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oo
oo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Zoooo
nfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oook
JP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oo
nfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`00
0?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]Z
oooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?
oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00
;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5
o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00oooonf[ooookJT;o
oo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooook
J_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oo
nfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]Z
oooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oook
JP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00001\
\>"],
  ImageRangeCache->{{{0, 575}, {575, 0}} -> {-0.0952157, -0.535939, \
0.00195734, 0.00186413}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[BoxData[
    RowBox[{\(XML`MathML`BoxesToMathML::"notboxes"\), \(\(:\)\(\ \)\), \
"\<\"\\!\\({\\(\\(RowBox[\\(\\({\\\"MixedRealRoots\\\", \\(\\(\[LeftSkeleton] \
3 \[RightSkeleton]\\)\\), \\(\\(RowBox[\\(\\({\\\"Plot\\\", \\\"[\\\", \
\\(\\(RowBox[\\(\\({\\\"0\\\", \\\",\\\", \\(\\(\[LeftSkeleton] 3 \
\[RightSkeleton]\\)\\), \\\",\\\", \\(\\(RowBox[\\(\\(\[LeftSkeleton] 1 \
\[RightSkeleton]\\)\\)]\\)\\)}\\)\\)]\\)\\), \
\\\"]\\\"}\\)\\)]\\)\\)}\\)\\)]\\)\\), \\(\\(\[LeftSkeleton] 1 \
\[RightSkeleton]\\)\\)}\\) is not a valid box structure. The first argument \
in \\!\\(XML`MathML`BoxesToMathML[\\(\\(\\(\\({\\(\\(RowBox[\\(\\({\\\"\
MixedRealRoots\\\", \\(\\(\[LeftSkeleton] 3 \[RightSkeleton]\\)\\), \
\\(\\(RowBox[\\(\\({\\\"Plot\\\", \\\"[\\\", \\(\\(\[LeftSkeleton] 1 \
\[RightSkeleton]\\)\\), \\\"]\\\"}\\)\\)]\\)\\)}\\)\\)]\\)\\), \\(\\(\
\[LeftSkeleton] 1 \[RightSkeleton]\\)\\)}\\)\\), \\(\\(\[LeftSkeleton] 2 \
\[RightSkeleton]\\)\\), \\(\\(\[LeftSkeleton] 1 \[RightSkeleton]\\)\\)\\)\\)]\
\\) must be a valid box structure. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"XML`MathML`BoxesToMathML::notboxes\\\
\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(XML`MathML`BoxesToMathML::"notboxes"\), \(\(:\)\(\ \)\), \
"\<\"\\!\\({\\(\\(RowBox[\\(\\({\\(\[LeftSkeleton] 1 \
\[RightSkeleton]\\)}\\)\\)]\\)\\), \\(\\(\[LeftSkeleton] 1 \
\[RightSkeleton]\\)\\), \\(\\(RowBox[\\(\\({\\(\\(RowBox[\\(\\({\\\"FreeEnd\\\
\", \\\"[\\\", \\(\\(RowBox[\\(\\({\\\"y_\\\", \\\" \\\", \\\",\\\", \\\" \
\\\", \\\"x_\\\"}\\)\\)]\\)\\), \\\"]\\\"}\\)\\)]\\)\\), \
\\(\\(\[LeftSkeleton] 3 \[RightSkeleton]\\)\\), \\(\\(\[LeftSkeleton] 1 \
\[RightSkeleton]\\)\\)}\\)\\)]\\)\\)}\\) is not a valid box structure. The \
first argument in \\!\\(XML`MathML`BoxesToMathML[\\(\\(\[LeftSkeleton] 1 \
\[RightSkeleton]\\)\\)]\\) must be a valid box structure. \\!\\(\\*ButtonBox[\
\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\\\", \
ButtonFrame->None, ButtonData:>\\\"XML`MathML`BoxesToMathML::notboxes\\\"]\\)\
\"\>"}]], "Message"]
},
FrontEndVersion->"5.2 for Macintosh",
ScreenRectangle->{{4, 1920}, {0, 1178}},
ScreenStyleEnvironment->"Presentation",
CellGrouping->Manual,
WindowSize->{1251, 836},
WindowMargins->{{207, Automatic}, {Automatic, 0}},
WindowTitle->"Lecture 21 MIT 3.016 (Fall 2005)   \[Copyright] W. Craig Carter \
2003-2005",
ShowCellLabel->False,
CellLabelAutoDelete->True,
StyleDefinitions -> "3016_Carter.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "mmtag:21:foward_differencing__higher_order_ODEs"->{
    Cell[2492, 70, 266, 6, 85, "Input",
      CellTags->{
      "mmtag:21:foward_differencing__higher_order_ODEs", 
        "mmtag:21:foward_differencing__example_function"}]},
  "mmtag:21:foward_differencing__example_function"->{
    Cell[2492, 70, 266, 6, 85, "Input",
      CellTags->{
      "mmtag:21:foward_differencing__higher_order_ODEs", 
        "mmtag:21:foward_differencing__example_function"}]},
  "mmtag:21:discrete_approximation_to_derivative"->{
    Cell[2859, 83, 390, 8, 106, "Input",
      CellTags->{
      "mmtag:21:discrete_approximation_to_derivative", 
        "mmtag:21:derivatives__discrete_approximation"}]},
  "mmtag:21:derivatives__discrete_approximation"->{
    Cell[2859, 83, 390, 8, 106, "Input",
      CellTags->{
      "mmtag:21:discrete_approximation_to_derivative", 
        "mmtag:21:derivatives__discrete_approximation"}]},
  "mmtag:21:derivatives__discrete_approximation_second_derivative"->{
    Cell[3455, 101, 387, 7, 59, "Input",
      CellTags->{
      "mmtag:21:derivatives__discrete_approximation_second_derivative", 
        "mmtag:21:second_derivatives__discrete_approximation"}]},
  "mmtag:21:second_derivatives__discrete_approximation"->{
    Cell[3455, 101, 387, 7, 59, "Input",
      CellTags->{
      "mmtag:21:derivatives__discrete_approximation_second_derivative", 
        "mmtag:21:second_derivatives__discrete_approximation"}]},
  "mmtag:21:second_order_odes__characterizing_solution_behavior"->{
    Cell[864079, 42374, 220, 4, 77, "Text",
      CellTags->
      "mmtag:21:second_order_odes__characterizing_solution_behavior"]},
  "mmtag:21:second_order_odes__general solution_for_constant_coefficients"->{
    Cell[866081, 42454, 158, 2, 73, "Subsubsection",
      CellTags->
      "mmtag:21:second_order_odes__general \
solution_for_constant_coefficients"]},
  "mmtag:21:graphics__building_piece_by_piece"->{
    Cell[867628, 42503, 215, 4, 77, "Input",
      CellTags->"mmtag:21:graphics__building_piece_by_piece"]},
  "mmtag:21:Reduce[]"->{
    Cell[1078136, 48991, 109, 2, 77, "Input",
      CellTags->"mmtag:21:Reduce[]"]},
  "mmtag:21:second_order_odes__using_boundary_values"->{
    Cell[1231601, 54503, 237, 6, 77, "Text",
      CellTags->"mmtag:21:second_order_odes__using_boundary_values"]},
  "mmtag:21:beam_theory"->{
    Cell[1236060, 54636, 194, 5, 106, "Subtitle",
      CellTags->{
      "mmtag:21:beam_theory", "mmtag:21:fourth_order_odes__beam_theory"}]},
  "mmtag:21:fourth_order_odes__beam_theory"->{
    Cell[1236060, 54636, 194, 5, 106, "Subtitle",
      CellTags->{
      "mmtag:21:beam_theory", "mmtag:21:fourth_order_odes__beam_theory"}]},
  "mmtag:21:beam_equation"->{
    Cell[1236404, 54650, 220, 4, 77, "Input",
      CellTags->"mmtag:21:beam_equation"]},
  "mmtag:21:beam_boundary_conditions"->{
    Cell[1236627, 54656, 158, 3, 77, "Text",
      CellTags->{
      "mmtag:21:beam_boundary_conditions", 
        "mmtag:21:boundary_conditions__for_beams"}]},
  "mmtag:21:boundary_conditions__for_beams"->{
    Cell[1236627, 54656, 158, 3, 77, "Text",
      CellTags->{
      "mmtag:21:beam_boundary_conditions", 
        "mmtag:21:boundary_conditions__for_beams"}]},
  "mmtag:21:beams__general_solutions_for_deflection"->{
    Cell[1237318, 54677, 181, 3, 77, "Input",
      CellTags->"mmtag:21:beams__general_solutions_for_deflection"]},
  "mmtag:21:beams__clamped_and_loaded"->{
    Cell[1237718, 54691, 584, 13, 119, "Input",
      CellTags->{
      "mmtag:21:beams__clamped_and_loaded", 
        "mmtag:21:beams__clamped_both_ends_with_point_load"}]},
  "mmtag:21:beams__clamped_both_ends_with_point_load"->{
    Cell[1237718, 54691, 584, 13, 119, "Input",
      CellTags->{
      "mmtag:21:beams__clamped_and_loaded", 
        "mmtag:21:beams__clamped_both_ends_with_point_load"}]},
  "mmtag:21:beams__point_loads_and_distributed_loads"->{
    Cell[1395592, 58357, 232, 6, 77, "Text",
      CellTags->{
      "mmtag:21:beams__point_loads_and_distributed_loads", 
        "mmtag:21:beams__distributed_loads"}]},
  "mmtag:21:beams__distributed_loads"->{
    Cell[1395592, 58357, 232, 6, 77, "Text",
      CellTags->{
      "mmtag:21:beams__point_loads_and_distributed_loads", 
        "mmtag:21:beams__distributed_loads"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"mmtag:21:foward_differencing__higher_order_ODEs", 1527281, 61913},
  {"mmtag:21:foward_differencing__example_function", 1527512, 61918},
  {"mmtag:21:discrete_approximation_to_derivative", 1527742, 61923},
  {"mmtag:21:derivatives__discrete_approximation", 1527968, 61928},
  {"mmtag:21:derivatives__discrete_approximation_second_derivative", 1528212, \
61933},
  {"mmtag:21:second_derivatives__discrete_approximation", 1528469, 61938},
  {"mmtag:21:second_order_odes__characterizing_solution_behavior", 1528735, \
61943},
  {"mmtag:21:second_order_odes__general solution_for_constant_coefficients", \
1528946, 61947},
  {"mmtag:21:graphics__building_piece_by_piece", 1529150, 61952},
  {"mmtag:21:Reduce[]", 1529284, 61955},
  {"mmtag:21:second_order_odes__using_boundary_values", 1529426, 61958},
  {"mmtag:21:beam_theory", 1529570, 61961},
  {"mmtag:21:fourth_order_odes__beam_theory", 1529761, 61965},
  {"mmtag:21:beam_equation", 1529935, 61969},
  {"mmtag:21:beam_boundary_conditions", 1530066, 61972},
  {"mmtag:21:boundary_conditions__for_beams", 1530274, 61977},
  {"mmtag:21:beams__general_solutions_for_deflection", 1530491, 61982},
  {"mmtag:21:beams__clamped_and_loaded", 1530649, 61985},
  {"mmtag:21:beams__clamped_both_ends_with_point_load", 1530881, 61990},
  {"mmtag:21:beams__point_loads_and_distributed_loads", 1531113, 61995},
  {"mmtag:21:beams__distributed_loads", 1531325, 62000}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 61, 0, 60, "Title"],
Cell[1818, 53, 75, 0, 52, "Subtitle"],
Cell[1896, 55, 442, 9, 113, "Text"],
Cell[2341, 66, 74, 0, 59, "Text"],
Cell[2418, 68, 71, 0, 59, "Text"],
Cell[2492, 70, 266, 6, 85, "Input",
  CellTags->{
  "mmtag:21:foward_differencing__higher_order_ODEs", 
    "mmtag:21:foward_differencing__example_function"}],
Cell[2761, 78, 95, 3, 59, "Text"],
Cell[2859, 83, 390, 8, 106, "Input",
  CellTags->{
  "mmtag:21:discrete_approximation_to_derivative", 
    "mmtag:21:derivatives__discrete_approximation"}],
Cell[3252, 93, 178, 4, 86, "Text"],

Cell[CellGroupData[{
Cell[3455, 101, 387, 7, 59, "Input",
  CellTags->{
  "mmtag:21:derivatives__discrete_approximation_second_derivative", 
    "mmtag:21:second_derivatives__discrete_approximation"}],
Cell[3845, 110, 189, 3, 82, "Output"]
}, Open  ]],
Cell[4049, 116, 52, 0, 59, "Text"],

Cell[CellGroupData[{
Cell[4126, 120, 103, 2, 59, "Input"],
Cell[4232, 124, 222, 4, 79, "Output"]
}, Open  ]],
Cell[4469, 131, 56, 0, 59, "Text"],

Cell[CellGroupData[{
Cell[4550, 135, 83, 1, 59, "Input"],
Cell[4636, 138, 261, 4, 79, "Output"]
}, Open  ]],
Cell[4912, 145, 227, 4, 86, "Text"],

Cell[CellGroupData[{
Cell[5164, 153, 605, 9, 118, "Subsubsection"],
Cell[5772, 164, 482, 8, 122, "Input"],

Cell[CellGroupData[{
Cell[6279, 176, 84, 1, 59, "Input"],
Cell[6366, 179, 51, 1, 74, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6454, 185, 84, 1, 59, "Input"],
Cell[6541, 188, 72, 1, 74, "Output"]
}, Open  ]],
Cell[6628, 192, 135, 3, 59, "Text"],
Cell[6766, 197, 127, 2, 59, "Input"],

Cell[CellGroupData[{
Cell[6918, 203, 67, 1, 59, "Input"],
Cell[6988, 206, 490, 7, 95, "Output"]
}, Open  ]],
Cell[7493, 216, 101, 3, 59, "Text"],

Cell[CellGroupData[{
Cell[7619, 223, 80, 1, 59, "Input"],
Cell[7702, 226, 427535, 21116, 364, 389703, 20644, "GraphicsData", \
"PostScript", "Graphics"],
Cell[435240, 21344, 130, 3, 74, "Output"]
}, Open  ]],
Cell[435385, 21350, 54, 0, 59, "Text"],
Cell[435442, 21352, 123, 2, 59, "Input"],

Cell[CellGroupData[{
Cell[435590, 21358, 80, 1, 59, "Input"],
Cell[435673, 21361, 428130, 21000, 364, 385991, 20475, "GraphicsData", \
"PostScript", "Graphics"],
Cell[863806, 42363, 130, 3, 74, "Output"]
}, Open  ]],
Cell[863951, 42369, 125, 3, 88, "Subtitle"],
Cell[864079, 42374, 220, 4, 77, "Text",
  CellTags->"mmtag:21:second_order_odes__characterizing_solution_behavior"]
}, Open  ]],

Cell[CellGroupData[{
Cell[864336, 42383, 85, 1, 55, "Subsubsection"],
Cell[864424, 42386, 179, 3, 59, "Input"],

Cell[CellGroupData[{
Cell[864628, 42393, 45, 1, 59, "Input"],
Cell[864676, 42396, 333, 8, 74, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[865058, 42410, 105, 3, 55, "Subsubsection"],
Cell[865166, 42415, 70, 1, 59, "Input"],

Cell[CellGroupData[{
Cell[865261, 42420, 52, 1, 59, "Input"],
Cell[865316, 42423, 187, 3, 76, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[865552, 42432, 126, 3, 55, "Subsubsection"],

Cell[CellGroupData[{
Cell[865703, 42439, 108, 2, 59, "Input"],
Cell[865814, 42443, 218, 5, 100, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[866081, 42454, 158, 2, 73, "Subsubsection",
  CellTags->
  "mmtag:21:second_order_odes__general solution_for_constant_coefficients"],

Cell[CellGroupData[{
Cell[866264, 42460, 109, 2, 59, "Input"],
Cell[866376, 42464, 91, 1, 100, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[866504, 42470, 110, 2, 59, "Input"],
Cell[866617, 42474, 91, 1, 100, "Output"]
}, Open  ]],
Cell[866723, 42478, 692, 14, 243, "Text"]
}, Open  ]],
Cell[867430, 42495, 173, 4, 55, "Subsubsection"],

Cell[CellGroupData[{
Cell[867628, 42503, 215, 4, 77, "Input",
  CellTags->"mmtag:21:graphics__building_piece_by_piece"],
Cell[867846, 42509, 39070, 1011, 364, 16140, 723, "GraphicsData", \
"PostScript", "Graphics"],
Cell[906919, 43522, 130, 3, 74, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[907086, 43530, 232, 5, 80, "Input"],
Cell[907321, 43537, 48992, 1200, 364, 18975, 825, "GraphicsData", \
"PostScript", "Graphics"],
Cell[956316, 44739, 130, 3, 74, "Output"]
}, Open  ]],
Cell[956461, 44745, 420, 12, 106, "Text"],

Cell[CellGroupData[{
Cell[956906, 44761, 192, 4, 59, "Input"],
Cell[957101, 44767, 130, 3, 74, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[957268, 44775, 420, 9, 122, "Input"],
Cell[957691, 44786, 50311, 1865, 364, 25146, 1550, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1008005, 46653, 130, 3, 74, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1008172, 46661, 93, 1, 59, "Input"],
Cell[1008268, 46664, 69600, 2312, 364, 32738, 1852, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1077871, 48978, 130, 3, 74, "Output"]
}, Open  ]],
Cell[1078016, 48984, 95, 3, 59, "Text"],

Cell[CellGroupData[{
Cell[1078136, 48991, 109, 2, 77, "Input",
  CellTags->"mmtag:21:Reduce[]"],
Cell[1078248, 48995, 88, 1, 105, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1078373, 49001, 207, 5, 59, "Input"],
Cell[1078583, 49008, 130, 3, 74, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1078750, 49016, 76, 1, 59, "Input"],
Cell[1078829, 49019, 74, 1, 74, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1078940, 49025, 458, 9, 122, "Input"],
Cell[1079401, 49036, 130, 3, 74, "Output"],
Cell[1079534, 49041, 50501, 1797, 364, 28270, 1518, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1130038, 50840, 130, 3, 74, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1130205, 50848, 76, 1, 59, "Input"],
Cell[1130284, 50851, 88, 1, 105, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1130409, 50857, 184, 4, 59, "Input"],
Cell[1130596, 50863, 130, 3, 74, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1130763, 50871, 119, 2, 59, "Input"],
Cell[1130885, 50875, 100489, 3618, 364, 54181, 3042, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1231377, 54495, 130, 3, 74, "Output"]
}, Open  ]],
Cell[1231522, 54501, 76, 0, 52, "Subtitle"],
Cell[1231601, 54503, 237, 6, 77, "Text",
  CellTags->"mmtag:21:second_order_odes__using_boundary_values"],
Cell[1231841, 54511, 102, 3, 132, "Subsubtitle"],

Cell[CellGroupData[{
Cell[1231968, 54518, 126, 2, 59, "Input"],
Cell[1232097, 54522, 357, 5, 26, "Message"],
Cell[1232457, 54529, 359, 5, 26, "Message"]
}, Open  ]],
Cell[1232831, 54537, 234, 9, 55, "Subsubsection"],

Cell[CellGroupData[{
Cell[1233090, 54550, 143, 3, 59, "Input"],
Cell[1233236, 54555, 450, 7, 118, "Output"]
}, Open  ]],
Cell[1233701, 54565, 54, 0, 55, "Subsubsection"],

Cell[CellGroupData[{
Cell[1233780, 54569, 118, 2, 59, "Input"],
Cell[1233901, 54573, 270, 4, 144, "Output"]
}, Open  ]],
Cell[1234186, 54580, 105, 3, 59, "Text"],

Cell[CellGroupData[{
Cell[1234316, 54587, 68, 1, 59, "Input"],
Cell[1234387, 54590, 340, 5, 106, "Output"]
}, Open  ]],
Cell[1234742, 54598, 83, 1, 55, "Subsubsection"],

Cell[CellGroupData[{
Cell[1234850, 54603, 175, 4, 59, "Input"],
Cell[1235028, 54609, 225, 3, 131, "Output"],
Cell[1235256, 54614, 224, 3, 116, "Input"]
}, Open  ]],
Cell[1235495, 54620, 49, 0, 55, "Subsubsection"],

Cell[CellGroupData[{
Cell[1235569, 54624, 118, 2, 59, "Input"],
Cell[1235690, 54628, 355, 5, 148, "Output"]
}, Open  ]],
Cell[1236060, 54636, 194, 5, 106, "Subtitle",
  CellTags->{
  "mmtag:21:beam_theory", "mmtag:21:fourth_order_odes__beam_theory"}],
Cell[1236257, 54643, 45, 0, 59, "Text"],
Cell[1236305, 54645, 96, 3, 59, "Text"],
Cell[1236404, 54650, 220, 4, 77, "Input",
  CellTags->"mmtag:21:beam_equation"],
Cell[1236627, 54656, 158, 3, 77, "Text",
  CellTags->{
  "mmtag:21:beam_boundary_conditions", 
    "mmtag:21:boundary_conditions__for_beams"}],
Cell[1236788, 54661, 450, 9, 101, "Input"],
Cell[1237241, 54672, 52, 1, 59, "Input"],

Cell[CellGroupData[{
Cell[1237318, 54677, 181, 3, 77, "Input",
  CellTags->"mmtag:21:beams__general_solutions_for_deflection"],
Cell[1237502, 54682, 129, 2, 79, "Output"]
}, Open  ]],
Cell[1237646, 54687, 47, 0, 59, "Text"],

Cell[CellGroupData[{
Cell[1237718, 54691, 584, 13, 119, "Input",
  CellTags->{
  "mmtag:21:beams__clamped_and_loaded", 
    "mmtag:21:beams__clamped_both_ends_with_point_load"}],
Cell[1238305, 54706, 38467, 879, 584, 11556, 542, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1276775, 55587, 130, 3, 74, "Output"]
}, Open  ]],
Cell[1276920, 55593, 57, 0, 59, "Text"],
Cell[1276980, 55595, 54, 1, 59, "Input"],

Cell[CellGroupData[{
Cell[1277059, 55600, 457, 10, 101, "Input"],
Cell[1277519, 55612, 37903, 871, 584, 11531, 541, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1315425, 56485, 130, 3, 74, "Output"]
}, Open  ]],
Cell[1315570, 56491, 69, 0, 59, "Text"],
Cell[1315642, 56493, 83, 1, 59, "Input"],

Cell[CellGroupData[{
Cell[1315750, 56498, 464, 10, 101, "Input"],
Cell[1316217, 56510, 38678, 904, 584, 12002, 570, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1354898, 57416, 130, 3, 74, "Output"]
}, Open  ]],
Cell[1355043, 57422, 72, 0, 59, "Text"],
Cell[1355118, 57424, 83, 1, 59, "Input"],

Cell[CellGroupData[{
Cell[1355226, 57429, 466, 10, 101, "Input"],
Cell[1355695, 57441, 39749, 908, 584, 11809, 558, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1395447, 58351, 130, 3, 74, "Output"]
}, Open  ]],
Cell[1395592, 58357, 232, 6, 77, "Text",
  CellTags->{
  "mmtag:21:beams__point_loads_and_distributed_loads", 
    "mmtag:21:beams__distributed_loads"}],
Cell[1395827, 58365, 72, 1, 59, "Input"],

Cell[CellGroupData[{
Cell[1395924, 58370, 467, 10, 101, "Input"],
Cell[1396394, 58382, 38401, 914, 584, 12268, 587, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1434798, 59298, 130, 3, 74, "Output"]
}, Open  ]],
Cell[1434943, 59304, 70, 0, 59, "Text"],
Cell[1435016, 59306, 152, 3, 59, "Input"],

Cell[CellGroupData[{
Cell[1435193, 59313, 60, 1, 59, "Input"],
Cell[1435256, 59316, 49662, 1596, 364, 24181, 1277, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1484921, 60914, 130, 3, 74, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1485088, 60922, 462, 10, 101, "Input"],
Cell[1485553, 60934, 38586, 914, 584, 12214, 584, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1524142, 61850, 130, 3, 56, "Output"]
}, Open  ]],
Cell[1524287, 61856, 1232, 18, 74, "Message"],
Cell[1525522, 61876, 887, 13, 58, "Message"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

